rviceTemplate.Voice, self).__init__()

                self.yang_name = "voice"
                self.yang_parent_name = "service-template"
                self.is_top_level_class = False
                self.has_list_ancestor = True
                self.ylist_key_names = []
                self._child_classes = OrderedDict([])
                self._leafs = OrderedDict([
                    ('vlan', (YLeaf(YType.empty, 'vlan'), ['Empty'])),
                ])
                self.vlan = None
                self._segment_path = lambda: "voice"
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(Native.ServiceTemplate.Voice, [u'vlan'], name, value)


    class Switch(Entity):
        """
        Config commands for the switches in the stack
        
        .. attribute:: number  (key)
        
        	
        	**type**\: int
        
        	**range:** 1..9
        
        .. attribute:: provision
        
        	Configure Switch provision / offline config
        	**type**\:  :py:class:`Provision <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Switch.Provision>`
        
        

        """

        _prefix = 'ios-sw'
        _revision = '2018-01-10'

        def __init__(self):
            super(Native.Switch, self).__init__()

            self.yang_name = "switch"
            self.yang_parent_name = "native"
            self.is_top_level_class = False
            self.has_list_ancestor = False
            self.ylist_key_names = ['number']
            self._child_classes = OrderedDict([])
            self._leafs = OrderedDict([
                ('number', (YLeaf(YType.uint8, 'number'), ['int'])),
                ('provision', (YLeaf(YType.enumeration, 'provision'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Switch.Provision')])),
            ])
            self.number = None
            self.provision = None
            self._segment_path = lambda: "Cisco-IOS-XE-switch:switch" + "[number='" + str(self.number) + "']"
            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/%s" % self._segment_path()
            self._is_frozen = True

        def __setattr__(self, name, value):
            self._perform_setattr(Native.Switch, [u'number', u'provision'], name, value)

        class Provision(Enum):
            """
            Provision (Enum Class)

            Configure Switch provision / offline config

            .. data:: ws_c2960x_24pd_l = 0

            .. data:: ws_c3650_48ps = 1

            .. data:: ws_c3650_24ps = 2

            .. data:: ws_c3850_48p = 3

            .. data:: ws_c3850_24p = 4

            .. data:: ws_c3850_48t = 5

            .. data:: ws_c3850_24t = 6

            .. data:: ws_c3850_48f = 7

            .. data:: ws_c3850_48u = 8

            .. data:: ws_c3850_24u = 9

            .. data:: ws_c3850_12x48u = 10

            .. data:: ws_c3850_24xu = 11

            .. data:: ws_c3850_24ux = 12

            .. data:: ws_c3850_12s = 13

            .. data:: ws_c3850_24s = 14

            .. data:: ws_c3850_12xs = 15

            .. data:: ws_c3850_24xs = 16

            .. data:: ws_c3850_48xs = 17

            .. data:: ws_c3650_12x48fd = 18

            .. data:: ws_c3650_12x48uq = 19

            .. data:: ws_c3650_12x48ur = 20

            .. data:: ws_c3650_12x48uz = 21

            .. data:: ws_c3650_24pd = 22

            .. data:: ws_c3650_24pdm = 23

            .. data:: ws_c3650_24td = 24

            .. data:: ws_c3650_24ts = 25

            .. data:: ws_c3650_48fqm = 26

            .. data:: ws_c3650_48pd = 27

            .. data:: ws_c3650_48pq = 28

            .. data:: ws_c3650_48td = 29

            .. data:: ws_c3650_48tq = 30

            .. data:: ws_c3650_48ts = 31

            .. data:: ws_c3650_8x24pd = 32

            .. data:: ws_c3650_8x24uq = 33

            .. data:: ws_c3750x_24p = 34

            .. data:: ws_c3750x_12s = 35

            .. data:: ws_c3850_12x48au = 36

            .. data:: c9300_24p = 37

            .. data:: c9300_24t = 38

            .. data:: c9300_24u = 39

            .. data:: c9300_48p = 40

            .. data:: c9300_48t = 41

            .. data:: c9300_48u = 42

            """

            ws_c2960x_24pd_l = Enum.YLeaf(0, "ws-c2960x-24pd-l")

            ws_c3650_48ps = Enum.YLeaf(1, "ws-c3650-48ps")

            ws_c3650_24ps = Enum.YLeaf(2, "ws-c3650-24ps")

            ws_c3850_48p = Enum.YLeaf(3, "ws-c3850-48p")

            ws_c3850_24p = Enum.YLeaf(4, "ws-c3850-24p")

            ws_c3850_48t = Enum.YLeaf(5, "ws-c3850-48t")

            ws_c3850_24t = Enum.YLeaf(6, "ws-c3850-24t")

            ws_c3850_48f = Enum.YLeaf(7, "ws-c3850-48f")

            ws_c3850_48u = Enum.YLeaf(8, "ws-c3850-48u")

            ws_c3850_24u = Enum.YLeaf(9, "ws-c3850-24u")

            ws_c3850_12x48u = Enum.YLeaf(10, "ws-c3850-12x48u")

            ws_c3850_24xu = Enum.YLeaf(11, "ws-c3850-24xu")

            ws_c3850_24ux = Enum.YLeaf(12, "ws-c3850-24ux")

            ws_c3850_12s = Enum.YLeaf(13, "ws-c3850-12s")

            ws_c3850_24s = Enum.YLeaf(14, "ws-c3850-24s")

            ws_c3850_12xs = Enum.YLeaf(15, "ws-c3850-12xs")

            ws_c3850_24xs = Enum.YLeaf(16, "ws-c3850-24xs")

            ws_c3850_48xs = Enum.YLeaf(17, "ws-c3850-48xs")

            ws_c3650_12x48fd = Enum.YLeaf(18, "ws-c3650-12x48fd")

            ws_c3650_12x48uq = Enum.YLeaf(19, "ws-c3650-12x48uq")

            ws_c3650_12x48ur = Enum.YLeaf(20, "ws-c3650-12x48ur")

            ws_c3650_12x48uz = Enum.YLeaf(21, "ws-c3650-12x48uz")

            ws_c3650_24pd = Enum.YLeaf(22, "ws-c3650-24pd")

            ws_c3650_24pdm = Enum.YLeaf(23, "ws-c3650-24pdm")

            ws_c3650_24td = Enum.YLeaf(24, "ws-c3650-24td")

            ws_c3650_24ts = Enum.YLeaf(25, "ws-c3650-24ts")

            ws_c3650_48fqm = Enum.YLeaf(26, "ws-c3650-48fqm")

            ws_c3650_48pd = Enum.YLeaf(27, "ws-c3650-48pd")

            ws_c3650_48pq = Enum.YLeaf(28, "ws-c3650-48pq")

            ws_c3650_48td = Enum.YLeaf(29, "ws-c3650-48td")

            ws_c3650_48tq = Enum.YLeaf(30, "ws-c3650-48tq")

            ws_c3650_48ts = Enum.YLeaf(31, "ws-c3650-48ts")

            ws_c3650_8x24pd = Enum.YLeaf(32, "ws-c3650-8x24pd")

            ws_c3650_8x24uq = Enum.YLeaf(33, "ws-c3650-8x24uq")

            ws_c3750x_24p = Enum.YLeaf(34, "ws-c3750x-24p")

            ws_c3750x_12s = Enum.YLeaf(35, "ws-c3750x-12s")

            ws_c3850_12x48au = Enum.YLeaf(36, "ws-c3850-12x48au")

            c9300_24p = Enum.YLeaf(37, "c9300-24p")

            c9300_24t = Enum.YLeaf(38, "c9300-24t")

            c9300_24u = Enum.YLeaf(39, "c9300-24u")

            c9300_48p = Enum.YLeaf(40, "c9300-48p")

            c9300_48t = Enum.YLeaf(41, "c9300-48t")

            c9300_48u = Enum.YLeaf(42, "c9300-48u")



    class SwitchVirtual(Entity):
        """
        
        
        .. attribute:: domain  (key)
        
        	
        	**type**\: int
        
        	**range:** 0..4294967295
        
        .. attribute:: virtual
        
        	
        	**type**\: :py:class:`Empty<ydk.types.Empty>`
        
        .. attribute:: switch
        
        	Configure switch command
        	**type**\:  :py:class:`Switch <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.SwitchVirtual.Switch>`
        
        .. attribute:: mac_address
        
        	
        	**type**\:  :py:class:`MacAddress <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.SwitchVirtual.MacAddress>`
        
        .. attribute:: dual_active
        
        	Virtual switch dual\-active config
        	**type**\:  :py:class:`DualActive <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.SwitchVirtual.DualActive>`
        
        

        """

        _prefix = 'ios-sw'
        _revision = '2018-01-10'

        def __init__(self):
            super(Native.SwitchVirtual, self).__init__()

            self.yang_name = "switch-virtual"
            self.yang_parent_name = "native"
            self.is_top_level_class = False
            self.has_list_ancestor = False
            self.ylist_key_names = ['domain']
            self._child_classes = OrderedDict([("switch", ("switch", Native.SwitchVirtual.Switch)), ("mac-address", ("mac_address", Native.SwitchVirtual.MacAddress)), ("dual-active", ("dual_active", Native.SwitchVirtual.DualActive))])
            self._leafs = OrderedDict([
                ('domain', (YLeaf(YType.uint32, 'domain'), ['int'])),
                ('virtual', (YLeaf(YType.empty, 'virtual'), ['Empty'])),
            ])
            self.domain = None
            self.virtual = None

            self.switch = Native.SwitchVirtual.Switch()
            self.switch.parent = self
            self._children_name_map["switch"] = "switch"

            self.mac_address = Native.SwitchVirtual.MacAddress()
            self.mac_address.parent = self
            self._children_name_map["mac_address"] = "mac-address"

            self.dual_active = Native.SwitchVirtual.DualActive()
            self.dual_active.parent = self
            self._children_name_map["dual_active"] = "dual-active"
            self._segment_path = lambda: "Cisco-IOS-XE-switch:switch-virtual" + "[domain='" + str(self.domain) + "']"
            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/%s" % self._segment_path()
            self._is_frozen = True

        def __setattr__(self, name, value):
            self._perform_setattr(Native.SwitchVirtual, [u'domain', u'virtual'], name, value)


        class Switch(Entity):
            """
            Configure switch command
            
            .. attribute:: switch_number
            
            	Virtual switch number
            	**type**\: int
            
            	**range:** 1..2
            
            .. attribute:: priority
            
            	Virtual switch priority value
            	**type**\: int
            
            	**range:** 0..4294967295
            
            .. attribute:: mode
            
            	
            	**type**\:  :py:class:`Mode <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.SwitchVirtual.Switch.Mode>`
            
            

            """

            _prefix = 'ios-sw'
            _revision = '2018-01-10'

            def __init__(self):
                super(Native.SwitchVirtual.Switch, self).__init__()

                self.yang_name = "switch"
                self.yang_parent_name = "switch-virtual"
                self.is_top_level_class = False
                self.has_list_ancestor = True
                self.ylist_key_names = []
                self._child_classes = OrderedDict([])
                self._leafs = OrderedDict([
                    ('switch_number', (YLeaf(YType.uint32, 'switch-number'), ['int'])),
                    ('priority', (YLeaf(YType.uint32, 'priority'), ['int'])),
                    ('mode', (YLeaf(YType.enumeration, 'mode'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'SwitchVirtual.Switch.Mode')])),
                ])
                self.switch_number = None
                self.priority = None
                self.mode = None
                self._segment_path = lambda: "switch"
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(Native.SwitchVirtual.Switch, [u'switch_number', u'priority', u'mode'], name, value)

            class Mode(Enum):
                """
                Mode (Enum Class)

                .. data:: virtual = 0

                """

                virtual = Enum.YLeaf(0, "virtual")



        class MacAddress(Entity):
            """
            
            
            .. attribute:: use_virtual
            
            	
            	**type**\: :py:class:`Empty<ydk.types.Empty>`
            
            

            """

            _prefix = 'ios-sw'
            _revision = '2018-01-10'

            def __init__(self):
                super(Native.SwitchVirtual.MacAddress, self).__init__()

                self.yang_name = "mac-address"
                self.yang_parent_name = "switch-virtual"
                self.is_top_level_class = False
                self.has_list_ancestor = True
                self.ylist_key_names = []
                self._child_classes = OrderedDict([])
                self._leafs = OrderedDict([
                    ('use_virtual', (YLeaf(YType.empty, 'use-virtual'), ['Empty'])),
                ])
                self.use_virtual = None
                self._segment_path = lambda: "mac-address"
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(Native.SwitchVirtual.MacAddress, [u'use_virtual'], name, value)


        class DualActive(Entity):
            """
            Virtual switch dual\-active config
            
            .. attribute:: recovery
            
            	Recovery IP address
            	**type**\:  :py:class:`Recovery <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.SwitchVirtual.DualActive.Recovery>`
            
            .. attribute:: detection
            
            	Dual\-active detection enable
            	**type**\:  :py:class:`Detection <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.SwitchVirtual.DualActive.Detection>`
            
            

            """

            _prefix = 'ios-sw'
            _revision = '2018-01-10'

            def __init__(self):
                super(Native.SwitchVirtual.DualActive, self).__init__()

                self.yang_name = "dual-active"
                self.yang_parent_name = "switch-virtual"
                self.is_top_level_class = False
                self.has_list_ancestor = True
                self.ylist_key_names = []
                self._child_classes = OrderedDict([("recovery", ("recovery", Native.SwitchVirtual.DualActive.Recovery)), ("detection", ("detection", Native.SwitchVirtual.DualActive.Detection))])
                self._leafs = OrderedDict()

                self.recovery = Native.SwitchVirtual.DualActive.Recovery()
                self.recovery.parent = self
                self._children_name_map["recovery"] = "recovery"

                self.detection = Native.SwitchVirtual.DualActive.Detection()
                self.detection.parent = self
                self._children_name_map["detection"] = "detection"
                self._segment_path = lambda: "dual-active"
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(Native.SwitchVirtual.DualActive, [], name, value)


            class Recovery(Entity):
                """
                Recovery IP address
                
                .. attribute:: switch
                
                	Switch ID for recovery IP address
                	**type**\: int
                
                	**range:** 1..2
                
                .. attribute:: ip
                
                	Recovery IP address
                	**type**\:  :py:class:`Ip <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.SwitchVirtual.DualActive.Recovery.Ip>`
                
                

                """

                _prefix = 'ios-sw'
                _revision = '2018-01-10'

                def __init__(self):
                    super(Native.SwitchVirtual.DualActive.Recovery, self).__init__()

                    self.yang_name = "recovery"
                    self.yang_parent_name = "dual-active"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("ip", ("ip", Native.SwitchVirtual.DualActive.Recovery.Ip))])
                    self._leafs = OrderedDict([
                        ('switch', (YLeaf(YType.uint8, 'switch'), ['int'])),
                    ])
                    self.switch = None

                    self.ip = Native.SwitchVirtual.DualActive.Recovery.Ip()
                    self.ip.parent = self
                    self._children_name_map["ip"] = "ip"
                    self._segment_path = lambda: "recovery"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.SwitchVirtual.DualActive.Recovery, [u'switch'], name, value)


                class Ip(Entity):
                    """
                    Recovery IP address
                    
                    .. attribute:: address
                    
                    	Recovery IP address
                    	**type**\: str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    .. attribute:: mask
                    
                    	IP address mask
                    	**type**\: str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    

                    """

                    _prefix = 'ios-sw'
                    _revision = '2018-01-10'

                    def __init__(self):
                        super(Native.SwitchVirtual.DualActive.Recovery.Ip, self).__init__()

                        self.yang_name = "ip"
                        self.yang_parent_name = "recovery"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('address', (YLeaf(YType.str, 'address'), ['str'])),
                            ('mask', (YLeaf(YType.str, 'mask'), ['str'])),
                        ])
                        self.address = None
                        self.mask = None
                        self._segment_path = lambda: "ip"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.SwitchVirtual.DualActive.Recovery.Ip, [u'address', u'mask'], name, value)


            class Detection(Entity):
                """
                Dual\-active detection enable
                
                .. attribute:: pagp
                
                	Dual\-active detection using PAgP
                	**type**\:  :py:class:`Pagp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.SwitchVirtual.DualActive.Detection.Pagp>`
                
                	**presence node**\: True
                
                

                """

                _prefix = 'ios-sw'
                _revision = '2018-01-10'

                def __init__(self):
                    super(Native.SwitchVirtual.DualActive.Detection, self).__init__()

                    self.yang_name = "detection"
                    self.yang_parent_name = "dual-active"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("pagp", ("pagp", Native.SwitchVirtual.DualActive.Detection.Pagp))])
                    self._leafs = OrderedDict()

                    self.pagp = None
                    self._children_name_map["pagp"] = "pagp"
                    self._segment_path = lambda: "detection"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.SwitchVirtual.DualActive.Detection, [], name, value)


                class Pagp(Entity):
                    """
                    Dual\-active detection using PAgP
                    
                    .. attribute:: trust
                    
                    	Trusted channels for PAgP dual\-active detection
                    	**type**\:  :py:class:`Trust <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.SwitchVirtual.DualActive.Detection.Pagp.Trust>`
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios-sw'
                    _revision = '2018-01-10'

                    def __init__(self):
                        super(Native.SwitchVirtual.DualActive.Detection.Pagp, self).__init__()

                        self.yang_name = "pagp"
                        self.yang_parent_name = "detection"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("trust", ("trust", Native.SwitchVirtual.DualActive.Detection.Pagp.Trust))])
                        self.is_presence_container = True
                        self._leafs = OrderedDict()

                        self.trust = Native.SwitchVirtual.DualActive.Detection.Pagp.Trust()
                        self.trust.parent = self
                        self._children_name_map["trust"] = "trust"
                        self._segment_path = lambda: "pagp"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.SwitchVirtual.DualActive.Detection.Pagp, [], name, value)


                    class Trust(Entity):
                        """
                        Trusted channels for PAgP dual\-active detection
                        
                        .. attribute:: channel_group
                        
                        	Etherchannel/port bundle to be used for pagp dual\-active detection
                        	**type**\: int
                        
                        	**range:** 1..254
                        
                        

                        """

                        _prefix = 'ios-sw'
                        _revision = '2018-01-10'

                        def __init__(self):
                            super(Native.SwitchVirtual.DualActive.Detection.Pagp.Trust, self).__init__()

                            self.yang_name = "trust"
                            self.yang_parent_name = "pagp"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('channel_group', (YLeaf(YType.uint8, 'channel-group'), ['int'])),
                            ])
                            self.channel_group = None
                            self._segment_path = lambda: "trust"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.SwitchVirtual.DualActive.Detection.Pagp.Trust, [u'channel_group'], name, value)


    class Device(Entity):
        """
        device classifier configuration
        
        .. attribute:: classifier
        
        	Enable/Disable classification of attached devices
        	**type**\: :py:class:`Empty<ydk.types.Empty>`
        
        

        """

        _prefix = 'ios-sw'
        _revision = '2018-01-10'

        def __init__(self):
            super(Native.Device, self).__init__()

            self.yang_name = "device"
            self.yang_parent_name = "native"
            self.is_top_level_class = False
            self.has_list_ancestor = False
            self.ylist_key_names = []
            self._child_classes = OrderedDict([])
            self._leafs = OrderedDict([
                ('classifier', (YLeaf(YType.empty, 'classifier'), ['Empty'])),
            ])
            self.classifier = None
            self._segment_path = lambda: "Cisco-IOS-XE-switch:device"
            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/%s" % self._segment_path()
            self._is_frozen = True

        def __setattr__(self, name, value):
            self._perform_setattr(Native.Device, [u'classifier'], name, value)


    class StackMac(Entity):
        """
        Global stack mac\-address feature configurations
        
        .. attribute:: persistent
        
        	persistent stack mac\-address
        	**type**\:  :py:class:`Persistent <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.StackMac.Persistent>`
        
        

        """

        _prefix = 'ios-sw'
        _revision = '2018-01-10'

        def __init__(self):
            super(Native.StackMac, self).__init__()

            self.yang_name = "stack-mac"
            self.yang_parent_name = "native"
            self.is_top_level_class = False
            self.has_list_ancestor = False
            self.ylist_key_names = []
            self._child_classes = OrderedDict([("persistent", ("persistent", Native.StackMac.Persistent))])
            self._leafs = OrderedDict()

            self.persistent = Native.StackMac.Persistent()
            self.persistent.parent = self
            self._children_name_map["persistent"] = "persistent"
            self._segment_path = lambda: "Cisco-IOS-XE-switch:stack-mac"
            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/%s" % self._segment_path()
            self._is_frozen = True

        def __setattr__(self, name, value):
            self._perform_setattr(Native.StackMac, [], name, value)


        class Persistent(Entity):
            """
            persistent stack mac\-address
            
            .. attribute:: timer
            
            	use stack mac\-address timer after master failure( 0 means still using the current MAC)
            	**type**\: int
            
            	**range:** 0..60
            
            

            """

            _prefix = 'ios-sw'
            _revision = '2018-01-10'

            def __init__(self):
                super(Native.StackMac.Persistent, self).__init__()

                self.yang_name = "persistent"
                self.yang_parent_name = "stack-mac"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = []
                self._child_classes = OrderedDict([])
                self._leafs = OrderedDict([
                    ('timer', (YLeaf(YType.uint8, 'timer'), ['int'])),
                ])
                self.timer = None
                self._segment_path = lambda: "persistent"
                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/Cisco-IOS-XE-switch:stack-mac/%s" % self._segment_path()
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(Native.StackMac.Persistent, [u'timer'], name, value)


    class L2protocolTunnel(Entity):
        """
        Tunnel Layer2 protocols
        
        .. attribute:: cos
        
        	Class of Service
        	**type**\: int
        
        	**range:** 0..7
        
        .. attribute:: global_
        
        	Global settings
        	**type**\:  :py:class:`Global <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.L2protocolTunnel.Global>`
        
        

        """

        _prefix = 'ios-sw'
        _revision = '2018-01-10'

        def __init__(self):
            super(Native.L2protocolTunnel, self).__init__()

            self.yang_name = "l2protocol-tunnel"
            self.yang_parent_name = "native"
            self.is_top_level_class = False
            self.has_list_ancestor = False
            self.ylist_key_names = []
            self._child_classes = OrderedDict([("global", ("global_", Native.L2protocolTunnel.Global))])
            self._leafs = OrderedDict([
                ('cos', (YLeaf(YType.uint8, 'cos'), ['int'])),
            ])
            self.cos = None

            self.global_ = Native.L2protocolTunnel.Global()
            self.global_.parent = self
            self._children_name_map["global_"] = "global"
            self._segment_path = lambda: "Cisco-IOS-XE-switch:l2protocol-tunnel"
            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/%s" % self._segment_path()
            self._is_frozen = True

        def __setattr__(self, name, value):
            self._perform_setattr(Native.L2protocolTunnel, [u'cos'], name, value)


        class Global(Entity):
            """
            Global settings
            
            .. attribute:: drop_threshold
            
            	L2PT packets drop threshold
            	**type**\: int
            
            	**range:** 100..20000
            
            

            """

            _prefix = 'ios-sw'
            _revision = '2018-01-10'

            def __init__(self):
                super(Native.L2protocolTunnel.Global, self).__init__()

                self.yang_name = "global"
                self.yang_parent_name = "l2protocol-tunnel"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = []
                self._child_classes = OrderedDict([])
                self._leafs = OrderedDict([
                    ('drop_threshold', (YLeaf(YType.uint16, 'drop-threshold'), ['int'])),
                ])
                self.drop_threshold = None
                self._segment_path = lambda: "global"
                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/Cisco-IOS-XE-switch:l2protocol-tunnel/%s" % self._segment_path()
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(Native.L2protocolTunnel.Global, [u'drop_threshold'], name, value)


    class Rep(Entity):
        """
        Resilient Ethernet Protocol characteristics
        
        .. attribute:: admin
        
        	administrative configuration
        	**type**\:  :py:class:`Admin <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Rep.Admin>`
        
        

        """

        _prefix = 'ios-sw'
        _revision = '2018-01-10'

        def __init__(self):
            super(Native.Rep, self).__init__()

            self.yang_name = "rep"
            self.yang_parent_name = "native"
            self.is_top_level_class = False
            self.has_list_ancestor = False
            self.ylist_key_names = []
            self._child_classes = OrderedDict([("admin", ("admin", Native.Rep.Admin))])
            self._leafs = OrderedDict()

            self.admin = Native.Rep.Admin()
            self.admin.parent = self
            self._children_name_map["admin"] = "admin"
            self._segment_path = lambda: "Cisco-IOS-XE-switch:rep"
            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/%s" % self._segment_path()
            self._is_frozen = True

        def __setattr__(self, name, value):
            self._perform_setattr(Native.Rep, [], name, value)


        class Admin(Entity):
            """
            administrative configuration
            
            .. attribute:: vlan
            
            	VLAN
            	**type**\: list of  		 :py:class:`Vlan <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Rep.Admin.Vlan>`
            
            

            """

            _prefix = 'ios-sw'
            _revision = '2018-01-10'

            def __init__(self):
                super(Native.Rep.Admin, self).__init__()

                self.yang_name = "admin"
                self.yang_parent_name = "rep"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = []
                self._child_classes = OrderedDict([("vlan", ("vlan", Native.Rep.Admin.Vlan))])
                self._leafs = OrderedDict()

                self.vlan = YList(self)
                self._segment_path = lambda: "admin"
                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/Cisco-IOS-XE-switch:rep/%s" % self._segment_path()
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(Native.Rep.Admin, [], name, value)


            class Vlan(Entity):
                """
                VLAN
                
                .. attribute:: name  (key)
                
                	
                	**type**\: int
                
                	**range:** 2..4094
                
                

                """

                _prefix = 'ios-sw'
                _revision = '2018-01-10'

                def __init__(self):
                    super(Native.Rep.Admin.Vlan, self).__init__()

                    self.yang_name = "vlan"
                    self.yang_parent_name = "admin"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = ['name']
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('name', (YLeaf(YType.uint16, 'name'), ['int'])),
                    ])
                    self.name = None
                    self._segment_path = lambda: "vlan" + "[name='" + str(self.name) + "']"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/Cisco-IOS-XE-switch:rep/admin/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Rep.Admin.Vlan, [u'name'], name, value)


    class HwSwitch(Entity):
        """
        Hw\-switch
        
        .. attribute:: switch
        
        	Switch in the system
        	**type**\:  :py:class:`Switch <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.HwSwitch.Switch>`
        
        

        """

        _prefix = 'ios-sw'
        _revision = '2018-01-10'

        def __init__(self):
            super(Native.HwSwitch, self).__init__()

            self.yang_name = "hw-switch"
            self.yang_parent_name = "native"
            self.is_top_level_class = False
            self.has_list_ancestor = False
            self.ylist_key_names = []
            self._child_classes = OrderedDict([("switch", ("switch", Native.HwSwitch.Switch))])
            self._leafs = OrderedDict()

            self.switch = Native.HwSwitch.Switch()
            self.switch.parent = self
            self._children_name_map["switch"] = "switch"
            self._segment_path = lambda: "Cisco-IOS-XE-switch:hw-switch"
            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/%s" % self._segment_path()
            self._is_frozen = True

        def __setattr__(self, name, value):
            self._perform_setattr(Native.HwSwitch, [], name, value)


        class Switch(Entity):
            """
            Switch in the system
            
            .. attribute:: switch_number
            
            	
            	**type**\: list of  		 :py:class:`SwitchNumber <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.HwSwitch.Switch.SwitchNumber>`
            
            

            """

            _prefix = 'ios-sw'
            _revision = '2018-01-10'

            def __init__(self):
                super(Native.HwSwitch.Switch, self).__init__()

                self.yang_name = "switch"
                self.yang_parent_name = "hw-switch"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = []
                self._child_classes = OrderedDict([("switch-number", ("switch_number", Native.HwSwitch.Switch.SwitchNumber))])
                self._leafs = OrderedDict()

                self.switch_number = YList(self)
                self._segment_path = lambda: "switch"
                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/Cisco-IOS-XE-switch:hw-switch/%s" % self._segment_path()
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(Native.HwSwitch.Switch, [], name, value)


            class SwitchNumber(Entity):
                """
                
                
                .. attribute:: switch_number  (key)
                
                	Switch number in the Stack (Refer to show switch CLI)
                	**type**\: int
                
                	**range:** 1..9
                
                .. attribute:: logging
                
                	Logging onboard
                	**type**\:  :py:class:`Logging <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.HwSwitch.Switch.SwitchNumber.Logging>`
                
                

                """

                _prefix = 'ios-sw'
                _revision = '2018-01-10'

                def __init__(self):
                    super(Native.HwSwitch.Switch.SwitchNumber, self).__init__()

                    self.yang_name = "switch-number"
                    self.yang_parent_name = "switch"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = ['switch_number']
                    self._child_classes = OrderedDict([("logging", ("logging", Native.HwSwitch.Switch.SwitchNumber.Logging))])
                    self._leafs = OrderedDict([
                        ('switch_number', (YLeaf(YType.uint8, 'switch-number'), ['int'])),
                    ])
                    self.switch_number = None

                    self.logging = Native.HwSwitch.Switch.SwitchNumber.Logging()
                    self.logging.parent = self
                    self._children_name_map["logging"] = "logging"
                    self._segment_path = lambda: "switch-number" + "[switch-number='" + str(self.switch_number) + "']"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/Cisco-IOS-XE-switch:hw-switch/switch/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.HwSwitch.Switch.SwitchNumber, [u'switch_number'], name, value)


                class Logging(Entity):
                    """
                    Logging onboard
                    
                    .. attribute:: onboard
                    
                    	Logging onboard
                    	**type**\:  :py:class:`Onboard <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.HwSwitch.Switch.SwitchNumber.Logging.Onboard>`
                    
                    	**presence node**\: True
                    
                    

                    """

                    _prefix = 'ios-sw'
                    _revision = '2018-01-10'

                    def __init__(self):
                        super(Native.HwSwitch.Switch.SwitchNumber.Logging, self).__init__()

                        self.yang_name = "logging"
                        self.yang_parent_name = "switch-number"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("onboard", ("onboard", Native.HwSwitch.Switch.SwitchNumber.Logging.Onboard))])
                        self._leafs = OrderedDict()

                        self.onboard = None
                        self._children_name_map["onboard"] = "onboard"
                        self._segment_path = lambda: "logging"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.HwSwitch.Switch.SwitchNumber.Logging, [], name, value)


                    class Onboard(Entity):
                        """
                        Logging onboard
                        
                        .. attribute:: counter
                        
                        	Configure logging onboard counter
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: environment
                        
                        	Configure logging onboard environment
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: message
                        
                        	Configure logging onboard message
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: poe
                        
                        	Configure logging onboard poe
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: temperature
                        
                        	Configure logging onboard temperature
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: voltage
                        
                        	Configure logging onboard voltage
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-sw'
                        _revision = '2018-01-10'

                        def __init__(self):
                            super(Native.HwSwitch.Switch.SwitchNumber.Logging.Onboard, self).__init__()

                            self.yang_name = "onboard"
                            self.yang_parent_name = "logging"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('counter', (YLeaf(YType.empty, 'counter'), ['Empty'])),
                                ('environment', (YLeaf(YType.empty, 'environment'), ['Empty'])),
                                ('message', (YLeaf(YType.empty, 'message'), ['Empty'])),
                                ('poe', (YLeaf(YType.empty, 'poe'), ['Empty'])),
                                ('temperature', (YLeaf(YType.empty, 'temperature'), ['Empty'])),
                                ('voltage', (YLeaf(YType.empty, 'voltage'), ['Empty'])),
                            ])
                            self.counter = None
                            self.environment = None
                            self.message = None
                            self.poe = None
                            self.temperature = None
                            self.voltage = None
                            self._segment_path = lambda: "onboard"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.HwSwitch.Switch.SwitchNumber.Logging.Onboard, [u'counter', u'environment', u'message', u'poe', u'temperature', u'voltage'], name, value)


    class Feature(Entity):
        """
        feature enable config
        
        .. attribute:: openflow
        
        	feature OpenFlow Plug\-in enable config
        	**type**\: :py:class:`Empty<ydk.types.Empty>`
        
        

        """

        _prefix = 'ios-sw'
        _revision = '2018-01-10'

        def __init__(self):
            super(Native.Feature, self).__init__()

            self.yang_name = "feature"
            self.yang_parent_name = "native"
            self.is_top_level_class = False
            self.has_list_ancestor = False
            self.ylist_key_names = []
            self._child_classes = OrderedDict([])
            self._leafs = OrderedDict([
                ('openflow', (YLeaf(YType.empty, 'openflow'), ['Empty'])),
            ])
            self.openflow = None
            self._segment_path = lambda: "Cisco-IOS-XE-switch:feature"
            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/%s" % self._segment_path()
            self._is_frozen = True

        def __setattr__(self, name, value):
            self._perform_setattr(Native.Feature, [u'openflow'], name, value)


    class Openflow(Entity):
        """
        OpenFlow configuration
        
        .. attribute:: switch
        
        	OpenFlow Plug\-in logical switch config
        	**type**\: list of  		 :py:class:`Switch <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Openflow.Switch>`
        
        

        """

        _prefix = 'ios-sw'
        _revision = '2018-01-10'

        def __init__(self):
            super(Native.Openflow, self).__init__()

            self.yang_name = "openflow"
            self.yang_parent_name = "native"
            self.is_top_level_class = False
            self.has_list_ancestor = False
            self.ylist_key_names = []
            self._child_classes = OrderedDict([("switch", ("switch", Native.Openflow.Switch))])
            self._leafs = OrderedDict()

            self.switch = YList(self)
            self._segment_path = lambda: "Cisco-IOS-XE-switch:openflow"
            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/%s" % self._segment_path()
            self._is_frozen = True

        def __setattr__(self, name, value):
            self._perform_setattr(Native.Openflow, [], name, value)


        class Switch(Entity):
            """
            OpenFlow Plug\-in logical switch config
            
            .. attribute:: number  (key)
            
            	
            	**type**\: int
            
            	**range:** 0..4294967295
            
            .. attribute:: pipeline
            
            	OpenFlow Plug\-in pipeline id config
            	**type**\: int
            
            	**range:** 0..4294967295
            
            .. attribute:: controller
            
            	set OpenFlow controller connection info
            	**type**\:  :py:class:`Controller <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Openflow.Switch.Controller>`
            
            .. attribute:: of_port
            
            	OpenFlow port/interface
            	**type**\:  :py:class:`OfPort <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Openflow.Switch.OfPort>`
            
            .. attribute:: datapath_id
            
            	Set OpenFlow logical switch datapath\-id
            	**type**\: str
            
            .. attribute:: protocol_version
            
            	Set OpenFlow protocol version
            	**type**\:  :py:class:`ProtocolVersion <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Openflow.Switch.ProtocolVersion>`
            
            .. attribute:: max_backoff
            
            	OpenFlow Plug\-in max backoff in seconds
            	**type**\: int
            
            	**range:** 1..65535
            
            .. attribute:: probe_interval
            
            	OpenFlow Plug\-in probe interval in seconds
            	**type**\: int
            
            	**range:** 5..65535
            
            .. attribute:: rate_limit
            
            	OpenFlow rate limit to controller
            	**type**\:  :py:class:`RateLimit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Openflow.Switch.RateLimit>`
            
            .. attribute:: shutdown
            
            	shutdown OpenFlow Plug\-in logical switch
            	**type**\: :py:class:`Empty<ydk.types.Empty>`
            
            .. attribute:: statistics
            
            	Statistics configuration
            	**type**\:  :py:class:`Statistics <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Openflow.Switch.Statistics>`
            
            .. attribute:: dataplane_default
            
            	set OpenFlow Plug\-in dataplane config
            	**type**\:  :py:class:`DataplaneDefault <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Openflow.Switch.DataplaneDefault>`
            
            .. attribute:: default_miss
            
            	Specifies behavior if a packet does not match any controller installed flow
            	**type**\:  :py:class:`DefaultMiss <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Openflow.Switch.DefaultMiss>`
            
            .. attribute:: logging
            
            	Enable logging
            	**type**\:  :py:class:`Logging <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Openflow.Switch.Logging>`
            
            .. attribute:: tls
            
            	OpenFlow switch tls
            	**type**\:  :py:class:`Tls <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Openflow.Switch.Tls>`
            
            

            """

            _prefix = 'ios-sw'
            _revision = '2018-01-10'

            def __init__(self):
                super(Native.Openflow.Switch, self).__init__()

                self.yang_name = "switch"
                self.yang_parent_name = "openflow"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = ['number']
                self._child_classes = OrderedDict([("controller", ("controller", Native.Openflow.Switch.Controller)), ("of-port", ("of_port", Native.Openflow.Switch.OfPort)), ("rate-limit", ("rate_limit", Native.Openflow.Switch.RateLimit)), ("statistics", ("statistics", Native.Openflow.Switch.Statistics)), ("logging", ("logging", Native.Openflow.Switch.Logging)), ("tls", ("tls", Native.Openflow.Switch.Tls))])
                self._leafs = OrderedDict([
                    ('number', (YLeaf(YType.uint32, 'number'), ['int'])),
                    ('pipeline', (YLeaf(YType.uint32, 'pipeline'), ['int'])),
                    ('datapath_id', (YLeaf(YType.str, 'datapath-id'), ['str'])),
                    ('protocol_version', (YLeaf(YType.enumeration, 'protocol-version'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Openflow.Switch.ProtocolVersion')])),
                    ('max_backoff', (YLeaf(YType.uint16, 'max-backoff'), ['int'])),
                    ('probe_interval', (YLeaf(YType.uint16, 'probe-interval'), ['int'])),
                    ('shutdown', (YLeaf(YType.empty, 'shutdown'), ['Empty'])),
                    ('dataplane_default', (YLeaf(YType.enumeration, 'dataplane-default'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Openflow.Switch.DataplaneDefault')])),
                    ('default_miss', (YLeaf(YType.enumeration, 'default-miss'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Openflow.Switch.DefaultMiss')])),
                ])
                self.number = None
                self.pipeline = None
                self.datapath_id = None
                self.protocol_version = None
                self.max_backoff = None
                self.probe_interval = None
                self.shutdown = None
                self.dataplane_default = None
                self.default_miss = None

                self.controller = Native.Openflow.Switch.Controller()
                self.controller.parent = self
                self._children_name_map["controller"] = "controller"

                self.of_port = Native.Openflow.Switch.OfPort()
                self.of_port.parent = self
                self._children_name_map["of_port"] = "of-port"

                self.rate_limit = Native.Openflow.Switch.RateLimit()
                self.rate_limit.parent = self
                self._children_name_map["rate_limit"] = "rate-limit"

                self.statistics = Native.Openflow.Switch.Statistics()
                self.statistics.parent = self
                self._children_name_map["statistics"] = "statistics"

                self.logging = Native.Openflow.Switch.Logging()
                self.logging.parent = self
                self._children_name_map["logging"] = "logging"

                self.tls = Native.Openflow.Switch.Tls()
                self.tls.parent = self
                self._children_name_map["tls"] = "tls"
                self._segment_path = lambda: "switch" + "[number='" + str(self.number) + "']"
                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/Cisco-IOS-XE-switch:openflow/%s" % self._segment_path()
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(Native.Openflow.Switch, [u'number', u'pipeline', u'datapath_id', u'protocol_version', u'max_backoff', u'probe_interval', u'shutdown', u'dataplane_default', u'default_miss'], name, value)

            class DataplaneDefault(Enum):
                """
                DataplaneDefault (Enum Class)

                set OpenFlow Plug\-in dataplane config

                .. data:: secure = 0

                .. data:: standalone = 1

                """

                secure = Enum.YLeaf(0, "secure")

                standalone = Enum.YLeaf(1, "standalone")


            class DefaultMiss(Enum):
                """
                DefaultMiss (Enum Class)

                Specifies behavior if a packet does not match any controller installed flow

                .. data:: continue_drop = 0

                .. data:: drop = 1

                """

                continue_drop = Enum.YLeaf(0, "continue-drop")

                drop = Enum.YLeaf(1, "drop")


            class ProtocolVersion(Enum):
                """
                ProtocolVersion (Enum Class)

                Set OpenFlow protocol version

                .. data:: Y_1__DOT__0 = 0

                .. data:: Y_1__DOT__3 = 1

                .. data:: negotiate = 2

                """

                Y_1__DOT__0 = Enum.YLeaf(0, "1.0")

                Y_1__DOT__3 = Enum.YLeaf(1, "1.3")

                negotiate = Enum.YLeaf(2, "negotiate")



            class Controller(Entity):
                """
                set OpenFlow controller connection info
                
                .. attribute:: ipv4
                
                	OpenFlow controller IPv4 protocol
                	**type**\: list of  		 :py:class:`Ipv4 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Openflow.Switch.Controller.Ipv4>`
                
                

                """

                _prefix = 'ios-sw'
                _revision = '2018-01-10'

                def __init__(self):
                    super(Native.Openflow.Switch.Controller, self).__init__()

                    self.yang_name = "controller"
                    self.yang_parent_name = "switch"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("ipv4", ("ipv4", Native.Openflow.Switch.Controller.Ipv4))])
                    self._leafs = OrderedDict()

                    self.ipv4 = YList(self)
                    self._segment_path = lambda: "controller"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Openflow.Switch.Controller, [], name, value)


                class Ipv4(Entity):
                    """
                    OpenFlow controller IPv4 protocol
                    
                    .. attribute:: address  (key)
                    
                    	IPv4 Address of the OpenFlow controller
                    	**type**\: str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    .. attribute:: port
                    
                    	OpenFlow controller TCP port (default is 6653)
                    	**type**\: list of  		 :py:class:`Port <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Openflow.Switch.Controller.Ipv4.Port>`
                    
                    

                    """

                    _prefix = 'ios-sw'
                    _revision = '2018-01-10'

                    def __init__(self):
                        super(Native.Openflow.Switch.Controller.Ipv4, self).__init__()

                        self.yang_name = "ipv4"
                        self.yang_parent_name = "controller"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = ['address']
                        self._child_classes = OrderedDict([("port", ("port", Native.Openflow.Switch.Controller.Ipv4.Port))])
                        self._leafs = OrderedDict([
                            ('address', (YLeaf(YType.str, 'address'), ['str'])),
                        ])
                        self.address = None

                        self.port = YList(self)
                        self._segment_path = lambda: "ipv4" + "[address='" + str(self.address) + "']"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Openflow.Switch.Controller.Ipv4, [u'address'], name, value)


                    class Port(Entity):
                        """
                        OpenFlow controller TCP port (default is 6653)
                        
                        .. attribute:: number  (key)
                        
                        	
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: vrf
                        
                        	OpenFlow controller vrf
                        	**type**\: list of  		 :py:class:`Vrf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Openflow.Switch.Controller.Ipv4.Port.Vrf>`
                        
                        

                        """

                        _prefix = 'ios-sw'
                        _revision = '2018-01-10'

                        def __init__(self):
                            super(Native.Openflow.Switch.Controller.Ipv4.Port, self).__init__()

                            self.yang_name = "port"
                            self.yang_parent_name = "ipv4"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['number']
                            self._child_classes = OrderedDict([("vrf", ("vrf", Native.Openflow.Switch.Controller.Ipv4.Port.Vrf))])
                            self._leafs = OrderedDict([
                                ('number', (YLeaf(YType.uint16, 'number'), ['int'])),
                            ])
                            self.number = None

                            self.vrf = YList(self)
                            self._segment_path = lambda: "port" + "[number='" + str(self.number) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Openflow.Switch.Controller.Ipv4.Port, [u'number'], name, value)


                        class Vrf(Entity):
                            """
                            OpenFlow controller vrf
                            
                            .. attribute:: name  (key)
                            
                            	
                            	**type**\: str
                            
                            .. attribute:: security
                            
                            	OpenFlow controller connection security
                            	**type**\:  :py:class:`Security <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Openflow.Switch.Controller.Ipv4.Port.Vrf.Security>`
                            
                            

                            """

                            _prefix = 'ios-sw'
                            _revision = '2018-01-10'

                            def __init__(self):
                                super(Native.Openflow.Switch.Controller.Ipv4.Port.Vrf, self).__init__()

                                self.yang_name = "vrf"
                                self.yang_parent_name = "port"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = ['name']
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                    ('security', (YLeaf(YType.enumeration, 'security'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Openflow.Switch.Controller.Ipv4.Port.Vrf.Security')])),
                                ])
                                self.name = None
                                self.security = None
                                self._segment_path = lambda: "vrf" + "[name='" + str(self.name) + "']"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Openflow.Switch.Controller.Ipv4.Port.Vrf, [u'name', u'security'], name, value)

                            class Security(Enum):
                                """
                                Security (Enum Class)

                                OpenFlow controller connection security

                                .. data:: none = 0

                                .. data:: tls = 1

                                """

                                none = Enum.YLeaf(0, "none")

                                tls = Enum.YLeaf(1, "tls")



            class OfPort(Entity):
                """
                OpenFlow port/interface
                
                .. attribute:: interface
                
                	OpenFlow Plug\-in interface
                	**type**\: list of  		 :py:class:`Interface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Openflow.Switch.OfPort.Interface>`
                
                

                """

                _prefix = 'ios-sw'
                _revision = '2018-01-10'

                def __init__(self):
                    super(Native.Openflow.Switch.OfPort, self).__init__()

                    self.yang_name = "of-port"
                    self.yang_parent_name = "switch"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("interface", ("interface", Native.Openflow.Switch.OfPort.Interface))])
                    self._leafs = OrderedDict()

                    self.interface = YList(self)
                    self._segment_path = lambda: "of-port"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Openflow.Switch.OfPort, [], name, value)


                class Interface(Entity):
                    """
                    OpenFlow Plug\-in interface
                    
                    .. attribute:: name  (key)
                    
                    	
                    	**type**\: str
                    
                    

                    """

                    _prefix = 'ios-sw'
                    _revision = '2018-01-10'

                    def __init__(self):
                        super(Native.Openflow.Switch.OfPort.Interface, self).__init__()

                        self.yang_name = "interface"
                        self.yang_parent_name = "of-port"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = ['name']
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('name', (YLeaf(YType.str, 'name'), ['str'])),
                        ])
                        self.name = None
                        self._segment_path = lambda: "interface" + "[name='" + str(self.name) + "']"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Openflow.Switch.OfPort.Interface, [u'name'], name, value)


            class RateLimit(Entity):
                """
                OpenFlow rate limit to controller
                
                .. attribute:: packet_in
                
                	packet in rate (default is 0, indefinite)
                	**type**\: int
                
                	**range:** 1..65535
                
                .. attribute:: burst
                
                	Maximum number of packets to controller (default is 0, indefinite)
                	**type**\: int
                
                	**range:** 1..65535
                
                

                """

                _prefix = 'ios-sw'
                _revision = '2018-01-10'

                def __init__(self):
                    super(Native.Openflow.Switch.RateLimit, self).__init__()

                    self.yang_name = "rate-limit"
                    self.yang_parent_name = "switch"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('packet_in', (YLeaf(YType.uint16, 'packet_in'), ['int'])),
                        ('burst', (YLeaf(YType.uint16, 'burst'), ['int'])),
                    ])
                    self.packet_in = None
                    self.burst = None
                    self._segment_path = lambda: "rate-limit"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Openflow.Switch.RateLimit, [u'packet_in', u'burst'], name, value)


            class Statistics(Entity):
                """
                Statistics configuration
                
                .. attribute:: collection_interval
                
                	OpenFlow flow statistics collection interval in seconds
                	**type**\: int
                
                	**range:** 0..16
                
                

                """

                _prefix = 'ios-sw'
                _revision = '2018-01-10'

                def __init__(self):
                    super(Native.Openflow.Switch.Statistics, self).__init__()

                    self.yang_name = "statistics"
                    self.yang_parent_name = "switch"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('collection_interval', (YLeaf(YType.uint8, 'collection-interval'), ['int'])),
                    ])
                    self.collection_interval = None
                    self._segment_path = lambda: "statistics"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Openflow.Switch.Statistics, [u'collection_interval'], name, value)


            class Logging(Entity):
                """
                Enable logging
                
                .. attribute:: flow_modify
                
                	Enable logging for flow\-modify
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                

                """

                _prefix = 'ios-sw'
                _revision = '2018-01-10'

                def __init__(self):
                    super(Native.Openflow.Switch.Logging, self).__init__()

                    self.yang_name = "logging"
                    self.yang_parent_name = "switch"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('flow_modify', (YLeaf(YType.empty, 'flow-modify'), ['Empty'])),
                    ])
                    self.flow_modify = None
                    self._segment_path = lambda: "logging"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Openflow.Switch.Logging, [u'flow_modify'], name, value)


            class Tls(Entity):
                """
                OpenFlow switch tls
                
                .. attribute:: trustpoint
                
                	tls trust point
                	**type**\:  :py:class:`Trustpoint <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Openflow.Switch.Tls.Trustpoint>`
                
                

                """

                _prefix = 'ios-sw'
                _revision = '2018-01-10'

                def __init__(self):
                    super(Native.Openflow.Switch.Tls, self).__init__()

                    self.yang_name = "tls"
                    self.yang_parent_name = "switch"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("trustpoint", ("trustpoint", Native.Openflow.Switch.Tls.Trustpoint))])
                    self._leafs = OrderedDict()

                    self.trustpoint = Native.Openflow.Switch.Tls.Trustpoint()
                    self.trustpoint.parent = self
                    self._children_name_map["trustpoint"] = "trustpoint"
                    self._segment_path = lambda: "tls"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Openflow.Switch.Tls, [], name, value)


                class Trustpoint(Entity):
                    """
                    tls trust point
                    
                    .. attribute:: local
                    
                    	tls local trust point
                    	**type**\: str
                    
                    .. attribute:: remote
                    
                    	tls remote trust point
                    	**type**\: str
                    
                    

                    """

                    _prefix = 'ios-sw'
                    _revision = '2018-01-10'

                    def __init__(self):
                        super(Native.Openflow.Switch.Tls.Trustpoint, self).__init__()

                        self.yang_name = "trustpoint"
                        self.yang_parent_name = "tls"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('local', (YLeaf(YType.str, 'local'), ['str'])),
                            ('remote', (YLeaf(YType.str, 'remote'), ['str'])),
                        ])
                        self.local = None
                        self.remote = None
                        self._segment_path = lambda: "trustpoint"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Openflow.Switch.Tls.Trustpoint, [u'local', u'remote'], name, value)


    class EtAnalytics(Entity):
        """
        Encrypted Traffic Analytics
        
        .. attribute:: ip
        
        	Specify netflow record export destination ip address and port
        	**type**\:  :py:class:`Ip <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.EtAnalytics.Ip>`
        
        .. attribute:: inactive_timeout
        
        	Specify Inactive flow timeout value
        	**type**\: int
        
        	**range:** 1..604800
        
        .. attribute:: whitelist
        
        	Whitelist traffic
        	**type**\:  :py:class:`Whitelist <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.EtAnalytics.Whitelist>`
        
        

        This class is a :ref:`presence class<presence-class>`

        """

        _prefix = 'ios-eta'
        _revision = '2018-06-28'

        def __init__(self):
            super(Native.EtAnalytics, self).__init__()

            self.yang_name = "et-analytics"
            self.yang_parent_name = "native"
            self.is_top_level_class = False
            self.has_list_ancestor = False
            self.ylist_key_names = []
            self._child_classes = OrderedDict([("ip", ("ip", Native.EtAnalytics.Ip)), ("whitelist", ("whitelist", Native.EtAnalytics.Whitelist))])
            self.is_presence_container = True
            self._leafs = OrderedDict([
                ('inactive_timeout', (YLeaf(YType.uint32, 'inactive-timeout'), ['int'])),
            ])
            self.inactive_timeout = None

            self.ip = Native.EtAnalytics.Ip()
            self.ip.parent = self
            self._children_name_map["ip"] = "ip"

            self.whitelist = Native.EtAnalytics.Whitelist()
            self.whitelist.parent = self
            self._children_name_map["whitelist"] = "whitelist"
            self._segment_path = lambda: "Cisco-IOS-XE-eta:et-analytics"
            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/%s" % self._segment_path()
            self._is_frozen = True

        def __setattr__(self, name, value):
            self._perform_setattr(Native.EtAnalytics, ['inactive_timeout'], name, value)


        class Ip(Entity):
            """
            Specify netflow record export destination ip address and port
            
            .. attribute:: flow_export
            
            	netflow record export
            	**type**\:  :py:class:`FlowExport <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.EtAnalytics.Ip.FlowExport>`
            
            

            """

            _prefix = 'ios-eta'
            _revision = '2018-06-28'

            def __init__(self):
                super(Native.EtAnalytics.Ip, self).__init__()

                self.yang_name = "ip"
                self.yang_parent_name = "et-analytics"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = []
                self._child_classes = OrderedDict([("flow-export", ("flow_export", Native.EtAnalytics.Ip.FlowExport))])
                self._leafs = OrderedDict()

                self.flow_export = Native.EtAnalytics.Ip.FlowExport()
                self.flow_export.parent = self
                self._children_name_map["flow_export"] = "flow-export"
                self._segment_path = lambda: "ip"
                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/Cisco-IOS-XE-eta:et-analytics/%s" % self._segment_path()
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(Native.EtAnalytics.Ip, [], name, value)


            class FlowExport(Entity):
                """
                netflow record export
                
                .. attribute:: destination
                
                	netflow record export destination
                	**type**\: list of  		 :py:class:`Destination <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.EtAnalytics.Ip.FlowExport.Destination>`
                
                .. attribute:: destination_vrf
                
                	
                	**type**\:  :py:class:`DestinationVrf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.EtAnalytics.Ip.FlowExport.DestinationVrf>`
                
                

                """

                _prefix = 'ios-eta'
                _revision = '2018-06-28'

                def __init__(self):
                    super(Native.EtAnalytics.Ip.FlowExport, self).__init__()

                    self.yang_name = "flow-export"
                    self.yang_parent_name = "ip"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("destination", ("destination", Native.EtAnalytics.Ip.FlowExport.Destination)), ("destination-vrf", ("destination_vrf", Native.EtAnalytics.Ip.FlowExport.DestinationVrf))])
                    self._leafs = OrderedDict()

                    self.destination_vrf = Native.EtAnalytics.Ip.FlowExport.DestinationVrf()
                    self.destination_vrf.parent = self
                    self._children_name_map["destination_vrf"] = "destination-vrf"

                    self.destination = YList(self)
                    self._segment_path = lambda: "flow-export"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/Cisco-IOS-XE-eta:et-analytics/ip/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.EtAnalytics.Ip.FlowExport, [], name, value)


                class Destination(Entity):
                    """
                    netflow record export destination
                    
                    .. attribute:: address  (key)
                    
                    	
                    	**type**\: str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    .. attribute:: port  (key)
                    
                    	
                    	**type**\: int
                    
                    	**range:** 1..65535
                    
                    

                    """

                    _prefix = 'ios-eta'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.EtAnalytics.Ip.FlowExport.Destination, self).__init__()

                        self.yang_name = "destination"
                        self.yang_parent_name = "flow-export"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = ['address','port']
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('address', (YLeaf(YType.str, 'address'), ['str'])),
                            ('port', (YLeaf(YType.uint16, 'port'), ['int'])),
                        ])
                        self.address = None
                        self.port = None
                        self._segment_path = lambda: "destination" + "[address='" + str(self.address) + "']" + "[port='" + str(self.port) + "']"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/Cisco-IOS-XE-eta:et-analytics/ip/flow-export/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.EtAnalytics.Ip.FlowExport.Destination, ['address', 'port'], name, value)


                class DestinationVrf(Entity):
                    """
                    
                    
                    .. attribute:: destination
                    
                    	netflow record export destination
                    	**type**\: list of  		 :py:class:`Destination <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.EtAnalytics.Ip.FlowExport.DestinationVrf.Destination>`
                    
                    

                    """

                    _prefix = 'ios-eta'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.EtAnalytics.Ip.FlowExport.DestinationVrf, self).__init__()

                        self.yang_name = "destination-vrf"
                        self.yang_parent_name = "flow-export"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("destination", ("destination", Native.EtAnalytics.Ip.FlowExport.DestinationVrf.Destination))])
                        self._leafs = OrderedDict()

                        self.destination = YList(self)
                        self._segment_path = lambda: "destination-vrf"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/Cisco-IOS-XE-eta:et-analytics/ip/flow-export/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.EtAnalytics.Ip.FlowExport.DestinationVrf, [], name, value)


                    class Destination(Entity):
                        """
                        netflow record export destination
                        
                        .. attribute:: address  (key)
                        
                        	
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: port  (key)
                        
                        	
                        	**type**\: int
                        
                        	**range:** 1..65535
                        
                        .. attribute:: vrf  (key)
                        
                        	Optional VRF label
                        	**type**\: str
                        
                        	**length:** 1..32
                        
                        

                        """

                        _prefix = 'ios-eta'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.EtAnalytics.Ip.FlowExport.DestinationVrf.Destination, self).__init__()

                            self.yang_name = "destination"
                            self.yang_parent_name = "destination-vrf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = ['address','port','vrf']
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('address', (YLeaf(YType.str, 'address'), ['str'])),
                                ('port', (YLeaf(YType.uint16, 'port'), ['int'])),
                                ('vrf', (YLeaf(YType.str, 'vrf'), ['str'])),
                            ])
                            self.address = None
                            self.port = None
                            self.vrf = None
                            self._segment_path = lambda: "destination" + "[address='" + str(self.address) + "']" + "[port='" + str(self.port) + "']" + "[vrf='" + str(self.vrf) + "']"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/Cisco-IOS-XE-eta:et-analytics/ip/flow-export/destination-vrf/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.EtAnalytics.Ip.FlowExport.DestinationVrf.Destination, ['address', 'port', 'vrf'], name, value)


        class Whitelist(Entity):
            """
            Whitelist traffic
            
            .. attribute:: acl
            
            	Access list
            	**type**\: union of the below types:
            
            		**type**\: int
            
            			**range:** 1..199 \| 1300..2699
            
            		**type**\: str
            
            			**length:** 1..64
            
            

            """

            _prefix = 'ios-eta'
            _revision = '2018-06-28'

            def __init__(self):
                super(Native.EtAnalytics.Whitelist, self).__init__()

                self.yang_name = "whitelist"
                self.yang_parent_name = "et-analytics"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = []
                self._child_classes = OrderedDict([])
                self._leafs = OrderedDict([
                    ('acl', (YLeaf(YType.str, 'acl'), ['int','str'])),
                ])
                self.acl = None
                self._segment_path = lambda: "whitelist"
                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/Cisco-IOS-XE-eta:et-analytics/%s" % self._segment_path()
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(Native.EtAnalytics.Whitelist, ['acl'], name, value)


    class Dialer(Entity):
        """
        Dialer commands
        
        .. attribute:: watch_list
        
        	Dialer watch list
        	**type**\: list of  		 :py:class:`WatchList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Dialer.WatchList>`
        
        

        """

        _prefix = 'ios-cell'
        _revision = '2017-12-20'

        def __init__(self):
            super(Native.Dialer, self).__init__()

            self.yang_name = "dialer"
            self.yang_parent_name = "native"
            self.is_top_level_class = False
            self.has_list_ancestor = False
            self.ylist_key_names = []
            self._child_classes = OrderedDict([("watch-list", ("watch_list", Native.Dialer.WatchList))])
            self._leafs = OrderedDict()

            self.watch_list = YList(self)
            self._segment_path = lambda: "Cisco-IOS-XE-cellular:dialer"
            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/%s" % self._segment_path()
            self._is_frozen = True

        def __setattr__(self, name, value):
            self._perform_setattr(Native.Dialer, [], name, value)


        class WatchList(Entity):
            """
            Dialer watch list
            
            .. attribute:: number  (key)
            
            	
            	**type**\: int
            
            	**range:** 1..255
            
            .. attribute:: delay
            
            	Dialer watch delay
            	**type**\: list of  		 :py:class:`Delay <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Dialer.WatchList.Delay>`
            
            .. attribute:: ip
            
            	IP
            	**type**\: list of  		 :py:class:`Ip <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Dialer.WatchList.Ip>`
            
            

            """

            _prefix = 'ios-cell'
            _revision = '2017-12-20'

            def __init__(self):
                super(Native.Dialer.WatchList, self).__init__()

                self.yang_name = "watch-list"
                self.yang_parent_name = "dialer"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = ['number']
                self._child_classes = OrderedDict([("delay", ("delay", Native.Dialer.WatchList.Delay)), ("ip", ("ip", Native.Dialer.WatchList.Ip))])
                self._leafs = OrderedDict([
                    ('number', (YLeaf(YType.uint8, 'number'), ['int'])),
                ])
                self.number = None

                self.delay = YList(self)
                self.ip = YList(self)
                self._segment_path = lambda: "watch-list" + "[number='" + str(self.number) + "']"
                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/Cisco-IOS-XE-cellular:dialer/%s" % self._segment_path()
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(Native.Dialer.WatchList, ['number'], name, value)


            class Delay(Entity):
                """
                Dialer watch delay
                
                .. attribute:: interval  (key)
                
                	
                	**type**\:  :py:class:`Interval <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Dialer.WatchList.Delay.Interval>`
                
                .. attribute:: initial
                
                	Delay for initial check of watched route after boot
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: delay_time
                
                	Delay time in seconds
                	**type**\: int
                
                	**range:** 1..2147483
                
                

                """

                _prefix = 'ios-cell'
                _revision = '2017-12-20'

                def __init__(self):
                    super(Native.Dialer.WatchList.Delay, self).__init__()

                    self.yang_name = "delay"
                    self.yang_parent_name = "watch-list"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = ['interval']
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('interval', (YLeaf(YType.enumeration, 'interval'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Dialer.WatchList.Delay.Interval')])),
                        ('initial', (YLeaf(YType.empty, 'initial'), ['Empty'])),
                        ('delay_time', (YLeaf(YType.uint32, 'delay-time'), ['int'])),
                    ])
                    self.interval = None
                    self.initial = None
                    self.delay_time = None
                    self._segment_path = lambda: "delay" + "[interval='" + str(self.interval) + "']"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Dialer.WatchList.Delay, ['interval', 'initial', 'delay_time'], name, value)

                class Interval(Enum):
                    """
                    Interval (Enum Class)

                    .. data:: connect = 0

                    .. data:: disconnect = 1

                    .. data:: route_check = 2

                    """

                    connect = Enum.YLeaf(0, "connect")

                    disconnect = Enum.YLeaf(1, "disconnect")

                    route_check = Enum.YLeaf(2, "route-check")



            class Ip(Entity):
                """
                IP
                
                .. attribute:: address  (key)
                
                	IP address
                	**type**\: str
                
                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                
                .. attribute:: mask
                
                	IP subnet mask
                	**type**\: str
                
                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                
                

                """

                _prefix = 'ios-cell'
                _revision = '2017-12-20'

                def __init__(self):
                    super(Native.Dialer.WatchList.Ip, self).__init__()

                    self.yang_name = "ip"
                    self.yang_parent_name = "watch-list"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = ['address']
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('address', (YLeaf(YType.str, 'address'), ['str'])),
                        ('mask', (YLeaf(YType.str, 'mask'), ['str'])),
                    ])
                    self.address = None
                    self.mask = None
                    self._segment_path = lambda: "ip" + "[address='" + str(self.address) + "']"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Dialer.WatchList.Ip, ['address', 'mask'], name, value)


    class DialerList(Entity):
        """
        Create a dialer list entry
        
        .. attribute:: group_number  (key)
        
        	
        	**type**\: int
        
        	**range:** 1..128
        
        .. attribute:: protocol
        
        	
        	**type**\: list of  		 :py:class:`Protocol <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.DialerList.Protocol>`
        
        

        """

        _prefix = 'ios-cell'
        _revision = '2017-12-20'

        def __init__(self):
            super(Native.DialerList, self).__init__()

            self.yang_name = "dialer-list"
            self.yang_parent_name = "native"
            self.is_top_level_class = False
            self.has_list_ancestor = False
            self.ylist_key_names = ['group_number']
            self._child_classes = OrderedDict([("protocol", ("protocol", Native.DialerList.Protocol))])
            self._leafs = OrderedDict([
                ('group_number', (YLeaf(YType.uint8, 'group-number'), ['int'])),
            ])
            self.group_number = None

            self.protocol = YList(self)
            self._segment_path = lambda: "Cisco-IOS-XE-cellular:dialer-list" + "[group-number='" + str(self.group_number) + "']"
            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/%s" % self._segment_path()
            self._is_frozen = True

        def __setattr__(self, name, value):
            self._perform_setattr(Native.DialerList, ['group_number'], name, value)


        class Protocol(Entity):
            """
            
            
            .. attribute:: protocol_type  (key)
            
            	
            	**type**\:  :py:class:`ProtocolType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.DialerList.Protocol.ProtocolType>`
            
            .. attribute:: access
            
            	
            	**type**\:  :py:class:`Access <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.DialerList.Protocol.Access>`
            
            .. attribute:: list_name
            
            	
            	**type**\: str
            
            

            """

            _prefix = 'ios-cell'
            _revision = '2017-12-20'

            def __init__(self):
                super(Native.DialerList.Protocol, self).__init__()

                self.yang_name = "protocol"
                self.yang_parent_name = "dialer-list"
                self.is_top_level_class = False
                self.has_list_ancestor = True
                self.ylist_key_names = ['protocol_type']
                self._child_classes = OrderedDict([])
                self._leafs = OrderedDict([
                    ('protocol_type', (YLeaf(YType.enumeration, 'protocol-type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'DialerList.Protocol.ProtocolType')])),
                    ('access', (YLeaf(YType.enumeration, 'access'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'DialerList.Protocol.Access')])),
                    ('list_name', (YLeaf(YType.str, 'list-name'), ['str'])),
                ])
                self.protocol_type = None
                self.access = None
                self.list_name = None
                self._segment_path = lambda: "protocol" + "[protocol-type='" + str(self.protocol_type) + "']"
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(Native.DialerList.Protocol, ['protocol_type', 'access', 'list_name'], name, value)

            class Access(Enum):
                """
                Access (Enum Class)

                .. data:: deny = 0

                .. data:: list = 1

                .. data:: permit = 2

                """

                deny = Enum.YLeaf(0, "deny")

                list = Enum.YLeaf(1, "list")

                permit = Enum.YLeaf(2, "permit")


            class ProtocolType(Enum):
                """
                ProtocolType (Enum Class)

                .. data:: appletalk = 0

                .. data:: bridge = 1

                .. data:: clns = 2

                .. data:: clns_es = 3

                .. data:: clns_is = 4

                .. data:: decnet = 5

                .. data:: decnet_node = 6

                .. data:: decnet_router_L1 = 7

                .. data:: decnet_router_L2 = 8

                .. data:: ip = 9

                .. data:: ipv6 = 10

                .. data:: ipx = 11

                .. data:: llc2 = 12

                .. data:: netbios = 13

                .. data:: novell = 14

                .. data:: vines = 15

                .. data:: xns = 16

                """

                appletalk = Enum.YLeaf(0, "appletalk")

                bridge = Enum.YLeaf(1, "bridge")

                clns = Enum.YLeaf(2, "clns")

                clns_es = Enum.YLeaf(3, "clns_es")

                clns_is = Enum.YLeaf(4, "clns_is")

                decnet = Enum.YLeaf(5, "decnet")

                decnet_node = Enum.YLeaf(6, "decnet_node")

                decnet_router_L1 = Enum.YLeaf(7, "decnet_router-L1")

                decnet_router_L2 = Enum.YLeaf(8, "decnet_router-L2")

                ip = Enum.YLeaf(9, "ip")

                ipv6 = Enum.YLeaf(10, "ipv6")

                ipx = Enum.YLeaf(11, "ipx")

                llc2 = Enum.YLeaf(12, "llc2")

                netbios = Enum.YLeaf(13, "netbios")

                novell = Enum.YLeaf(14, "novell")

                vines = Enum.YLeaf(15, "vines")

                xns = Enum.YLeaf(16, "xns")



    class Utd(Entity):
        """
        Global Unified Threat Defense
        
        .. attribute:: all_interfaces
        
        	Enable intrusion inspection on all supported interfaces
        	**type**\: :py:class:`Empty<ydk.types.Empty>`
        
        .. attribute:: redirect
        
        	Specify the interface connected to the UTD
        	**type**\:  :py:class:`Redirect <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Utd.Redirect>`
        
        .. attribute:: engine
        
        	Select UTD engine mode to run
        	**type**\:  :py:class:`Engine <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Utd.Engine>`
        
        	**presence node**\: True
        
        

        This class is a :ref:`presence class<presence-class>`

        """

        _prefix = 'ios-utd'
        _revision = '2018-06-28'

        def __init__(self):
            super(Native.Utd, self).__init__()

            self.yang_name = "utd"
            self.yang_parent_name = "native"
            self.is_top_level_class = False
            self.has_list_ancestor = False
            self.ylist_key_names = []
            self._child_classes = OrderedDict([("redirect", ("redirect", Native.Utd.Redirect)), ("engine", ("engine", Native.Utd.Engine))])
            self.is_presence_container = True
            self._leafs = OrderedDict([
                ('all_interfaces', (YLeaf(YType.empty, 'all-interfaces'), ['Empty'])),
            ])
            self.all_interfaces = None

            self.redirect = Native.Utd.Redirect()
            self.redirect.parent = self
            self._children_name_map["redirect"] = "redirect"

            self.engine = None
            self._children_name_map["engine"] = "engine"
            self._segment_path = lambda: "Cisco-IOS-XE-utd:utd"
            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/%s" % self._segment_path()
            self._is_frozen = True

        def __setattr__(self, name, value):
            self._perform_setattr(Native.Utd, ['all_interfaces'], name, value)


        class Redirect(Entity):
            """
            Specify the interface connected to the UTD
            
            .. attribute:: interface
            
            	Specify the interface connected to UTD
            	**type**\:  :py:class:`Interface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Utd.Redirect.Interface>`
            
            

            """

            _prefix = 'ios-utd'
            _revision = '2018-06-28'

            def __init__(self):
                super(Native.Utd.Redirect, self).__init__()

                self.yang_name = "redirect"
                self.yang_parent_name = "utd"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = []
                self._child_classes = OrderedDict([("interface", ("interface", Native.Utd.Redirect.Interface))])
                self._leafs = OrderedDict()

                self.interface = Native.Utd.Redirect.Interface()
                self.interface.parent = self
                self._children_name_map["interface"] = "interface"
                self._segment_path = lambda: "redirect"
                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/Cisco-IOS-XE-utd:utd/%s" % self._segment_path()
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(Native.Utd.Redirect, [], name, value)


            class Interface(Entity):
                """
                Specify the interface connected to UTD
                
                .. attribute:: bdi
                
                	Bridge\-Domain interface
                	**type**\: str
                
                	**length:** 1..64
                
                .. attribute:: virtualportgroup
                
                	Virtual Port Group
                	**type**\: int
                
                	**range:** 0..65535
                
                

                """

                _prefix = 'ios-utd'
                _revision = '2018-06-28'

                def __init__(self):
                    super(Native.Utd.Redirect.Interface, self).__init__()

                    self.yang_name = "interface"
                    self.yang_parent_name = "redirect"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('bdi', (YLeaf(YType.str, 'BDI'), ['str'])),
                        ('virtualportgroup', (YLeaf(YType.uint16, 'VirtualPortGroup'), ['int'])),
                    ])
                    self.bdi = None
                    self.virtualportgroup = None
                    self._segment_path = lambda: "interface"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/Cisco-IOS-XE-utd:utd/redirect/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Utd.Redirect.Interface, ['bdi', 'virtualportgroup'], name, value)


        class Engine(Entity):
            """
            Select UTD engine mode to run
            
            .. attribute:: mode
            
            	
            	**type**\:  :py:class:`Mode <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Utd.Engine.Mode>`
            
            .. attribute:: fail
            
            	Enter the UTD engine fail mode operation
            	**type**\:  :py:class:`Fail <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Utd.Engine.Fail>`
            
            

            This class is a :ref:`presence class<presence-class>`

            """

            _prefix = 'ios-utd'
            _revision = '2018-06-28'

            def __init__(self):
                super(Native.Utd.Engine, self).__init__()

                self.yang_name = "engine"
                self.yang_parent_name = "utd"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = []
                self._child_classes = OrderedDict([("fail", ("fail", Native.Utd.Engine.Fail))])
                self.is_presence_container = True
                self._leafs = OrderedDict([
                    ('mode', (YLeaf(YType.enumeration, 'mode'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Utd.Engine.Mode')])),
                ])
                self.mode = None

                self.fail = Native.Utd.Engine.Fail()
                self.fail.parent = self
                self._children_name_map["fail"] = "fail"
                self._segment_path = lambda: "engine"
                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/Cisco-IOS-XE-utd:utd/%s" % self._segment_path()
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(Native.Utd.Engine, ['mode'], name, value)

            class Mode(Enum):
                """
                Mode (Enum Class)

                .. data:: standard = 0

                .. data:: advanced = 1

                """

                standard = Enum.YLeaf(0, "standard")

                advanced = Enum.YLeaf(1, "advanced")



            class Fail(Entity):
                """
                Enter the UTD engine fail mode operation
                
                .. attribute:: close
                
                	Drop all IPS/IDS traffic on UTD engine failure
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                

                """

                _prefix = 'ios-utd'
                _revision = '2018-06-28'

                def __init__(self):
                    super(Native.Utd.Engine.Fail, self).__init__()

                    self.yang_name = "fail"
                    self.yang_parent_name = "engine"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('close', (YLeaf(YType.empty, 'close'), ['Empty'])),
                    ])
                    self.close = None
                    self._segment_path = lambda: "fail"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/Cisco-IOS-XE-utd:utd/engine/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Utd.Engine.Fail, ['close'], name, value)


    class UtdSt(Entity):
        """
        
        
        .. attribute:: utd
        
        	Global Unified Threat Defense Engine
        	**type**\:  :py:class:`Utd <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.UtdSt.Utd>`
        
        

        """

        _prefix = 'ios-utd'
        _revision = '2018-06-28'

        def __init__(self):
            super(Native.UtdSt, self).__init__()

            self.yang_name = "utd-st"
            self.yang_parent_name = "native"
            self.is_top_level_class = False
            self.has_list_ancestor = False
            self.ylist_key_names = []
            self._child_classes = OrderedDict([("utd", ("utd", Native.UtdSt.Utd))])
            self._leafs = OrderedDict()

            self.utd = Native.UtdSt.Utd()
            self.utd.parent = self
            self._children_name_map["utd"] = "utd"
            self._segment_path = lambda: "Cisco-IOS-XE-utd:utd-st"
            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/%s" % self._segment_path()
            self._is_frozen = True

        def __setattr__(self, name, value):
            self._perform_setattr(Native.UtdSt, [], name, value)


        class Utd(Entity):
            """
            Global Unified Threat Defense Engine
            
            .. attribute:: web_filter
            
            	UTD web\-filter profile configuration
            	**type**\:  :py:class:`WebFilter <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.UtdSt.Utd.WebFilter>`
            
            .. attribute:: engine
            
            	UTD engine
            	**type**\:  :py:class:`Engine <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.UtdSt.Utd.Engine>`
            
            .. attribute:: threat_inspection
            
            	UTD Threat Inspection (IPS/IDS) config modes
            	**type**\:  :py:class:`ThreatInspection <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.UtdSt.Utd.ThreatInspection>`
            
            

            """

            _prefix = 'ios-utd'
            _revision = '2018-06-28'

            def __init__(self):
                super(Native.UtdSt.Utd, self).__init__()

                self.yang_name = "utd"
                self.yang_parent_name = "utd-st"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = []
                self._child_classes = OrderedDict([("web-filter", ("web_filter", Native.UtdSt.Utd.WebFilter)), ("engine", ("engine", Native.UtdSt.Utd.Engine)), ("threat-inspection", ("threat_inspection", Native.UtdSt.Utd.ThreatInspection))])
                self._leafs = OrderedDict()

                self.web_filter = Native.UtdSt.Utd.WebFilter()
                self.web_filter.parent = self
                self._children_name_map["web_filter"] = "web-filter"

                self.engine = Native.UtdSt.Utd.Engine()
                self.engine.parent = self
                self._children_name_map["engine"] = "engine"

                self.threat_inspection = Native.UtdSt.Utd.ThreatInspection()
                self.threat_inspection.parent = self
                self._children_name_map["threat_inspection"] = "threat-inspection"
                self._segment_path = lambda: "utd"
                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/Cisco-IOS-XE-utd:utd-st/%s" % self._segment_path()
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(Native.UtdSt.Utd, [], name, value)


            class WebFilter(Entity):
                """
                UTD web\-filter profile configuration
                
                .. attribute:: block
                
                	UTD block profile information
                	**type**\:  :py:class:`Block <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.UtdSt.Utd.WebFilter.Block>`
                
                .. attribute:: sourcedb
                
                	UTD Web filtering source DB configuration submode
                	**type**\: list of  		 :py:class:`Sourcedb <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.UtdSt.Utd.WebFilter.Sourcedb>`
                
                .. attribute:: url
                
                	UTD URL based web\-filtering submode
                	**type**\:  :py:class:`Url <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.UtdSt.Utd.WebFilter.Url>`
                
                .. attribute:: domain
                
                	UTD Domain based web\-filtering submode
                	**type**\:  :py:class:`Domain <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.UtdSt.Utd.WebFilter.Domain>`
                
                

                """

                _prefix = 'ios-utd'
                _revision = '2018-06-28'

                def __init__(self):
                    super(Native.UtdSt.Utd.WebFilter, self).__init__()

                    self.yang_name = "web-filter"
                    self.yang_parent_name = "utd"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("block", ("block", Native.UtdSt.Utd.WebFilter.Block)), ("sourcedb", ("sourcedb", Native.UtdSt.Utd.WebFilter.Sourcedb)), ("url", ("url", Native.UtdSt.Utd.WebFilter.Url)), ("domain", ("domain", Native.UtdSt.Utd.WebFilter.Domain))])
                    self._leafs = OrderedDict()

                    self.block = Native.UtdSt.Utd.WebFilter.Block()
                    self.block.parent = self
                    self._children_name_map["block"] = "block"

                    self.url = Native.UtdSt.Utd.WebFilter.Url()
                    self.url.parent = self
                    self._children_name_map["url"] = "url"

                    self.domain = Native.UtdSt.Utd.WebFilter.Domain()
                    self.domain.parent = self
                    self._children_name_map["domain"] = "domain"

                    self.sourcedb = YList(self)
                    self._segment_path = lambda: "web-filter"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/Cisco-IOS-XE-utd:utd-st/utd/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.UtdSt.Utd.WebFilter, [], name, value)


                class Block(Entity):
                    """
                    UTD block profile information
                    
                    .. attribute:: local_server
                    
                    	UTD local block server configuration profile
                    	**type**\:  :py:class:`LocalServer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.UtdSt.Utd.WebFilter.Block.LocalServer>`
                    
                    .. attribute:: page
                    
                    	UTD inline block page response profile
                    	**type**\:  :py:class:`Page <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.UtdSt.Utd.WebFilter.Block.Page>`
                    
                    

                    """

                    _prefix = 'ios-utd'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.UtdSt.Utd.WebFilter.Block, self).__init__()

                        self.yang_name = "block"
                        self.yang_parent_name = "web-filter"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("local-server", ("local_server", Native.UtdSt.Utd.WebFilter.Block.LocalServer)), ("page", ("page", Native.UtdSt.Utd.WebFilter.Block.Page))])
                        self._leafs = OrderedDict()

                        self.local_server = Native.UtdSt.Utd.WebFilter.Block.LocalServer()
                        self.local_server.parent = self
                        self._children_name_map["local_server"] = "local-server"

                        self.page = Native.UtdSt.Utd.WebFilter.Block.Page()
                        self.page.parent = self
                        self._children_name_map["page"] = "page"
                        self._segment_path = lambda: "block"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/Cisco-IOS-XE-utd:utd-st/utd/web-filter/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.UtdSt.Utd.WebFilter.Block, [], name, value)


                    class LocalServer(Entity):
                        """
                        UTD local block server configuration profile
                        
                        .. attribute:: profile
                        
                        	Provide the profile ID
                        	**type**\: list of  		 :py:class:`Profile <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.UtdSt.Utd.WebFilter.Block.LocalServer.Profile>`
                        
                        

                        """

                        _prefix = 'ios-utd'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.UtdSt.Utd.WebFilter.Block.LocalServer, self).__init__()

                            self.yang_name = "local-server"
                            self.yang_parent_name = "block"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("profile", ("profile", Native.UtdSt.Utd.WebFilter.Block.LocalServer.Profile))])
                            self._leafs = OrderedDict()

                            self.profile = YList(self)
                            self._segment_path = lambda: "local-server"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/Cisco-IOS-XE-utd:utd-st/utd/web-filter/block/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.UtdSt.Utd.WebFilter.Block.LocalServer, [], name, value)


                        class Profile(Entity):
                            """
                            Provide the profile ID
                            
                            .. attribute:: id  (key)
                            
                            	
                            	**type**\: str
                            
                            	**length:** 1..512
                            
                            .. attribute:: block_page_interface
                            
                            	Provide the interface to be used for the block server
                            	**type**\:  :py:class:`BlockPageInterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.UtdSt.Utd.WebFilter.Block.LocalServer.Profile.BlockPageInterface>`
                            
                            .. attribute:: content
                            
                            	Provide the content to be served from the server
                            	**type**\:  :py:class:`Content <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.UtdSt.Utd.WebFilter.Block.LocalServer.Profile.Content>`
                            
                            .. attribute:: http_ports
                            
                            	Provide the HTTP ports to be used
                            	**type**\: str
                            
                            	**length:** 1..100
                            
                            

                            """

                            _prefix = 'ios-utd'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.UtdSt.Utd.WebFilter.Block.LocalServer.Profile, self).__init__()

                                self.yang_name = "profile"
                                self.yang_parent_name = "local-server"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = ['id']
                                self._child_classes = OrderedDict([("block-page-interface", ("block_page_interface", Native.UtdSt.Utd.WebFilter.Block.LocalServer.Profile.BlockPageInterface)), ("content", ("content", Native.UtdSt.Utd.WebFilter.Block.LocalServer.Profile.Content))])
                                self._leafs = OrderedDict([
                                    ('id', (YLeaf(YType.str, 'id'), ['str'])),
                                    ('http_ports', (YLeaf(YType.str, 'http-ports'), ['str'])),
                                ])
                                self.id = None
                                self.http_ports = None

                                self.block_page_interface = Native.UtdSt.Utd.WebFilter.Block.LocalServer.Profile.BlockPageInterface()
                                self.block_page_interface.parent = self
                                self._children_name_map["block_page_interface"] = "block-page-interface"

                                self.content = Native.UtdSt.Utd.WebFilter.Block.LocalServer.Profile.Content()
                                self.content.parent = self
                                self._children_name_map["content"] = "content"
                                self._segment_path = lambda: "profile" + "[id='" + str(self.id) + "']"
                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/Cisco-IOS-XE-utd:utd-st/utd/web-filter/block/local-server/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.UtdSt.Utd.WebFilter.Block.LocalServer.Profile, ['id', 'http_ports'], name, value)


                            class BlockPageInterface(Entity):
                                """
                                Provide the interface to be used for the block server
                                
                                .. attribute:: loopback
                                
                                	Loopback interface
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'ios-utd'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.UtdSt.Utd.WebFilter.Block.LocalServer.Profile.BlockPageInterface, self).__init__()

                                    self.yang_name = "block-page-interface"
                                    self.yang_parent_name = "profile"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('loopback', (YLeaf(YType.uint32, 'Loopback'), ['int'])),
                                    ])
                                    self.loopback = None
                                    self._segment_path = lambda: "block-page-interface"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.UtdSt.Utd.WebFilter.Block.LocalServer.Profile.BlockPageInterface, ['loopback'], name, value)


                            class Content(Entity):
                                """
                                Provide the content to be served from the server
                                
                                .. attribute:: text
                                
                                	Provide the text to be printed in the web page served
                                	**type**\: str
                                
                                	**length:** 1..512
                                
                                .. attribute:: file
                                
                                	Provide the HTML file to be served
                                	**type**\: str
                                
                                	**length:** 1..512
                                
                                

                                """

                                _prefix = 'ios-utd'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.UtdSt.Utd.WebFilter.Block.LocalServer.Profile.Content, self).__init__()

                                    self.yang_name = "content"
                                    self.yang_parent_name = "profile"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('text', (YLeaf(YType.str, 'text'), ['str'])),
                                        ('file', (YLeaf(YType.str, 'file'), ['str'])),
                                    ])
                                    self.text = None
                                    self.file = None
                                    self._segment_path = lambda: "content"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.UtdSt.Utd.WebFilter.Block.LocalServer.Profile.Content, ['text', 'file'], name, value)


                    class Page(Entity):
                        """
                        UTD inline block page response profile
                        
                        .. attribute:: profile
                        
                        	Provide the profile ID
                        	**type**\: list of  		 :py:class:`Profile <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.UtdSt.Utd.WebFilter.Block.Page.Profile>`
                        
                        

                        """

                        _prefix = 'ios-utd'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.UtdSt.Utd.WebFilter.Block.Page, self).__init__()

                            self.yang_name = "page"
                            self.yang_parent_name = "block"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("profile", ("profile", Native.UtdSt.Utd.WebFilter.Block.Page.Profile))])
                            self._leafs = OrderedDict()

                            self.profile = YList(self)
                            self._segment_path = lambda: "page"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/Cisco-IOS-XE-utd:utd-st/utd/web-filter/block/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.UtdSt.Utd.WebFilter.Block.Page, [], name, value)


                        class Profile(Entity):
                            """
                            Provide the profile ID
                            
                            .. attribute:: id  (key)
                            
                            	
                            	**type**\: str
                            
                            	**length:** 1..512
                            
                            .. attribute:: file
                            
                            	Specify the file name to be used for the block page
                            	**type**\: str
                            
                            	**length:** 1..512
                            
                            .. attribute:: redirect_url
                            
                            	Specify the URL to be used for redirection
                            	**type**\: str
                            
                            	**length:** 1..512
                            
                            .. attribute:: text
                            
                            	Specify the text to be used to be sent back
                            	**type**\: str
                            
                            	**length:** 1..512
                            
                            

                            """

                            _prefix = 'ios-utd'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.UtdSt.Utd.WebFilter.Block.Page.Profile, self).__init__()

                                self.yang_name = "profile"
                                self.yang_parent_name = "page"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = ['id']
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('id', (YLeaf(YType.str, 'id'), ['str'])),
                                    ('file', (YLeaf(YType.str, 'file'), ['str'])),
                                    ('redirect_url', (YLeaf(YType.str, 'redirect-url'), ['str'])),
                                    ('text', (YLeaf(YType.str, 'text'), ['str'])),
                                ])
                                self.id = None
                                self.file = None
                                self.redirect_url = None
                                self.text = None
                                self._segment_path = lambda: "profile" + "[id='" + str(self.id) + "']"
                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/Cisco-IOS-XE-utd:utd-st/utd/web-filter/block/page/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.UtdSt.Utd.WebFilter.Block.Page.Profile, ['id', 'file', 'redirect_url', 'text'], name, value)


                class Sourcedb(Entity):
                    """
                    UTD Web filtering source DB configuration submode
                    
                    .. attribute:: id  (key)
                    
                    	
                    	**type**\: str
                    
                    	**length:** 1..512
                    
                    .. attribute:: logging
                    
                    	Provide source DB logging information
                    	**type**\:  :py:class:`Logging <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.UtdSt.Utd.WebFilter.Sourcedb.Logging>`
                    
                    

                    """

                    _prefix = 'ios-utd'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.UtdSt.Utd.WebFilter.Sourcedb, self).__init__()

                        self.yang_name = "sourcedb"
                        self.yang_parent_name = "web-filter"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = ['id']
                        self._child_classes = OrderedDict([("logging", ("logging", Native.UtdSt.Utd.WebFilter.Sourcedb.Logging))])
                        self._leafs = OrderedDict([
                            ('id', (YLeaf(YType.str, 'id'), ['str'])),
                        ])
                        self.id = None

                        self.logging = Native.UtdSt.Utd.WebFilter.Sourcedb.Logging()
                        self.logging.parent = self
                        self._children_name_map["logging"] = "logging"
                        self._segment_path = lambda: "sourcedb" + "[id='" + str(self.id) + "']"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/Cisco-IOS-XE-utd:utd-st/utd/web-filter/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.UtdSt.Utd.WebFilter.Sourcedb, ['id'], name, value)


                    class Logging(Entity):
                        """
                        Provide source DB logging information
                        
                        .. attribute:: level
                        
                        	Provide the logging level
                        	**type**\:  :py:class:`Level <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.UtdSt.Utd.WebFilter.Sourcedb.Logging.Level>`
                        
                        

                        """

                        _prefix = 'ios-utd'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.UtdSt.Utd.WebFilter.Sourcedb.Logging, self).__init__()

                            self.yang_name = "logging"
                            self.yang_parent_name = "sourcedb"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('level', (YLeaf(YType.enumeration, 'level'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'UtdSt.Utd.WebFilter.Sourcedb.Logging.Level')])),
                            ])
                            self.level = None
                            self._segment_path = lambda: "logging"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.UtdSt.Utd.WebFilter.Sourcedb.Logging, ['level'], name, value)

                        class Level(Enum):
                            """
                            Level (Enum Class)

                            Provide the logging level

                            .. data:: debug = 0

                            .. data:: error = 1

                            .. data:: info = 2

                            .. data:: trace = 3

                            .. data:: warning = 4

                            """

                            debug = Enum.YLeaf(0, "debug")

                            error = Enum.YLeaf(1, "error")

                            info = Enum.YLeaf(2, "info")

                            trace = Enum.YLeaf(3, "trace")

                            warning = Enum.YLeaf(4, "warning")



                class Url(Entity):
                    """
                    UTD URL based web\-filtering submode
                    
                    .. attribute:: profile
                    
                    	Provide the profile ID
                    	**type**\: list of  		 :py:class:`Profile <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.UtdSt.Utd.WebFilter.Url.Profile>`
                    
                    

                    """

                    _prefix = 'ios-utd'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.UtdSt.Utd.WebFilter.Url, self).__init__()

                        self.yang_name = "url"
                        self.yang_parent_name = "web-filter"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("profile", ("profile", Native.UtdSt.Utd.WebFilter.Url.Profile))])
                        self._leafs = OrderedDict()

                        self.profile = YList(self)
                        self._segment_path = lambda: "url"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/Cisco-IOS-XE-utd:utd-st/utd/web-filter/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.UtdSt.Utd.WebFilter.Url, [], name, value)


                    class Profile(Entity):
                        """
                        Provide the profile ID
                        
                        .. attribute:: id  (key)
                        
                        	
                        	**type**\: str
                        
                        	**length:** 1..512
                        
                        .. attribute:: alert
                        
                        	Provide the logging alert level
                        	**type**\: list of   :py:class:`Alert <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.UtdSt.Utd.WebFilter.Url.Profile.Alert>`
                        
                        .. attribute:: blacklist
                        
                        	Choose the blacklist parameter\-map
                        	**type**\:  :py:class:`Blacklist <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.UtdSt.Utd.WebFilter.Url.Profile.Blacklist>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: categories
                        
                        	Choose from a list of categories
                        	**type**\:  :py:class:`Categories <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.UtdSt.Utd.WebFilter.Url.Profile.Categories>`
                        
                        .. attribute:: block
                        
                        	Provide information on the block page/server to be used
                        	**type**\:  :py:class:`Block <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.UtdSt.Utd.WebFilter.Url.Profile.Block>`
                        
                        .. attribute:: log
                        
                        	Choose the URL filtering preprocessor debug log options
                        	**type**\:  :py:class:`Log <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.UtdSt.Utd.WebFilter.Url.Profile.Log>`
                        
                        .. attribute:: reputation
                        
                        	Choose the reputation range for the URLs to be blocked
                        	**type**\:  :py:class:`Reputation <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.UtdSt.Utd.WebFilter.Url.Profile.Reputation>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: sourcedb
                        
                        	Choose source DB related configs
                        	**type**\:  :py:class:`Sourcedb <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.UtdSt.Utd.WebFilter.Url.Profile.Sourcedb>`
                        
                        .. attribute:: whitelist
                        
                        	Choose the whitelist parameter\-map
                        	**type**\:  :py:class:`Whitelist <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.UtdSt.Utd.WebFilter.Url.Profile.Whitelist>`
                        
                        	**presence node**\: True
                        
                        

                        """

                        _prefix = 'ios-utd'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.UtdSt.Utd.WebFilter.Url.Profile, self).__init__()

                            self.yang_name = "profile"
                            self.yang_parent_name = "url"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = ['id']
                            self._child_classes = OrderedDict([("blacklist", ("blacklist", Native.UtdSt.Utd.WebFilter.Url.Profile.Blacklist)), ("categories", ("categories", Native.UtdSt.Utd.WebFilter.Url.Profile.Categories)), ("block", ("block", Native.UtdSt.Utd.WebFilter.Url.Profile.Block)), ("log", ("log", Native.UtdSt.Utd.WebFilter.Url.Profile.Log)), ("reputation", ("reputation", Native.UtdSt.Utd.WebFilter.Url.Profile.Reputation)), ("sourcedb", ("sourcedb", Native.UtdSt.Utd.WebFilter.Url.Profile.Sourcedb)), ("whitelist", ("whitelist", Native.UtdSt.Utd.WebFilter.Url.Profile.Whitelist))])
                            self._leafs = OrderedDict([
                                ('id', (YLeaf(YType.str, 'id'), ['str'])),
                                ('alert', (YLeafList(YType.enumeration, 'alert'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'UtdSt.Utd.WebFilter.Url.Profile.Alert')])),
                            ])
                            self.id = None
                            self.alert = []

                            self.blacklist = None
                            self._children_name_map["blacklist"] = "blacklist"

                            self.categories = Native.UtdSt.Utd.WebFilter.Url.Profile.Categories()
                            self.categories.parent = self
                            self._children_name_map["categories"] = "categories"

                            self.block = Native.UtdSt.Utd.WebFilter.Url.Profile.Block()
                            self.block.parent = self
                            self._children_name_map["block"] = "block"

                            self.log = Native.UtdSt.Utd.WebFilter.Url.Profile.Log()
                            self.log.parent = self
                            self._children_name_map["log"] = "log"

                            self.reputation = None
                            self._children_name_map["reputation"] = "reputation"

                            self.sourcedb = Native.UtdSt.Utd.WebFilter.Url.Profile.Sourcedb()
                            self.sourcedb.parent = self
                            self._children_name_map["sourcedb"] = "sourcedb"

                            self.whitelist = None
                            self._children_name_map["whitelist"] = "whitelist"
                            self._segment_path = lambda: "profile" + "[id='" + str(self.id) + "']"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/Cisco-IOS-XE-utd:utd-st/utd/web-filter/url/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.UtdSt.Utd.WebFilter.Url.Profile, ['id', 'alert'], name, value)

                        class Alert(Enum):
                            """
                            Alert (Enum Class)

                            Provide the logging alert level

                            .. data:: all = 0

                            .. data:: blacklist = 1

                            .. data:: categories_reputation = 2

                            .. data:: whitelist = 3

                            """

                            all = Enum.YLeaf(0, "all")

                            blacklist = Enum.YLeaf(1, "blacklist")

                            categories_reputation = Enum.YLeaf(2, "categories-reputation")

                            whitelist = Enum.YLeaf(3, "whitelist")



                        class Blacklist(Entity):
                            """
                            Choose the blacklist parameter\-map
                            
                            .. attribute:: parameter_map
                            
                            	Enter the parameter\-map information for the regex
                            	**type**\:  :py:class:`ParameterMap <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.UtdSt.Utd.WebFilter.Url.Profile.Blacklist.ParameterMap>`
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-utd'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.UtdSt.Utd.WebFilter.Url.Profile.Blacklist, self).__init__()

                                self.yang_name = "blacklist"
                                self.yang_parent_name = "profile"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("parameter-map", ("parameter_map", Native.UtdSt.Utd.WebFilter.Url.Profile.Blacklist.ParameterMap))])
                                self.is_presence_container = True
                                self._leafs = OrderedDict()

                                self.parameter_map = Native.UtdSt.Utd.WebFilter.Url.Profile.Blacklist.ParameterMap()
                                self.parameter_map.parent = self
                                self._children_name_map["parameter_map"] = "parameter-map"
                                self._segment_path = lambda: "blacklist"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.UtdSt.Utd.WebFilter.Url.Profile.Blacklist, [], name, value)


                            class ParameterMap(Entity):
                                """
                                Enter the parameter\-map information for the regex
                                
                                .. attribute:: regex
                                
                                	Provide the regex parameter\-map name
                                	**type**\: str
                                
                                	**length:** 1..256
                                
                                

                                """

                                _prefix = 'ios-utd'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.UtdSt.Utd.WebFilter.Url.Profile.Blacklist.ParameterMap, self).__init__()

                                    self.yang_name = "parameter-map"
                                    self.yang_parent_name = "blacklist"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('regex', (YLeaf(YType.str, 'regex'), ['str'])),
                                    ])
                                    self.regex = None
                                    self._segment_path = lambda: "parameter-map"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.UtdSt.Utd.WebFilter.Url.Profile.Blacklist.ParameterMap, ['regex'], name, value)


                        class Categories(Entity):
                            """
                            Choose from a list of categories
                            
                            .. attribute:: allow
                            
                            	Choose the list of categories to be allowed
                            	**type**\:  :py:class:`Allow <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.UtdSt.Utd.WebFilter.Url.Profile.Categories.Allow>`
                            
                            	**presence node**\: True
                            
                            .. attribute:: block
                            
                            	Choose the list of categories to be blocked
                            	**type**\:  :py:class:`Block <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.UtdSt.Utd.WebFilter.Url.Profile.Categories.Block>`
                            
                            	**presence node**\: True
                            
                            

                            """

                            _prefix = 'ios-utd'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.UtdSt.Utd.WebFilter.Url.Profile.Categories, self).__init__()

                                self.yang_name = "categories"
                                self.yang_parent_name = "profile"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("allow", ("allow", Native.UtdSt.Utd.WebFilter.Url.Profile.Categories.Allow)), ("block", ("block", Native.UtdSt.Utd.WebFilter.Url.Profile.Categories.Block))])
                                self._leafs = OrderedDict()

                                self.allow = None
                                self._children_name_map["allow"] = "allow"

                                self.block = None
                                self._children_name_map["block"] = "block"
                                self._segment_path = lambda: "categories"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.UtdSt.Utd.WebFilter.Url.Profile.Categories, [], name, value)


                            class Allow(Entity):
                                """
                                Choose the list of categories to be allowed
                                
                                .. attribute:: category
                                
                                	
                                	**type**\: list of  		 :py:class:`Category <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.UtdSt.Utd.WebFilter.Url.Profile.Categories.Allow.Category>`
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-utd'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.UtdSt.Utd.WebFilter.Url.Profile.Categories.Allow, self).__init__()

                                    self.yang_name = "allow"
                                    self.yang_parent_name = "categories"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("category", ("category", Native.UtdSt.Utd.WebFilter.Url.Profile.Categories.Allow.Category))])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict()

                                    self.category = YList(self)
                                    self._segment_path = lambda: "allow"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.UtdSt.Utd.WebFilter.Url.Profile.Categories.Allow, [], name, value)


                                class Category(Entity):
                                    """
                                    
                                    
                                    .. attribute:: name  (key)
                                    
                                    	
                                    	**type**\:  :py:class:`UtdCategoryType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_utd.UtdCategoryType>`
                                    
                                    

                                    """

                                    _prefix = 'ios-utd'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.UtdSt.Utd.WebFilter.Url.Profile.Categories.Allow.Category, self).__init__()

                                        self.yang_name = "category"
                                        self.yang_parent_name = "allow"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = ['name']
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('name', (YLeaf(YType.enumeration, 'name'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_utd', 'UtdCategoryType', '')])),
                                        ])
                                        self.name = None
                                        self._segment_path = lambda: "category" + "[name='" + str(self.name) + "']"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.UtdSt.Utd.WebFilter.Url.Profile.Categories.Allow.Category, ['name'], name, value)


                            class Block(Entity):
                                """
                                Choose the list of categories to be blocked
                                
                                .. attribute:: category
                                
                                	
                                	**type**\: list of  		 :py:class:`Category <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.UtdSt.Utd.WebFilter.Url.Profile.Categories.Block.Category>`
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-utd'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.UtdSt.Utd.WebFilter.Url.Profile.Categories.Block, self).__init__()

                                    self.yang_name = "block"
                                    self.yang_parent_name = "categories"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("category", ("category", Native.UtdSt.Utd.WebFilter.Url.Profile.Categories.Block.Category))])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict()

                                    self.category = YList(self)
                                    self._segment_path = lambda: "block"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.UtdSt.Utd.WebFilter.Url.Profile.Categories.Block, [], name, value)


                                class Category(Entity):
                                    """
                                    
                                    
                                    .. attribute:: name  (key)
                                    
                                    	
                                    	**type**\:  :py:class:`UtdCategoryType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_utd.UtdCategoryType>`
                                    
                                    

                                    """

                                    _prefix = 'ios-utd'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.UtdSt.Utd.WebFilter.Url.Profile.Categories.Block.Category, self).__init__()

                                        self.yang_name = "category"
                                        self.yang_parent_name = "block"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = ['name']
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('name', (YLeaf(YType.enumeration, 'name'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_utd', 'UtdCategoryType', '')])),
                                        ])
                                        self.name = None
                                        self._segment_path = lambda: "category" + "[name='" + str(self.name) + "']"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.UtdSt.Utd.WebFilter.Url.Profile.Categories.Block.Category, ['name'], name, value)


                        class Block(Entity):
                            """
                            Provide information on the block page/server to be used
                            
                            .. attribute:: local_server
                            
                            	Provide the local block server profile ID
                            	**type**\: str
                            
                            	**length:** 1..512
                            
                            .. attribute:: page_profile
                            
                            	Provide the ID of the block page profile to be used
                            	**type**\: str
                            
                            	**length:** 1..512
                            
                            

                            """

                            _prefix = 'ios-utd'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.UtdSt.Utd.WebFilter.Url.Profile.Block, self).__init__()

                                self.yang_name = "block"
                                self.yang_parent_name = "profile"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('local_server', (YLeaf(YType.str, 'local-server'), ['str'])),
                                    ('page_profile', (YLeaf(YType.str, 'page-profile'), ['str'])),
                                ])
                                self.local_server = None
                                self.page_profile = None
                                self._segment_path = lambda: "block"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.UtdSt.Utd.WebFilter.Url.Profile.Block, ['local_server', 'page_profile'], name, value)


                        class Log(Entity):
                            """
                            Choose the URL filtering preprocessor debug log options
                            
                            .. attribute:: level
                            
                            	Choose the URL filtering preprocessor log level
                            	**type**\:  :py:class:`Level <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.UtdSt.Utd.WebFilter.Url.Profile.Log.Level>`
                            
                            

                            """

                            _prefix = 'ios-utd'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.UtdSt.Utd.WebFilter.Url.Profile.Log, self).__init__()

                                self.yang_name = "log"
                                self.yang_parent_name = "profile"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('level', (YLeaf(YType.enumeration, 'level'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'UtdSt.Utd.WebFilter.Url.Profile.Log.Level')])),
                                ])
                                self.level = None
                                self._segment_path = lambda: "log"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.UtdSt.Utd.WebFilter.Url.Profile.Log, ['level'], name, value)

                            class Level(Enum):
                                """
                                Level (Enum Class)

                                Choose the URL filtering preprocessor log level

                                .. data:: detailed = 0

                                .. data:: error = 1

                                .. data:: info = 2

                                """

                                detailed = Enum.YLeaf(0, "detailed")

                                error = Enum.YLeaf(1, "error")

                                info = Enum.YLeaf(2, "info")



                        class Reputation(Entity):
                            """
                            Choose the reputation range for the URLs to be blocked
                            
                            .. attribute:: block_threshold
                            
                            	Block the URLs with reputation at or above the specified level
                            	**type**\:  :py:class:`BlockThreshold <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.UtdSt.Utd.WebFilter.Url.Profile.Reputation.BlockThreshold>`
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-utd'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.UtdSt.Utd.WebFilter.Url.Profile.Reputation, self).__init__()

                                self.yang_name = "reputation"
                                self.yang_parent_name = "profile"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('block_threshold', (YLeaf(YType.enumeration, 'block-threshold'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'UtdSt.Utd.WebFilter.Url.Profile.Reputation.BlockThreshold')])),
                                ])
                                self.block_threshold = None
                                self._segment_path = lambda: "reputation"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.UtdSt.Utd.WebFilter.Url.Profile.Reputation, ['block_threshold'], name, value)

                            class BlockThreshold(Enum):
                                """
                                BlockThreshold (Enum Class)

                                Block the URLs with reputation at or above the specified level

                                .. data:: high_risk = 0

                                .. data:: low_risk = 1

                                .. data:: moderate_risk = 2

                                .. data:: suspicious = 3

                                .. data:: trustworthy = 4

                                """

                                high_risk = Enum.YLeaf(0, "high-risk")

                                low_risk = Enum.YLeaf(1, "low-risk")

                                moderate_risk = Enum.YLeaf(2, "moderate-risk")

                                suspicious = Enum.YLeaf(3, "suspicious")

                                trustworthy = Enum.YLeaf(4, "trustworthy")



                        class Sourcedb(Entity):
                            """
                            Choose source DB related configs
                            
                            .. attribute:: fail
                            
                            	Choose the fail option to apply when the source DB is down
                            	**type**\:  :py:class:`Fail <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.UtdSt.Utd.WebFilter.Url.Profile.Sourcedb.Fail>`
                            
                            

                            """

                            _prefix = 'ios-utd'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.UtdSt.Utd.WebFilter.Url.Profile.Sourcedb, self).__init__()

                                self.yang_name = "sourcedb"
                                self.yang_parent_name = "profile"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("fail", ("fail", Native.UtdSt.Utd.WebFilter.Url.Profile.Sourcedb.Fail))])
                                self._leafs = OrderedDict()

                                self.fail = Native.UtdSt.Utd.WebFilter.Url.Profile.Sourcedb.Fail()
                                self.fail.parent = self
                                self._children_name_map["fail"] = "fail"
                                self._segment_path = lambda: "sourcedb"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.UtdSt.Utd.WebFilter.Url.Profile.Sourcedb, [], name, value)


                            class Fail(Entity):
                                """
                                Choose the fail option to apply when the source DB is down
                                
                                .. attribute:: close
                                
                                	Drop all URL filtering traffic on source DB failure
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                """

                                _prefix = 'ios-utd'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.UtdSt.Utd.WebFilter.Url.Profile.Sourcedb.Fail, self).__init__()

                                    self.yang_name = "fail"
                                    self.yang_parent_name = "sourcedb"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('close', (YLeaf(YType.empty, 'close'), ['Empty'])),
                                    ])
                                    self.close = None
                                    self._segment_path = lambda: "fail"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.UtdSt.Utd.WebFilter.Url.Profile.Sourcedb.Fail, ['close'], name, value)


                        class Whitelist(Entity):
                            """
                            Choose the whitelist parameter\-map
                            
                            .. attribute:: parameter_map
                            
                            	Enter the parameter\-map information for the regex
                            	**type**\:  :py:class:`ParameterMap <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.UtdSt.Utd.WebFilter.Url.Profile.Whitelist.ParameterMap>`
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-utd'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.UtdSt.Utd.WebFilter.Url.Profile.Whitelist, self).__init__()

                                self.yang_name = "whitelist"
                                self.yang_parent_name = "profile"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("parameter-map", ("parameter_map", Native.UtdSt.Utd.WebFilter.Url.Profile.Whitelist.ParameterMap))])
                                self.is_presence_container = True
                                self._leafs = OrderedDict()

                                self.parameter_map = Native.UtdSt.Utd.WebFilter.Url.Profile.Whitelist.ParameterMap()
                                self.parameter_map.parent = self
                                self._children_name_map["parameter_map"] = "parameter-map"
                                self._segment_path = lambda: "whitelist"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.UtdSt.Utd.WebFilter.Url.Profile.Whitelist, [], name, value)


                            class ParameterMap(Entity):
                                """
                                Enter the parameter\-map information for the regex
                                
                                .. attribute:: regex
                                
                                	Provide the regex parameter\-map name
                                	**type**\: str
                                
                                	**length:** 1..256
                                
                                

                                """

                                _prefix = 'ios-utd'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.UtdSt.Utd.WebFilter.Url.Profile.Whitelist.ParameterMap, self).__init__()

                                    self.yang_name = "parameter-map"
                                    self.yang_parent_name = "whitelist"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('regex', (YLeaf(YType.str, 'regex'), ['str'])),
                                    ])
                                    self.regex = None
                                    self._segment_path = lambda: "parameter-map"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.UtdSt.Utd.WebFilter.Url.Profile.Whitelist.ParameterMap, ['regex'], name, value)


                class Domain(Entity):
                    """
                    UTD Domain based web\-filtering submode
                    
                    .. attribute:: profile
                    
                    	Provide the profile ID
                    	**type**\: list of  		 :py:class:`Profile <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.UtdSt.Utd.WebFilter.Domain.Profile>`
                    
                    

                    """

                    _prefix = 'ios-utd'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.UtdSt.Utd.WebFilter.Domain, self).__init__()

                        self.yang_name = "domain"
                        self.yang_parent_name = "web-filter"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("profile", ("profile", Native.UtdSt.Utd.WebFilter.Domain.Profile))])
                        self._leafs = OrderedDict()

                        self.profile = YList(self)
                        self._segment_path = lambda: "domain"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/Cisco-IOS-XE-utd:utd-st/utd/web-filter/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.UtdSt.Utd.WebFilter.Domain, [], name, value)


                    class Profile(Entity):
                        """
                        Provide the profile ID
                        
                        .. attribute:: id  (key)
                        
                        	
                        	**type**\: str
                        
                        	**length:** 1..512
                        
                        .. attribute:: alert
                        
                        	Provide the logging alert level
                        	**type**\:  :py:class:`Alert <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.UtdSt.Utd.WebFilter.Domain.Profile.Alert>`
                        
                        .. attribute:: blacklist
                        
                        	Choose the blacklist parameter\-map
                        	**type**\:  :py:class:`Blacklist <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.UtdSt.Utd.WebFilter.Domain.Profile.Blacklist>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: redirect_server
                        
                        	Provide the IP address for the redirect server for blocked domains
                        	**type**\:  :py:class:`RedirectServer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.UtdSt.Utd.WebFilter.Domain.Profile.RedirectServer>`
                        
                        .. attribute:: whitelist
                        
                        	Choose the whitelist parameter\-map
                        	**type**\:  :py:class:`Whitelist <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.UtdSt.Utd.WebFilter.Domain.Profile.Whitelist>`
                        
                        	**presence node**\: True
                        
                        

                        """

                        _prefix = 'ios-utd'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.UtdSt.Utd.WebFilter.Domain.Profile, self).__init__()

                            self.yang_name = "profile"
                            self.yang_parent_name = "domain"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = ['id']
                            self._child_classes = OrderedDict([("blacklist", ("blacklist", Native.UtdSt.Utd.WebFilter.Domain.Profile.Blacklist)), ("redirect-server", ("redirect_server", Native.UtdSt.Utd.WebFilter.Domain.Profile.RedirectServer)), ("whitelist", ("whitelist", Native.UtdSt.Utd.WebFilter.Domain.Profile.Whitelist))])
                            self._leafs = OrderedDict([
                                ('id', (YLeaf(YType.str, 'id'), ['str'])),
                                ('alert', (YLeaf(YType.enumeration, 'alert'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'UtdSt.Utd.WebFilter.Domain.Profile.Alert')])),
                            ])
                            self.id = None
                            self.alert = None

                            self.blacklist = None
                            self._children_name_map["blacklist"] = "blacklist"

                            self.redirect_server = Native.UtdSt.Utd.WebFilter.Domain.Profile.RedirectServer()
                            self.redirect_server.parent = self
                            self._children_name_map["redirect_server"] = "redirect-server"

                            self.whitelist = None
                            self._children_name_map["whitelist"] = "whitelist"
                            self._segment_path = lambda: "profile" + "[id='" + str(self.id) + "']"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/Cisco-IOS-XE-utd:utd-st/utd/web-filter/domain/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.UtdSt.Utd.WebFilter.Domain.Profile, ['id', 'alert'], name, value)

                        class Alert(Enum):
                            """
                            Alert (Enum Class)

                            Provide the logging alert level

                            .. data:: all = 0

                            .. data:: blacklist = 1

                            .. data:: whitelist = 2

                            """

                            all = Enum.YLeaf(0, "all")

                            blacklist = Enum.YLeaf(1, "blacklist")

                            whitelist = Enum.YLeaf(2, "whitelist")



                        class Blacklist(Entity):
                            """
                            Choose the blacklist parameter\-map
                            
                            .. attribute:: parameter_map
                            
                            	Enter the parameter\-map information for the regex
                            	**type**\:  :py:class:`ParameterMap <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.UtdSt.Utd.WebFilter.Domain.Profile.Blacklist.ParameterMap>`
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-utd'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.UtdSt.Utd.WebFilter.Domain.Profile.Blacklist, self).__init__()

                                self.yang_name = "blacklist"
                                self.yang_parent_name = "profile"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("parameter-map", ("parameter_map", Native.UtdSt.Utd.WebFilter.Domain.Profile.Blacklist.ParameterMap))])
                                self.is_presence_container = True
                                self._leafs = OrderedDict()

                                self.parameter_map = Native.UtdSt.Utd.WebFilter.Domain.Profile.Blacklist.ParameterMap()
                                self.parameter_map.parent = self
                                self._children_name_map["parameter_map"] = "parameter-map"
                                self._segment_path = lambda: "blacklist"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.UtdSt.Utd.WebFilter.Domain.Profile.Blacklist, [], name, value)


                            class ParameterMap(Entity):
                                """
                                Enter the parameter\-map information for the regex
                                
                                .. attribute:: regex
                                
                                	Provide the regex parameter\-map name
                                	**type**\: str
                                
                                	**length:** 1..256
                                
                                

                                """

                                _prefix = 'ios-utd'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.UtdSt.Utd.WebFilter.Domain.Profile.Blacklist.ParameterMap, self).__init__()

                                    self.yang_name = "parameter-map"
                                    self.yang_parent_name = "blacklist"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('regex', (YLeaf(YType.str, 'regex'), ['str'])),
                                    ])
                                    self.regex = None
                                    self._segment_path = lambda: "parameter-map"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.UtdSt.Utd.WebFilter.Domain.Profile.Blacklist.ParameterMap, ['regex'], name, value)


                        class RedirectServer(Entity):
                            """
                            Provide the IP address for the redirect server for blocked domains
                            
                            .. attribute:: external
                            
                            	Provide data about the external redirect server
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: local_block_server
                            
                            	Use the local block server as the redirect server
                            	**type**\: str
                            
                            	**length:** 1..512
                            
                            

                            """

                            _prefix = 'ios-utd'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.UtdSt.Utd.WebFilter.Domain.Profile.RedirectServer, self).__init__()

                                self.yang_name = "redirect-server"
                                self.yang_parent_name = "profile"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('external', (YLeaf(YType.str, 'external'), ['str'])),
                                    ('local_block_server', (YLeaf(YType.str, 'local-block-server'), ['str'])),
                                ])
                                self.external = None
                                self.local_block_server = None
                                self._segment_path = lambda: "redirect-server"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.UtdSt.Utd.WebFilter.Domain.Profile.RedirectServer, ['external', 'local_block_server'], name, value)


                        class Whitelist(Entity):
                            """
                            Choose the whitelist parameter\-map
                            
                            .. attribute:: parameter_map
                            
                            	Enter the parameter\-map information for the regex
                            	**type**\:  :py:class:`ParameterMap <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.UtdSt.Utd.WebFilter.Domain.Profile.Whitelist.ParameterMap>`
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-utd'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.UtdSt.Utd.WebFilter.Domain.Profile.Whitelist, self).__init__()

                                self.yang_name = "whitelist"
                                self.yang_parent_name = "profile"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("parameter-map", ("parameter_map", Native.UtdSt.Utd.WebFilter.Domain.Profile.Whitelist.ParameterMap))])
                                self.is_presence_container = True
                                self._leafs = OrderedDict()

                                self.parameter_map = Native.UtdSt.Utd.WebFilter.Domain.Profile.Whitelist.ParameterMap()
                                self.parameter_map.parent = self
                                self._children_name_map["parameter_map"] = "parameter-map"
                                self._segment_path = lambda: "whitelist"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.UtdSt.Utd.WebFilter.Domain.Profile.Whitelist, [], name, value)


                            class ParameterMap(Entity):
                                """
                                Enter the parameter\-map information for the regex
                                
                                .. attribute:: regex
                                
                                	Provide the regex parameter\-map name
                                	**type**\: str
                                
                                	**length:** 1..256
                                
                                

                                """

                                _prefix = 'ios-utd'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.UtdSt.Utd.WebFilter.Domain.Profile.Whitelist.ParameterMap, self).__init__()

                                    self.yang_name = "parameter-map"
                                    self.yang_parent_name = "whitelist"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('regex', (YLeaf(YType.str, 'regex'), ['str'])),
                                    ])
                                    self.regex = None
                                    self._segment_path = lambda: "parameter-map"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.UtdSt.Utd.WebFilter.Domain.Profile.Whitelist.ParameterMap, ['regex'], name, value)


            class Engine(Entity):
                """
                UTD engine
                
                .. attribute:: advanced
                
                	UTD engine advanced
                	**type**\:  :py:class:`Advanced <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.UtdSt.Utd.Engine.Advanced>`
                
                	**presence node**\: True
                
                .. attribute:: standard
                
                	UTD engine standard
                	**type**\:  :py:class:`Standard <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.UtdSt.Utd.Engine.Standard>`
                
                	**presence node**\: True
                
                

                """

                _prefix = 'ios-utd'
                _revision = '2018-06-28'

                def __init__(self):
                    super(Native.UtdSt.Utd.Engine, self).__init__()

                    self.yang_name = "engine"
                    self.yang_parent_name = "utd"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("advanced", ("advanced", Native.UtdSt.Utd.Engine.Advanced)), ("standard", ("standard", Native.UtdSt.Utd.Engine.Standard))])
                    self._leafs = OrderedDict()

                    self.advanced = None
                    self._children_name_map["advanced"] = "advanced"

                    self.standard = None
                    self._children_name_map["standard"] = "standard"
                    self._segment_path = lambda: "engine"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/Cisco-IOS-XE-utd:utd-st/utd/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.UtdSt.Utd.Engine, [], name, value)


                class Advanced(Entity):
                    """
                    UTD engine advanced
                    
                    .. attribute:: threat
                    
                    	Provide threat detection
                    	**type**\:  :py:class:`Threat <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.UtdSt.Utd.Engine.Advanced.Threat>`
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios-utd'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.UtdSt.Utd.Engine.Advanced, self).__init__()

                        self.yang_name = "advanced"
                        self.yang_parent_name = "engine"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("threat", ("threat", Native.UtdSt.Utd.Engine.Advanced.Threat))])
                        self.is_presence_container = True
                        self._leafs = OrderedDict()

                        self.threat = Native.UtdSt.Utd.Engine.Advanced.Threat()
                        self.threat.parent = self
                        self._children_name_map["threat"] = "threat"
                        self._segment_path = lambda: "advanced"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/Cisco-IOS-XE-utd:utd-st/utd/engine/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.UtdSt.Utd.Engine.Advanced, [], name, value)


                    class Threat(Entity):
                        """
                        Provide threat detection
                        
                        .. attribute:: detection
                        
                        	Provide threat detection
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-utd'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.UtdSt.Utd.Engine.Advanced.Threat, self).__init__()

                            self.yang_name = "threat"
                            self.yang_parent_name = "advanced"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('detection', (YLeaf(YType.empty, 'detection'), ['Empty'])),
                            ])
                            self.detection = None
                            self._segment_path = lambda: "threat"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/Cisco-IOS-XE-utd:utd-st/utd/engine/advanced/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.UtdSt.Utd.Engine.Advanced.Threat, ['detection'], name, value)


                class Standard(Entity):
                    """
                    UTD engine standard
                    
                    .. attribute:: logging
                    
                    	Provide config options for logging the alerts
                    	**type**\:  :py:class:`Logging <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.UtdSt.Utd.Engine.Standard.Logging>`
                    
                    .. attribute:: threat_inspection
                    
                    	IPS (or IDS) specific config commands
                    	**type**\:  :py:class:`ThreatInspection <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.UtdSt.Utd.Engine.Standard.ThreatInspection>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: web_filter
                    
                    	UTD engine standard web\-filtering configs
                    	**type**\:  :py:class:`WebFilter <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.UtdSt.Utd.Engine.Standard.WebFilter>`
                    
                    	**presence node**\: True
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios-utd'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.UtdSt.Utd.Engine.Standard, self).__init__()

                        self.yang_name = "standard"
                        self.yang_parent_name = "engine"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("logging", ("logging", Native.UtdSt.Utd.Engine.Standard.Logging)), ("threat-inspection", ("threat_inspection", Native.UtdSt.Utd.Engine.Standard.ThreatInspection)), ("web-filter", ("web_filter", Native.UtdSt.Utd.Engine.Standard.WebFilter))])
                        self.is_presence_container = True
                        self._leafs = OrderedDict()

                        self.logging = Native.UtdSt.Utd.Engine.Standard.Logging()
                        self.logging.parent = self
                        self._children_name_map["logging"] = "logging"

                        self.threat_inspection = None
                        self._children_name_map["threat_inspection"] = "threat-inspection"

                        self.web_filter = None
                        self._children_name_map["web_filter"] = "web-filter"
                        self._segment_path = lambda: "standard"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/Cisco-IOS-XE-utd:utd-st/utd/engine/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.UtdSt.Utd.Engine.Standard, [], name, value)


                    class Logging(Entity):
                        """
                        Provide config options for logging the alerts
                        
                        .. attribute:: host
                        
                        	Log the alerts to a host
                        	**type**\: list of  		 :py:class:`Host <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.UtdSt.Utd.Engine.Standard.Logging.Host>`
                        
                        .. attribute:: syslog
                        
                        	Log the alerts to IOS syslogs
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'ios-utd'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.UtdSt.Utd.Engine.Standard.Logging, self).__init__()

                            self.yang_name = "logging"
                            self.yang_parent_name = "standard"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("host", ("host", Native.UtdSt.Utd.Engine.Standard.Logging.Host))])
                            self._leafs = OrderedDict([
                                ('syslog', (YLeaf(YType.empty, 'syslog'), ['Empty'])),
                            ])
                            self.syslog = None

                            self.host = YList(self)
                            self._segment_path = lambda: "logging"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/Cisco-IOS-XE-utd:utd-st/utd/engine/standard/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.UtdSt.Utd.Engine.Standard.Logging, ['syslog'], name, value)


                        class Host(Entity):
                            """
                            Log the alerts to a host
                            
                            .. attribute:: name  (key)
                            
                            	
                            	**type**\: str
                            
                            	**length:** 1..45
                            
                            

                            """

                            _prefix = 'ios-utd'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.UtdSt.Utd.Engine.Standard.Logging.Host, self).__init__()

                                self.yang_name = "host"
                                self.yang_parent_name = "logging"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = ['name']
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                ])
                                self.name = None
                                self._segment_path = lambda: "host" + "[name='" + str(self.name) + "']"
                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/Cisco-IOS-XE-utd:utd-st/utd/engine/standard/logging/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.UtdSt.Utd.Engine.Standard.Logging.Host, ['name'], name, value)


                    class ThreatInspection(Entity):
                        """
                        IPS (or IDS) specific config commands
                        
                        .. attribute:: signature
                        
                        	Provide config options for the signatures
                        	**type**\:  :py:class:`Signature <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.UtdSt.Utd.Engine.Standard.ThreatInspection.Signature>`
                        
                        .. attribute:: threat
                        
                        	Provide the threat detection/protection option (default=detection)
                        	**type**\:  :py:class:`Threat <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.UtdSt.Utd.Engine.Standard.ThreatInspection.Threat>`
                        
                        .. attribute:: policy
                        
                        	Provide the policy option (default=balanced)
                        	**type**\:  :py:class:`Policy <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.UtdSt.Utd.Engine.Standard.ThreatInspection.Policy>`
                        
                        .. attribute:: logging
                        
                        	Provide logging level for the alerts for IPS/IDS
                        	**type**\:  :py:class:`Logging <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.UtdSt.Utd.Engine.Standard.ThreatInspection.Logging>`
                        
                        .. attribute:: whitelist
                        
                        	Enable whitelisting under the utd engine
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-utd'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.UtdSt.Utd.Engine.Standard.ThreatInspection, self).__init__()

                            self.yang_name = "threat-inspection"
                            self.yang_parent_name = "standard"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("signature", ("signature", Native.UtdSt.Utd.Engine.Standard.ThreatInspection.Signature)), ("logging", ("logging", Native.UtdSt.Utd.Engine.Standard.ThreatInspection.Logging))])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('threat', (YLeaf(YType.enumeration, 'threat'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'UtdSt.Utd.Engine.Standard.ThreatInspection.Threat')])),
                                ('policy', (YLeaf(YType.enumeration, 'policy'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'UtdSt.Utd.Engine.Standard.ThreatInspection.Policy')])),
                                ('whitelist', (YLeaf(YType.empty, 'whitelist'), ['Empty'])),
                            ])
                            self.threat = None
                            self.policy = None
                            self.whitelist = None

                            self.signature = Native.UtdSt.Utd.Engine.Standard.ThreatInspection.Signature()
                            self.signature.parent = self
                            self._children_name_map["signature"] = "signature"

                            self.logging = Native.UtdSt.Utd.Engine.Standard.ThreatInspection.Logging()
                            self.logging.parent = self
                            self._children_name_map["logging"] = "logging"
                            self._segment_path = lambda: "threat-inspection"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/Cisco-IOS-XE-utd:utd-st/utd/engine/standard/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.UtdSt.Utd.Engine.Standard.ThreatInspection, ['threat', 'policy', 'whitelist'], name, value)

                        class Policy(Enum):
                            """
                            Policy (Enum Class)

                            Provide the policy option (default=balanced)

                            .. data:: balanced = 0

                            .. data:: connectivity = 1

                            .. data:: security = 2

                            """

                            balanced = Enum.YLeaf(0, "balanced")

                            connectivity = Enum.YLeaf(1, "connectivity")

                            security = Enum.YLeaf(2, "security")


                        class Threat(Enum):
                            """
                            Threat (Enum Class)

                            Provide the threat detection/protection option (default=detection)

                            .. data:: detection = 0

                            .. data:: protection = 1

                            """

                            detection = Enum.YLeaf(0, "detection")

                            protection = Enum.YLeaf(1, "protection")



                        class Signature(Entity):
                            """
                            Provide config options for the signatures
                            
                            .. attribute:: update
                            
                            	Provide config options for the signature updates
                            	**type**\:  :py:class:`Update <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.UtdSt.Utd.Engine.Standard.ThreatInspection.Signature.Update>`
                            
                            

                            """

                            _prefix = 'ios-utd'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.UtdSt.Utd.Engine.Standard.ThreatInspection.Signature, self).__init__()

                                self.yang_name = "signature"
                                self.yang_parent_name = "threat-inspection"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("update", ("update", Native.UtdSt.Utd.Engine.Standard.ThreatInspection.Signature.Update))])
                                self._leafs = OrderedDict()

                                self.update = Native.UtdSt.Utd.Engine.Standard.ThreatInspection.Signature.Update()
                                self.update.parent = self
                                self._children_name_map["update"] = "update"
                                self._segment_path = lambda: "signature"
                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/Cisco-IOS-XE-utd:utd-st/utd/engine/standard/threat-inspection/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.UtdSt.Utd.Engine.Standard.ThreatInspection.Signature, [], name, value)


                            class Update(Entity):
                                """
                                Provide config options for the signature updates
                                
                                .. attribute:: occur_at
                                
                                	Specify update occurence by calendar time
                                	**type**\:  :py:class:`OccurAt <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.UtdSt.Utd.Engine.Standard.ThreatInspection.Signature.Update.OccurAt>`
                                
                                .. attribute:: server
                                
                                	Provide config options for the signature update server
                                	**type**\:  :py:class:`Server <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.UtdSt.Utd.Engine.Standard.ThreatInspection.Signature.Update.Server>`
                                
                                

                                """

                                _prefix = 'ios-utd'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.UtdSt.Utd.Engine.Standard.ThreatInspection.Signature.Update, self).__init__()

                                    self.yang_name = "update"
                                    self.yang_parent_name = "signature"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("occur-at", ("occur_at", Native.UtdSt.Utd.Engine.Standard.ThreatInspection.Signature.Update.OccurAt)), ("server", ("server", Native.UtdSt.Utd.Engine.Standard.ThreatInspection.Signature.Update.Server))])
                                    self._leafs = OrderedDict()

                                    self.occur_at = Native.UtdSt.Utd.Engine.Standard.ThreatInspection.Signature.Update.OccurAt()
                                    self.occur_at.parent = self
                                    self._children_name_map["occur_at"] = "occur-at"

                                    self.server = Native.UtdSt.Utd.Engine.Standard.ThreatInspection.Signature.Update.Server()
                                    self.server.parent = self
                                    self._children_name_map["server"] = "server"
                                    self._segment_path = lambda: "update"
                                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/Cisco-IOS-XE-utd:utd-st/utd/engine/standard/threat-inspection/signature/%s" % self._segment_path()
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.UtdSt.Utd.Engine.Standard.ThreatInspection.Signature.Update, [], name, value)


                                class OccurAt(Entity):
                                    """
                                    Specify update occurence by calendar time
                                    
                                    .. attribute:: daily
                                    
                                    	Option for daily update
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: monthly
                                    
                                    	Option for monthly update
                                    	**type**\: str
                                    
                                    	**length:** 1..512
                                    
                                    .. attribute:: weekly
                                    
                                    	Option for weekly update
                                    	**type**\: str
                                    
                                    	**length:** 1..512
                                    
                                    .. attribute:: hours
                                    
                                    	
                                    	**type**\: int
                                    
                                    	**range:** 0..23
                                    
                                    .. attribute:: minutes
                                    
                                    	
                                    	**type**\: int
                                    
                                    	**range:** 0..59
                                    
                                    

                                    """

                                    _prefix = 'ios-utd'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.UtdSt.Utd.Engine.Standard.ThreatInspection.Signature.Update.OccurAt, self).__init__()

                                        self.yang_name = "occur-at"
                                        self.yang_parent_name = "update"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('daily', (YLeaf(YType.empty, 'daily'), ['Empty'])),
                                            ('monthly', (YLeaf(YType.str, 'monthly'), ['str'])),
                                            ('weekly', (YLeaf(YType.str, 'weekly'), ['str'])),
                                            ('hours', (YLeaf(YType.uint8, 'hours'), ['int'])),
                                            ('minutes', (YLeaf(YType.uint8, 'minutes'), ['int'])),
                                        ])
                                        self.daily = None
                                        self.monthly = None
                                        self.weekly = None
                                        self.hours = None
                                        self.minutes = None
                                        self._segment_path = lambda: "occur-at"
                                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/Cisco-IOS-XE-utd:utd-st/utd/engine/standard/threat-inspection/signature/update/%s" % self._segment_path()
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.UtdSt.Utd.Engine.Standard.ThreatInspection.Signature.Update.OccurAt, ['daily', 'monthly', 'weekly', 'hours', 'minutes'], name, value)


                                class Server(Entity):
                                    """
                                    Provide config options for the signature update server
                                    
                                    .. attribute:: cisco
                                    
                                    	Use Cisco site to provide updates
                                    	**type**\:  :py:class:`Cisco <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.UtdSt.Utd.Engine.Standard.ThreatInspection.Signature.Update.Server.Cisco>`
                                    
                                    .. attribute:: url
                                    
                                    	Enter the complete URL for the path to the update server
                                    	**type**\:  :py:class:`Url <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.UtdSt.Utd.Engine.Standard.ThreatInspection.Signature.Update.Server.Url>`
                                    
                                    

                                    """

                                    _prefix = 'ios-utd'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.UtdSt.Utd.Engine.Standard.ThreatInspection.Signature.Update.Server, self).__init__()

                                        self.yang_name = "server"
                                        self.yang_parent_name = "update"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("cisco", ("cisco", Native.UtdSt.Utd.Engine.Standard.ThreatInspection.Signature.Update.Server.Cisco)), ("url", ("url", Native.UtdSt.Utd.Engine.Standard.ThreatInspection.Signature.Update.Server.Url))])
                                        self._leafs = OrderedDict()

                                        self.cisco = Native.UtdSt.Utd.Engine.Standard.ThreatInspection.Signature.Update.Server.Cisco()
                                        self.cisco.parent = self
                                        self._children_name_map["cisco"] = "cisco"

                                        self.url = Native.UtdSt.Utd.Engine.Standard.ThreatInspection.Signature.Update.Server.Url()
                                        self.url.parent = self
                                        self._children_name_map["url"] = "url"
                                        self._segment_path = lambda: "server"
                                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/Cisco-IOS-XE-utd:utd-st/utd/engine/standard/threat-inspection/signature/update/%s" % self._segment_path()
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.UtdSt.Utd.Engine.Standard.ThreatInspection.Signature.Update.Server, [], name, value)


                                    class Cisco(Entity):
                                        """
                                        Use Cisco site to provide updates
                                        
                                        .. attribute:: username
                                        
                                        	Provide the username for authentication
                                        	**type**\: str
                                        
                                        	**length:** 1..512
                                        
                                        .. attribute:: password
                                        
                                        	Provide the password for authentication
                                        	**type**\: str
                                        
                                        	**length:** 1..512
                                        
                                        

                                        """

                                        _prefix = 'ios-utd'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.UtdSt.Utd.Engine.Standard.ThreatInspection.Signature.Update.Server.Cisco, self).__init__()

                                            self.yang_name = "cisco"
                                            self.yang_parent_name = "server"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = False
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('username', (YLeaf(YType.str, 'username'), ['str'])),
                                                ('password', (YLeaf(YType.str, 'password'), ['str'])),
                                            ])
                                            self.username = None
                                            self.password = None
                                            self._segment_path = lambda: "cisco"
                                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/Cisco-IOS-XE-utd:utd-st/utd/engine/standard/threat-inspection/signature/update/server/%s" % self._segment_path()
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.UtdSt.Utd.Engine.Standard.ThreatInspection.Signature.Update.Server.Cisco, ['username', 'password'], name, value)


                                    class Url(Entity):
                                        """
                                        Enter the complete URL for the path to the update server
                                        
                                        .. attribute:: all
                                        
                                        	
                                        	**type**\:  :py:class:`All <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.UtdSt.Utd.Engine.Standard.ThreatInspection.Signature.Update.Server.Url.All>`
                                        
                                        .. attribute:: name
                                        
                                        	
                                        	**type**\: str
                                        
                                        	**length:** 1..512
                                        
                                        

                                        """

                                        _prefix = 'ios-utd'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.UtdSt.Utd.Engine.Standard.ThreatInspection.Signature.Update.Server.Url, self).__init__()

                                            self.yang_name = "url"
                                            self.yang_parent_name = "server"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = False
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("all", ("all", Native.UtdSt.Utd.Engine.Standard.ThreatInspection.Signature.Update.Server.Url.All))])
                                            self._leafs = OrderedDict([
                                                ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                            ])
                                            self.name = None

                                            self.all = Native.UtdSt.Utd.Engine.Standard.ThreatInspection.Signature.Update.Server.Url.All()
                                            self.all.parent = self
                                            self._children_name_map["all"] = "all"
                                            self._segment_path = lambda: "url"
                                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/Cisco-IOS-XE-utd:utd-st/utd/engine/standard/threat-inspection/signature/update/server/%s" % self._segment_path()
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.UtdSt.Utd.Engine.Standard.ThreatInspection.Signature.Update.Server.Url, ['name'], name, value)


                                        class All(Entity):
                                            """
                                            
                                            
                                            .. attribute:: name
                                            
                                            	
                                            	**type**\: str
                                            
                                            	**length:** 1..512
                                            
                                            .. attribute:: username
                                            
                                            	Provide the username for authentication
                                            	**type**\: str
                                            
                                            	**length:** 1..512
                                            
                                            .. attribute:: password
                                            
                                            	Provide the password for authentication
                                            	**type**\: str
                                            
                                            	**length:** 1..512
                                            
                                            

                                            """

                                            _prefix = 'ios-utd'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.UtdSt.Utd.Engine.Standard.ThreatInspection.Signature.Update.Server.Url.All, self).__init__()

                                                self.yang_name = "all"
                                                self.yang_parent_name = "url"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = False
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                                    ('username', (YLeaf(YType.str, 'username'), ['str'])),
                                                    ('password', (YLeaf(YType.str, 'password'), ['str'])),
                                                ])
                                                self.name = None
                                                self.username = None
                                                self.password = None
                                                self._segment_path = lambda: "all"
                                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/Cisco-IOS-XE-utd:utd-st/utd/engine/standard/threat-inspection/signature/update/server/url/%s" % self._segment_path()
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.UtdSt.Utd.Engine.Standard.ThreatInspection.Signature.Update.Server.Url.All, ['name', 'username', 'password'], name, value)


                        class Logging(Entity):
                            """
                            Provide logging level for the alerts for IPS/IDS
                            
                            .. attribute:: level
                            
                            	Provide the log level
                            	**type**\:  :py:class:`Level <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.UtdSt.Utd.Engine.Standard.ThreatInspection.Logging.Level>`
                            
                            

                            """

                            _prefix = 'ios-utd'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.UtdSt.Utd.Engine.Standard.ThreatInspection.Logging, self).__init__()

                                self.yang_name = "logging"
                                self.yang_parent_name = "threat-inspection"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('level', (YLeaf(YType.enumeration, 'level'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'UtdSt.Utd.Engine.Standard.ThreatInspection.Logging.Level')])),
                                ])
                                self.level = None
                                self._segment_path = lambda: "logging"
                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/Cisco-IOS-XE-utd:utd-st/utd/engine/standard/threat-inspection/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.UtdSt.Utd.Engine.Standard.ThreatInspection.Logging, ['level'], name, value)

                            class Level(Enum):
                                """
                                Level (Enum Class)

                                Provide the log level

                                .. data:: emerg = 0

                                .. data:: alert = 1

                                .. data:: crit = 2

                                .. data:: err = 3

                                .. data:: warning = 4

                                .. data:: notice = 5

                                .. data:: info = 6

                                .. data:: debug = 7

                                """

                                emerg = Enum.YLeaf(0, "emerg")

                                alert = Enum.YLeaf(1, "alert")

                                crit = Enum.YLeaf(2, "crit")

                                err = Enum.YLeaf(3, "err")

                                warning = Enum.YLeaf(4, "warning")

                                notice = Enum.YLeaf(5, "notice")

                                info = Enum.YLeaf(6, "info")

                                debug = Enum.YLeaf(7, "debug")



                    class WebFilter(Entity):
                        """
                        UTD engine standard web\-filtering configs
                        
                        .. attribute:: sourcedb
                        
                        	Choose the source DB profile to use for web filtering
                        	**type**\: str
                        
                        	**length:** 1..512
                        
                        .. attribute:: domain_profile
                        
                        	Choose the domain profile to use for web filtering
                        	**type**\: str
                        
                        	**length:** 1..512
                        
                        .. attribute:: url_profile
                        
                        	Choose the url profile to use for web filtering
                        	**type**\: str
                        
                        	**length:** 1..512
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-utd'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.UtdSt.Utd.Engine.Standard.WebFilter, self).__init__()

                            self.yang_name = "web-filter"
                            self.yang_parent_name = "standard"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('sourcedb', (YLeaf(YType.str, 'sourcedb'), ['str'])),
                                ('domain_profile', (YLeaf(YType.str, 'domain-profile'), ['str'])),
                                ('url_profile', (YLeaf(YType.str, 'url-profile'), ['str'])),
                            ])
                            self.sourcedb = None
                            self.domain_profile = None
                            self.url_profile = None
                            self._segment_path = lambda: "web-filter"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/Cisco-IOS-XE-utd:utd-st/utd/engine/standard/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.UtdSt.Utd.Engine.Standard.WebFilter, ['sourcedb', 'domain_profile', 'url_profile'], name, value)


            class ThreatInspection(Entity):
                """
                UTD Threat Inspection (IPS/IDS) config modes
                
                .. attribute:: whitelist
                
                	UTD whitelist config submode
                	**type**\:  :py:class:`Whitelist <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.UtdSt.Utd.ThreatInspection.Whitelist>`
                
                	**presence node**\: True
                
                

                """

                _prefix = 'ios-utd'
                _revision = '2018-06-28'

                def __init__(self):
                    super(Native.UtdSt.Utd.ThreatInspection, self).__init__()

                    self.yang_name = "threat-inspection"
                    self.yang_parent_name = "utd"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("whitelist", ("whitelist", Native.UtdSt.Utd.ThreatInspection.Whitelist))])
                    self._leafs = OrderedDict()

                    self.whitelist = None
                    self._children_name_map["whitelist"] = "whitelist"
                    self._segment_path = lambda: "threat-inspection"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/Cisco-IOS-XE-utd:utd-st/utd/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.UtdSt.Utd.ThreatInspection, [], name, value)


                class Whitelist(Entity):
                    """
                    UTD whitelist config submode
                    
                    .. attribute:: generator
                    
                    	Provide generator for the whitelist
                    	**type**\: list of  		 :py:class:`Generator <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.UtdSt.Utd.ThreatInspection.Whitelist.Generator>`
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ios-utd'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.UtdSt.Utd.ThreatInspection.Whitelist, self).__init__()

                        self.yang_name = "whitelist"
                        self.yang_parent_name = "threat-inspection"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("generator", ("generator", Native.UtdSt.Utd.ThreatInspection.Whitelist.Generator))])
                        self.is_presence_container = True
                        self._leafs = OrderedDict()

                        self.generator = YList(self)
                        self._segment_path = lambda: "whitelist"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/Cisco-IOS-XE-utd:utd-st/utd/threat-inspection/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.UtdSt.Utd.ThreatInspection.Whitelist, [], name, value)


                    class Generator(Entity):
                        """
                        Provide generator for the whitelist
                        
                        .. attribute:: id  (key)
                        
                        	Provide the generator ID to be whitelisted
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: signature
                        
                        	Provide signature for the whitelist
                        	**type**\: list of  		 :py:class:`Signature <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.UtdSt.Utd.ThreatInspection.Whitelist.Generator.Signature>`
                        
                        

                        """

                        _prefix = 'ios-utd'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.UtdSt.Utd.ThreatInspection.Whitelist.Generator, self).__init__()

                            self.yang_name = "generator"
                            self.yang_parent_name = "whitelist"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = ['id']
                            self._child_classes = OrderedDict([("signature", ("signature", Native.UtdSt.Utd.ThreatInspection.Whitelist.Generator.Signature))])
                            self._leafs = OrderedDict([
                                ('id', (YLeaf(YType.uint32, 'id'), ['int'])),
                            ])
                            self.id = None

                            self.signature = YList(self)
                            self._segment_path = lambda: "generator" + "[id='" + str(self.id) + "']"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/Cisco-IOS-XE-utd:utd-st/utd/threat-inspection/whitelist/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.UtdSt.Utd.ThreatInspection.Whitelist.Generator, ['id'], name, value)


                        class Signature(Entity):
                            """
                            Provide signature for the whitelist
                            
                            .. attribute:: id  (key)
                            
                            	Provide the signature ID to be whitelisted
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: comment
                            
                            	Provide a comment for the whitelist
                            	**type**\: str
                            
                            	**length:** 1..512
                            
                            

                            """

                            _prefix = 'ios-utd'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.UtdSt.Utd.ThreatInspection.Whitelist.Generator.Signature, self).__init__()

                                self.yang_name = "signature"
                                self.yang_parent_name = "generator"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = ['id']
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('id', (YLeaf(YType.uint32, 'id'), ['int'])),
                                    ('comment', (YLeaf(YType.str, 'comment'), ['str'])),
                                ])
                                self.id = None
                                self.comment = None
                                self._segment_path = lambda: "signature" + "[id='" + str(self.id) + "']"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.UtdSt.Utd.ThreatInspection.Whitelist.Generator.Signature, ['id', 'comment'], name, value)


    class UtdMt(Entity):
        """
        
        
        .. attribute:: utd
        
        	Global Unified Threat Defense
        	**type**\:  :py:class:`Utd <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.UtdMt.Utd>`
        
        

        """

        _prefix = 'ios-utd'
        _revision = '2018-06-28'

        def __init__(self):
            super(Native.UtdMt, self).__init__()

            self.yang_name = "utd-mt"
            self.yang_parent_name = "native"
            self.is_top_level_class = False
            self.has_list_ancestor = False
            self.ylist_key_names = []
            self._child_classes = OrderedDict([("utd", ("utd", Native.UtdMt.Utd))])
            self._leafs = OrderedDict()

            self.utd = Native.UtdMt.Utd()
            self.utd.parent = self
            self._children_name_map["utd"] = "utd"
            self._segment_path = lambda: "Cisco-IOS-XE-utd:utd-mt"
            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/%s" % self._segment_path()
            self._is_frozen = True

        def __setattr__(self, name, value):
            self._perform_setattr(Native.UtdMt, [], name, value)


        class Utd(Entity):
            """
            Global Unified Threat Defense
            
            .. attribute:: multi_tenancy
            
            	Enable UTD multi\-tenancy mode
            	**type**\: :py:class:`Empty<ydk.types.Empty>`
            
            .. attribute:: engine
            
            	UTD engine
            	**type**\:  :py:class:`Engine <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.UtdMt.Utd.Engine>`
            
            

            """

            _prefix = 'ios-utd'
            _revision = '2018-06-28'

            def __init__(self):
                super(Native.UtdMt.Utd, self).__init__()

                self.yang_name = "utd"
                self.yang_parent_name = "utd-mt"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = []
                self._child_classes = OrderedDict([("engine", ("engine", Native.UtdMt.Utd.Engine))])
                self._leafs = OrderedDict([
                    ('multi_tenancy', (YLeaf(YType.empty, 'multi-tenancy'), ['Empty'])),
                ])
                self.multi_tenancy = None

                self.engine = Native.UtdMt.Utd.Engine()
                self.engine.parent = self
                self._children_name_map["engine"] = "engine"
                self._segment_path = lambda: "utd"
                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/Cisco-IOS-XE-utd:utd-mt/%s" % self._segment_path()
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(Native.UtdMt.Utd, ['multi_tenancy'], name, value)


            class Engine(Entity):
                """
                UTD engine
                
                .. attribute:: standard
                
                	UTD engine standard
                	**type**\:  :py:class:`Standard <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.UtdMt.Utd.Engine.Standard>`
                
                

                """

                _prefix = 'ios-utd'
                _revision = '2018-06-28'

                def __init__(self):
                    super(Native.UtdMt.Utd.Engine, self).__init__()

                    self.yang_name = "engine"
                    self.yang_parent_name = "utd"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("standard", ("standard", Native.UtdMt.Utd.Engine.Standard))])
                    self._leafs = OrderedDict()

                    self.standard = Native.UtdMt.Utd.Engine.Standard()
                    self.standard.parent = self
                    self._children_name_map["standard"] = "standard"
                    self._segment_path = lambda: "engine"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/Cisco-IOS-XE-utd:utd-mt/utd/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.UtdMt.Utd.Engine, [], name, value)


                class Standard(Entity):
                    """
                    UTD engine standard
                    
                    .. attribute:: multi_tenancy
                    
                    	Enable UTD multi\-tenancy mode
                    	**type**\:  :py:class:`MultiTenancy <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.UtdMt.Utd.Engine.Standard.MultiTenancy>`
                    
                    	**presence node**\: True
                    
                    

                    """

                    _prefix = 'ios-utd'
                    _revision = '2018-06-28'

                    def __init__(self):
                        super(Native.UtdMt.Utd.Engine.Standard, self).__init__()

                        self.yang_name = "standard"
                        self.yang_parent_name = "engine"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("multi-tenancy", ("multi_tenancy", Native.UtdMt.Utd.Engine.Standard.MultiTenancy))])
                        self._leafs = OrderedDict()

                        self.multi_tenancy = None
                        self._children_name_map["multi_tenancy"] = "multi-tenancy"
                        self._segment_path = lambda: "standard"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/Cisco-IOS-XE-utd:utd-mt/utd/engine/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.UtdMt.Utd.Engine.Standard, [], name, value)


                    class MultiTenancy(Entity):
                        """
                        Enable UTD multi\-tenancy mode
                        
                        .. attribute:: web_filter
                        
                        	UTD web\-filter profile configuration
                        	**type**\:  :py:class:`WebFilter <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.UtdMt.Utd.Engine.Standard.MultiTenancy.WebFilter>`
                        
                        .. attribute:: threat_inspection
                        
                        	UTD Threat Inspection (IPS/IDS) config modes
                        	**type**\:  :py:class:`ThreatInspection <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.UtdMt.Utd.Engine.Standard.MultiTenancy.ThreatInspection>`
                        
                        .. attribute:: utd
                        
                        	UTD engine standard settings
                        	**type**\:  :py:class:`Utd_ <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.UtdMt.Utd.Engine.Standard.MultiTenancy.Utd_>`
                        
                        .. attribute:: policy
                        
                        	Multi\-tenancy utd policy
                        	**type**\: list of  		 :py:class:`Policy <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.UtdMt.Utd.Engine.Standard.MultiTenancy.Policy>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-utd'
                        _revision = '2018-06-28'

                        def __init__(self):
                            super(Native.UtdMt.Utd.Engine.Standard.MultiTenancy, self).__init__()

                            self.yang_name = "multi-tenancy"
                            self.yang_parent_name = "standard"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("web-filter", ("web_filter", Native.UtdMt.Utd.Engine.Standard.MultiTenancy.WebFilter)), ("threat-inspection", ("threat_inspection", Native.UtdMt.Utd.Engine.Standard.MultiTenancy.ThreatInspection)), ("utd", ("utd", Native.UtdMt.Utd.Engine.Standard.MultiTenancy.Utd_)), ("policy", ("policy", Native.UtdMt.Utd.Engine.Standard.MultiTenancy.Policy))])
                            self.is_presence_container = True
                            self._leafs = OrderedDict()

                            self.web_filter = Native.UtdMt.Utd.Engine.Standard.MultiTenancy.WebFilter()
                            self.web_filter.parent = self
                            self._children_name_map["web_filter"] = "web-filter"

                            self.threat_inspection = Native.UtdMt.Utd.Engine.Standard.MultiTenancy.ThreatInspection()
                            self.threat_inspection.parent = self
                            self._children_name_map["threat_inspection"] = "threat-inspection"

                            self.utd = Native.UtdMt.Utd.Engine.Standard.MultiTenancy.Utd_()
                            self.utd.parent = self
                            self._children_name_map["utd"] = "utd"

                            self.policy = YList(self)
                            self._segment_path = lambda: "multi-tenancy"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/Cisco-IOS-XE-utd:utd-mt/utd/engine/standard/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.UtdMt.Utd.Engine.Standard.MultiTenancy, [], name, value)


                        class WebFilter(Entity):
                            """
                            UTD web\-filter profile configuration
                            
                            .. attribute:: block
                            
                            	UTD block profile information
                            	**type**\:  :py:class:`Block <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.UtdMt.Utd.Engine.Standard.MultiTenancy.WebFilter.Block>`
                            
                            .. attribute:: sourcedb
                            
                            	UTD Web filtering source DB configuration submode
                            	**type**\: list of  		 :py:class:`Sourcedb <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.UtdMt.Utd.Engine.Standard.MultiTenancy.WebFilter.Sourcedb>`
                            
                            .. attribute:: url
                            
                            	UTD URL based web\-filtering submode
                            	**type**\:  :py:class:`Url <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.UtdMt.Utd.Engine.Standard.MultiTenancy.WebFilter.Url>`
                            
                            

                            """

                            _prefix = 'ios-utd'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.UtdMt.Utd.Engine.Standard.MultiTenancy.WebFilter, self).__init__()

                                self.yang_name = "web-filter"
                                self.yang_parent_name = "multi-tenancy"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("block", ("block", Native.UtdMt.Utd.Engine.Standard.MultiTenancy.WebFilter.Block)), ("sourcedb", ("sourcedb", Native.UtdMt.Utd.Engine.Standard.MultiTenancy.WebFilter.Sourcedb)), ("url", ("url", Native.UtdMt.Utd.Engine.Standard.MultiTenancy.WebFilter.Url))])
                                self._leafs = OrderedDict()

                                self.block = Native.UtdMt.Utd.Engine.Standard.MultiTenancy.WebFilter.Block()
                                self.block.parent = self
                                self._children_name_map["block"] = "block"

                                self.url = Native.UtdMt.Utd.Engine.Standard.MultiTenancy.WebFilter.Url()
                                self.url.parent = self
                                self._children_name_map["url"] = "url"

                                self.sourcedb = YList(self)
                                self._segment_path = lambda: "web-filter"
                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/Cisco-IOS-XE-utd:utd-mt/utd/engine/standard/multi-tenancy/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.UtdMt.Utd.Engine.Standard.MultiTenancy.WebFilter, [], name, value)


                            class Block(Entity):
                                """
                                UTD block profile information
                                
                                .. attribute:: local_server
                                
                                	UTD local block server configuration profile
                                	**type**\:  :py:class:`LocalServer <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.UtdMt.Utd.Engine.Standard.MultiTenancy.WebFilter.Block.LocalServer>`
                                
                                .. attribute:: page
                                
                                	UTD inline block page response profile
                                	**type**\:  :py:class:`Page <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.UtdMt.Utd.Engine.Standard.MultiTenancy.WebFilter.Block.Page>`
                                
                                

                                """

                                _prefix = 'ios-utd'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.UtdMt.Utd.Engine.Standard.MultiTenancy.WebFilter.Block, self).__init__()

                                    self.yang_name = "block"
                                    self.yang_parent_name = "web-filter"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("local-server", ("local_server", Native.UtdMt.Utd.Engine.Standard.MultiTenancy.WebFilter.Block.LocalServer)), ("page", ("page", Native.UtdMt.Utd.Engine.Standard.MultiTenancy.WebFilter.Block.Page))])
                                    self._leafs = OrderedDict()

                                    self.local_server = Native.UtdMt.Utd.Engine.Standard.MultiTenancy.WebFilter.Block.LocalServer()
                                    self.local_server.parent = self
                                    self._children_name_map["local_server"] = "local-server"

                                    self.page = Native.UtdMt.Utd.Engine.Standard.MultiTenancy.WebFilter.Block.Page()
                                    self.page.parent = self
                                    self._children_name_map["page"] = "page"
                                    self._segment_path = lambda: "block"
                                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/Cisco-IOS-XE-utd:utd-mt/utd/engine/standard/multi-tenancy/web-filter/%s" % self._segment_path()
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.UtdMt.Utd.Engine.Standard.MultiTenancy.WebFilter.Block, [], name, value)


                                class LocalServer(Entity):
                                    """
                                    UTD local block server configuration profile
                                    
                                    .. attribute:: profile
                                    
                                    	Provide the profile ID
                                    	**type**\: list of  		 :py:class:`Profile <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.UtdMt.Utd.Engine.Standard.MultiTenancy.WebFilter.Block.LocalServer.Profile>`
                                    
                                    

                                    """

                                    _prefix = 'ios-utd'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.UtdMt.Utd.Engine.Standard.MultiTenancy.WebFilter.Block.LocalServer, self).__init__()

                                        self.yang_name = "local-server"
                                        self.yang_parent_name = "block"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("profile", ("profile", Native.UtdMt.Utd.Engine.Standard.MultiTenancy.WebFilter.Block.LocalServer.Profile))])
                                        self._leafs = OrderedDict()

                                        self.profile = YList(self)
                                        self._segment_path = lambda: "local-server"
                                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/Cisco-IOS-XE-utd:utd-mt/utd/engine/standard/multi-tenancy/web-filter/block/%s" % self._segment_path()
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.UtdMt.Utd.Engine.Standard.MultiTenancy.WebFilter.Block.LocalServer, [], name, value)


                                    class Profile(Entity):
                                        """
                                        Provide the profile ID
                                        
                                        .. attribute:: id  (key)
                                        
                                        	
                                        	**type**\: str
                                        
                                        	**length:** 1..512
                                        
                                        .. attribute:: block_page_interface
                                        
                                        	Provide the interface to be used for the block server
                                        	**type**\:  :py:class:`BlockPageInterface <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.UtdMt.Utd.Engine.Standard.MultiTenancy.WebFilter.Block.LocalServer.Profile.BlockPageInterface>`
                                        
                                        .. attribute:: content
                                        
                                        	Provide the content to be served from the server
                                        	**type**\:  :py:class:`Content <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.UtdMt.Utd.Engine.Standard.MultiTenancy.WebFilter.Block.LocalServer.Profile.Content>`
                                        
                                        .. attribute:: http_ports
                                        
                                        	Provide the HTTP ports to be used
                                        	**type**\: str
                                        
                                        	**length:** 1..100
                                        
                                        

                                        """

                                        _prefix = 'ios-utd'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.UtdMt.Utd.Engine.Standard.MultiTenancy.WebFilter.Block.LocalServer.Profile, self).__init__()

                                            self.yang_name = "profile"
                                            self.yang_parent_name = "local-server"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = False
                                            self.ylist_key_names = ['id']
                                            self._child_classes = OrderedDict([("block-page-interface", ("block_page_interface", Native.UtdMt.Utd.Engine.Standard.MultiTenancy.WebFilter.Block.LocalServer.Profile.BlockPageInterface)), ("content", ("content", Native.UtdMt.Utd.Engine.Standard.MultiTenancy.WebFilter.Block.LocalServer.Profile.Content))])
                                            self._leafs = OrderedDict([
                                                ('id', (YLeaf(YType.str, 'id'), ['str'])),
                                                ('http_ports', (YLeaf(YType.str, 'http-ports'), ['str'])),
                                            ])
                                            self.id = None
                                            self.http_ports = None

                                            self.block_page_interface = Native.UtdMt.Utd.Engine.Standard.MultiTenancy.WebFilter.Block.LocalServer.Profile.BlockPageInterface()
                                            self.block_page_interface.parent = self
                                            self._children_name_map["block_page_interface"] = "block-page-interface"

                                            self.content = Native.UtdMt.Utd.Engine.Standard.MultiTenancy.WebFilter.Block.LocalServer.Profile.Content()
                                            self.content.parent = self
                                            self._children_name_map["content"] = "content"
                                            self._segment_path = lambda: "profile" + "[id='" + str(self.id) + "']"
                                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/Cisco-IOS-XE-utd:utd-mt/utd/engine/standard/multi-tenancy/web-filter/block/local-server/%s" % self._segment_path()
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.UtdMt.Utd.Engine.Standard.MultiTenancy.WebFilter.Block.LocalServer.Profile, ['id', 'http_ports'], name, value)


                                        class BlockPageInterface(Entity):
                                            """
                                            Provide the interface to be used for the block server
                                            
                                            .. attribute:: loopback
                                            
                                            	Loopback interface
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ios-utd'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.UtdMt.Utd.Engine.Standard.MultiTenancy.WebFilter.Block.LocalServer.Profile.BlockPageInterface, self).__init__()

                                                self.yang_name = "block-page-interface"
                                                self.yang_parent_name = "profile"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('loopback', (YLeaf(YType.uint32, 'Loopback'), ['int'])),
                                                ])
                                                self.loopback = None
                                                self._segment_path = lambda: "block-page-interface"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.UtdMt.Utd.Engine.Standard.MultiTenancy.WebFilter.Block.LocalServer.Profile.BlockPageInterface, ['loopback'], name, value)


                                        class Content(Entity):
                                            """
                                            Provide the content to be served from the server
                                            
                                            .. attribute:: text
                                            
                                            	Provide the text to be printed in the web page served
                                            	**type**\: str
                                            
                                            	**length:** 1..512
                                            
                                            .. attribute:: file
                                            
                                            	Provide the HTML file to be served
                                            	**type**\: str
                                            
                                            	**length:** 1..512
                                            
                                            

                                            """

                                            _prefix = 'ios-utd'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.UtdMt.Utd.Engine.Standard.MultiTenancy.WebFilter.Block.LocalServer.Profile.Content, self).__init__()

                                                self.yang_name = "content"
                                                self.yang_parent_name = "profile"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('text', (YLeaf(YType.str, 'text'), ['str'])),
                                                    ('file', (YLeaf(YType.str, 'file'), ['str'])),
                                                ])
                                                self.text = None
                                                self.file = None
                                                self._segment_path = lambda: "content"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.UtdMt.Utd.Engine.Standard.MultiTenancy.WebFilter.Block.LocalServer.Profile.Content, ['text', 'file'], name, value)


                                class Page(Entity):
                                    """
                                    UTD inline block page response profile
                                    
                                    .. attribute:: profile
                                    
                                    	Provide the profile ID
                                    	**type**\: list of  		 :py:class:`Profile <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.UtdMt.Utd.Engine.Standard.MultiTenancy.WebFilter.Block.Page.Profile>`
                                    
                                    

                                    """

                                    _prefix = 'ios-utd'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.UtdMt.Utd.Engine.Standard.MultiTenancy.WebFilter.Block.Page, self).__init__()

                                        self.yang_name = "page"
                                        self.yang_parent_name = "block"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("profile", ("profile", Native.UtdMt.Utd.Engine.Standard.MultiTenancy.WebFilter.Block.Page.Profile))])
                                        self._leafs = OrderedDict()

                                        self.profile = YList(self)
                                        self._segment_path = lambda: "page"
                                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/Cisco-IOS-XE-utd:utd-mt/utd/engine/standard/multi-tenancy/web-filter/block/%s" % self._segment_path()
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.UtdMt.Utd.Engine.Standard.MultiTenancy.WebFilter.Block.Page, [], name, value)


                                    class Profile(Entity):
                                        """
                                        Provide the profile ID
                                        
                                        .. attribute:: id  (key)
                                        
                                        	
                                        	**type**\: str
                                        
                                        	**length:** 1..512
                                        
                                        .. attribute:: file
                                        
                                        	Specify the file name to be used for the block page
                                        	**type**\: str
                                        
                                        	**length:** 1..512
                                        
                                        .. attribute:: redirect_url
                                        
                                        	Specify the URL to be used for redirection
                                        	**type**\: str
                                        
                                        	**length:** 1..512
                                        
                                        .. attribute:: text
                                        
                                        	Specify the text to be used to be sent back
                                        	**type**\: str
                                        
                                        	**length:** 1..512
                                        
                                        

                                        """

                                        _prefix = 'ios-utd'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.UtdMt.Utd.Engine.Standard.MultiTenancy.WebFilter.Block.Page.Profile, self).__init__()

                                            self.yang_name = "profile"
                                            self.yang_parent_name = "page"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = False
                                            self.ylist_key_names = ['id']
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('id', (YLeaf(YType.str, 'id'), ['str'])),
                                                ('file', (YLeaf(YType.str, 'file'), ['str'])),
                                                ('redirect_url', (YLeaf(YType.str, 'redirect-url'), ['str'])),
                                                ('text', (YLeaf(YType.str, 'text'), ['str'])),
                                            ])
                                            self.id = None
                                            self.file = None
                                            self.redirect_url = None
                                            self.text = None
                                            self._segment_path = lambda: "profile" + "[id='" + str(self.id) + "']"
                                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/Cisco-IOS-XE-utd:utd-mt/utd/engine/standard/multi-tenancy/web-filter/block/page/%s" % self._segment_path()
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.UtdMt.Utd.Engine.Standard.MultiTenancy.WebFilter.Block.Page.Profile, ['id', 'file', 'redirect_url', 'text'], name, value)


                            class Sourcedb(Entity):
                                """
                                UTD Web filtering source DB configuration submode
                                
                                .. attribute:: id  (key)
                                
                                	
                                	**type**\: str
                                
                                	**length:** 1..512
                                
                                .. attribute:: logging
                                
                                	Provide source DB logging information
                                	**type**\:  :py:class:`Logging <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.UtdMt.Utd.Engine.Standard.MultiTenancy.WebFilter.Sourcedb.Logging>`
                                
                                

                                """

                                _prefix = 'ios-utd'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.UtdMt.Utd.Engine.Standard.MultiTenancy.WebFilter.Sourcedb, self).__init__()

                                    self.yang_name = "sourcedb"
                                    self.yang_parent_name = "web-filter"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self.ylist_key_names = ['id']
                                    self._child_classes = OrderedDict([("logging", ("logging", Native.UtdMt.Utd.Engine.Standard.MultiTenancy.WebFilter.Sourcedb.Logging))])
                                    self._leafs = OrderedDict([
                                        ('id', (YLeaf(YType.str, 'id'), ['str'])),
                                    ])
                                    self.id = None

                                    self.logging = Native.UtdMt.Utd.Engine.Standard.MultiTenancy.WebFilter.Sourcedb.Logging()
                                    self.logging.parent = self
                                    self._children_name_map["logging"] = "logging"
                                    self._segment_path = lambda: "sourcedb" + "[id='" + str(self.id) + "']"
                                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/Cisco-IOS-XE-utd:utd-mt/utd/engine/standard/multi-tenancy/web-filter/%s" % self._segment_path()
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.UtdMt.Utd.Engine.Standard.MultiTenancy.WebFilter.Sourcedb, ['id'], name, value)


                                class Logging(Entity):
                                    """
                                    Provide source DB logging information
                                    
                                    .. attribute:: level
                                    
                                    	Provide the logging level
                                    	**type**\:  :py:class:`Level <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.UtdMt.Utd.Engine.Standard.MultiTenancy.WebFilter.Sourcedb.Logging.Level>`
                                    
                                    

                                    """

                                    _prefix = 'ios-utd'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.UtdMt.Utd.Engine.Standard.MultiTenancy.WebFilter.Sourcedb.Logging, self).__init__()

                                        self.yang_name = "logging"
                                        self.yang_parent_name = "sourcedb"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('level', (YLeaf(YType.enumeration, 'level'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'UtdMt.Utd.Engine.Standard.MultiTenancy.WebFilter.Sourcedb.Logging.Level')])),
                                        ])
                                        self.level = None
                                        self._segment_path = lambda: "logging"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.UtdMt.Utd.Engine.Standard.MultiTenancy.WebFilter.Sourcedb.Logging, ['level'], name, value)

                                    class Level(Enum):
                                        """
                                        Level (Enum Class)

                                        Provide the logging level

                                        .. data:: debug = 0

                                        .. data:: error = 1

                                        .. data:: info = 2

                                        .. data:: trace = 3

                                        .. data:: warning = 4

                                        """

                                        debug = Enum.YLeaf(0, "debug")

                                        error = Enum.YLeaf(1, "error")

                                        info = Enum.YLeaf(2, "info")

                                        trace = Enum.YLeaf(3, "trace")

                                        warning = Enum.YLeaf(4, "warning")



                            class Url(Entity):
                                """
                                UTD URL based web\-filtering submode
                                
                                .. attribute:: profile
                                
                                	Provide the profile ID
                                	**type**\: list of  		 :py:class:`Profile <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.UtdMt.Utd.Engine.Standard.MultiTenancy.WebFilter.Url.Profile>`
                                
                                

                                """

                                _prefix = 'ios-utd'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.UtdMt.Utd.Engine.Standard.MultiTenancy.WebFilter.Url, self).__init__()

                                    self.yang_name = "url"
                                    self.yang_parent_name = "web-filter"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("profile", ("profile", Native.UtdMt.Utd.Engine.Standard.MultiTenancy.WebFilter.Url.Profile))])
                                    self._leafs = OrderedDict()

                                    self.profile = YList(self)
                                    self._segment_path = lambda: "url"
                                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/Cisco-IOS-XE-utd:utd-mt/utd/engine/standard/multi-tenancy/web-filter/%s" % self._segment_path()
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.UtdMt.Utd.Engine.Standard.MultiTenancy.WebFilter.Url, [], name, value)


                                class Profile(Entity):
                                    """
                                    Provide the profile ID
                                    
                                    .. attribute:: id  (key)
                                    
                                    	
                                    	**type**\: str
                                    
                                    	**length:** 1..512
                                    
                                    .. attribute:: alert
                                    
                                    	Provide the logging alert level
                                    	**type**\: list of   :py:class:`Alert <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.UtdMt.Utd.Engine.Standard.MultiTenancy.WebFilter.Url.Profile.Alert>`
                                    
                                    .. attribute:: blacklist
                                    
                                    	Choose the blacklist parameter\-map
                                    	**type**\:  :py:class:`Blacklist <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.UtdMt.Utd.Engine.Standard.MultiTenancy.WebFilter.Url.Profile.Blacklist>`
                                    
                                    	**presence node**\: True
                                    
                                    .. attribute:: categories
                                    
                                    	Choose from a list of categories
                                    	**type**\:  :py:class:`Categories <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.UtdMt.Utd.Engine.Standard.MultiTenancy.WebFilter.Url.Profile.Categories>`
                                    
                                    .. attribute:: block
                                    
                                    	Provide information on the block page/server to be used
                                    	**type**\:  :py:class:`Block <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.UtdMt.Utd.Engine.Standard.MultiTenancy.WebFilter.Url.Profile.Block>`
                                    
                                    .. attribute:: log
                                    
                                    	Choose the URL filtering preprocessor debug log options
                                    	**type**\:  :py:class:`Log <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.UtdMt.Utd.Engine.Standard.MultiTenancy.WebFilter.Url.Profile.Log>`
                                    
                                    .. attribute:: reputation
                                    
                                    	Choose the reputation range for the URLs to be blocked
                                    	**type**\:  :py:class:`Reputation <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.UtdMt.Utd.Engine.Standard.MultiTenancy.WebFilter.Url.Profile.Reputation>`
                                    
                                    	**presence node**\: True
                                    
                                    .. attribute:: sourcedb
                                    
                                    	Choose source DB related configs
                                    	**type**\:  :py:class:`Sourcedb <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.UtdMt.Utd.Engine.Standard.MultiTenancy.WebFilter.Url.Profile.Sourcedb>`
                                    
                                    .. attribute:: whitelist
                                    
                                    	Choose the whitelist parameter\-map
                                    	**type**\:  :py:class:`Whitelist <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.UtdMt.Utd.Engine.Standard.MultiTenancy.WebFilter.Url.Profile.Whitelist>`
                                    
                                    	**presence node**\: True
                                    
                                    

                                    """

                                    _prefix = 'ios-utd'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.UtdMt.Utd.Engine.Standard.MultiTenancy.WebFilter.Url.Profile, self).__init__()

                                        self.yang_name = "profile"
                                        self.yang_parent_name = "url"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = ['id']
                                        self._child_classes = OrderedDict([("blacklist", ("blacklist", Native.UtdMt.Utd.Engine.Standard.MultiTenancy.WebFilter.Url.Profile.Blacklist)), ("categories", ("categories", Native.UtdMt.Utd.Engine.Standard.MultiTenancy.WebFilter.Url.Profile.Categories)), ("block", ("block", Native.UtdMt.Utd.Engine.Standard.MultiTenancy.WebFilter.Url.Profile.Block)), ("log", ("log", Native.UtdMt.Utd.Engine.Standard.MultiTenancy.WebFilter.Url.Profile.Log)), ("reputation", ("reputation", Native.UtdMt.Utd.Engine.Standard.MultiTenancy.WebFilter.Url.Profile.Reputation)), ("sourcedb", ("sourcedb", Native.UtdMt.Utd.Engine.Standard.MultiTenancy.WebFilter.Url.Profile.Sourcedb)), ("whitelist", ("whitelist", Native.UtdMt.Utd.Engine.Standard.MultiTenancy.WebFilter.Url.Profile.Whitelist))])
                                        self._leafs = OrderedDict([
                                            ('id', (YLeaf(YType.str, 'id'), ['str'])),
                                            ('alert', (YLeafList(YType.enumeration, 'alert'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'UtdMt.Utd.Engine.Standard.MultiTenancy.WebFilter.Url.Profile.Alert')])),
                                        ])
                                        self.id = None
                                        self.alert = []

                                        self.blacklist = None
                                        self._children_name_map["blacklist"] = "blacklist"

                                        self.categories = Native.UtdMt.Utd.Engine.Standard.MultiTenancy.WebFilter.Url.Profile.Categories()
                                        self.categories.parent = self
                                        self._children_name_map["categories"] = "categories"

                                        self.block = Native.UtdMt.Utd.Engine.Standard.MultiTenancy.WebFilter.Url.Profile.Block()
                                        self.block.parent = self
                                        self._children_name_map["block"] = "block"

                                        self.log = Native.UtdMt.Utd.Engine.Standard.MultiTenancy.WebFilter.Url.Profile.Log()
                                        self.log.parent = self
                                        self._children_name_map["log"] = "log"

                                        self.reputation = None
                                        self._children_name_map["reputation"] = "reputation"

                                        self.sourcedb = Native.UtdMt.Utd.Engine.Standard.MultiTenancy.WebFilter.Url.Profile.Sourcedb()
                                        self.sourcedb.parent = self
                                        self._children_name_map["sourcedb"] = "sourcedb"

                                        self.whitelist = None
                                        self._children_name_map["whitelist"] = "whitelist"
                                        self._segment_path = lambda: "profile" + "[id='" + str(self.id) + "']"
                                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/Cisco-IOS-XE-utd:utd-mt/utd/engine/standard/multi-tenancy/web-filter/url/%s" % self._segment_path()
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.UtdMt.Utd.Engine.Standard.MultiTenancy.WebFilter.Url.Profile, ['id', 'alert'], name, value)

                                    class Alert(Enum):
                                        """
                                        Alert (Enum Class)

                                        Provide the logging alert level

                                        .. data:: all = 0

                                        .. data:: blacklist = 1

                                        .. data:: categories_reputation = 2

                                        .. data:: whitelist = 3

                                        """

                                        all = Enum.YLeaf(0, "all")

                                        blacklist = Enum.YLeaf(1, "blacklist")

                                        categories_reputation = Enum.YLeaf(2, "categories-reputation")

                                        whitelist = Enum.YLeaf(3, "whitelist")



                                    class Blacklist(Entity):
                                        """
                                        Choose the blacklist parameter\-map
                                        
                                        .. attribute:: parameter_map
                                        
                                        	Enter the parameter\-map information for the regex
                                        	**type**\:  :py:class:`ParameterMap <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.UtdMt.Utd.Engine.Standard.MultiTenancy.WebFilter.Url.Profile.Blacklist.ParameterMap>`
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-utd'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.UtdMt.Utd.Engine.Standard.MultiTenancy.WebFilter.Url.Profile.Blacklist, self).__init__()

                                            self.yang_name = "blacklist"
                                            self.yang_parent_name = "profile"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("parameter-map", ("parameter_map", Native.UtdMt.Utd.Engine.Standard.MultiTenancy.WebFilter.Url.Profile.Blacklist.ParameterMap))])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict()

                                            self.parameter_map = Native.UtdMt.Utd.Engine.Standard.MultiTenancy.WebFilter.Url.Profile.Blacklist.ParameterMap()
                                            self.parameter_map.parent = self
                                            self._children_name_map["parameter_map"] = "parameter-map"
                                            self._segment_path = lambda: "blacklist"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.UtdMt.Utd.Engine.Standard.MultiTenancy.WebFilter.Url.Profile.Blacklist, [], name, value)


                                        class ParameterMap(Entity):
                                            """
                                            Enter the parameter\-map information for the regex
                                            
                                            .. attribute:: regex
                                            
                                            	Provide the regex parameter\-map name
                                            	**type**\: str
                                            
                                            	**length:** 1..256
                                            
                                            

                                            """

                                            _prefix = 'ios-utd'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.UtdMt.Utd.Engine.Standard.MultiTenancy.WebFilter.Url.Profile.Blacklist.ParameterMap, self).__init__()

                                                self.yang_name = "parameter-map"
                                                self.yang_parent_name = "blacklist"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('regex', (YLeaf(YType.str, 'regex'), ['str'])),
                                                ])
                                                self.regex = None
                                                self._segment_path = lambda: "parameter-map"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.UtdMt.Utd.Engine.Standard.MultiTenancy.WebFilter.Url.Profile.Blacklist.ParameterMap, ['regex'], name, value)


                                    class Categories(Entity):
                                        """
                                        Choose from a list of categories
                                        
                                        .. attribute:: allow
                                        
                                        	Choose the list of categories to be allowed
                                        	**type**\:  :py:class:`Allow <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.UtdMt.Utd.Engine.Standard.MultiTenancy.WebFilter.Url.Profile.Categories.Allow>`
                                        
                                        	**presence node**\: True
                                        
                                        .. attribute:: block
                                        
                                        	Choose the list of categories to be blocked
                                        	**type**\:  :py:class:`Block <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.UtdMt.Utd.Engine.Standard.MultiTenancy.WebFilter.Url.Profile.Categories.Block>`
                                        
                                        	**presence node**\: True
                                        
                                        

                                        """

                                        _prefix = 'ios-utd'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.UtdMt.Utd.Engine.Standard.MultiTenancy.WebFilter.Url.Profile.Categories, self).__init__()

                                            self.yang_name = "categories"
                                            self.yang_parent_name = "profile"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("allow", ("allow", Native.UtdMt.Utd.Engine.Standard.MultiTenancy.WebFilter.Url.Profile.Categories.Allow)), ("block", ("block", Native.UtdMt.Utd.Engine.Standard.MultiTenancy.WebFilter.Url.Profile.Categories.Block))])
                                            self._leafs = OrderedDict()

                                            self.allow = None
                                            self._children_name_map["allow"] = "allow"

                                            self.block = None
                                            self._children_name_map["block"] = "block"
                                            self._segment_path = lambda: "categories"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.UtdMt.Utd.Engine.Standard.MultiTenancy.WebFilter.Url.Profile.Categories, [], name, value)


                                        class Allow(Entity):
                                            """
                                            Choose the list of categories to be allowed
                                            
                                            .. attribute:: category
                                            
                                            	
                                            	**type**\: list of  		 :py:class:`Category <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.UtdMt.Utd.Engine.Standard.MultiTenancy.WebFilter.Url.Profile.Categories.Allow.Category>`
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ios-utd'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.UtdMt.Utd.Engine.Standard.MultiTenancy.WebFilter.Url.Profile.Categories.Allow, self).__init__()

                                                self.yang_name = "allow"
                                                self.yang_parent_name = "categories"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("category", ("category", Native.UtdMt.Utd.Engine.Standard.MultiTenancy.WebFilter.Url.Profile.Categories.Allow.Category))])
                                                self.is_presence_container = True
                                                self._leafs = OrderedDict()

                                                self.category = YList(self)
                                                self._segment_path = lambda: "allow"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.UtdMt.Utd.Engine.Standard.MultiTenancy.WebFilter.Url.Profile.Categories.Allow, [], name, value)


                                            class Category(Entity):
                                                """
                                                
                                                
                                                .. attribute:: name  (key)
                                                
                                                	
                                                	**type**\:  :py:class:`UtdCategoryType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_utd.UtdCategoryType>`
                                                
                                                

                                                """

                                                _prefix = 'ios-utd'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.UtdMt.Utd.Engine.Standard.MultiTenancy.WebFilter.Url.Profile.Categories.Allow.Category, self).__init__()

                                                    self.yang_name = "category"
                                                    self.yang_parent_name = "allow"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = ['name']
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('name', (YLeaf(YType.enumeration, 'name'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_utd', 'UtdCategoryType', '')])),
                                                    ])
                                                    self.name = None
                                                    self._segment_path = lambda: "category" + "[name='" + str(self.name) + "']"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.UtdMt.Utd.Engine.Standard.MultiTenancy.WebFilter.Url.Profile.Categories.Allow.Category, ['name'], name, value)


                                        class Block(Entity):
                                            """
                                            Choose the list of categories to be blocked
                                            
                                            .. attribute:: category
                                            
                                            	
                                            	**type**\: list of  		 :py:class:`Category <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.UtdMt.Utd.Engine.Standard.MultiTenancy.WebFilter.Url.Profile.Categories.Block.Category>`
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ios-utd'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.UtdMt.Utd.Engine.Standard.MultiTenancy.WebFilter.Url.Profile.Categories.Block, self).__init__()

                                                self.yang_name = "block"
                                                self.yang_parent_name = "categories"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("category", ("category", Native.UtdMt.Utd.Engine.Standard.MultiTenancy.WebFilter.Url.Profile.Categories.Block.Category))])
                                                self.is_presence_container = True
                                                self._leafs = OrderedDict()

                                                self.category = YList(self)
                                                self._segment_path = lambda: "block"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.UtdMt.Utd.Engine.Standard.MultiTenancy.WebFilter.Url.Profile.Categories.Block, [], name, value)


                                            class Category(Entity):
                                                """
                                                
                                                
                                                .. attribute:: name  (key)
                                                
                                                	
                                                	**type**\:  :py:class:`UtdCategoryType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_utd.UtdCategoryType>`
                                                
                                                

                                                """

                                                _prefix = 'ios-utd'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.UtdMt.Utd.Engine.Standard.MultiTenancy.WebFilter.Url.Profile.Categories.Block.Category, self).__init__()

                                                    self.yang_name = "category"
                                                    self.yang_parent_name = "block"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = ['name']
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('name', (YLeaf(YType.enumeration, 'name'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_utd', 'UtdCategoryType', '')])),
                                                    ])
                                                    self.name = None
                                                    self._segment_path = lambda: "category" + "[name='" + str(self.name) + "']"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.UtdMt.Utd.Engine.Standard.MultiTenancy.WebFilter.Url.Profile.Categories.Block.Category, ['name'], name, value)


                                    class Block(Entity):
                                        """
                                        Provide information on the block page/server to be used
                                        
                                        .. attribute:: local_server
                                        
                                        	Provide the local block server profile ID
                                        	**type**\: str
                                        
                                        	**length:** 1..512
                                        
                                        .. attribute:: page_profile
                                        
                                        	Provide the ID of the block page profile to be used
                                        	**type**\: str
                                        
                                        	**length:** 1..512
                                        
                                        

                                        """

                                        _prefix = 'ios-utd'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.UtdMt.Utd.Engine.Standard.MultiTenancy.WebFilter.Url.Profile.Block, self).__init__()

                                            self.yang_name = "block"
                                            self.yang_parent_name = "profile"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('local_server', (YLeaf(YType.str, 'local-server'), ['str'])),
                                                ('page_profile', (YLeaf(YType.str, 'page-profile'), ['str'])),
                                            ])
                                            self.local_server = None
                                            self.page_profile = None
                                            self._segment_path = lambda: "block"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.UtdMt.Utd.Engine.Standard.MultiTenancy.WebFilter.Url.Profile.Block, ['local_server', 'page_profile'], name, value)


                                    class Log(Entity):
                                        """
                                        Choose the URL filtering preprocessor debug log options
                                        
                                        .. attribute:: level
                                        
                                        	Choose the URL filtering preprocessor log level
                                        	**type**\:  :py:class:`Level <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.UtdMt.Utd.Engine.Standard.MultiTenancy.WebFilter.Url.Profile.Log.Level>`
                                        
                                        

                                        """

                                        _prefix = 'ios-utd'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.UtdMt.Utd.Engine.Standard.MultiTenancy.WebFilter.Url.Profile.Log, self).__init__()

                                            self.yang_name = "log"
                                            self.yang_parent_name = "profile"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('level', (YLeaf(YType.enumeration, 'level'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'UtdMt.Utd.Engine.Standard.MultiTenancy.WebFilter.Url.Profile.Log.Level')])),
                                            ])
                                            self.level = None
                                            self._segment_path = lambda: "log"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.UtdMt.Utd.Engine.Standard.MultiTenancy.WebFilter.Url.Profile.Log, ['level'], name, value)

                                        class Level(Enum):
                                            """
                                            Level (Enum Class)

                                            Choose the URL filtering preprocessor log level

                                            .. data:: detailed = 0

                                            .. data:: error = 1

                                            .. data:: info = 2

                                            """

                                            detailed = Enum.YLeaf(0, "detailed")

                                            error = Enum.YLeaf(1, "error")

                                            info = Enum.YLeaf(2, "info")



                                    class Reputation(Entity):
                                        """
                                        Choose the reputation range for the URLs to be blocked
                                        
                                        .. attribute:: block_threshold
                                        
                                        	Block the URLs with reputation at or above the specified level
                                        	**type**\:  :py:class:`BlockThreshold <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.UtdMt.Utd.Engine.Standard.MultiTenancy.WebFilter.Url.Profile.Reputation.BlockThreshold>`
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-utd'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.UtdMt.Utd.Engine.Standard.MultiTenancy.WebFilter.Url.Profile.Reputation, self).__init__()

                                            self.yang_name = "reputation"
                                            self.yang_parent_name = "profile"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict([
                                                ('block_threshold', (YLeaf(YType.enumeration, 'block-threshold'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'UtdMt.Utd.Engine.Standard.MultiTenancy.WebFilter.Url.Profile.Reputation.BlockThreshold')])),
                                            ])
                                            self.block_threshold = None
                                            self._segment_path = lambda: "reputation"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.UtdMt.Utd.Engine.Standard.MultiTenancy.WebFilter.Url.Profile.Reputation, ['block_threshold'], name, value)

                                        class BlockThreshold(Enum):
                                            """
                                            BlockThreshold (Enum Class)

                                            Block the URLs with reputation at or above the specified level

                                            .. data:: high_risk = 0

                                            .. data:: low_risk = 1

                                            .. data:: moderate_risk = 2

                                            .. data:: suspicious = 3

                                            .. data:: trustworthy = 4

                                            """

                                            high_risk = Enum.YLeaf(0, "high-risk")

                                            low_risk = Enum.YLeaf(1, "low-risk")

                                            moderate_risk = Enum.YLeaf(2, "moderate-risk")

                                            suspicious = Enum.YLeaf(3, "suspicious")

                                            trustworthy = Enum.YLeaf(4, "trustworthy")



                                    class Sourcedb(Entity):
                                        """
                                        Choose source DB related configs
                                        
                                        .. attribute:: fail
                                        
                                        	Choose the fail option to apply when the source DB is down
                                        	**type**\:  :py:class:`Fail <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.UtdMt.Utd.Engine.Standard.MultiTenancy.WebFilter.Url.Profile.Sourcedb.Fail>`
                                        
                                        

                                        """

                                        _prefix = 'ios-utd'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.UtdMt.Utd.Engine.Standard.MultiTenancy.WebFilter.Url.Profile.Sourcedb, self).__init__()

                                            self.yang_name = "sourcedb"
                                            self.yang_parent_name = "profile"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("fail", ("fail", Native.UtdMt.Utd.Engine.Standard.MultiTenancy.WebFilter.Url.Profile.Sourcedb.Fail))])
                                            self._leafs = OrderedDict()

                                            self.fail = Native.UtdMt.Utd.Engine.Standard.MultiTenancy.WebFilter.Url.Profile.Sourcedb.Fail()
                                            self.fail.parent = self
                                            self._children_name_map["fail"] = "fail"
                                            self._segment_path = lambda: "sourcedb"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.UtdMt.Utd.Engine.Standard.MultiTenancy.WebFilter.Url.Profile.Sourcedb, [], name, value)


                                        class Fail(Entity):
                                            """
                                            Choose the fail option to apply when the source DB is down
                                            
                                            .. attribute:: close
                                            
                                            	Drop all URL filtering traffic on source DB failure
                                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                            
                                            

                                            """

                                            _prefix = 'ios-utd'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.UtdMt.Utd.Engine.Standard.MultiTenancy.WebFilter.Url.Profile.Sourcedb.Fail, self).__init__()

                                                self.yang_name = "fail"
                                                self.yang_parent_name = "sourcedb"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('close', (YLeaf(YType.empty, 'close'), ['Empty'])),
                                                ])
                                                self.close = None
                                                self._segment_path = lambda: "fail"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.UtdMt.Utd.Engine.Standard.MultiTenancy.WebFilter.Url.Profile.Sourcedb.Fail, ['close'], name, value)


                                    class Whitelist(Entity):
                                        """
                                        Choose the whitelist parameter\-map
                                        
                                        .. attribute:: parameter_map
                                        
                                        	Enter the parameter\-map information for the regex
                                        	**type**\:  :py:class:`ParameterMap <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.UtdMt.Utd.Engine.Standard.MultiTenancy.WebFilter.Url.Profile.Whitelist.ParameterMap>`
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ios-utd'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.UtdMt.Utd.Engine.Standard.MultiTenancy.WebFilter.Url.Profile.Whitelist, self).__init__()

                                            self.yang_name = "whitelist"
                                            self.yang_parent_name = "profile"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("parameter-map", ("parameter_map", Native.UtdMt.Utd.Engine.Standard.MultiTenancy.WebFilter.Url.Profile.Whitelist.ParameterMap))])
                                            self.is_presence_container = True
                                            self._leafs = OrderedDict()

                                            self.parameter_map = Native.UtdMt.Utd.Engine.Standard.MultiTenancy.WebFilter.Url.Profile.Whitelist.ParameterMap()
                                            self.parameter_map.parent = self
                                            self._children_name_map["parameter_map"] = "parameter-map"
                                            self._segment_path = lambda: "whitelist"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.UtdMt.Utd.Engine.Standard.MultiTenancy.WebFilter.Url.Profile.Whitelist, [], name, value)


                                        class ParameterMap(Entity):
                                            """
                                            Enter the parameter\-map information for the regex
                                            
                                            .. attribute:: regex
                                            
                                            	Provide the regex parameter\-map name
                                            	**type**\: str
                                            
                                            	**length:** 1..256
                                            
                                            

                                            """

                                            _prefix = 'ios-utd'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.UtdMt.Utd.Engine.Standard.MultiTenancy.WebFilter.Url.Profile.Whitelist.ParameterMap, self).__init__()

                                                self.yang_name = "parameter-map"
                                                self.yang_parent_name = "whitelist"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('regex', (YLeaf(YType.str, 'regex'), ['str'])),
                                                ])
                                                self.regex = None
                                                self._segment_path = lambda: "parameter-map"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.UtdMt.Utd.Engine.Standard.MultiTenancy.WebFilter.Url.Profile.Whitelist.ParameterMap, ['regex'], name, value)


                        class ThreatInspection(Entity):
                            """
                            UTD Threat Inspection (IPS/IDS) config modes
                            
                            .. attribute:: whitelist
                            
                            	UTD whitelist config submode
                            	**type**\:  :py:class:`Whitelist <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.UtdMt.Utd.Engine.Standard.MultiTenancy.ThreatInspection.Whitelist>`
                            
                            .. attribute:: profile
                            
                            	UTD Threat Inspection profile
                            	**type**\: list of  		 :py:class:`Profile <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.UtdMt.Utd.Engine.Standard.MultiTenancy.ThreatInspection.Profile>`
                            
                            

                            """

                            _prefix = 'ios-utd'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.UtdMt.Utd.Engine.Standard.MultiTenancy.ThreatInspection, self).__init__()

                                self.yang_name = "threat-inspection"
                                self.yang_parent_name = "multi-tenancy"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("whitelist", ("whitelist", Native.UtdMt.Utd.Engine.Standard.MultiTenancy.ThreatInspection.Whitelist)), ("profile", ("profile", Native.UtdMt.Utd.Engine.Standard.MultiTenancy.ThreatInspection.Profile))])
                                self._leafs = OrderedDict()

                                self.whitelist = Native.UtdMt.Utd.Engine.Standard.MultiTenancy.ThreatInspection.Whitelist()
                                self.whitelist.parent = self
                                self._children_name_map["whitelist"] = "whitelist"

                                self.profile = YList(self)
                                self._segment_path = lambda: "threat-inspection"
                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/Cisco-IOS-XE-utd:utd-mt/utd/engine/standard/multi-tenancy/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.UtdMt.Utd.Engine.Standard.MultiTenancy.ThreatInspection, [], name, value)


                            class Whitelist(Entity):
                                """
                                UTD whitelist config submode
                                
                                .. attribute:: profile
                                
                                	UTD whitelist profile
                                	**type**\: list of  		 :py:class:`Profile <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.UtdMt.Utd.Engine.Standard.MultiTenancy.ThreatInspection.Whitelist.Profile>`
                                
                                

                                """

                                _prefix = 'ios-utd'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.UtdMt.Utd.Engine.Standard.MultiTenancy.ThreatInspection.Whitelist, self).__init__()

                                    self.yang_name = "whitelist"
                                    self.yang_parent_name = "threat-inspection"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("profile", ("profile", Native.UtdMt.Utd.Engine.Standard.MultiTenancy.ThreatInspection.Whitelist.Profile))])
                                    self._leafs = OrderedDict()

                                    self.profile = YList(self)
                                    self._segment_path = lambda: "whitelist"
                                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/Cisco-IOS-XE-utd:utd-mt/utd/engine/standard/multi-tenancy/threat-inspection/%s" % self._segment_path()
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.UtdMt.Utd.Engine.Standard.MultiTenancy.ThreatInspection.Whitelist, [], name, value)


                                class Profile(Entity):
                                    """
                                    UTD whitelist profile
                                    
                                    .. attribute:: name  (key)
                                    
                                    	
                                    	**type**\: str
                                    
                                    	**length:** 1..512
                                    
                                    .. attribute:: generator
                                    
                                    	Provide generator for the whitelist
                                    	**type**\: list of  		 :py:class:`Generator <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.UtdMt.Utd.Engine.Standard.MultiTenancy.ThreatInspection.Whitelist.Profile.Generator>`
                                    
                                    

                                    """

                                    _prefix = 'ios-utd'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.UtdMt.Utd.Engine.Standard.MultiTenancy.ThreatInspection.Whitelist.Profile, self).__init__()

                                        self.yang_name = "profile"
                                        self.yang_parent_name = "whitelist"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = ['name']
                                        self._child_classes = OrderedDict([("generator", ("generator", Native.UtdMt.Utd.Engine.Standard.MultiTenancy.ThreatInspection.Whitelist.Profile.Generator))])
                                        self._leafs = OrderedDict([
                                            ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                        ])
                                        self.name = None

                                        self.generator = YList(self)
                                        self._segment_path = lambda: "profile" + "[name='" + str(self.name) + "']"
                                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/Cisco-IOS-XE-utd:utd-mt/utd/engine/standard/multi-tenancy/threat-inspection/whitelist/%s" % self._segment_path()
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.UtdMt.Utd.Engine.Standard.MultiTenancy.ThreatInspection.Whitelist.Profile, ['name'], name, value)


                                    class Generator(Entity):
                                        """
                                        Provide generator for the whitelist
                                        
                                        .. attribute:: id  (key)
                                        
                                        	Provide the generator ID to be whitelisted
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: signature
                                        
                                        	Provide signature for the whitelist
                                        	**type**\: list of  		 :py:class:`Signature <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.UtdMt.Utd.Engine.Standard.MultiTenancy.ThreatInspection.Whitelist.Profile.Generator.Signature>`
                                        
                                        

                                        """

                                        _prefix = 'ios-utd'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.UtdMt.Utd.Engine.Standard.MultiTenancy.ThreatInspection.Whitelist.Profile.Generator, self).__init__()

                                            self.yang_name = "generator"
                                            self.yang_parent_name = "profile"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = ['id']
                                            self._child_classes = OrderedDict([("signature", ("signature", Native.UtdMt.Utd.Engine.Standard.MultiTenancy.ThreatInspection.Whitelist.Profile.Generator.Signature))])
                                            self._leafs = OrderedDict([
                                                ('id', (YLeaf(YType.uint32, 'id'), ['int'])),
                                            ])
                                            self.id = None

                                            self.signature = YList(self)
                                            self._segment_path = lambda: "generator" + "[id='" + str(self.id) + "']"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.UtdMt.Utd.Engine.Standard.MultiTenancy.ThreatInspection.Whitelist.Profile.Generator, ['id'], name, value)


                                        class Signature(Entity):
                                            """
                                            Provide signature for the whitelist
                                            
                                            .. attribute:: id  (key)
                                            
                                            	Provide the signature ID to be whitelisted
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: comment
                                            
                                            	Provide a comment for the whitelist
                                            	**type**\: str
                                            
                                            	**length:** 1..512
                                            
                                            

                                            """

                                            _prefix = 'ios-utd'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.UtdMt.Utd.Engine.Standard.MultiTenancy.ThreatInspection.Whitelist.Profile.Generator.Signature, self).__init__()

                                                self.yang_name = "signature"
                                                self.yang_parent_name = "generator"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['id']
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('id', (YLeaf(YType.uint32, 'id'), ['int'])),
                                                    ('comment', (YLeaf(YType.str, 'comment'), ['str'])),
                                                ])
                                                self.id = None
                                                self.comment = None
                                                self._segment_path = lambda: "signature" + "[id='" + str(self.id) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.UtdMt.Utd.Engine.Standard.MultiTenancy.ThreatInspection.Whitelist.Profile.Generator.Signature, ['id', 'comment'], name, value)


                            class Profile(Entity):
                                """
                                UTD Threat Inspection profile
                                
                                .. attribute:: name  (key)
                                
                                	
                                	**type**\: str
                                
                                	**length:** 1..512
                                
                                .. attribute:: threat
                                
                                	Provide the threat detection/protection option (default=detection)
                                	**type**\:  :py:class:`Threat <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.UtdMt.Utd.Engine.Standard.MultiTenancy.ThreatInspection.Profile.Threat>`
                                
                                .. attribute:: policy
                                
                                	Provide the policy option (default=balanced)
                                	**type**\:  :py:class:`Policy <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.UtdMt.Utd.Engine.Standard.MultiTenancy.ThreatInspection.Profile.Policy>`
                                
                                .. attribute:: logging
                                
                                	Provide logging level for the alerts for IPS/IDS
                                	**type**\:  :py:class:`Logging <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.UtdMt.Utd.Engine.Standard.MultiTenancy.ThreatInspection.Profile.Logging>`
                                
                                .. attribute:: whitelist
                                
                                	Associate a whitelist profile with this profile
                                	**type**\:  :py:class:`Whitelist <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.UtdMt.Utd.Engine.Standard.MultiTenancy.ThreatInspection.Profile.Whitelist>`
                                
                                

                                """

                                _prefix = 'ios-utd'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.UtdMt.Utd.Engine.Standard.MultiTenancy.ThreatInspection.Profile, self).__init__()

                                    self.yang_name = "profile"
                                    self.yang_parent_name = "threat-inspection"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self.ylist_key_names = ['name']
                                    self._child_classes = OrderedDict([("logging", ("logging", Native.UtdMt.Utd.Engine.Standard.MultiTenancy.ThreatInspection.Profile.Logging)), ("whitelist", ("whitelist", Native.UtdMt.Utd.Engine.Standard.MultiTenancy.ThreatInspection.Profile.Whitelist))])
                                    self._leafs = OrderedDict([
                                        ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                        ('threat', (YLeaf(YType.enumeration, 'threat'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'UtdMt.Utd.Engine.Standard.MultiTenancy.ThreatInspection.Profile.Threat')])),
                                        ('policy', (YLeaf(YType.enumeration, 'policy'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'UtdMt.Utd.Engine.Standard.MultiTenancy.ThreatInspection.Profile.Policy')])),
                                    ])
                                    self.name = None
                                    self.threat = None
                                    self.policy = None

                                    self.logging = Native.UtdMt.Utd.Engine.Standard.MultiTenancy.ThreatInspection.Profile.Logging()
                                    self.logging.parent = self
                                    self._children_name_map["logging"] = "logging"

                                    self.whitelist = Native.UtdMt.Utd.Engine.Standard.MultiTenancy.ThreatInspection.Profile.Whitelist()
                                    self.whitelist.parent = self
                                    self._children_name_map["whitelist"] = "whitelist"
                                    self._segment_path = lambda: "profile" + "[name='" + str(self.name) + "']"
                                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/Cisco-IOS-XE-utd:utd-mt/utd/engine/standard/multi-tenancy/threat-inspection/%s" % self._segment_path()
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.UtdMt.Utd.Engine.Standard.MultiTenancy.ThreatInspection.Profile, ['name', 'threat', 'policy'], name, value)

                                class Policy(Enum):
                                    """
                                    Policy (Enum Class)

                                    Provide the policy option (default=balanced)

                                    .. data:: balanced = 0

                                    .. data:: connectivity = 1

                                    .. data:: security = 2

                                    """

                                    balanced = Enum.YLeaf(0, "balanced")

                                    connectivity = Enum.YLeaf(1, "connectivity")

                                    security = Enum.YLeaf(2, "security")


                                class Threat(Enum):
                                    """
                                    Threat (Enum Class)

                                    Provide the threat detection/protection option (default=detection)

                                    .. data:: detection = 0

                                    .. data:: protection = 1

                                    """

                                    detection = Enum.YLeaf(0, "detection")

                                    protection = Enum.YLeaf(1, "protection")



                                class Logging(Entity):
                                    """
                                    Provide logging level for the alerts for IPS/IDS
                                    
                                    .. attribute:: level
                                    
                                    	Provide the log level
                                    	**type**\:  :py:class:`Level <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.UtdMt.Utd.Engine.Standard.MultiTenancy.ThreatInspection.Profile.Logging.Level>`
                                    
                                    

                                    """

                                    _prefix = 'ios-utd'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.UtdMt.Utd.Engine.Standard.MultiTenancy.ThreatInspection.Profile.Logging, self).__init__()

                                        self.yang_name = "logging"
                                        self.yang_parent_name = "profile"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('level', (YLeaf(YType.enumeration, 'level'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'UtdMt.Utd.Engine.Standard.MultiTenancy.ThreatInspection.Profile.Logging.Level')])),
                                        ])
                                        self.level = None
                                        self._segment_path = lambda: "logging"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.UtdMt.Utd.Engine.Standard.MultiTenancy.ThreatInspection.Profile.Logging, ['level'], name, value)

                                    class Level(Enum):
                                        """
                                        Level (Enum Class)

                                        Provide the log level

                                        .. data:: emerg = 0

                                        .. data:: alert = 1

                                        .. data:: crit = 2

                                        .. data:: err = 3

                                        .. data:: warning = 4

                                        .. data:: notice = 5

                                        .. data:: info = 6

                                        .. data:: debug = 7

                                        """

                                        emerg = Enum.YLeaf(0, "emerg")

                                        alert = Enum.YLeaf(1, "alert")

                                        crit = Enum.YLeaf(2, "crit")

                                        err = Enum.YLeaf(3, "err")

                                        warning = Enum.YLeaf(4, "warning")

                                        notice = Enum.YLeaf(5, "notice")

                                        info = Enum.YLeaf(6, "info")

                                        debug = Enum.YLeaf(7, "debug")



                                class Whitelist(Entity):
                                    """
                                    Associate a whitelist profile with this profile
                                    
                                    .. attribute:: profile
                                    
                                    	UTD whitelist profile
                                    	**type**\: str
                                    
                                    	**length:** 1..512
                                    
                                    

                                    """

                                    _prefix = 'ios-utd'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.UtdMt.Utd.Engine.Standard.MultiTenancy.ThreatInspection.Profile.Whitelist, self).__init__()

                                        self.yang_name = "whitelist"
                                        self.yang_parent_name = "profile"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('profile', (YLeaf(YType.str, 'profile'), ['str'])),
                                        ])
                                        self.profile = None
                                        self._segment_path = lambda: "whitelist"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.UtdMt.Utd.Engine.Standard.MultiTenancy.ThreatInspection.Profile.Whitelist, ['profile'], name, value)


                        class Utd_(Entity):
                            """
                            UTD engine standard settings
                            
                            .. attribute:: global_
                            
                            	UTD engine standard global settings
                            	**type**\:  :py:class:`Global <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.UtdMt.Utd.Engine.Standard.MultiTenancy.Utd_.Global>`
                            
                            	**presence node**\: True
                            
                            

                            """

                            _prefix = 'ios-utd'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.UtdMt.Utd.Engine.Standard.MultiTenancy.Utd_, self).__init__()

                                self.yang_name = "utd"
                                self.yang_parent_name = "multi-tenancy"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("global", ("global_", Native.UtdMt.Utd.Engine.Standard.MultiTenancy.Utd_.Global))])
                                self._leafs = OrderedDict()

                                self.global_ = None
                                self._children_name_map["global_"] = "global"
                                self._segment_path = lambda: "utd"
                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/Cisco-IOS-XE-utd:utd-mt/utd/engine/standard/multi-tenancy/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.UtdMt.Utd.Engine.Standard.MultiTenancy.Utd_, [], name, value)


                            class Global(Entity):
                                """
                                UTD engine standard global settings
                                
                                .. attribute:: logging
                                
                                	Provide config options for logging the alerts
                                	**type**\:  :py:class:`Logging <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.UtdMt.Utd.Engine.Standard.MultiTenancy.Utd_.Global.Logging>`
                                
                                .. attribute:: threat_inspection
                                
                                	IPS (or IDS) specific config commands
                                	**type**\:  :py:class:`ThreatInspection <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.UtdMt.Utd.Engine.Standard.MultiTenancy.Utd_.Global.ThreatInspection>`
                                
                                	**presence node**\: True
                                
                                .. attribute:: web_filter
                                
                                	UTD engine standard web\-filtering configs
                                	**type**\:  :py:class:`WebFilter <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.UtdMt.Utd.Engine.Standard.MultiTenancy.Utd_.Global.WebFilter>`
                                
                                	**presence node**\: True
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ios-utd'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.UtdMt.Utd.Engine.Standard.MultiTenancy.Utd_.Global, self).__init__()

                                    self.yang_name = "global"
                                    self.yang_parent_name = "utd"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("logging", ("logging", Native.UtdMt.Utd.Engine.Standard.MultiTenancy.Utd_.Global.Logging)), ("threat-inspection", ("threat_inspection", Native.UtdMt.Utd.Engine.Standard.MultiTenancy.Utd_.Global.ThreatInspection)), ("web-filter", ("web_filter", Native.UtdMt.Utd.Engine.Standard.MultiTenancy.Utd_.Global.WebFilter))])
                                    self.is_presence_container = True
                                    self._leafs = OrderedDict()

                                    self.logging = Native.UtdMt.Utd.Engine.Standard.MultiTenancy.Utd_.Global.Logging()
                                    self.logging.parent = self
                                    self._children_name_map["logging"] = "logging"

                                    self.threat_inspection = None
                                    self._children_name_map["threat_inspection"] = "threat-inspection"

                                    self.web_filter = None
                                    self._children_name_map["web_filter"] = "web-filter"
                                    self._segment_path = lambda: "global"
                                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/Cisco-IOS-XE-utd:utd-mt/utd/engine/standard/multi-tenancy/utd/%s" % self._segment_path()
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.UtdMt.Utd.Engine.Standard.MultiTenancy.Utd_.Global, [], name, value)


                                class Logging(Entity):
                                    """
                                    Provide config options for logging the alerts
                                    
                                    .. attribute:: host
                                    
                                    	Log the alerts to a host
                                    	**type**\: list of  		 :py:class:`Host <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.UtdMt.Utd.Engine.Standard.MultiTenancy.Utd_.Global.Logging.Host>`
                                    
                                    .. attribute:: syslog
                                    
                                    	Log the alerts to IOS syslogs
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    """

                                    _prefix = 'ios-utd'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.UtdMt.Utd.Engine.Standard.MultiTenancy.Utd_.Global.Logging, self).__init__()

                                        self.yang_name = "logging"
                                        self.yang_parent_name = "global"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("host", ("host", Native.UtdMt.Utd.Engine.Standard.MultiTenancy.Utd_.Global.Logging.Host))])
                                        self._leafs = OrderedDict([
                                            ('syslog', (YLeaf(YType.empty, 'syslog'), ['Empty'])),
                                        ])
                                        self.syslog = None

                                        self.host = YList(self)
                                        self._segment_path = lambda: "logging"
                                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/Cisco-IOS-XE-utd:utd-mt/utd/engine/standard/multi-tenancy/utd/global/%s" % self._segment_path()
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.UtdMt.Utd.Engine.Standard.MultiTenancy.Utd_.Global.Logging, ['syslog'], name, value)


                                    class Host(Entity):
                                        """
                                        Log the alerts to a host
                                        
                                        .. attribute:: name  (key)
                                        
                                        	
                                        	**type**\: str
                                        
                                        	**length:** 1..45
                                        
                                        

                                        """

                                        _prefix = 'ios-utd'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.UtdMt.Utd.Engine.Standard.MultiTenancy.Utd_.Global.Logging.Host, self).__init__()

                                            self.yang_name = "host"
                                            self.yang_parent_name = "logging"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = False
                                            self.ylist_key_names = ['name']
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                            ])
                                            self.name = None
                                            self._segment_path = lambda: "host" + "[name='" + str(self.name) + "']"
                                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/Cisco-IOS-XE-utd:utd-mt/utd/engine/standard/multi-tenancy/utd/global/logging/%s" % self._segment_path()
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.UtdMt.Utd.Engine.Standard.MultiTenancy.Utd_.Global.Logging.Host, ['name'], name, value)


                                class ThreatInspection(Entity):
                                    """
                                    IPS (or IDS) specific config commands
                                    
                                    .. attribute:: signature
                                    
                                    	Provide config options for the signatures
                                    	**type**\:  :py:class:`Signature <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.UtdMt.Utd.Engine.Standard.MultiTenancy.Utd_.Global.ThreatInspection.Signature>`
                                    
                                    

                                    This class is a :ref:`presence class<presence-class>`

                                    """

                                    _prefix = 'ios-utd'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.UtdMt.Utd.Engine.Standard.MultiTenancy.Utd_.Global.ThreatInspection, self).__init__()

                                        self.yang_name = "threat-inspection"
                                        self.yang_parent_name = "global"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("signature", ("signature", Native.UtdMt.Utd.Engine.Standard.MultiTenancy.Utd_.Global.ThreatInspection.Signature))])
                                        self.is_presence_container = True
                                        self._leafs = OrderedDict()

                                        self.signature = Native.UtdMt.Utd.Engine.Standard.MultiTenancy.Utd_.Global.ThreatInspection.Signature()
                                        self.signature.parent = self
                                        self._children_name_map["signature"] = "signature"
                                        self._segment_path = lambda: "threat-inspection"
                                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/Cisco-IOS-XE-utd:utd-mt/utd/engine/standard/multi-tenancy/utd/global/%s" % self._segment_path()
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.UtdMt.Utd.Engine.Standard.MultiTenancy.Utd_.Global.ThreatInspection, [], name, value)


                                    class Signature(Entity):
                                        """
                                        Provide config options for the signatures
                                        
                                        .. attribute:: update
                                        
                                        	Provide config options for the signature updates
                                        	**type**\:  :py:class:`Update <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.UtdMt.Utd.Engine.Standard.MultiTenancy.Utd_.Global.ThreatInspection.Signature.Update>`
                                        
                                        

                                        """

                                        _prefix = 'ios-utd'
                                        _revision = '2018-06-28'

                                        def __init__(self):
                                            super(Native.UtdMt.Utd.Engine.Standard.MultiTenancy.Utd_.Global.ThreatInspection.Signature, self).__init__()

                                            self.yang_name = "signature"
                                            self.yang_parent_name = "threat-inspection"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = False
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("update", ("update", Native.UtdMt.Utd.Engine.Standard.MultiTenancy.Utd_.Global.ThreatInspection.Signature.Update))])
                                            self._leafs = OrderedDict()

                                            self.update = Native.UtdMt.Utd.Engine.Standard.MultiTenancy.Utd_.Global.ThreatInspection.Signature.Update()
                                            self.update.parent = self
                                            self._children_name_map["update"] = "update"
                                            self._segment_path = lambda: "signature"
                                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/Cisco-IOS-XE-utd:utd-mt/utd/engine/standard/multi-tenancy/utd/global/threat-inspection/%s" % self._segment_path()
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.UtdMt.Utd.Engine.Standard.MultiTenancy.Utd_.Global.ThreatInspection.Signature, [], name, value)


                                        class Update(Entity):
                                            """
                                            Provide config options for the signature updates
                                            
                                            .. attribute:: occur_at
                                            
                                            	Specify update occurence by calendar time
                                            	**type**\:  :py:class:`OccurAt <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.UtdMt.Utd.Engine.Standard.MultiTenancy.Utd_.Global.ThreatInspection.Signature.Update.OccurAt>`
                                            
                                            .. attribute:: server
                                            
                                            	Provide config options for the signature update server
                                            	**type**\:  :py:class:`Server <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.UtdMt.Utd.Engine.Standard.MultiTenancy.Utd_.Global.ThreatInspection.Signature.Update.Server>`
                                            
                                            

                                            """

                                            _prefix = 'ios-utd'
                                            _revision = '2018-06-28'

                                            def __init__(self):
                                                super(Native.UtdMt.Utd.Engine.Standard.MultiTenancy.Utd_.Global.ThreatInspection.Signature.Update, self).__init__()

                                                self.yang_name = "update"
                                                self.yang_parent_name = "signature"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = False
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("occur-at", ("occur_at", Native.UtdMt.Utd.Engine.Standard.MultiTenancy.Utd_.Global.ThreatInspection.Signature.Update.OccurAt)), ("server", ("server", Native.UtdMt.Utd.Engine.Standard.MultiTenancy.Utd_.Global.ThreatInspection.Signature.Update.Server))])
                                                self._leafs = OrderedDict()

                                                self.occur_at = Native.UtdMt.Utd.Engine.Standard.MultiTenancy.Utd_.Global.ThreatInspection.Signature.Update.OccurAt()
                                                self.occur_at.parent = self
                                                self._children_name_map["occur_at"] = "occur-at"

                                                self.server = Native.UtdMt.Utd.Engine.Standard.MultiTenancy.Utd_.Global.ThreatInspection.Signature.Update.Server()
                                                self.server.parent = self
                                                self._children_name_map["server"] = "server"
                                                self._segment_path = lambda: "update"
                                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/Cisco-IOS-XE-utd:utd-mt/utd/engine/standard/multi-tenancy/utd/global/threat-inspection/signature/%s" % self._segment_path()
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.UtdMt.Utd.Engine.Standard.MultiTenancy.Utd_.Global.ThreatInspection.Signature.Update, [], name, value)


                                            class OccurAt(Entity):
                                                """
                                                Specify update occurence by calendar time
                                                
                                                .. attribute:: daily
                                                
                                                	Option for daily update
                                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                                
                                                .. attribute:: monthly
                                                
                                                	Option for monthly update
                                                	**type**\: str
                                                
                                                	**length:** 1..512
                                                
                                                .. attribute:: weekly
                                                
                                                	Option for weekly update
                                                	**type**\: str
                                                
                                                	**length:** 1..512
                                                
                                                .. attribute:: hours
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 0..23
                                                
                                                .. attribute:: minutes
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 0..59
                                                
                                                

                                                """

                                                _prefix = 'ios-utd'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.UtdMt.Utd.Engine.Standard.MultiTenancy.Utd_.Global.ThreatInspection.Signature.Update.OccurAt, self).__init__()

                                                    self.yang_name = "occur-at"
                                                    self.yang_parent_name = "update"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = False
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('daily', (YLeaf(YType.empty, 'daily'), ['Empty'])),
                                                        ('monthly', (YLeaf(YType.str, 'monthly'), ['str'])),
                                                        ('weekly', (YLeaf(YType.str, 'weekly'), ['str'])),
                                                        ('hours', (YLeaf(YType.uint8, 'hours'), ['int'])),
                                                        ('minutes', (YLeaf(YType.uint8, 'minutes'), ['int'])),
                                                    ])
                                                    self.daily = None
                                                    self.monthly = None
                                                    self.weekly = None
                                                    self.hours = None
                                                    self.minutes = None
                                                    self._segment_path = lambda: "occur-at"
                                                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/Cisco-IOS-XE-utd:utd-mt/utd/engine/standard/multi-tenancy/utd/global/threat-inspection/signature/update/%s" % self._segment_path()
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.UtdMt.Utd.Engine.Standard.MultiTenancy.Utd_.Global.ThreatInspection.Signature.Update.OccurAt, ['daily', 'monthly', 'weekly', 'hours', 'minutes'], name, value)


                                            class Server(Entity):
                                                """
                                                Provide config options for the signature update server
                                                
                                                .. attribute:: cisco
                                                
                                                	Use Cisco site to provide updates
                                                	**type**\:  :py:class:`Cisco <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.UtdMt.Utd.Engine.Standard.MultiTenancy.Utd_.Global.ThreatInspection.Signature.Update.Server.Cisco>`
                                                
                                                .. attribute:: url
                                                
                                                	Enter the complete URL for the path to the update server
                                                	**type**\:  :py:class:`Url <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.UtdMt.Utd.Engine.Standard.MultiTenancy.Utd_.Global.ThreatInspection.Signature.Update.Server.Url>`
                                                
                                                

                                                """

                                                _prefix = 'ios-utd'
                                                _revision = '2018-06-28'

                                                def __init__(self):
                                                    super(Native.UtdMt.Utd.Engine.Standard.MultiTenancy.Utd_.Global.ThreatInspection.Signature.Update.Server, self).__init__()

                                                    self.yang_name = "server"
                                                    self.yang_parent_name = "update"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = False
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("cisco", ("cisco", Native.UtdMt.Utd.Engine.Standard.MultiTenancy.Utd_.Global.ThreatInspection.Signature.Update.Server.Cisco)), ("url", ("url", Native.UtdMt.Utd.Engine.Standard.MultiTenancy.Utd_.Global.ThreatInspection.Signature.Update.Server.Url))])
                                                    self._leafs = OrderedDict()

                                                    self.cisco = Native.UtdMt.Utd.Engine.Standard.MultiTenancy.Utd_.Global.ThreatInspection.Signature.Update.Server.Cisco()
                                                    self.cisco.parent = self
                                                    self._children_name_map["cisco"] = "cisco"

                                                    self.url = Native.UtdMt.Utd.Engine.Standard.MultiTenancy.Utd_.Global.ThreatInspection.Signature.Update.Server.Url()
                                                    self.url.parent = self
                                                    self._children_name_map["url"] = "url"
                                                    self._segment_path = lambda: "server"
                                                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/Cisco-IOS-XE-utd:utd-mt/utd/engine/standard/multi-tenancy/utd/global/threat-inspection/signature/update/%s" % self._segment_path()
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.UtdMt.Utd.Engine.Standard.MultiTenancy.Utd_.Global.ThreatInspection.Signature.Update.Server, [], name, value)


                                                class Cisco(Entity):
                                                    """
                                                    Use Cisco site to provide updates
                                                    
                                                    .. attribute:: username
                                                    
                                                    	Provide the username for authentication
                                                    	**type**\: str
                                                    
                                                    	**length:** 1..512
                                                    
                                                    .. attribute:: password
                                                    
                                                    	Provide the password for authentication
                                                    	**type**\: str
                                                    
                                                    	**length:** 1..512
                                                    
                                                    

                                                    """

                                                    _prefix = 'ios-utd'
                                                    _revision = '2018-06-28'

                                                    def __init__(self):
                                                        super(Native.UtdMt.Utd.Engine.Standard.MultiTenancy.Utd_.Global.ThreatInspection.Signature.Update.Server.Cisco, self).__init__()

                                                        self.yang_name = "cisco"
                                                        self.yang_parent_name = "server"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = False
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('username', (YLeaf(YType.str, 'username'), ['str'])),
                                                            ('password', (YLeaf(YType.str, 'password'), ['str'])),
                                                        ])
                                                        self.username = None
                                                        self.password = None
                                                        self._segment_path = lambda: "cisco"
                                                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/Cisco-IOS-XE-utd:utd-mt/utd/engine/standard/multi-tenancy/utd/global/threat-inspection/signature/update/server/%s" % self._segment_path()
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.UtdMt.Utd.Engine.Standard.MultiTenancy.Utd_.Global.ThreatInspection.Signature.Update.Server.Cisco, ['username', 'password'], name, value)


                                                class Url(Entity):
                                                    """
                                                    Enter the complete URL for the path to the update server
                                                    
                                                    .. attribute:: all
                                                    
                                                    	
                                                    	**type**\:  :py:class:`All <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.UtdMt.Utd.Engine.Standard.MultiTenancy.Utd_.Global.ThreatInspection.Signature.Update.Server.Url.All>`
                                                    
                                                    .. attribute:: name
                                                    
                                                    	
                                                    	**type**\: str
                                                    
                                                    	**length:** 1..512
                                                    
                                                    

                                                    """

                                                    _prefix = 'ios-utd'
                                                    _revision = '2018-06-28'

                                                    def __init__(self):
                                                        super(Native.UtdMt.Utd.Engine.Standard.MultiTenancy.Utd_.Global.ThreatInspection.Signature.Update.Server.Url, self).__init__()

                                                        self.yang_name = "url"
                                                        self.yang_parent_name = "server"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = False
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("all", ("all", Native.UtdMt.Utd.Engine.Standard.MultiTenancy.Utd_.Global.ThreatInspection.Signature.Update.Server.Url.All))])
                                                        self._leafs = OrderedDict([
                                                            ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                                        ])
                                                        self.name = None

                                                        self.all = Native.UtdMt.Utd.Engine.Standard.MultiTenancy.Utd_.Global.ThreatInspection.Signature.Update.Server.Url.All()
                                                        self.all.parent = self
                                                        self._children_name_map["all"] = "all"
                                                        self._segment_path = lambda: "url"
                                                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/Cisco-IOS-XE-utd:utd-mt/utd/engine/standard/multi-tenancy/utd/global/threat-inspection/signature/update/server/%s" % self._segment_path()
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.UtdMt.Utd.Engine.Standard.MultiTenancy.Utd_.Global.ThreatInspection.Signature.Update.Server.Url, ['name'], name, value)


                                                    class All(Entity):
                                                        """
                                                        
                                                        
                                                        .. attribute:: name
                                                        
                                                        	
                                                        	**type**\: str
                                                        
                                                        	**length:** 1..512
                                                        
                                                        .. attribute:: username
                                                        
                                                        	Provide the username for authentication
                                                        	**type**\: str
                                                        
                                                        	**length:** 1..512
                                                        
                                                        .. attribute:: password
                                                        
                                                        	Provide the password for authentication
                                                        	**type**\: str
                                                        
                                                        	**length:** 1..512
                                                        
                                                        

                                                        """

                                                        _prefix = 'ios-utd'
                                                        _revision = '2018-06-28'

                                                        def __init__(self):
                                                            super(Native.UtdMt.Utd.Engine.Standard.MultiTenancy.Utd_.Global.ThreatInspection.Signature.Update.Server.Url.All, self).__init__()

                                                            self.yang_name = "all"
                                                            self.yang_parent_name = "url"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = False
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                                                ('username', (YLeaf(YType.str, 'username'), ['str'])),
                                                                ('password', (YLeaf(YType.str, 'password'), ['str'])),
                                                            ])
                                                            self.name = None
                                                            self.username = None
                                                            self.password = None
                                                            self._segment_path = lambda: "all"
                                                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/Cisco-IOS-XE-utd:utd-mt/utd/engine/standard/multi-tenancy/utd/global/threat-inspection/signature/update/server/url/%s" % self._segment_path()
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Native.UtdMt.Utd.Engine.Standard.MultiTenancy.Utd_.Global.ThreatInspection.Signature.Update.Server.Url.All, ['name', 'username', 'password'], name, value)


                                class WebFilter(Entity):
                                    """
                                    UTD engine standard web\-filtering configs
                                    
                                    .. attribute:: sourcedb
                                    
                                    	Choose the source DB profile to use for web filtering
                                    	**type**\: str
                                    
                                    	**length:** 1..512
                                    
                                    

                                    This class is a :ref:`presence class<presence-class>`

                                    """

                                    _prefix = 'ios-utd'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.UtdMt.Utd.Engine.Standard.MultiTenancy.Utd_.Global.WebFilter, self).__init__()

                                        self.yang_name = "web-filter"
                                        self.yang_parent_name = "global"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self.is_presence_container = True
                                        self._leafs = OrderedDict([
                                            ('sourcedb', (YLeaf(YType.str, 'sourcedb'), ['str'])),
                                        ])
                                        self.sourcedb = None
                                        self._segment_path = lambda: "web-filter"
                                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/Cisco-IOS-XE-utd:utd-mt/utd/engine/standard/multi-tenancy/utd/global/%s" % self._segment_path()
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.UtdMt.Utd.Engine.Standard.MultiTenancy.Utd_.Global.WebFilter, ['sourcedb'], name, value)


                        class Policy(Entity):
                            """
                            Multi\-tenancy utd policy
                            
                            .. attribute:: name  (key)
                            
                            	
                            	**type**\: str
                            
                            	**length:** 1..512
                            
                            .. attribute:: all_interfaces
                            
                            	Enable intrusion inspection on all supported interfaces for this set of VRFs
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: fail
                            
                            	Enter the UTD engine fail mode operation
                            	**type**\:  :py:class:`Fail <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.UtdMt.Utd.Engine.Standard.MultiTenancy.Policy.Fail>`
                            
                            .. attribute:: vrf
                            
                            	Associate a VRF with this policy
                            	**type**\: list of  		 :py:class:`Vrf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.UtdMt.Utd.Engine.Standard.MultiTenancy.Policy.Vrf>`
                            
                            .. attribute:: threat_inspection
                            
                            	Associate threat\-inspection profile with this policy
                            	**type**\:  :py:class:`ThreatInspection <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.UtdMt.Utd.Engine.Standard.MultiTenancy.Policy.ThreatInspection>`
                            
                            .. attribute:: web_filter
                            
                            	Associate web filter profile with this policy
                            	**type**\:  :py:class:`WebFilter <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.UtdMt.Utd.Engine.Standard.MultiTenancy.Policy.WebFilter>`
                            
                            

                            """

                            _prefix = 'ios-utd'
                            _revision = '2018-06-28'

                            def __init__(self):
                                super(Native.UtdMt.Utd.Engine.Standard.MultiTenancy.Policy, self).__init__()

                                self.yang_name = "policy"
                                self.yang_parent_name = "multi-tenancy"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = ['name']
                                self._child_classes = OrderedDict([("fail", ("fail", Native.UtdMt.Utd.Engine.Standard.MultiTenancy.Policy.Fail)), ("vrf", ("vrf", Native.UtdMt.Utd.Engine.Standard.MultiTenancy.Policy.Vrf)), ("threat-inspection", ("threat_inspection", Native.UtdMt.Utd.Engine.Standard.MultiTenancy.Policy.ThreatInspection)), ("web-filter", ("web_filter", Native.UtdMt.Utd.Engine.Standard.MultiTenancy.Policy.WebFilter))])
                                self._leafs = OrderedDict([
                                    ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                    ('all_interfaces', (YLeaf(YType.empty, 'all-interfaces'), ['Empty'])),
                                ])
                                self.name = None
                                self.all_interfaces = None

                                self.fail = Native.UtdMt.Utd.Engine.Standard.MultiTenancy.Policy.Fail()
                                self.fail.parent = self
                                self._children_name_map["fail"] = "fail"

                                self.threat_inspection = Native.UtdMt.Utd.Engine.Standard.MultiTenancy.Policy.ThreatInspection()
                                self.threat_inspection.parent = self
                                self._children_name_map["threat_inspection"] = "threat-inspection"

                                self.web_filter = Native.UtdMt.Utd.Engine.Standard.MultiTenancy.Policy.WebFilter()
                                self.web_filter.parent = self
                                self._children_name_map["web_filter"] = "web-filter"

                                self.vrf = YList(self)
                                self._segment_path = lambda: "policy" + "[name='" + str(self.name) + "']"
                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/Cisco-IOS-XE-utd:utd-mt/utd/engine/standard/multi-tenancy/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.UtdMt.Utd.Engine.Standard.MultiTenancy.Policy, ['name', 'all_interfaces'], name, value)


                            class Fail(Entity):
                                """
                                Enter the UTD engine fail mode operation
                                
                                .. attribute:: close
                                
                                	Drop all IPS/IDS traffic on UTD engine failure
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                """

                                _prefix = 'ios-utd'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.UtdMt.Utd.Engine.Standard.MultiTenancy.Policy.Fail, self).__init__()

                                    self.yang_name = "fail"
                                    self.yang_parent_name = "policy"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('close', (YLeaf(YType.empty, 'close'), ['Empty'])),
                                    ])
                                    self.close = None
                                    self._segment_path = lambda: "fail"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.UtdMt.Utd.Engine.Standard.MultiTenancy.Policy.Fail, ['close'], name, value)


                            class Vrf(Entity):
                                """
                                Associate a VRF with this policy
                                
                                .. attribute:: name  (key)
                                
                                	
                                	**type**\: str
                                
                                	**length:** 1..32
                                
                                

                                """

                                _prefix = 'ios-utd'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.UtdMt.Utd.Engine.Standard.MultiTenancy.Policy.Vrf, self).__init__()

                                    self.yang_name = "vrf"
                                    self.yang_parent_name = "policy"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = ['name']
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                    ])
                                    self.name = None
                                    self._segment_path = lambda: "vrf" + "[name='" + str(self.name) + "']"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.UtdMt.Utd.Engine.Standard.MultiTenancy.Policy.Vrf, ['name'], name, value)


                            class ThreatInspection(Entity):
                                """
                                Associate threat\-inspection profile with this policy
                                
                                .. attribute:: profile
                                
                                	Associate threat\-inspection profile with this policy
                                	**type**\: str
                                
                                	**length:** 1..512
                                
                                

                                """

                                _prefix = 'ios-utd'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.UtdMt.Utd.Engine.Standard.MultiTenancy.Policy.ThreatInspection, self).__init__()

                                    self.yang_name = "threat-inspection"
                                    self.yang_parent_name = "policy"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('profile', (YLeaf(YType.str, 'profile'), ['str'])),
                                    ])
                                    self.profile = None
                                    self._segment_path = lambda: "threat-inspection"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.UtdMt.Utd.Engine.Standard.MultiTenancy.Policy.ThreatInspection, ['profile'], name, value)


                            class WebFilter(Entity):
                                """
                                Associate web filter profile with this policy
                                
                                .. attribute:: url
                                
                                	Associate web filter profile with this policy
                                	**type**\:  :py:class:`Url <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.UtdMt.Utd.Engine.Standard.MultiTenancy.Policy.WebFilter.Url>`
                                
                                

                                """

                                _prefix = 'ios-utd'
                                _revision = '2018-06-28'

                                def __init__(self):
                                    super(Native.UtdMt.Utd.Engine.Standard.MultiTenancy.Policy.WebFilter, self).__init__()

                                    self.yang_name = "web-filter"
                                    self.yang_parent_name = "policy"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("url", ("url", Native.UtdMt.Utd.Engine.Standard.MultiTenancy.Policy.WebFilter.Url))])
                                    self._leafs = OrderedDict()

                                    self.url = Native.UtdMt.Utd.Engine.Standard.MultiTenancy.Policy.WebFilter.Url()
                                    self.url.parent = self
                                    self._children_name_map["url"] = "url"
                                    self._segment_path = lambda: "web-filter"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.UtdMt.Utd.Engine.Standard.MultiTenancy.Policy.WebFilter, [], name, value)


                                class Url(Entity):
                                    """
                                    Associate web filter profile with this policy
                                    
                                    .. attribute:: profile
                                    
                                    	Associate web filter profile with this policy
                                    	**type**\: str
                                    
                                    	**length:** 1..512
                                    
                                    

                                    """

                                    _prefix = 'ios-utd'
                                    _revision = '2018-06-28'

                                    def __init__(self):
                                        super(Native.UtdMt.Utd.Engine.Standard.MultiTenancy.Policy.WebFilter.Url, self).__init__()

                                        self.yang_name = "url"
                                        self.yang_parent_name = "web-filter"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('profile', (YLeaf(YType.str, 'profile'), ['str'])),
                                        ])
                                        self.profile = None
                                        self._segment_path = lambda: "url"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.UtdMt.Utd.Engine.Standard.MultiTenancy.Policy.WebFilter.Url, ['profile'], name, value)


    class FabricGroup(Entity):
        """
        
        
        .. attribute:: fabric
        
        	Fabric Configuration submode
        	**type**\:  :py:class:`Fabric <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.FabricGroup.Fabric>`
        
        

        """

        _prefix = 'ios-iwanfabric'
        _revision = '2017-11-27'

        def __init__(self):
            super(Native.FabricGroup, self).__init__()

            self.yang_name = "fabric-group"
            self.yang_parent_name = "native"
            self.is_top_level_class = False
            self.has_list_ancestor = False
            self.ylist_key_names = []
            self._child_classes = OrderedDict([("fabric", ("fabric", Native.FabricGroup.Fabric))])
            self._leafs = OrderedDict()

            self.fabric = Native.FabricGroup.Fabric()
            self.fabric.parent = self
            self._children_name_map["fabric"] = "fabric"
            self._segment_path = lambda: "Cisco-IOS-XE-iwanfabric:fabric-group"
            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/%s" % self._segment_path()
            self._is_frozen = True

        def __setattr__(self, name, value):
            self._perform_setattr(Native.FabricGroup, [], name, value)


        class Fabric(Entity):
            """
            Fabric Configuration submode
            
            .. attribute:: auto
            
            	Fabric auto Configuration Commands
            	**type**\:  :py:class:`Auto <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.FabricGroup.Fabric.Auto>`
            
            	**presence node**\: True
            
            

            """

            _prefix = 'ios-iwanfabric'
            _revision = '2017-11-27'

            def __init__(self):
                super(Native.FabricGroup.Fabric, self).__init__()

                self.yang_name = "fabric"
                self.yang_parent_name = "fabric-group"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = []
                self._child_classes = OrderedDict([("auto", ("auto", Native.FabricGroup.Fabric.Auto))])
                self._leafs = OrderedDict()

                self.auto = None
                self._children_name_map["auto"] = "auto"
                self._segment_path = lambda: "fabric"
                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/Cisco-IOS-XE-iwanfabric:fabric-group/%s" % self._segment_path()
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(Native.FabricGroup.Fabric, [], name, value)


            class Auto(Entity):
                """
                Fabric auto Configuration Commands
                
                .. attribute:: config_fabric_auto
                
                	
                	**type**\:  :py:class:`ConfigFabricAuto <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.FabricGroup.Fabric.Auto.ConfigFabricAuto>`
                
                

                This class is a :ref:`presence class<presence-class>`

                """

                _prefix = 'ios-iwanfabric'
                _revision = '2017-11-27'

                def __init__(self):
                    super(Native.FabricGroup.Fabric.Auto, self).__init__()

                    self.yang_name = "auto"
                    self.yang_parent_name = "fabric"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("config-fabric-auto", ("config_fabric_auto", Native.FabricGroup.Fabric.Auto.ConfigFabricAuto))])
                    self.is_presence_container = True
                    self._leafs = OrderedDict()

                    self.config_fabric_auto = Native.FabricGroup.Fabric.Auto.ConfigFabricAuto()
                    self.config_fabric_auto.parent = self
                    self._children_name_map["config_fabric_auto"] = "config-fabric-auto"
                    self._segment_path = lambda: "auto"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/Cisco-IOS-XE-iwanfabric:fabric-group/fabric/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.FabricGroup.Fabric.Auto, [], name, value)


                class ConfigFabricAuto(Entity):
                    """
                    
                    
                    .. attribute:: domain
                    
                    	domain Configuration Commands
                    	**type**\:  :py:class:`Domain <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.FabricGroup.Fabric.Auto.ConfigFabricAuto.Domain>`
                    
                    

                    """

                    _prefix = 'ios-iwanfabric'
                    _revision = '2017-11-27'

                    def __init__(self):
                        super(Native.FabricGroup.Fabric.Auto.ConfigFabricAuto, self).__init__()

                        self.yang_name = "config-fabric-auto"
                        self.yang_parent_name = "auto"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("domain", ("domain", Native.FabricGroup.Fabric.Auto.ConfigFabricAuto.Domain))])
                        self._leafs = OrderedDict()

                        self.domain = Native.FabricGroup.Fabric.Auto.ConfigFabricAuto.Domain()
                        self.domain.parent = self
                        self._children_name_map["domain"] = "domain"
                        self._segment_path = lambda: "config-fabric-auto"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/Cisco-IOS-XE-iwanfabric:fabric-group/fabric/auto/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.FabricGroup.Fabric.Auto.ConfigFabricAuto, [], name, value)


                    class Domain(Entity):
                        """
                        domain Configuration Commands
                        
                        .. attribute:: iwan_fabric
                        
                        	iwan\-fabric Configuration Commands
                        	**type**\:  :py:class:`IwanFabric <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.FabricGroup.Fabric.Auto.ConfigFabricAuto.Domain.IwanFabric>`
                        
                        	**presence node**\: True
                        
                        

                        """

                        _prefix = 'ios-iwanfabric'
                        _revision = '2017-11-27'

                        def __init__(self):
                            super(Native.FabricGroup.Fabric.Auto.ConfigFabricAuto.Domain, self).__init__()

                            self.yang_name = "domain"
                            self.yang_parent_name = "config-fabric-auto"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("iwan-fabric", ("iwan_fabric", Native.FabricGroup.Fabric.Auto.ConfigFabricAuto.Domain.IwanFabric))])
                            self._leafs = OrderedDict()

                            self.iwan_fabric = None
                            self._children_name_map["iwan_fabric"] = "iwan-fabric"
                            self._segment_path = lambda: "domain"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/Cisco-IOS-XE-iwanfabric:fabric-group/fabric/auto/config-fabric-auto/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.FabricGroup.Fabric.Auto.ConfigFabricAuto.Domain, [], name, value)


                        class IwanFabric(Entity):
                            """
                            iwan\-fabric Configuration Commands
                            
                            .. attribute:: config_fabric_iwan
                            
                            	
                            	**type**\:  :py:class:`ConfigFabricIwan <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.FabricGroup.Fabric.Auto.ConfigFabricAuto.Domain.IwanFabric.ConfigFabricIwan>`
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-iwanfabric'
                            _revision = '2017-11-27'

                            def __init__(self):
                                super(Native.FabricGroup.Fabric.Auto.ConfigFabricAuto.Domain.IwanFabric, self).__init__()

                                self.yang_name = "iwan-fabric"
                                self.yang_parent_name = "domain"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("config-fabric-iwan", ("config_fabric_iwan", Native.FabricGroup.Fabric.Auto.ConfigFabricAuto.Domain.IwanFabric.ConfigFabricIwan))])
                                self.is_presence_container = True
                                self._leafs = OrderedDict()

                                self.config_fabric_iwan = Native.FabricGroup.Fabric.Auto.ConfigFabricAuto.Domain.IwanFabric.ConfigFabricIwan()
                                self.config_fabric_iwan.parent = self
                                self._children_name_map["config_fabric_iwan"] = "config-fabric-iwan"
                                self._segment_path = lambda: "iwan-fabric"
                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/Cisco-IOS-XE-iwanfabric:fabric-group/fabric/auto/config-fabric-auto/domain/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.FabricGroup.Fabric.Auto.ConfigFabricAuto.Domain.IwanFabric, [], name, value)


                            class ConfigFabricIwan(Entity):
                                """
                                
                                
                                .. attribute:: border
                                
                                	Enter the border type
                                	**type**\:  :py:class:`Border <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.FabricGroup.Fabric.Auto.ConfigFabricAuto.Domain.IwanFabric.ConfigFabricIwan.Border>`
                                
                                .. attribute:: control_plane
                                
                                	Enter the PMCS configuration
                                	**type**\:  :py:class:`ControlPlane <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.FabricGroup.Fabric.Auto.ConfigFabricAuto.Domain.IwanFabric.ConfigFabricIwan.ControlPlane>`
                                
                                .. attribute:: device_role
                                
                                	Enter the device role
                                	**type**\:  :py:class:`DeviceRole <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.FabricGroup.Fabric.Auto.ConfigFabricAuto.Domain.IwanFabric.ConfigFabricIwan.DeviceRole>`
                                
                                .. attribute:: fabric_device_id
                                
                                	Specify the fabric\-device\-id value
                                	**type**\: int
                                
                                	**range:** 1..65535
                                
                                .. attribute:: region
                                
                                	Enter the Region ID
                                	**type**\:  :py:class:`Region <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.FabricGroup.Fabric.Auto.ConfigFabricAuto.Domain.IwanFabric.ConfigFabricIwan.Region>`
                                
                                .. attribute:: shutdown
                                
                                	shut the device
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: site
                                
                                	Enter the site configuration
                                	**type**\:  :py:class:`Site <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.FabricGroup.Fabric.Auto.ConfigFabricAuto.Domain.IwanFabric.ConfigFabricIwan.Site>`
                                
                                .. attribute:: tenant
                                
                                	Tenant ID configuration
                                	**type**\:  :py:class:`Tenant <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.FabricGroup.Fabric.Auto.ConfigFabricAuto.Domain.IwanFabric.ConfigFabricIwan.Tenant>`
                                
                                .. attribute:: virtual_network
                                
                                	Enter the instancevirtual network ID
                                	**type**\:  :py:class:`VirtualNetwork <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.FabricGroup.Fabric.Auto.ConfigFabricAuto.Domain.IwanFabric.ConfigFabricIwan.VirtualNetwork>`
                                
                                

                                """

                                _prefix = 'ios-iwanfabric'
                                _revision = '2017-11-27'

                                def __init__(self):
                                    super(Native.FabricGroup.Fabric.Auto.ConfigFabricAuto.Domain.IwanFabric.ConfigFabricIwan, self).__init__()

                                    self.yang_name = "config-fabric-iwan"
                                    self.yang_parent_name = "iwan-fabric"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("border", ("border", Native.FabricGroup.Fabric.Auto.ConfigFabricAuto.Domain.IwanFabric.ConfigFabricIwan.Border)), ("control-plane", ("control_plane", Native.FabricGroup.Fabric.Auto.ConfigFabricAuto.Domain.IwanFabric.ConfigFabricIwan.ControlPlane)), ("device-role", ("device_role", Native.FabricGroup.Fabric.Auto.ConfigFabricAuto.Domain.IwanFabric.ConfigFabricIwan.DeviceRole)), ("region", ("region", Native.FabricGroup.Fabric.Auto.ConfigFabricAuto.Domain.IwanFabric.ConfigFabricIwan.Region)), ("site", ("site", Native.FabricGroup.Fabric.Auto.ConfigFabricAuto.Domain.IwanFabric.ConfigFabricIwan.Site)), ("tenant", ("tenant", Native.FabricGroup.Fabric.Auto.ConfigFabricAuto.Domain.IwanFabric.ConfigFabricIwan.Tenant)), ("virtual-network", ("virtual_network", Native.FabricGroup.Fabric.Auto.ConfigFabricAuto.Domain.IwanFabric.ConfigFabricIwan.VirtualNetwork))])
                                    self._leafs = OrderedDict([
                                        ('fabric_device_id', (YLeaf(YType.uint16, 'fabric-device-id'), ['int'])),
                                        ('shutdown', (YLeaf(YType.empty, 'shutdown'), ['Empty'])),
                                    ])
                                    self.fabric_device_id = None
                                    self.shutdown = None

                                    self.border = Native.FabricGroup.Fabric.Auto.ConfigFabricAuto.Domain.IwanFabric.ConfigFabricIwan.Border()
                                    self.border.parent = self
                                    self._children_name_map["border"] = "border"

                                    self.control_plane = Native.FabricGroup.Fabric.Auto.ConfigFabricAuto.Domain.IwanFabric.ConfigFabricIwan.ControlPlane()
                                    self.control_plane.parent = self
                                    self._children_name_map["control_plane"] = "control-plane"

                                    self.device_role = Native.FabricGroup.Fabric.Auto.ConfigFabricAuto.Domain.IwanFabric.ConfigFabricIwan.DeviceRole()
                                    self.device_role.parent = self
                                    self._children_name_map["device_role"] = "device-role"

                                    self.region = Native.FabricGroup.Fabric.Auto.ConfigFabricAuto.Domain.IwanFabric.ConfigFabricIwan.Region()
                                    self.region.parent = self
                                    self._children_name_map["region"] = "region"

                                    self.site = Native.FabricGroup.Fabric.Auto.ConfigFabricAuto.Domain.IwanFabric.ConfigFabricIwan.Site()
                                    self.site.parent = self
                                    self._children_name_map["site"] = "site"

                                    self.tenant = Native.FabricGroup.Fabric.Auto.ConfigFabricAuto.Domain.IwanFabric.ConfigFabricIwan.Tenant()
                                    self.tenant.parent = self
                                    self._children_name_map["tenant"] = "tenant"

                                    self.virtual_network = Native.FabricGroup.Fabric.Auto.ConfigFabricAuto.Domain.IwanFabric.ConfigFabricIwan.VirtualNetwork()
                                    self.virtual_network.parent = self
                                    self._children_name_map["virtual_network"] = "virtual-network"
                                    self._segment_path = lambda: "config-fabric-iwan"
                                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/Cisco-IOS-XE-iwanfabric:fabric-group/fabric/auto/config-fabric-auto/domain/iwan-fabric/%s" % self._segment_path()
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.FabricGroup.Fabric.Auto.ConfigFabricAuto.Domain.IwanFabric.ConfigFabricIwan, ['fabric_device_id', 'shutdown'], name, value)


                                class Border(Entity):
                                    """
                                    Enter the border type
                                    
                                    .. attribute:: self
                                    
                                    	self border type
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    """

                                    _prefix = 'ios-iwanfabric'
                                    _revision = '2017-11-27'

                                    def __init__(self):
                                        super(Native.FabricGroup.Fabric.Auto.ConfigFabricAuto.Domain.IwanFabric.ConfigFabricIwan.Border, self).__init__()

                                        self.yang_name = "border"
                                        self.yang_parent_name = "config-fabric-iwan"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('self', (YLeaf(YType.empty, 'self'), ['Empty'])),
                                        ])
                                        self.self = None
                                        self._segment_path = lambda: "border"
                                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/Cisco-IOS-XE-iwanfabric:fabric-group/fabric/auto/config-fabric-auto/domain/iwan-fabric/config-fabric-iwan/%s" % self._segment_path()
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.FabricGroup.Fabric.Auto.ConfigFabricAuto.Domain.IwanFabric.ConfigFabricIwan.Border, ['self'], name, value)


                                class ControlPlane(Entity):
                                    """
                                    Enter the PMCS configuration
                                    
                                    .. attribute:: destination_address
                                    
                                    	
                                    	**type**\:  :py:class:`DestinationAddress <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.FabricGroup.Fabric.Auto.ConfigFabricAuto.Domain.IwanFabric.ConfigFabricIwan.ControlPlane.DestinationAddress>`
                                    
                                    .. attribute:: source_address
                                    
                                    	Enter source interface
                                    	**type**\:  :py:class:`SourceAddress <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.FabricGroup.Fabric.Auto.ConfigFabricAuto.Domain.IwanFabric.ConfigFabricIwan.ControlPlane.SourceAddress>`
                                    
                                    

                                    """

                                    _prefix = 'ios-iwanfabric'
                                    _revision = '2017-11-27'

                                    def __init__(self):
                                        super(Native.FabricGroup.Fabric.Auto.ConfigFabricAuto.Domain.IwanFabric.ConfigFabricIwan.ControlPlane, self).__init__()

                                        self.yang_name = "control-plane"
                                        self.yang_parent_name = "config-fabric-iwan"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("destination-address", ("destination_address", Native.FabricGroup.Fabric.Auto.ConfigFabricAuto.Domain.IwanFabric.ConfigFabricIwan.ControlPlane.DestinationAddress)), ("source-address", ("source_address", Native.FabricGroup.Fabric.Auto.ConfigFabricAuto.Domain.IwanFabric.ConfigFabricIwan.ControlPlane.SourceAddress))])
                                        self._leafs = OrderedDict()

                                        self.destination_address = Native.FabricGroup.Fabric.Auto.ConfigFabricAuto.Domain.IwanFabric.ConfigFabricIwan.ControlPlane.DestinationAddress()
                                        self.destination_address.parent = self
                                        self._children_name_map["destination_address"] = "destination-address"

                                        self.source_address = Native.FabricGroup.Fabric.Auto.ConfigFabricAuto.Domain.IwanFabric.ConfigFabricIwan.ControlPlane.SourceAddress()
                                        self.source_address.parent = self
                                        self._children_name_map["source_address"] = "source-address"
                                        self._segment_path = lambda: "control-plane"
                                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/Cisco-IOS-XE-iwanfabric:fabric-group/fabric/auto/config-fabric-auto/domain/iwan-fabric/config-fabric-iwan/%s" % self._segment_path()
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.FabricGroup.Fabric.Auto.ConfigFabricAuto.Domain.IwanFabric.ConfigFabricIwan.ControlPlane, [], name, value)


                                    class DestinationAddress(Entity):
                                        """
                                        
                                        
                                        .. attribute:: ipv4
                                        
                                        	
                                        	**type**\: list of  		 :py:class:`Ipv4 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.FabricGroup.Fabric.Auto.ConfigFabricAuto.Domain.IwanFabric.ConfigFabricIwan.ControlPlane.DestinationAddress.Ipv4>`
                                        
                                        

                                        """

                                        _prefix = 'ios-iwanfabric'
                                        _revision = '2017-11-27'

                                        def __init__(self):
                                            super(Native.FabricGroup.Fabric.Auto.ConfigFabricAuto.Domain.IwanFabric.ConfigFabricIwan.ControlPlane.DestinationAddress, self).__init__()

                                            self.yang_name = "destination-address"
                                            self.yang_parent_name = "control-plane"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = False
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("ipv4", ("ipv4", Native.FabricGroup.Fabric.Auto.ConfigFabricAuto.Domain.IwanFabric.ConfigFabricIwan.ControlPlane.DestinationAddress.Ipv4))])
                                            self._leafs = OrderedDict()

                                            self.ipv4 = YList(self)
                                            self._segment_path = lambda: "destination-address"
                                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/Cisco-IOS-XE-iwanfabric:fabric-group/fabric/auto/config-fabric-auto/domain/iwan-fabric/config-fabric-iwan/control-plane/%s" % self._segment_path()
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.FabricGroup.Fabric.Auto.ConfigFabricAuto.Domain.IwanFabric.ConfigFabricIwan.ControlPlane.DestinationAddress, [], name, value)


                                        class Ipv4(Entity):
                                            """
                                            
                                            
                                            .. attribute:: ipv4  (key)
                                            
                                            	
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: auth_key
                                            
                                            	Authentication key type
                                            	**type**\:  :py:class:`AuthKey <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.FabricGroup.Fabric.Auto.ConfigFabricAuto.Domain.IwanFabric.ConfigFabricIwan.ControlPlane.DestinationAddress.Ipv4.AuthKey>`
                                            
                                            

                                            """

                                            _prefix = 'ios-iwanfabric'
                                            _revision = '2017-11-27'

                                            def __init__(self):
                                                super(Native.FabricGroup.Fabric.Auto.ConfigFabricAuto.Domain.IwanFabric.ConfigFabricIwan.ControlPlane.DestinationAddress.Ipv4, self).__init__()

                                                self.yang_name = "ipv4"
                                                self.yang_parent_name = "destination-address"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = False
                                                self.ylist_key_names = ['ipv4']
                                                self._child_classes = OrderedDict([("auth-key", ("auth_key", Native.FabricGroup.Fabric.Auto.ConfigFabricAuto.Domain.IwanFabric.ConfigFabricIwan.ControlPlane.DestinationAddress.Ipv4.AuthKey))])
                                                self._leafs = OrderedDict([
                                                    ('ipv4', (YLeaf(YType.str, 'ipv4'), ['str'])),
                                                ])
                                                self.ipv4 = None

                                                self.auth_key = Native.FabricGroup.Fabric.Auto.ConfigFabricAuto.Domain.IwanFabric.ConfigFabricIwan.ControlPlane.DestinationAddress.Ipv4.AuthKey()
                                                self.auth_key.parent = self
                                                self._children_name_map["auth_key"] = "auth-key"
                                                self._segment_path = lambda: "ipv4" + "[ipv4='" + str(self.ipv4) + "']"
                                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/Cisco-IOS-XE-iwanfabric:fabric-group/fabric/auto/config-fabric-auto/domain/iwan-fabric/config-fabric-iwan/control-plane/destination-address/%s" % self._segment_path()
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.FabricGroup.Fabric.Auto.ConfigFabricAuto.Domain.IwanFabric.ConfigFabricIwan.ControlPlane.DestinationAddress.Ipv4, ['ipv4'], name, value)


                                            class AuthKey(Entity):
                                                """
                                                Authentication key type
                                                
                                                .. attribute:: range
                                                
                                                	
                                                	**type**\: list of  		 :py:class:`Range <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.FabricGroup.Fabric.Auto.ConfigFabricAuto.Domain.IwanFabric.ConfigFabricIwan.ControlPlane.DestinationAddress.Ipv4.AuthKey.Range>`
                                                
                                                

                                                """

                                                _prefix = 'ios-iwanfabric'
                                                _revision = '2017-11-27'

                                                def __init__(self):
                                                    super(Native.FabricGroup.Fabric.Auto.ConfigFabricAuto.Domain.IwanFabric.ConfigFabricIwan.ControlPlane.DestinationAddress.Ipv4.AuthKey, self).__init__()

                                                    self.yang_name = "auth-key"
                                                    self.yang_parent_name = "ipv4"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("range", ("range", Native.FabricGroup.Fabric.Auto.ConfigFabricAuto.Domain.IwanFabric.ConfigFabricIwan.ControlPlane.DestinationAddress.Ipv4.AuthKey.Range))])
                                                    self._leafs = OrderedDict()

                                                    self.range = YList(self)
                                                    self._segment_path = lambda: "auth-key"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.FabricGroup.Fabric.Auto.ConfigFabricAuto.Domain.IwanFabric.ConfigFabricIwan.ControlPlane.DestinationAddress.Ipv4.AuthKey, [], name, value)


                                                class Range(Entity):
                                                    """
                                                    
                                                    
                                                    .. attribute:: range  (key)
                                                    
                                                    	Specify the auth\-key type
                                                    	**type**\: int
                                                    
                                                    	**range:** 1..65535
                                                    
                                                    .. attribute:: word
                                                    
                                                    	authentication key
                                                    	**type**\: str
                                                    
                                                    

                                                    """

                                                    _prefix = 'ios-iwanfabric'
                                                    _revision = '2017-11-27'

                                                    def __init__(self):
                                                        super(Native.FabricGroup.Fabric.Auto.ConfigFabricAuto.Domain.IwanFabric.ConfigFabricIwan.ControlPlane.DestinationAddress.Ipv4.AuthKey.Range, self).__init__()

                                                        self.yang_name = "range"
                                                        self.yang_parent_name = "auth-key"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = ['range']
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('range', (YLeaf(YType.uint16, 'range'), ['int'])),
                                                            ('word', (YLeaf(YType.str, 'word'), ['str'])),
                                                        ])
                                                        self.range = None
                                                        self.word = None
                                                        self._segment_path = lambda: "range" + "[range='" + str(self.range) + "']"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.FabricGroup.Fabric.Auto.ConfigFabricAuto.Domain.IwanFabric.ConfigFabricIwan.ControlPlane.DestinationAddress.Ipv4.AuthKey.Range, ['range', 'word'], name, value)


                                    class SourceAddress(Entity):
                                        """
                                        Enter source interface
                                        
                                        .. attribute:: interface
                                        
                                        	Virtual ACR interface
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'ios-iwanfabric'
                                        _revision = '2017-11-27'

                                        def __init__(self):
                                            super(Native.FabricGroup.Fabric.Auto.ConfigFabricAuto.Domain.IwanFabric.ConfigFabricIwan.ControlPlane.SourceAddress, self).__init__()

                                            self.yang_name = "source-address"
                                            self.yang_parent_name = "control-plane"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = False
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('interface', (YLeaf(YType.str, 'interface'), ['str'])),
                                            ])
                                            self.interface = None
                                            self._segment_path = lambda: "source-address"
                                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/Cisco-IOS-XE-iwanfabric:fabric-group/fabric/auto/config-fabric-auto/domain/iwan-fabric/config-fabric-iwan/control-plane/%s" % self._segment_path()
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.FabricGroup.Fabric.Auto.ConfigFabricAuto.Domain.IwanFabric.ConfigFabricIwan.ControlPlane.SourceAddress, ['interface'], name, value)


                                class DeviceRole(Entity):
                                    """
                                    Enter the device role
                                    
                                    .. attribute:: border
                                    
                                    	Border router device type
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: edge
                                    
                                    	Edge device type
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: nat_traversal_router
                                    
                                    	NAT traversal router device type
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: transit_router
                                    
                                    	Transit router device type
                                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    """

                                    _prefix = 'ios-iwanfabric'
                                    _revision = '2017-11-27'

                                    def __init__(self):
                                        super(Native.FabricGroup.Fabric.Auto.ConfigFabricAuto.Domain.IwanFabric.ConfigFabricIwan.DeviceRole, self).__init__()

                                        self.yang_name = "device-role"
                                        self.yang_parent_name = "config-fabric-iwan"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('border', (YLeaf(YType.empty, 'border'), ['Empty'])),
                                            ('edge', (YLeaf(YType.empty, 'edge'), ['Empty'])),
                                            ('nat_traversal_router', (YLeaf(YType.empty, 'nat-traversal-router'), ['Empty'])),
                                            ('transit_router', (YLeaf(YType.empty, 'transit-router'), ['Empty'])),
                                        ])
                                        self.border = None
                                        self.edge = None
                                        self.nat_traversal_router = None
                                        self.transit_router = None
                                        self._segment_path = lambda: "device-role"
                                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/Cisco-IOS-XE-iwanfabric:fabric-group/fabric/auto/config-fabric-auto/domain/iwan-fabric/config-fabric-iwan/%s" % self._segment_path()
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.FabricGroup.Fabric.Auto.ConfigFabricAuto.Domain.IwanFabric.ConfigFabricIwan.DeviceRole, ['border', 'edge', 'nat_traversal_router', 'transit_router'], name, value)


                                class Region(Entity):
                                    """
                                    Enter the Region ID
                                    
                                    .. attribute:: id
                                    
                                    	Specify the Region ID
                                    	**type**\:  :py:class:`Id <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.FabricGroup.Fabric.Auto.ConfigFabricAuto.Domain.IwanFabric.ConfigFabricIwan.Region.Id>`
                                    
                                    

                                    """

                                    _prefix = 'ios-iwanfabric'
                                    _revision = '2017-11-27'

                                    def __init__(self):
                                        super(Native.FabricGroup.Fabric.Auto.ConfigFabricAuto.Domain.IwanFabric.ConfigFabricIwan.Region, self).__init__()

                                        self.yang_name = "region"
                                        self.yang_parent_name = "config-fabric-iwan"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("id", ("id", Native.FabricGroup.Fabric.Auto.ConfigFabricAuto.Domain.IwanFabric.ConfigFabricIwan.Region.Id))])
                                        self._leafs = OrderedDict()

                                        self.id = Native.FabricGroup.Fabric.Auto.ConfigFabricAuto.Domain.IwanFabric.ConfigFabricIwan.Region.Id()
                                        self.id.parent = self
                                        self._children_name_map["id"] = "id"
                                        self._segment_path = lambda: "region"
                                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/Cisco-IOS-XE-iwanfabric:fabric-group/fabric/auto/config-fabric-auto/domain/iwan-fabric/config-fabric-iwan/%s" % self._segment_path()
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.FabricGroup.Fabric.Auto.ConfigFabricAuto.Domain.IwanFabric.ConfigFabricIwan.Region, [], name, value)


                                    class Id(Entity):
                                        """
                                        Specify the Region ID
                                        
                                        .. attribute:: range
                                        
                                        	
                                        	**type**\: list of  		 :py:class:`Range <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.FabricGroup.Fabric.Auto.ConfigFabricAuto.Domain.IwanFabric.ConfigFabricIwan.Region.Id.Range>`
                                        
                                        

                                        """

                                        _prefix = 'ios-iwanfabric'
                                        _revision = '2017-11-27'

                                        def __init__(self):
                                            super(Native.FabricGroup.Fabric.Auto.ConfigFabricAuto.Domain.IwanFabric.ConfigFabricIwan.Region.Id, self).__init__()

                                            self.yang_name = "id"
                                            self.yang_parent_name = "region"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = False
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("range", ("range", Native.FabricGroup.Fabric.Auto.ConfigFabricAuto.Domain.IwanFabric.ConfigFabricIwan.Region.Id.Range))])
                                            self._leafs = OrderedDict()

                                            self.range = YList(self)
                                            self._segment_path = lambda: "id"
                                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/Cisco-IOS-XE-iwanfabric:fabric-group/fabric/auto/config-fabric-auto/domain/iwan-fabric/config-fabric-iwan/region/%s" % self._segment_path()
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.FabricGroup.Fabric.Auto.ConfigFabricAuto.Domain.IwanFabric.ConfigFabricIwan.Region.Id, [], name, value)


                                        class Range(Entity):
                                            """
                                            
                                            
                                            .. attribute:: range  (key)
                                            
                                            	Specify the Region ID value
                                            	**type**\: int
                                            
                                            	**range:** 1..65535
                                            
                                            .. attribute:: name
                                            
                                            	region Name
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ios-iwanfabric'
                                            _revision = '2017-11-27'

                                            def __init__(self):
                                                super(Native.FabricGroup.Fabric.Auto.ConfigFabricAuto.Domain.IwanFabric.ConfigFabricIwan.Region.Id.Range, self).__init__()

                                                self.yang_name = "range"
                                                self.yang_parent_name = "id"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = False
                                                self.ylist_key_names = ['range']
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('range', (YLeaf(YType.uint16, 'range'), ['int'])),
                                                    ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                                ])
                                                self.range = None
                                                self.name = None
                                                self._segment_path = lambda: "range" + "[range='" + str(self.range) + "']"
                                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/Cisco-IOS-XE-iwanfabric:fabric-group/fabric/auto/config-fabric-auto/domain/iwan-fabric/config-fabric-iwan/region/id/%s" % self._segment_path()
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.FabricGroup.Fabric.Auto.ConfigFabricAuto.Domain.IwanFabric.ConfigFabricIwan.Region.Id.Range, ['range', 'name'], name, value)


                                class Site(Entity):
                                    """
                                    Enter the site configuration
                                    
                                    .. attribute:: id
                                    
                                    	Specify the site ID
                                    	**type**\:  :py:class:`Id <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.FabricGroup.Fabric.Auto.ConfigFabricAuto.Domain.IwanFabric.ConfigFabricIwan.Site.Id>`
                                    
                                    

                                    """

                                    _prefix = 'ios-iwanfabric'
                                    _revision = '2017-11-27'

                                    def __init__(self):
                                        super(Native.FabricGroup.Fabric.Auto.ConfigFabricAuto.Domain.IwanFabric.ConfigFabricIwan.Site, self).__init__()

                                        self.yang_name = "site"
                                        self.yang_parent_name = "config-fabric-iwan"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("id", ("id", Native.FabricGroup.Fabric.Auto.ConfigFabricAuto.Domain.IwanFabric.ConfigFabricIwan.Site.Id))])
                                        self._leafs = OrderedDict()

                                        self.id = Native.FabricGroup.Fabric.Auto.ConfigFabricAuto.Domain.IwanFabric.ConfigFabricIwan.Site.Id()
                                        self.id.parent = self
                                        self._children_name_map["id"] = "id"
                                        self._segment_path = lambda: "site"
                                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/Cisco-IOS-XE-iwanfabric:fabric-group/fabric/auto/config-fabric-auto/domain/iwan-fabric/config-fabric-iwan/%s" % self._segment_path()
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.FabricGroup.Fabric.Auto.ConfigFabricAuto.Domain.IwanFabric.ConfigFabricIwan.Site, [], name, value)


                                    class Id(Entity):
                                        """
                                        Specify the site ID
                                        
                                        .. attribute:: range
                                        
                                        	
                                        	**type**\: list of  		 :py:class:`Range <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.FabricGroup.Fabric.Auto.ConfigFabricAuto.Domain.IwanFabric.ConfigFabricIwan.Site.Id.Range>`
                                        
                                        

                                        """

                                        _prefix = 'ios-iwanfabric'
                                        _revision = '2017-11-27'

                                        def __init__(self):
                                            super(Native.FabricGroup.Fabric.Auto.ConfigFabricAuto.Domain.IwanFabric.ConfigFabricIwan.Site.Id, self).__init__()

                                            self.yang_name = "id"
                                            self.yang_parent_name = "site"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = False
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("range", ("range", Native.FabricGroup.Fabric.Auto.ConfigFabricAuto.Domain.IwanFabric.ConfigFabricIwan.Site.Id.Range))])
                                            self._leafs = OrderedDict()

                                            self.range = YList(self)
                                            self._segment_path = lambda: "id"
                                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/Cisco-IOS-XE-iwanfabric:fabric-group/fabric/auto/config-fabric-auto/domain/iwan-fabric/config-fabric-iwan/site/%s" % self._segment_path()
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.FabricGroup.Fabric.Auto.ConfigFabricAuto.Domain.IwanFabric.ConfigFabricIwan.Site.Id, [], name, value)


                                        class Range(Entity):
                                            """
                                            
                                            
                                            .. attribute:: range  (key)
                                            
                                            	Specify the site\-id value
                                            	**type**\: int
                                            
                                            	**range:** 1..65535
                                            
                                            .. attribute:: name
                                            
                                            	Site Name
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ios-iwanfabric'
                                            _revision = '2017-11-27'

                                            def __init__(self):
                                                super(Native.FabricGroup.Fabric.Auto.ConfigFabricAuto.Domain.IwanFabric.ConfigFabricIwan.Site.Id.Range, self).__init__()

                                                self.yang_name = "range"
                                                self.yang_parent_name = "id"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = False
                                                self.ylist_key_names = ['range']
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('range', (YLeaf(YType.uint16, 'range'), ['int'])),
                                                    ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                                ])
                                                self.range = None
                                                self.name = None
                                                self._segment_path = lambda: "range" + "[range='" + str(self.range) + "']"
                                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/Cisco-IOS-XE-iwanfabric:fabric-group/fabric/auto/config-fabric-auto/domain/iwan-fabric/config-fabric-iwan/site/id/%s" % self._segment_path()
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.FabricGroup.Fabric.Auto.ConfigFabricAuto.Domain.IwanFabric.ConfigFabricIwan.Site.Id.Range, ['range', 'name'], name, value)


                                class Tenant(Entity):
                                    """
                                    Tenant ID configuration
                                    
                                    .. attribute:: id
                                    
                                    	Specify the tenant id
                                    	**type**\:  :py:class:`Id <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.FabricGroup.Fabric.Auto.ConfigFabricAuto.Domain.IwanFabric.ConfigFabricIwan.Tenant.Id>`
                                    
                                    

                                    """

                                    _prefix = 'ios-iwanfabric'
                                    _revision = '2017-11-27'

                                    def __init__(self):
                                        super(Native.FabricGroup.Fabric.Auto.ConfigFabricAuto.Domain.IwanFabric.ConfigFabricIwan.Tenant, self).__init__()

                                        self.yang_name = "tenant"
                                        self.yang_parent_name = "config-fabric-iwan"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("id", ("id", Native.FabricGroup.Fabric.Auto.ConfigFabricAuto.Domain.IwanFabric.ConfigFabricIwan.Tenant.Id))])
                                        self._leafs = OrderedDict()

                                        self.id = Native.FabricGroup.Fabric.Auto.ConfigFabricAuto.Domain.IwanFabric.ConfigFabricIwan.Tenant.Id()
                                        self.id.parent = self
                                        self._children_name_map["id"] = "id"
                                        self._segment_path = lambda: "tenant"
                                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/Cisco-IOS-XE-iwanfabric:fabric-group/fabric/auto/config-fabric-auto/domain/iwan-fabric/config-fabric-iwan/%s" % self._segment_path()
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.FabricGroup.Fabric.Auto.ConfigFabricAuto.Domain.IwanFabric.ConfigFabricIwan.Tenant, [], name, value)


                                    class Id(Entity):
                                        """
                                        Specify the tenant id
                                        
                                        .. attribute:: range
                                        
                                        	
                                        	**type**\: list of  		 :py:class:`Range <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.FabricGroup.Fabric.Auto.ConfigFabricAuto.Domain.IwanFabric.ConfigFabricIwan.Tenant.Id.Range>`
                                        
                                        

                                        """

                                        _prefix = 'ios-iwanfabric'
                                        _revision = '2017-11-27'

                                        def __init__(self):
                                            super(Native.FabricGroup.Fabric.Auto.ConfigFabricAuto.Domain.IwanFabric.ConfigFabricIwan.Tenant.Id, self).__init__()

                                            self.yang_name = "id"
                                            self.yang_parent_name = "tenant"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = False
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("range", ("range", Native.FabricGroup.Fabric.Auto.ConfigFabricAuto.Domain.IwanFabric.ConfigFabricIwan.Tenant.Id.Range))])
                                            self._leafs = OrderedDict()

                                            self.range = YList(self)
                                            self._segment_path = lambda: "id"
                                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/Cisco-IOS-XE-iwanfabric:fabric-group/fabric/auto/config-fabric-auto/domain/iwan-fabric/config-fabric-iwan/tenant/%s" % self._segment_path()
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.FabricGroup.Fabric.Auto.ConfigFabricAuto.Domain.IwanFabric.ConfigFabricIwan.Tenant.Id, [], name, value)


                                        class Range(Entity):
                                            """
                                            
                                            
                                            .. attribute:: range  (key)
                                            
                                            	Specify the tenant\-id value
                                            	**type**\: int
                                            
                                            	**range:** 1..4294967295
                                            
                                            .. attribute:: name
                                            
                                            	Tenant Name
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ios-iwanfabric'
                                            _revision = '2017-11-27'

                                            def __init__(self):
                                                super(Native.FabricGroup.Fabric.Auto.ConfigFabricAuto.Domain.IwanFabric.ConfigFabricIwan.Tenant.Id.Range, self).__init__()

                                                self.yang_name = "range"
                                                self.yang_parent_name = "id"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = False
                                                self.ylist_key_names = ['range']
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('range', (YLeaf(YType.uint32, 'range'), ['int'])),
                                                    ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                                ])
                                                self.range = None
                                                self.name = None
                                                self._segment_path = lambda: "range" + "[range='" + str(self.range) + "']"
                                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/Cisco-IOS-XE-iwanfabric:fabric-group/fabric/auto/config-fabric-auto/domain/iwan-fabric/config-fabric-iwan/tenant/id/%s" % self._segment_path()
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.FabricGroup.Fabric.Auto.ConfigFabricAuto.Domain.IwanFabric.ConfigFabricIwan.Tenant.Id.Range, ['range', 'name'], name, value)


                                class VirtualNetwork(Entity):
                                    """
                                    Enter the instancevirtual network ID
                                    
                                    .. attribute:: name
                                    
                                    	Specify the virtual\-network name
                                    	**type**\:  :py:class:`Name <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.FabricGroup.Fabric.Auto.ConfigFabricAuto.Domain.IwanFabric.ConfigFabricIwan.VirtualNetwork.Name>`
                                    
                                    

                                    """

                                    _prefix = 'ios-iwanfabric'
                                    _revision = '2017-11-27'

                                    def __init__(self):
                                        super(Native.FabricGroup.Fabric.Auto.ConfigFabricAuto.Domain.IwanFabric.ConfigFabricIwan.VirtualNetwork, self).__init__()

                                        self.yang_name = "virtual-network"
                                        self.yang_parent_name = "config-fabric-iwan"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("name", ("name", Native.FabricGroup.Fabric.Auto.ConfigFabricAuto.Domain.IwanFabric.ConfigFabricIwan.VirtualNetwork.Name))])
                                        self._leafs = OrderedDict()

                                        self.name = Native.FabricGroup.Fabric.Auto.ConfigFabricAuto.Domain.IwanFabric.ConfigFabricIwan.VirtualNetwork.Name()
                                        self.name.parent = self
                                        self._children_name_map["name"] = "name"
                                        self._segment_path = lambda: "virtual-network"
                                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/Cisco-IOS-XE-iwanfabric:fabric-group/fabric/auto/config-fabric-auto/domain/iwan-fabric/config-fabric-iwan/%s" % self._segment_path()
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.FabricGroup.Fabric.Auto.ConfigFabricAuto.Domain.IwanFabric.ConfigFabricIwan.VirtualNetwork, [], name, value)


                                    class Name(Entity):
                                        """
                                        Specify the virtual\-network name
                                        
                                        .. attribute:: word
                                        
                                        	
                                        	**type**\: list of  		 :py:class:`Word <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.FabricGroup.Fabric.Auto.ConfigFabricAuto.Domain.IwanFabric.ConfigFabricIwan.VirtualNetwork.Name.Word>`
                                        
                                        

                                        """

                                        _prefix = 'ios-iwanfabric'
                                        _revision = '2017-11-27'

                                        def __init__(self):
                                            super(Native.FabricGroup.Fabric.Auto.ConfigFabricAuto.Domain.IwanFabric.ConfigFabricIwan.VirtualNetwork.Name, self).__init__()

                                            self.yang_name = "name"
                                            self.yang_parent_name = "virtual-network"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = False
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("word", ("word", Native.FabricGroup.Fabric.Auto.ConfigFabricAuto.Domain.IwanFabric.ConfigFabricIwan.VirtualNetwork.Name.Word))])
                                            self._leafs = OrderedDict()

                                            self.word = YList(self)
                                            self._segment_path = lambda: "name"
                                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/Cisco-IOS-XE-iwanfabric:fabric-group/fabric/auto/config-fabric-auto/domain/iwan-fabric/config-fabric-iwan/virtual-network/%s" % self._segment_path()
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Native.FabricGroup.Fabric.Auto.ConfigFabricAuto.Domain.IwanFabric.ConfigFabricIwan.VirtualNetwork.Name, [], name, value)


                                        class Word(Entity):
                                            """
                                            
                                            
                                            .. attribute:: word  (key)
                                            
                                            	virtual\-network name
                                            	**type**\: str
                                            
                                            .. attribute:: id
                                            
                                            	Specify the virtual\-network ID
                                            	**type**\: list of  		 :py:class:`Id <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.FabricGroup.Fabric.Auto.ConfigFabricAuto.Domain.IwanFabric.ConfigFabricIwan.VirtualNetwork.Name.Word.Id>`
                                            
                                            

                                            """

                                            _prefix = 'ios-iwanfabric'
                                            _revision = '2017-11-27'

                                            def __init__(self):
                                                super(Native.FabricGroup.Fabric.Auto.ConfigFabricAuto.Domain.IwanFabric.ConfigFabricIwan.VirtualNetwork.Name.Word, self).__init__()

                                                self.yang_name = "word"
                                                self.yang_parent_name = "name"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = False
                                                self.ylist_key_names = ['word']
                                                self._child_classes = OrderedDict([("id", ("id", Native.FabricGroup.Fabric.Auto.ConfigFabricAuto.Domain.IwanFabric.ConfigFabricIwan.VirtualNetwork.Name.Word.Id))])
                                                self._leafs = OrderedDict([
                                                    ('word', (YLeaf(YType.str, 'word'), ['str'])),
                                                ])
                                                self.word = None

                                                self.id = YList(self)
                                                self._segment_path = lambda: "word" + "[word='" + str(self.word) + "']"
                                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/Cisco-IOS-XE-iwanfabric:fabric-group/fabric/auto/config-fabric-auto/domain/iwan-fabric/config-fabric-iwan/virtual-network/name/%s" % self._segment_path()
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Native.FabricGroup.Fabric.Auto.ConfigFabricAuto.Domain.IwanFabric.ConfigFabricIwan.VirtualNetwork.Name.Word, ['word'], name, value)


                                            class Id(Entity):
                                                """
                                                Specify the virtual\-network ID
                                                
                                                .. attribute:: range  (key)
                                                
                                                	Specify the virtual\-network id value
                                                	**type**\: int
                                                
                                                	**range:** 0..16777214
                                                
                                                .. attribute:: config_fabric_iwan_virtual_network
                                                
                                                	
                                                	**type**\:  :py:class:`ConfigFabricIwanVirtualNetwork <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.FabricGroup.Fabric.Auto.ConfigFabricAuto.Domain.IwanFabric.ConfigFabricIwan.VirtualNetwork.Name.Word.Id.ConfigFabricIwanVirtualNetwork>`
                                                
                                                

                                                """

                                                _prefix = 'ios-iwanfabric'
                                                _revision = '2017-11-27'

                                                def __init__(self):
                                                    super(Native.FabricGroup.Fabric.Auto.ConfigFabricAuto.Domain.IwanFabric.ConfigFabricIwan.VirtualNetwork.Name.Word.Id, self).__init__()

                                                    self.yang_name = "id"
                                                    self.yang_parent_name = "word"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = ['range']
                                                    self._child_classes = OrderedDict([("config-fabric-iwan-virtual-network", ("config_fabric_iwan_virtual_network", Native.FabricGroup.Fabric.Auto.ConfigFabricAuto.Domain.IwanFabric.ConfigFabricIwan.VirtualNetwork.Name.Word.Id.ConfigFabricIwanVirtualNetwork))])
                                                    self._leafs = OrderedDict([
                                                        ('range', (YLeaf(YType.uint32, 'range'), ['int'])),
                                                    ])
                                                    self.range = None

                                                    self.config_fabric_iwan_virtual_network = Native.FabricGroup.Fabric.Auto.ConfigFabricAuto.Domain.IwanFabric.ConfigFabricIwan.VirtualNetwork.Name.Word.Id.ConfigFabricIwanVirtualNetwork()
                                                    self.config_fabric_iwan_virtual_network.parent = self
                                                    self._children_name_map["config_fabric_iwan_virtual_network"] = "config-fabric-iwan-virtual-network"
                                                    self._segment_path = lambda: "id" + "[range='" + str(self.range) + "']"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Native.FabricGroup.Fabric.Auto.ConfigFabricAuto.Domain.IwanFabric.ConfigFabricIwan.VirtualNetwork.Name.Word.Id, ['range'], name, value)


                                                class ConfigFabricIwanVirtualNetwork(Entity):
                                                    """
                                                    
                                                    
                                                    .. attribute:: enterprise_prefix
                                                    
                                                    	Enterprise prefix configuration
                                                    	**type**\:  :py:class:`EnterprisePrefix <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.FabricGroup.Fabric.Auto.ConfigFabricAuto.Domain.IwanFabric.ConfigFabricIwan.VirtualNetwork.Name.Word.Id.ConfigFabricIwanVirtualNetwork.EnterprisePrefix>`
                                                    
                                                    .. attribute:: prefix_group
                                                    
                                                    	prefix group configuration
                                                    	**type**\:  :py:class:`PrefixGroup <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.FabricGroup.Fabric.Auto.ConfigFabricAuto.Domain.IwanFabric.ConfigFabricIwan.VirtualNetwork.Name.Word.Id.ConfigFabricIwanVirtualNetwork.PrefixGroup>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ios-iwanfabric'
                                                    _revision = '2017-11-27'

                                                    def __init__(self):
                                                        super(Native.FabricGroup.Fabric.Auto.ConfigFabricAuto.Domain.IwanFabric.ConfigFabricIwan.VirtualNetwork.Name.Word.Id.ConfigFabricIwanVirtualNetwork, self).__init__()

                                                        self.yang_name = "config-fabric-iwan-virtual-network"
                                                        self.yang_parent_name = "id"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("enterprise-prefix", ("enterprise_prefix", Native.FabricGroup.Fabric.Auto.ConfigFabricAuto.Domain.IwanFabric.ConfigFabricIwan.VirtualNetwork.Name.Word.Id.ConfigFabricIwanVirtualNetwork.EnterprisePrefix)), ("prefix-group", ("prefix_group", Native.FabricGroup.Fabric.Auto.ConfigFabricAuto.Domain.IwanFabric.ConfigFabricIwan.VirtualNetwork.Name.Word.Id.ConfigFabricIwanVirtualNetwork.PrefixGroup))])
                                                        self._leafs = OrderedDict()

                                                        self.enterprise_prefix = Native.FabricGroup.Fabric.Auto.ConfigFabricAuto.Domain.IwanFabric.ConfigFabricIwan.VirtualNetwork.Name.Word.Id.ConfigFabricIwanVirtualNetwork.EnterprisePrefix()
                                                        self.enterprise_prefix.parent = self
                                                        self._children_name_map["enterprise_prefix"] = "enterprise-prefix"

                                                        self.prefix_group = Native.FabricGroup.Fabric.Auto.ConfigFabricAuto.Domain.IwanFabric.ConfigFabricIwan.VirtualNetwork.Name.Word.Id.ConfigFabricIwanVirtualNetwork.PrefixGroup()
                                                        self.prefix_group.parent = self
                                                        self._children_name_map["prefix_group"] = "prefix-group"
                                                        self._segment_path = lambda: "config-fabric-iwan-virtual-network"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Native.FabricGroup.Fabric.Auto.ConfigFabricAuto.Domain.IwanFabric.ConfigFabricIwan.VirtualNetwork.Name.Word.Id.ConfigFabricIwanVirtualNetwork, [], name, value)


                                                    class EnterprisePrefix(Entity):
                                                        """
                                                        Enterprise prefix configuration
                                                        
                                                        .. attribute:: ipv4
                                                        
                                                        	IPv4 enterprise prefix\-list
                                                        	**type**\:  :py:class:`Ipv4 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.FabricGroup.Fabric.Auto.ConfigFabricAuto.Domain.IwanFabric.ConfigFabricIwan.VirtualNetwork.Name.Word.Id.ConfigFabricIwanVirtualNetwork.EnterprisePrefix.Ipv4>`
                                                        
                                                        .. attribute:: ipv6
                                                        
                                                        	IPv6 enterprise prefix\-list
                                                        	**type**\:  :py:class:`Ipv6 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.FabricGroup.Fabric.Auto.ConfigFabricAuto.Domain.IwanFabric.ConfigFabricIwan.VirtualNetwork.Name.Word.Id.ConfigFabricIwanVirtualNetwork.EnterprisePrefix.Ipv6>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'ios-iwanfabric'
                                                        _revision = '2017-11-27'

                                                        def __init__(self):
                                                            super(Native.FabricGroup.Fabric.Auto.ConfigFabricAuto.Domain.IwanFabric.ConfigFabricIwan.VirtualNetwork.Name.Word.Id.ConfigFabricIwanVirtualNetwork.EnterprisePrefix, self).__init__()

                                                            self.yang_name = "enterprise-prefix"
                                                            self.yang_parent_name = "config-fabric-iwan-virtual-network"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([("ipv4", ("ipv4", Native.FabricGroup.Fabric.Auto.ConfigFabricAuto.Domain.IwanFabric.ConfigFabricIwan.VirtualNetwork.Name.Word.Id.ConfigFabricIwanVirtualNetwork.EnterprisePrefix.Ipv4)), ("ipv6", ("ipv6", Native.FabricGroup.Fabric.Auto.ConfigFabricAuto.Domain.IwanFabric.ConfigFabricIwan.VirtualNetwork.Name.Word.Id.ConfigFabricIwanVirtualNetwork.EnterprisePrefix.Ipv6))])
                                                            self._leafs = OrderedDict()

                                                            self.ipv4 = Native.FabricGroup.Fabric.Auto.ConfigFabricAuto.Domain.IwanFabric.ConfigFabricIwan.VirtualNetwork.Name.Word.Id.ConfigFabricIwanVirtualNetwork.EnterprisePrefix.Ipv4()
                                                            self.ipv4.parent = self
                                                            self._children_name_map["ipv4"] = "ipv4"

                                                            self.ipv6 = Native.FabricGroup.Fabric.Auto.ConfigFabricAuto.Domain.IwanFabric.ConfigFabricIwan.VirtualNetwork.Name.Word.Id.ConfigFabricIwanVirtualNetwork.EnterprisePrefix.Ipv6()
                                                            self.ipv6.parent = self
                                                            self._children_name_map["ipv6"] = "ipv6"
                                                            self._segment_path = lambda: "enterprise-prefix"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Native.FabricGroup.Fabric.Auto.ConfigFabricAuto.Domain.IwanFabric.ConfigFabricIwan.VirtualNetwork.Name.Word.Id.ConfigFabricIwanVirtualNetwork.EnterprisePrefix, [], name, value)


                                                        class Ipv4(Entity):
                                                            """
                                                            IPv4 enterprise prefix\-list
                                                            
                                                            .. attribute:: prefix_list
                                                            
                                                            	Up to 19 character list name
                                                            	**type**\: str
                                                            
                                                            

                                                            """

                                                            _prefix = 'ios-iwanfabric'
                                                            _revision = '2017-11-27'

                                                            def __init__(self):
                                                                super(Native.FabricGroup.Fabric.Auto.ConfigFabricAuto.Domain.IwanFabric.ConfigFabricIwan.VirtualNetwork.Name.Word.Id.ConfigFabricIwanVirtualNetwork.EnterprisePrefix.Ipv4, self).__init__()

                                                                self.yang_name = "ipv4"
                                                                self.yang_parent_name = "enterprise-prefix"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([])
                                                                self._leafs = OrderedDict([
                                                                    ('prefix_list', (YLeaf(YType.str, 'prefix-list'), ['str'])),
                                                                ])
                                                                self.prefix_list = None
                                                                self._segment_path = lambda: "ipv4"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Native.FabricGroup.Fabric.Auto.ConfigFabricAuto.Domain.IwanFabric.ConfigFabricIwan.VirtualNetwork.Name.Word.Id.ConfigFabricIwanVirtualNetwork.EnterprisePrefix.Ipv4, ['prefix_list'], name, value)


                                                        class Ipv6(Entity):
                                                            """
                                                            IPv6 enterprise prefix\-list
                                                            
                                                            .. attribute:: prefix_list
                                                            
                                                            	Up to 19 character list name
                                                            	**type**\: str
                                                            
                                                            

                                                            """

                                                            _prefix = 'ios-iwanfabric'
                                                            _revision = '2017-11-27'

                                                            def __init__(self):
                                                                super(Native.FabricGroup.Fabric.Auto.ConfigFabricAuto.Domain.IwanFabric.ConfigFabricIwan.VirtualNetwork.Name.Word.Id.ConfigFabricIwanVirtualNetwork.EnterprisePrefix.Ipv6, self).__init__()

                                                                self.yang_name = "ipv6"
                                                                self.yang_parent_name = "enterprise-prefix"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([])
                                                                self._leafs = OrderedDict([
                                                                    ('prefix_list', (YLeaf(YType.str, 'prefix-list'), ['str'])),
                                                                ])
                                                                self.prefix_list = None
                                                                self._segment_path = lambda: "ipv6"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Native.FabricGroup.Fabric.Auto.ConfigFabricAuto.Domain.IwanFabric.ConfigFabricIwan.VirtualNetwork.Name.Word.Id.ConfigFabricIwanVirtualNetwork.EnterprisePrefix.Ipv6, ['prefix_list'], name, value)


                                                    class PrefixGroup(Entity):
                                                        """
                                                        prefix group configuration
                                                        
                                                        .. attribute:: word
                                                        
                                                        	
                                                        	**type**\: list of  		 :py:class:`Word_ <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.FabricGroup.Fabric.Auto.ConfigFabricAuto.Domain.IwanFabric.ConfigFabricIwan.VirtualNetwork.Name.Word.Id.ConfigFabricIwanVirtualNetwork.PrefixGroup.Word_>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'ios-iwanfabric'
                                                        _revision = '2017-11-27'

                                                        def __init__(self):
                                                            super(Native.FabricGroup.Fabric.Auto.ConfigFabricAuto.Domain.IwanFabric.ConfigFabricIwan.VirtualNetwork.Name.Word.Id.ConfigFabricIwanVirtualNetwork.PrefixGroup, self).__init__()

                                                            self.yang_name = "prefix-group"
                                                            self.yang_parent_name = "config-fabric-iwan-virtual-network"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([("word", ("word", Native.FabricGroup.Fabric.Auto.ConfigFabricAuto.Domain.IwanFabric.ConfigFabricIwan.VirtualNetwork.Name.Word.Id.ConfigFabricIwanVirtualNetwork.PrefixGroup.Word_))])
                                                            self._leafs = OrderedDict()

                                                            self.word = YList(self)
                                                            self._segment_path = lambda: "prefix-group"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Native.FabricGroup.Fabric.Auto.ConfigFabricAuto.Domain.IwanFabric.ConfigFabricIwan.VirtualNetwork.Name.Word.Id.ConfigFabricIwanVirtualNetwork.PrefixGroup, [], name, value)


                                                        class Word_(Entity):
                                                            """
                                                            
                                                            
                                                            .. attribute:: word  (key)
                                                            
                                                            	Up to 19 character list name
                                                            	**type**\: str
                                                            
                                                            .. attribute:: vrf
                                                            
                                                            	Specify the virtual routing instance name
                                                            	**type**\: list of  		 :py:class:`Vrf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.FabricGroup.Fabric.Auto.ConfigFabricAuto.Domain.IwanFabric.ConfigFabricIwan.VirtualNetwork.Name.Word.Id.ConfigFabricIwanVirtualNetwork.PrefixGroup.Word_.Vrf>`
                                                            
                                                            

                                                            """

                                                            _prefix = 'ios-iwanfabric'
                                                            _revision = '2017-11-27'

                                                            def __init__(self):
                                                                super(Native.FabricGroup.Fabric.Auto.ConfigFabricAuto.Domain.IwanFabric.ConfigFabricIwan.VirtualNetwork.Name.Word.Id.ConfigFabricIwanVirtualNetwork.PrefixGroup.Word_, self).__init__()

                                                                self.yang_name = "word"
                                                                self.yang_parent_name = "prefix-group"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = ['word']
                                                                self._child_classes = OrderedDict([("vrf", ("vrf", Native.FabricGroup.Fabric.Auto.ConfigFabricAuto.Domain.IwanFabric.ConfigFabricIwan.VirtualNetwork.Name.Word.Id.ConfigFabricIwanVirtualNetwork.PrefixGroup.Word_.Vrf))])
                                                                self._leafs = OrderedDict([
                                                                    ('word', (YLeaf(YType.str, 'word'), ['str'])),
                                                                ])
                                                                self.word = None

                                                                self.vrf = YList(self)
                                                                self._segment_path = lambda: "word" + "[word='" + str(self.word) + "']"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Native.FabricGroup.Fabric.Auto.ConfigFabricAuto.Domain.IwanFabric.ConfigFabricIwan.VirtualNetwork.Name.Word.Id.ConfigFabricIwanVirtualNetwork.PrefixGroup.Word_, ['word'], name, value)


                                                            class Vrf(Entity):
                                                                """
                                                                Specify the virtual routing instance name
                                                                
                                                                .. attribute:: word  (key)
                                                                
                                                                	Up to 19 character list name
                                                                	**type**\: str
                                                                
                                                                .. attribute:: config_fabric_iwan_virtual_network_prefix_group
                                                                
                                                                	
                                                                	**type**\:  :py:class:`ConfigFabricIwanVirtualNetworkPrefixGroup <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.FabricGroup.Fabric.Auto.ConfigFabricAuto.Domain.IwanFabric.ConfigFabricIwan.VirtualNetwork.Name.Word.Id.ConfigFabricIwanVirtualNetwork.PrefixGroup.Word_.Vrf.ConfigFabricIwanVirtualNetworkPrefixGroup>`
                                                                
                                                                

                                                                """

                                                                _prefix = 'ios-iwanfabric'
                                                                _revision = '2017-11-27'

                                                                def __init__(self):
                                                                    super(Native.FabricGroup.Fabric.Auto.ConfigFabricAuto.Domain.IwanFabric.ConfigFabricIwan.VirtualNetwork.Name.Word.Id.ConfigFabricIwanVirtualNetwork.PrefixGroup.Word_.Vrf, self).__init__()

                                                                    self.yang_name = "vrf"
                                                                    self.yang_parent_name = "word"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self.ylist_key_names = ['word']
                                                                    self._child_classes = OrderedDict([("config-fabric-iwan-virtual-network-prefix-group", ("config_fabric_iwan_virtual_network_prefix_group", Native.FabricGroup.Fabric.Auto.ConfigFabricAuto.Domain.IwanFabric.ConfigFabricIwan.VirtualNetwork.Name.Word.Id.ConfigFabricIwanVirtualNetwork.PrefixGroup.Word_.Vrf.ConfigFabricIwanVirtualNetworkPrefixGroup))])
                                                                    self._leafs = OrderedDict([
                                                                        ('word', (YLeaf(YType.str, 'word'), ['str'])),
                                                                    ])
                                                                    self.word = None

                                                                    self.config_fabric_iwan_virtual_network_prefix_group = Native.FabricGroup.Fabric.Auto.ConfigFabricAuto.Domain.IwanFabric.ConfigFabricIwan.VirtualNetwork.Name.Word.Id.ConfigFabricIwanVirtualNetwork.PrefixGroup.Word_.Vrf.ConfigFabricIwanVirtualNetworkPrefixGroup()
                                                                    self.config_fabric_iwan_virtual_network_prefix_group.parent = self
                                                                    self._children_name_map["config_fabric_iwan_virtual_network_prefix_group"] = "config-fabric-iwan-virtual-network-prefix-group"
                                                                    self._segment_path = lambda: "vrf" + "[word='" + str(self.word) + "']"
                                                                    self._is_frozen = True

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Native.FabricGroup.Fabric.Auto.ConfigFabricAuto.Domain.IwanFabric.ConfigFabricIwan.VirtualNetwork.Name.Word.Id.ConfigFabricIwanVirtualNetwork.PrefixGroup.Word_.Vrf, ['word'], name, value)


                                                                class ConfigFabricIwanVirtualNetworkPrefixGroup(Entity):
                                                                    """
                                                                    
                                                                    
                                                                    .. attribute:: prefix
                                                                    
                                                                    	prefix\-group prefix configuration
                                                                    	**type**\:  :py:class:`Prefix <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.FabricGroup.Fabric.Auto.ConfigFabricAuto.Domain.IwanFabric.ConfigFabricIwan.VirtualNetwork.Name.Word.Id.ConfigFabricIwanVirtualNetwork.PrefixGroup.Word_.Vrf.ConfigFabricIwanVirtualNetworkPrefixGroup.Prefix>`
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ios-iwanfabric'
                                                                    _revision = '2017-11-27'

                                                                    def __init__(self):
                                                                        super(Native.FabricGroup.Fabric.Auto.ConfigFabricAuto.Domain.IwanFabric.ConfigFabricIwan.VirtualNetwork.Name.Word.Id.ConfigFabricIwanVirtualNetwork.PrefixGroup.Word_.Vrf.ConfigFabricIwanVirtualNetworkPrefixGroup, self).__init__()

                                                                        self.yang_name = "config-fabric-iwan-virtual-network-prefix-group"
                                                                        self.yang_parent_name = "vrf"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self.ylist_key_names = []
                                                                        self._child_classes = OrderedDict([("prefix", ("prefix", Native.FabricGroup.Fabric.Auto.ConfigFabricAuto.Domain.IwanFabric.ConfigFabricIwan.VirtualNetwork.Name.Word.Id.ConfigFabricIwanVirtualNetwork.PrefixGroup.Word_.Vrf.ConfigFabricIwanVirtualNetworkPrefixGroup.Prefix))])
                                                                        self._leafs = OrderedDict()

                                                                        self.prefix = Native.FabricGroup.Fabric.Auto.ConfigFabricAuto.Domain.IwanFabric.ConfigFabricIwan.VirtualNetwork.Name.Word.Id.ConfigFabricIwanVirtualNetwork.PrefixGroup.Word_.Vrf.ConfigFabricIwanVirtualNetworkPrefixGroup.Prefix()
                                                                        self.prefix.parent = self
                                                                        self._children_name_map["prefix"] = "prefix"
                                                                        self._segment_path = lambda: "config-fabric-iwan-virtual-network-prefix-group"
                                                                        self._is_frozen = True

                                                                    def __setattr__(self, name, value):
                                                                        self._perform_setattr(Native.FabricGroup.Fabric.Auto.ConfigFabricAuto.Domain.IwanFabric.ConfigFabricIwan.VirtualNetwork.Name.Word.Id.ConfigFabricIwanVirtualNetwork.PrefixGroup.Word_.Vrf.ConfigFabricIwanVirtualNetworkPrefixGroup, [], name, value)


                                                                    class Prefix(Entity):
                                                                        """
                                                                        prefix\-group prefix configuration
                                                                        
                                                                        .. attribute:: import_
                                                                        
                                                                        	prefix import
                                                                        	**type**\:  :py:class:`Import <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.FabricGroup.Fabric.Auto.ConfigFabricAuto.Domain.IwanFabric.ConfigFabricIwan.VirtualNetwork.Name.Word.Id.ConfigFabricIwanVirtualNetwork.PrefixGroup.Word_.Vrf.ConfigFabricIwanVirtualNetworkPrefixGroup.Prefix.Import>`
                                                                        
                                                                        .. attribute:: ipv4
                                                                        
                                                                        	IPv4 enterprise prefix\-list
                                                                        	**type**\:  :py:class:`Ipv4 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.FabricGroup.Fabric.Auto.ConfigFabricAuto.Domain.IwanFabric.ConfigFabricIwan.VirtualNetwork.Name.Word.Id.ConfigFabricIwanVirtualNetwork.PrefixGroup.Word_.Vrf.ConfigFabricIwanVirtualNetworkPrefixGroup.Prefix.Ipv4>`
                                                                        
                                                                        .. attribute:: ipv6
                                                                        
                                                                        	IPv6 enterprise prefix\-list
                                                                        	**type**\:  :py:class:`Ipv6 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.FabricGroup.Fabric.Auto.ConfigFabricAuto.Domain.IwanFabric.ConfigFabricIwan.VirtualNetwork.Name.Word.Id.ConfigFabricIwanVirtualNetwork.PrefixGroup.Word_.Vrf.ConfigFabricIwanVirtualNetworkPrefixGroup.Prefix.Ipv6>`
                                                                        
                                                                        

                                                                        """

                                                                        _prefix = 'ios-iwanfabric'
                                                                        _revision = '2017-11-27'

                                                                        def __init__(self):
                                                                            super(Native.FabricGroup.Fabric.Auto.ConfigFabricAuto.Domain.IwanFabric.ConfigFabricIwan.VirtualNetwork.Name.Word.Id.ConfigFabricIwanVirtualNetwork.PrefixGroup.Word_.Vrf.ConfigFabricIwanVirtualNetworkPrefixGroup.Prefix, self).__init__()

                                                                            self.yang_name = "prefix"
                                                                            self.yang_parent_name = "config-fabric-iwan-virtual-network-prefix-group"
                                                                            self.is_top_level_class = False
                                                                            self.has_list_ancestor = True
                                                                            self.ylist_key_names = []
                                                                            self._child_classes = OrderedDict([("import", ("import_", Native.FabricGroup.Fabric.Auto.ConfigFabricAuto.Domain.IwanFabric.ConfigFabricIwan.VirtualNetwork.Name.Word.Id.ConfigFabricIwanVirtualNetwork.PrefixGroup.Word_.Vrf.ConfigFabricIwanVirtualNetworkPrefixGroup.Prefix.Import)), ("ipv4", ("ipv4", Native.FabricGroup.Fabric.Auto.ConfigFabricAuto.Domain.IwanFabric.ConfigFabricIwan.VirtualNetwork.Name.Word.Id.ConfigFabricIwanVirtualNetwork.PrefixGroup.Word_.Vrf.ConfigFabricIwanVirtualNetworkPrefixGroup.Prefix.Ipv4)), ("ipv6", ("ipv6", Native.FabricGroup.Fabric.Auto.ConfigFabricAuto.Domain.IwanFabric.ConfigFabricIwan.VirtualNetwork.Name.Word.Id.ConfigFabricIwanVirtualNetwork.PrefixGroup.Word_.Vrf.ConfigFabricIwanVirtualNetworkPrefixGroup.Prefix.Ipv6))])
                                                                            self._leafs = OrderedDict()

                                                                            self.import_ = Native.FabricGroup.Fabric.Auto.ConfigFabricAuto.Domain.IwanFabric.ConfigFabricIwan.VirtualNetwork.Name.Word.Id.ConfigFabricIwanVirtualNetwork.PrefixGroup.Word_.Vrf.ConfigFabricIwanVirtualNetworkPrefixGroup.Prefix.Import()
                                                                            self.import_.parent = self
                                                                            self._children_name_map["import_"] = "import"

                                                                            self.ipv4 = Native.FabricGroup.Fabric.Auto.ConfigFabricAuto.Domain.IwanFabric.ConfigFabricIwan.VirtualNetwork.Name.Word.Id.ConfigFabricIwanVirtualNetwork.PrefixGroup.Word_.Vrf.ConfigFabricIwanVirtualNetworkPrefixGroup.Prefix.Ipv4()
                                                                            self.ipv4.parent = self
                                                                            self._children_name_map["ipv4"] = "ipv4"

                                                                            self.ipv6 = Native.FabricGroup.Fabric.Auto.ConfigFabricAuto.Domain.IwanFabric.ConfigFabricIwan.VirtualNetwork.Name.Word.Id.ConfigFabricIwanVirtualNetwork.PrefixGroup.Word_.Vrf.ConfigFabricIwanVirtualNetworkPrefixGroup.Prefix.Ipv6()
                                                                            self.ipv6.parent = self
                                                                            self._children_name_map["ipv6"] = "ipv6"
                                                                            self._segment_path = lambda: "prefix"
                                                                            self._is_frozen = True

                                                                        def __setattr__(self, name, value):
                                                                            self._perform_setattr(Native.FabricGroup.Fabric.Auto.ConfigFabricAuto.Domain.IwanFabric.ConfigFabricIwan.VirtualNetwork.Name.Word.Id.ConfigFabricIwanVirtualNetwork.PrefixGroup.Word_.Vrf.ConfigFabricIwanVirtualNetworkPrefixGroup.Prefix, [], name, value)


                                                                        class Import(Entity):
                                                                            """
                                                                            prefix import
                                                                            
                                                                            .. attribute:: bgp
                                                                            
                                                                            	import from bgp as
                                                                            	**type**\:  :py:class:`Bgp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.FabricGroup.Fabric.Auto.ConfigFabricAuto.Domain.IwanFabric.ConfigFabricIwan.VirtualNetwork.Name.Word.Id.ConfigFabricIwanVirtualNetwork.PrefixGroup.Word_.Vrf.ConfigFabricIwanVirtualNetworkPrefixGroup.Prefix.Import.Bgp>`
                                                                            
                                                                            .. attribute:: eigrp
                                                                            
                                                                            	
                                                                            	**type**\:  :py:class:`Eigrp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.FabricGroup.Fabric.Auto.ConfigFabricAuto.Domain.IwanFabric.ConfigFabricIwan.VirtualNetwork.Name.Word.Id.ConfigFabricIwanVirtualNetwork.PrefixGroup.Word_.Vrf.ConfigFabricIwanVirtualNetworkPrefixGroup.Prefix.Import.Eigrp>`
                                                                            
                                                                            .. attribute:: isis
                                                                            
                                                                            	import from isis as
                                                                            	**type**\:  :py:class:`Isis <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.FabricGroup.Fabric.Auto.ConfigFabricAuto.Domain.IwanFabric.ConfigFabricIwan.VirtualNetwork.Name.Word.Id.ConfigFabricIwanVirtualNetwork.PrefixGroup.Word_.Vrf.ConfigFabricIwanVirtualNetworkPrefixGroup.Prefix.Import.Isis>`
                                                                            
                                                                            .. attribute:: lan_fabric
                                                                            
                                                                            	import from lan\-fabric
                                                                            	**type**\:  :py:class:`LanFabric <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.FabricGroup.Fabric.Auto.ConfigFabricAuto.Domain.IwanFabric.ConfigFabricIwan.VirtualNetwork.Name.Word.Id.ConfigFabricIwanVirtualNetwork.PrefixGroup.Word_.Vrf.ConfigFabricIwanVirtualNetworkPrefixGroup.Prefix.Import.LanFabric>`
                                                                            
                                                                            .. attribute:: ospf
                                                                            
                                                                            	import from ospf as
                                                                            	**type**\:  :py:class:`Ospf <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.FabricGroup.Fabric.Auto.ConfigFabricAuto.Domain.IwanFabric.ConfigFabricIwan.VirtualNetwork.Name.Word.Id.ConfigFabricIwanVirtualNetwork.PrefixGroup.Word_.Vrf.ConfigFabricIwanVirtualNetworkPrefixGroup.Prefix.Import.Ospf>`
                                                                            
                                                                            .. attribute:: rip
                                                                            
                                                                            	import from rip as
                                                                            	**type**\:  :py:class:`Rip <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.FabricGroup.Fabric.Auto.ConfigFabricAuto.Domain.IwanFabric.ConfigFabricIwan.VirtualNetwork.Name.Word.Id.ConfigFabricIwanVirtualNetwork.PrefixGroup.Word_.Vrf.ConfigFabricIwanVirtualNetworkPrefixGroup.Prefix.Import.Rip>`
                                                                            
                                                                            .. attribute:: wan_fabric
                                                                            
                                                                            	import from wan\-fabric
                                                                            	**type**\:  :py:class:`WanFabric <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.FabricGroup.Fabric.Auto.ConfigFabricAuto.Domain.IwanFabric.ConfigFabricIwan.VirtualNetwork.Name.Word.Id.ConfigFabricIwanVirtualNetwork.PrefixGroup.Word_.Vrf.ConfigFabricIwanVirtualNetworkPrefixGroup.Prefix.Import.WanFabric>`
                                                                            
                                                                            

                                                                            """

                                                                            _prefix = 'ios-iwanfabric'
                                                                            _revision = '2017-11-27'

                                                                            def __init__(self):
                                                                                super(Native.FabricGroup.Fabric.Auto.ConfigFabricAuto.Domain.IwanFabric.ConfigFabricIwan.VirtualNetwork.Name.Word.Id.ConfigFabricIwanVirtualNetwork.PrefixGroup.Word_.Vrf.ConfigFabricIwanVirtualNetworkPrefixGroup.Prefix.Import, self).__init__()

                                                                                self.yang_name = "import"
                                                                                self.yang_parent_name = "prefix"
                                                                                self.is_top_level_class = False
                                                                                self.has_list_ancestor = True
                                                                                self.ylist_key_names = []
                                                                                self._child_classes = OrderedDict([("bgp", ("bgp", Native.FabricGroup.Fabric.Auto.ConfigFabricAuto.Domain.IwanFabric.ConfigFabricIwan.VirtualNetwork.Name.Word.Id.ConfigFabricIwanVirtualNetwork.PrefixGroup.Word_.Vrf.ConfigFabricIwanVirtualNetworkPrefixGroup.Prefix.Import.Bgp)), ("eigrp", ("eigrp", Native.FabricGroup.Fabric.Auto.ConfigFabricAuto.Domain.IwanFabric.ConfigFabricIwan.VirtualNetwork.Name.Word.Id.ConfigFabricIwanVirtualNetwork.PrefixGroup.Word_.Vrf.ConfigFabricIwanVirtualNetworkPrefixGroup.Prefix.Import.Eigrp)), ("isis", ("isis", Native.FabricGroup.Fabric.Auto.ConfigFabricAuto.Domain.IwanFabric.ConfigFabricIwan.VirtualNetwork.Name.Word.Id.ConfigFabricIwanVirtualNetwork.PrefixGroup.Word_.Vrf.ConfigFabricIwanVirtualNetworkPrefixGroup.Prefix.Import.Isis)), ("lan-fabric", ("lan_fabric", Native.FabricGroup.Fabric.Auto.ConfigFabricAuto.Domain.IwanFabric.ConfigFabricIwan.VirtualNetwork.Name.Word.Id.ConfigFabricIwanVirtualNetwork.PrefixGroup.Word_.Vrf.ConfigFabricIwanVirtualNetworkPrefixGroup.Prefix.Import.LanFabric)), ("ospf", ("ospf", Native.FabricGroup.Fabric.Auto.ConfigFabricAuto.Domain.IwanFabric.ConfigFabricIwan.VirtualNetwork.Name.Word.Id.ConfigFabricIwanVirtualNetwork.PrefixGroup.Word_.Vrf.ConfigFabricIwanVirtualNetworkPrefixGroup.Prefix.Import.Ospf)), ("rip", ("rip", Native.FabricGroup.Fabric.Auto.ConfigFabricAuto.Domain.IwanFabric.ConfigFabricIwan.VirtualNetwork.Name.Word.Id.ConfigFabricIwanVirtualNetwork.PrefixGroup.Word_.Vrf.ConfigFabricIwanVirtualNetworkPrefixGroup.Prefix.Import.Rip)), ("wan-fabric", ("wan_fabric", Native.FabricGroup.Fabric.Auto.ConfigFabricAuto.Domain.IwanFabric.ConfigFabricIwan.VirtualNetwork.Name.Word.Id.ConfigFabricIwanVirtualNetwork.PrefixGroup.Word_.Vrf.ConfigFabricIwanVirtualNetworkPrefixGroup.Prefix.Import.WanFabric))])
                                                                                self._leafs = OrderedDict()

                                                                                self.bgp = Native.FabricGroup.Fabric.Auto.ConfigFabricAuto.Domain.IwanFabric.ConfigFabricIwan.VirtualNetwork.Name.Word.Id.ConfigFabricIwanVirtualNetwork.PrefixGroup.Word_.Vrf.ConfigFabricIwanVirtualNetworkPrefixGroup.Prefix.Import.Bgp()
                                                                                self.bgp.parent = self
                                                                                self._children_name_map["bgp"] = "bgp"

                                                                                self.eigrp = Native.FabricGroup.Fabric.Auto.ConfigFabricAuto.Domain.IwanFabric.ConfigFabricIwan.VirtualNetwork.Name.Word.Id.ConfigFabricIwanVirtualNetwork.PrefixGroup.Word_.Vrf.ConfigFabricIwanVirtualNetworkPrefixGroup.Prefix.Import.Eigrp()
                                                                                self.eigrp.parent = self
                                                                                self._children_name_map["eigrp"] = "eigrp"

                                                                                self.isis = Native.FabricGroup.Fabric.Auto.ConfigFabricAuto.Domain.IwanFabric.ConfigFabricIwan.VirtualNetwork.Name.Word.Id.ConfigFabricIwanVirtualNetwork.PrefixGroup.Word_.Vrf.ConfigFabricIwanVirtualNetworkPrefixGroup.Prefix.Import.Isis()
                                                                                self.isis.parent = self
                                                                                self._children_name_map["isis"] = "isis"

                                                                                self.lan_fabric = Native.FabricGroup.Fabric.Auto.ConfigFabricAuto.Domain.IwanFabric.ConfigFabricIwan.VirtualNetwork.Name.Word.Id.ConfigFabricIwanVirtualNetwork.PrefixGroup.Word_.Vrf.ConfigFabricIwanVirtualNetworkPrefixGroup.Prefix.Import.LanFabric()
                                                                                self.lan_fabric.parent = self
                                                                                self._children_name_map["lan_fabric"] = "lan-fabric"

                                                                                self.ospf = Native.FabricGroup.Fabric.Auto.ConfigFabricAuto.Domain.IwanFabric.ConfigFabricIwan.VirtualNetwork.Name.Word.Id.ConfigFabricIwanVirtualNetwork.PrefixGroup.Word_.Vrf.ConfigFabricIwanVirtualNetworkPrefixGroup.Prefix.Import.Ospf()
                                                                                self.ospf.parent = self
                                                                                self._children_name_map["ospf"] = "ospf"

                                                                                self.rip = Native.FabricGroup.Fabric.Auto.ConfigFabricAuto.Domain.IwanFabric.ConfigFabricIwan.VirtualNetwork.Name.Word.Id.ConfigFabricIwanVirtualNetwork.PrefixGroup.Word_.Vrf.ConfigFabricIwanVirtualNetworkPrefixGroup.Prefix.Import.Rip()
                                                                                self.rip.parent = self
                                                                                self._children_name_map["rip"] = "rip"

                                                                                self.wan_fabric = Native.FabricGroup.Fabric.Auto.ConfigFabricAuto.Domain.IwanFabric.ConfigFabricIwan.VirtualNetwork.Name.Word.Id.ConfigFabricIwanVirtualNetwork.PrefixGroup.Word_.Vrf.ConfigFabricIwanVirtualNetworkPrefixGroup.Prefix.Import.WanFabric()
                                                                                self.wan_fabric.parent = self
                                                                                self._children_name_map["wan_fabric"] = "wan-fabric"
                                                                                self._segment_path = lambda: "import"
                                                                                self._is_frozen = True

                                                                            def __setattr__(self, name, value):
                                                                                self._perform_setattr(Native.FabricGroup.Fabric.Auto.ConfigFabricAuto.Domain.IwanFabric.ConfigFabricIwan.VirtualNetwork.Name.Word.Id.ConfigFabricIwanVirtualNetwork.PrefixGroup.Word_.Vrf.ConfigFabricIwanVirtualNetworkPrefixGroup.Prefix.Import, [], name, value)


                                                                            class Bgp(Entity):
                                                                                """
                                                                                import from bgp as
                                                                                
                                                                                .. attribute:: word
                                                                                
                                                                                	
                                                                                	**type**\: list of  		 :py:class:`Word_ <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.FabricGroup.Fabric.Auto.ConfigFabricAuto.Domain.IwanFabric.ConfigFabricIwan.VirtualNetwork.Name.Word.Id.ConfigFabricIwanVirtualNetwork.PrefixGroup.Word_.Vrf.ConfigFabricIwanVirtualNetworkPrefixGroup.Prefix.Import.Bgp.Word_>`
                                                                                
                                                                                

                                                                                """

                                                                                _prefix = 'ios-iwanfabric'
                                                                                _revision = '2017-11-27'

                                                                                def __init__(self):
                                                                                    super(Native.FabricGroup.Fabric.Auto.ConfigFabricAuto.Domain.IwanFabric.ConfigFabricIwan.VirtualNetwork.Name.Word.Id.ConfigFabricIwanVirtualNetwork.PrefixGroup.Word_.Vrf.ConfigFabricIwanVirtualNetworkPrefixGroup.Prefix.Import.Bgp, self).__init__()

                                                                                    self.yang_name = "bgp"
                                                                                    self.yang_parent_name = "import"
                                                                                    self.is_top_level_class = False
                                                                                    self.has_list_ancestor = True
                                                                                    self.ylist_key_names = []
                                                                                    self._child_classes = OrderedDict([("word", ("word", Native.FabricGroup.Fabric.Auto.ConfigFabricAuto.Domain.IwanFabric.ConfigFabricIwan.VirtualNetwork.Name.Word.Id.ConfigFabricIwanVirtualNetwork.PrefixGroup.Word_.Vrf.ConfigFabricIwanVirtualNetworkPrefixGroup.Prefix.Import.Bgp.Word_))])
                                                                                    self._leafs = OrderedDict()

                                                                                    self.word = YList(self)
                                                                                    self._segment_path = lambda: "bgp"
                                                                                    self._is_frozen = True

                                                                                def __setattr__(self, name, value):
                                                                                    self._perform_setattr(Native.FabricGroup.Fabric.Auto.ConfigFabricAuto.Domain.IwanFabric.ConfigFabricIwan.VirtualNetwork.Name.Word.Id.ConfigFabricIwanVirtualNetwork.PrefixGroup.Word_.Vrf.ConfigFabricIwanVirtualNetworkPrefixGroup.Prefix.Import.Bgp, [], name, value)


                                                                                class Word_(Entity):
                                                                                    """
                                                                                    
                                                                                    
                                                                                    .. attribute:: word  (key)
                                                                                    
                                                                                    	Up to 19 character AS name
                                                                                    	**type**\: str
                                                                                    
                                                                                    .. attribute:: route_map
                                                                                    
                                                                                    	Up to 19 characters route\-map name
                                                                                    	**type**\: str
                                                                                    
                                                                                    

                                                                                    """

                                                                                    _prefix = 'ios-iwanfabric'
                                                                                    _revision = '2017-11-27'

                                                                                    def __init__(self):
                                                                                        super(Native.FabricGroup.Fabric.Auto.ConfigFabricAuto.Domain.IwanFabric.ConfigFabricIwan.VirtualNetwork.Name.Word.Id.ConfigFabricIwanVirtualNetwork.PrefixGroup.Word_.Vrf.ConfigFabricIwanVirtualNetworkPrefixGroup.Prefix.Import.Bgp.Word_, self).__init__()

                                                                                        self.yang_name = "word"
                                                                                        self.yang_parent_name = "bgp"
                                                                                        self.is_top_level_class = False
                                                                                        self.has_list_ancestor = True
                                                                                        self.ylist_key_names = ['word']
                                                                                        self._child_classes = OrderedDict([])
                                                                                        self._leafs = OrderedDict([
                                                                                            ('word', (YLeaf(YType.str, 'word'), ['str'])),
                                                                                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                                                        ])
                                                                                        self.word = None
                                                                                        self.route_map = None
                                                                                        self._segment_path = lambda: "word" + "[word='" + str(self.word) + "']"
                                                                                        self._is_frozen = True

                                                                                    def __setattr__(self, name, value):
                                                                                        self._perform_setattr(Native.FabricGroup.Fabric.Auto.ConfigFabricAuto.Domain.IwanFabric.ConfigFabricIwan.VirtualNetwork.Name.Word.Id.ConfigFabricIwanVirtualNetwork.PrefixGroup.Word_.Vrf.ConfigFabricIwanVirtualNetworkPrefixGroup.Prefix.Import.Bgp.Word_, ['word', 'route_map'], name, value)


                                                                            class Eigrp(Entity):
                                                                                """
                                                                                
                                                                                
                                                                                .. attribute:: word
                                                                                
                                                                                	
                                                                                	**type**\: list of  		 :py:class:`Word_ <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.FabricGroup.Fabric.Auto.ConfigFabricAuto.Domain.IwanFabric.ConfigFabricIwan.VirtualNetwork.Name.Word.Id.ConfigFabricIwanVirtualNetwork.PrefixGroup.Word_.Vrf.ConfigFabricIwanVirtualNetworkPrefixGroup.Prefix.Import.Eigrp.Word_>`
                                                                                
                                                                                

                                                                                """

                                                                                _prefix = 'ios-iwanfabric'
                                                                                _revision = '2017-11-27'

                                                                                def __init__(self):
                                                                                    super(Native.FabricGroup.Fabric.Auto.ConfigFabricAuto.Domain.IwanFabric.ConfigFabricIwan.VirtualNetwork.Name.Word.Id.ConfigFabricIwanVirtualNetwork.PrefixGroup.Word_.Vrf.ConfigFabricIwanVirtualNetworkPrefixGroup.Prefix.Import.Eigrp, self).__init__()

                                                                                    self.yang_name = "eigrp"
                                                                                    self.yang_parent_name = "import"
                                                                                    self.is_top_level_class = False
                                                                                    self.has_list_ancestor = True
                                                                                    self.ylist_key_names = []
                                                                                    self._child_classes = OrderedDict([("word", ("word", Native.FabricGroup.Fabric.Auto.ConfigFabricAuto.Domain.IwanFabric.ConfigFabricIwan.VirtualNetwork.Name.Word.Id.ConfigFabricIwanVirtualNetwork.PrefixGroup.Word_.Vrf.ConfigFabricIwanVirtualNetworkPrefixGroup.Prefix.Import.Eigrp.Word_))])
                                                                                    self._leafs = OrderedDict()

                                                                                    self.word = YList(self)
                                                                                    self._segment_path = lambda: "eigrp"
                                                                                    self._is_frozen = True

                                                                                def __setattr__(self, name, value):
                                                                                    self._perform_setattr(Native.FabricGroup.Fabric.Auto.ConfigFabricAuto.Domain.IwanFabric.ConfigFabricIwan.VirtualNetwork.Name.Word.Id.ConfigFabricIwanVirtualNetwork.PrefixGroup.Word_.Vrf.ConfigFabricIwanVirtualNetworkPrefixGroup.Prefix.Import.Eigrp, [], name, value)


                                                                                class Word_(Entity):
                                                                                    """
                                                                                    
                                                                                    
                                                                                    .. attribute:: word  (key)
                                                                                    
                                                                                    	
                                                                                    	**type**\: str
                                                                                    
                                                                                    .. attribute:: route_map
                                                                                    
                                                                                    	Up to 19 characters route\-map name
                                                                                    	**type**\: str
                                                                                    
                                                                                    

                                                                                    """

                                                                                    _prefix = 'ios-iwanfabric'
                                                                                    _revision = '2017-11-27'

                                                                                    def __init__(self):
                                                                                        super(Native.FabricGroup.Fabric.Auto.ConfigFabricAuto.Domain.IwanFabric.ConfigFabricIwan.VirtualNetwork.Name.Word.Id.ConfigFabricIwanVirtualNetwork.PrefixGroup.Word_.Vrf.ConfigFabricIwanVirtualNetworkPrefixGroup.Prefix.Import.Eigrp.Word_, self).__init__()

                                                                                        self.yang_name = "word"
                                                                                        self.yang_parent_name = "eigrp"
                                                                                        self.is_top_level_class = False
                                                                                        self.has_list_ancestor = True
                                                                                        self.ylist_key_names = ['word']
                                                                                        self._child_classes = OrderedDict([])
                                                                                        self._leafs = OrderedDict([
                                                                                            ('word', (YLeaf(YType.str, 'word'), ['str'])),
                                                                                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                                                        ])
                                                                                        self.word = None
                                                                                        self.route_map = None
                                                                                        self._segment_path = lambda: "word" + "[word='" + str(self.word) + "']"
                                                                                        self._is_frozen = True

                                                                                    def __setattr__(self, name, value):
                                                                                        self._perform_setattr(Native.FabricGroup.Fabric.Auto.ConfigFabricAuto.Domain.IwanFabric.ConfigFabricIwan.VirtualNetwork.Name.Word.Id.ConfigFabricIwanVirtualNetwork.PrefixGroup.Word_.Vrf.ConfigFabricIwanVirtualNetworkPrefixGroup.Prefix.Import.Eigrp.Word_, ['word', 'route_map'], name, value)


                                                                            class Isis(Entity):
                                                                                """
                                                                                import from isis as
                                                                                
                                                                                .. attribute:: word
                                                                                
                                                                                	
                                                                                	**type**\: list of  		 :py:class:`Word_ <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.FabricGroup.Fabric.Auto.ConfigFabricAuto.Domain.IwanFabric.ConfigFabricIwan.VirtualNetwork.Name.Word.Id.ConfigFabricIwanVirtualNetwork.PrefixGroup.Word_.Vrf.ConfigFabricIwanVirtualNetworkPrefixGroup.Prefix.Import.Isis.Word_>`
                                                                                
                                                                                

                                                                                """

                                                                                _prefix = 'ios-iwanfabric'
                                                                                _revision = '2017-11-27'

                                                                                def __init__(self):
                                                                                    super(Native.FabricGroup.Fabric.Auto.ConfigFabricAuto.Domain.IwanFabric.ConfigFabricIwan.VirtualNetwork.Name.Word.Id.ConfigFabricIwanVirtualNetwork.PrefixGroup.Word_.Vrf.ConfigFabricIwanVirtualNetworkPrefixGroup.Prefix.Import.Isis, self).__init__()

                                                                                    self.yang_name = "isis"
                                                                                    self.yang_parent_name = "import"
                                                                                    self.is_top_level_class = False
                                                                                    self.has_list_ancestor = True
                                                                                    self.ylist_key_names = []
                                                                                    self._child_classes = OrderedDict([("word", ("word", Native.FabricGroup.Fabric.Auto.ConfigFabricAuto.Domain.IwanFabric.ConfigFabricIwan.VirtualNetwork.Name.Word.Id.ConfigFabricIwanVirtualNetwork.PrefixGroup.Word_.Vrf.ConfigFabricIwanVirtualNetworkPrefixGroup.Prefix.Import.Isis.Word_))])
                                                                                    self._leafs = OrderedDict()

                                                                                    self.word = YList(self)
                                                                                    self._segment_path = lambda: "isis"
                                                                                    self._is_frozen = True

                                                                                def __setattr__(self, name, value):
                                                                                    self._perform_setattr(Native.FabricGroup.Fabric.Auto.ConfigFabricAuto.Domain.IwanFabric.ConfigFabricIwan.VirtualNetwork.Name.Word.Id.ConfigFabricIwanVirtualNetwork.PrefixGroup.Word_.Vrf.ConfigFabricIwanVirtualNetworkPrefixGroup.Prefix.Import.Isis, [], name, value)


                                                                                class Word_(Entity):
                                                                                    """
                                                                                    
                                                                                    
                                                                                    .. attribute:: word  (key)
                                                                                    
                                                                                    	
                                                                                    	**type**\: str
                                                                                    
                                                                                    .. attribute:: route_map
                                                                                    
                                                                                    	Up to 19 characters route\-map name
                                                                                    	**type**\: str
                                                                                    
                                                                                    

                                                                                    """

                                                                                    _prefix = 'ios-iwanfabric'
                                                                                    _revision = '2017-11-27'

                                                                                    def __init__(self):
                                                                                        super(Native.FabricGroup.Fabric.Auto.ConfigFabricAuto.Domain.IwanFabric.ConfigFabricIwan.VirtualNetwork.Name.Word.Id.ConfigFabricIwanVirtualNetwork.PrefixGroup.Word_.Vrf.ConfigFabricIwanVirtualNetworkPrefixGroup.Prefix.Import.Isis.Word_, self).__init__()

                                                                                        self.yang_name = "word"
                                                                                        self.yang_parent_name = "isis"
                                                                                        self.is_top_level_class = False
                                                                                        self.has_list_ancestor = True
                                                                                        self.ylist_key_names = ['word']
                                                                                        self._child_classes = OrderedDict([])
                                                                                        self._leafs = OrderedDict([
                                                                                            ('word', (YLeaf(YType.str, 'word'), ['str'])),
                                                                                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                                                        ])
                                                                                        self.word = None
                                                                                        self.route_map = None
                                                                                        self._segment_path = lambda: "word" + "[word='" + str(self.word) + "']"
                                                                                        self._is_frozen = True

                                                                                    def __setattr__(self, name, value):
                                                                                        self._perform_setattr(Native.FabricGroup.Fabric.Auto.ConfigFabricAuto.Domain.IwanFabric.ConfigFabricIwan.VirtualNetwork.Name.Word.Id.ConfigFabricIwanVirtualNetwork.PrefixGroup.Word_.Vrf.ConfigFabricIwanVirtualNetworkPrefixGroup.Prefix.Import.Isis.Word_, ['word', 'route_map'], name, value)


                                                                            class LanFabric(Entity):
                                                                                """
                                                                                import from lan\-fabric
                                                                                
                                                                                .. attribute:: route_map
                                                                                
                                                                                	Up to 19 characters route\-map name
                                                                                	**type**\: str
                                                                                
                                                                                

                                                                                """

                                                                                _prefix = 'ios-iwanfabric'
                                                                                _revision = '2017-11-27'

                                                                                def __init__(self):
                                                                                    super(Native.FabricGroup.Fabric.Auto.ConfigFabricAuto.Domain.IwanFabric.ConfigFabricIwan.VirtualNetwork.Name.Word.Id.ConfigFabricIwanVirtualNetwork.PrefixGroup.Word_.Vrf.ConfigFabricIwanVirtualNetworkPrefixGroup.Prefix.Import.LanFabric, self).__init__()

                                                                                    self.yang_name = "lan-fabric"
                                                                                    self.yang_parent_name = "import"
                                                                                    self.is_top_level_class = False
                                                                                    self.has_list_ancestor = True
                                                                                    self.ylist_key_names = []
                                                                                    self._child_classes = OrderedDict([])
                                                                                    self._leafs = OrderedDict([
                                                                                        ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                                                    ])
                                                                                    self.route_map = None
                                                                                    self._segment_path = lambda: "lan-fabric"
                                                                                    self._is_frozen = True

                                                                                def __setattr__(self, name, value):
                                                                                    self._perform_setattr(Native.FabricGroup.Fabric.Auto.ConfigFabricAuto.Domain.IwanFabric.ConfigFabricIwan.VirtualNetwork.Name.Word.Id.ConfigFabricIwanVirtualNetwork.PrefixGroup.Word_.Vrf.ConfigFabricIwanVirtualNetworkPrefixGroup.Prefix.Import.LanFabric, ['route_map'], name, value)


                                                                            class Ospf(Entity):
                                                                                """
                                                                                import from ospf as
                                                                                
                                                                                .. attribute:: word
                                                                                
                                                                                	
                                                                                	**type**\: list of  		 :py:class:`Word_ <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.FabricGroup.Fabric.Auto.ConfigFabricAuto.Domain.IwanFabric.ConfigFabricIwan.VirtualNetwork.Name.Word.Id.ConfigFabricIwanVirtualNetwork.PrefixGroup.Word_.Vrf.ConfigFabricIwanVirtualNetworkPrefixGroup.Prefix.Import.Ospf.Word_>`
                                                                                
                                                                                

                                                                                """

                                                                                _prefix = 'ios-iwanfabric'
                                                                                _revision = '2017-11-27'

                                                                                def __init__(self):
                                                                                    super(Native.FabricGroup.Fabric.Auto.ConfigFabricAuto.Domain.IwanFabric.ConfigFabricIwan.VirtualNetwork.Name.Word.Id.ConfigFabricIwanVirtualNetwork.PrefixGroup.Word_.Vrf.ConfigFabricIwanVirtualNetworkPrefixGroup.Prefix.Import.Ospf, self).__init__()

                                                                                    self.yang_name = "ospf"
                                                                                    self.yang_parent_name = "import"
                                                                                    self.is_top_level_class = False
                                                                                    self.has_list_ancestor = True
                                                                                    self.ylist_key_names = []
                                                                                    self._child_classes = OrderedDict([("word", ("word", Native.FabricGroup.Fabric.Auto.ConfigFabricAuto.Domain.IwanFabric.ConfigFabricIwan.VirtualNetwork.Name.Word.Id.ConfigFabricIwanVirtualNetwork.PrefixGroup.Word_.Vrf.ConfigFabricIwanVirtualNetworkPrefixGroup.Prefix.Import.Ospf.Word_))])
                                                                                    self._leafs = OrderedDict()

                                                                                    self.word = YList(self)
                                                                                    self._segment_path = lambda: "ospf"
                                                                                    self._is_frozen = True

                                                                                def __setattr__(self, name, value):
                                                                                    self._perform_setattr(Native.FabricGroup.Fabric.Auto.ConfigFabricAuto.Domain.IwanFabric.ConfigFabricIwan.VirtualNetwork.Name.Word.Id.ConfigFabricIwanVirtualNetwork.PrefixGroup.Word_.Vrf.ConfigFabricIwanVirtualNetworkPrefixGroup.Prefix.Import.Ospf, [], name, value)


                                                                                class Word_(Entity):
                                                                                    """
                                                                                    
                                                                                    
                                                                                    .. attribute:: word  (key)
                                                                                    
                                                                                    	
                                                                                    	**type**\: str
                                                                                    
                                                                                    .. attribute:: route_map
                                                                                    
                                                                                    	Up to 19 characters route\-map name
                                                                                    	**type**\: str
                                                                                    
                                                                                    

                                                                                    """

                                                                                    _prefix = 'ios-iwanfabric'
                                                                                    _revision = '2017-11-27'

                                                                                    def __init__(self):
                                                                                        super(Native.FabricGroup.Fabric.Auto.ConfigFabricAuto.Domain.IwanFabric.ConfigFabricIwan.VirtualNetwork.Name.Word.Id.ConfigFabricIwanVirtualNetwork.PrefixGroup.Word_.Vrf.ConfigFabricIwanVirtualNetworkPrefixGroup.Prefix.Import.Ospf.Word_, self).__init__()

                                                                                        self.yang_name = "word"
                                                                                        self.yang_parent_name = "ospf"
                                                                                        self.is_top_level_class = False
                                                                                        self.has_list_ancestor = True
                                                                                        self.ylist_key_names = ['word']
                                                                                        self._child_classes = OrderedDict([])
                                                                                        self._leafs = OrderedDict([
                                                                                            ('word', (YLeaf(YType.str, 'word'), ['str'])),
                                                                                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                                                        ])
                                                                                        self.word = None
                                                                                        self.route_map = None
                                                                                        self._segment_path = lambda: "word" + "[word='" + str(self.word) + "']"
                                                                                        self._is_frozen = True

                                                                                    def __setattr__(self, name, value):
                                                                                        self._perform_setattr(Native.FabricGroup.Fabric.Auto.ConfigFabricAuto.Domain.IwanFabric.ConfigFabricIwan.VirtualNetwork.Name.Word.Id.ConfigFabricIwanVirtualNetwork.PrefixGroup.Word_.Vrf.ConfigFabricIwanVirtualNetworkPrefixGroup.Prefix.Import.Ospf.Word_, ['word', 'route_map'], name, value)


                                                                            class Rip(Entity):
                                                                                """
                                                                                import from rip as
                                                                                
                                                                                .. attribute:: word
                                                                                
                                                                                	
                                                                                	**type**\: list of  		 :py:class:`Word_ <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.FabricGroup.Fabric.Auto.ConfigFabricAuto.Domain.IwanFabric.ConfigFabricIwan.VirtualNetwork.Name.Word.Id.ConfigFabricIwanVirtualNetwork.PrefixGroup.Word_.Vrf.ConfigFabricIwanVirtualNetworkPrefixGroup.Prefix.Import.Rip.Word_>`
                                                                                
                                                                                

                                                                                """

                                                                                _prefix = 'ios-iwanfabric'
                                                                                _revision = '2017-11-27'

                                                                                def __init__(self):
                                                                                    super(Native.FabricGroup.Fabric.Auto.ConfigFabricAuto.Domain.IwanFabric.ConfigFabricIwan.VirtualNetwork.Name.Word.Id.ConfigFabricIwanVirtualNetwork.PrefixGroup.Word_.Vrf.ConfigFabricIwanVirtualNetworkPrefixGroup.Prefix.Import.Rip, self).__init__()

                                                                                    self.yang_name = "rip"
                                                                                    self.yang_parent_name = "import"
                                                                                    self.is_top_level_class = False
                                                                                    self.has_list_ancestor = True
                                                                                    self.ylist_key_names = []
                                                                                    self._child_classes = OrderedDict([("word", ("word", Native.FabricGroup.Fabric.Auto.ConfigFabricAuto.Domain.IwanFabric.ConfigFabricIwan.VirtualNetwork.Name.Word.Id.ConfigFabricIwanVirtualNetwork.PrefixGroup.Word_.Vrf.ConfigFabricIwanVirtualNetworkPrefixGroup.Prefix.Import.Rip.Word_))])
                                                                                    self._leafs = OrderedDict()

                                                                                    self.word = YList(self)
                                                                                    self._segment_path = lambda: "rip"
                                                                                    self._is_frozen = True

                                                                                def __setattr__(self, name, value):
                                                                                    self._perform_setattr(Native.FabricGroup.Fabric.Auto.ConfigFabricAuto.Domain.IwanFabric.ConfigFabricIwan.VirtualNetwork.Name.Word.Id.ConfigFabricIwanVirtualNetwork.PrefixGroup.Word_.Vrf.ConfigFabricIwanVirtualNetworkPrefixGroup.Prefix.Import.Rip, [], name, value)


                                                                                class Word_(Entity):
                                                                                    """
                                                                                    
                                                                                    
                                                                                    .. attribute:: word  (key)
                                                                                    
                                                                                    	Up to 19 character AS name
                                                                                    	**type**\: str
                                                                                    
                                                                                    .. attribute:: route_map
                                                                                    
                                                                                    	Up to 19 characters route\-map name
                                                                                    	**type**\: str
                                                                                    
                                                                                    

                                                                                    """

                                                                                    _prefix = 'ios-iwanfabric'
                                                                                    _revision = '2017-11-27'

                                                                                    def __init__(self):
                                                                                        super(Native.FabricGroup.Fabric.Auto.ConfigFabricAuto.Domain.IwanFabric.ConfigFabricIwan.VirtualNetwork.Name.Word.Id.ConfigFabricIwanVirtualNetwork.PrefixGroup.Word_.Vrf.ConfigFabricIwanVirtualNetworkPrefixGroup.Prefix.Import.Rip.Word_, self).__init__()

                                                                                        self.yang_name = "word"
                                                                                        self.yang_parent_name = "rip"
                                                                                        self.is_top_level_class = False
                                                                                        self.has_list_ancestor = True
                                                                                        self.ylist_key_names = ['word']
                                                                                        self._child_classes = OrderedDict([])
                                                                                        self._leafs = OrderedDict([
                                                                                            ('word', (YLeaf(YType.str, 'word'), ['str'])),
                                                                                            ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                                                        ])
                                                                                        self.word = None
                                                                                        self.route_map = None
                                                                                        self._segment_path = lambda: "word" + "[word='" + str(self.word) + "']"
                                                                                        self._is_frozen = True

                                                                                    def __setattr__(self, name, value):
                                                                                        self._perform_setattr(Native.FabricGroup.Fabric.Auto.ConfigFabricAuto.Domain.IwanFabric.ConfigFabricIwan.VirtualNetwork.Name.Word.Id.ConfigFabricIwanVirtualNetwork.PrefixGroup.Word_.Vrf.ConfigFabricIwanVirtualNetworkPrefixGroup.Prefix.Import.Rip.Word_, ['word', 'route_map'], name, value)


                                                                            class WanFabric(Entity):
                                                                                """
                                                                                import from wan\-fabric
                                                                                
                                                                                .. attribute:: route_map
                                                                                
                                                                                	Up to 19 characters route\-map name
                                                                                	**type**\: str
                                                                                
                                                                                

                                                                                """

                                                                                _prefix = 'ios-iwanfabric'
                                                                                _revision = '2017-11-27'

                                                                                def __init__(self):
                                                                                    super(Native.FabricGroup.Fabric.Auto.ConfigFabricAuto.Domain.IwanFabric.ConfigFabricIwan.VirtualNetwork.Name.Word.Id.ConfigFabricIwanVirtualNetwork.PrefixGroup.Word_.Vrf.ConfigFabricIwanVirtualNetworkPrefixGroup.Prefix.Import.WanFabric, self).__init__()

                                                                                    self.yang_name = "wan-fabric"
                                                                                    self.yang_parent_name = "import"
                                                                                    self.is_top_level_class = False
                                                                                    self.has_list_ancestor = True
                                                                                    self.ylist_key_names = []
                                                                                    self._child_classes = OrderedDict([])
                                                                                    self._leafs = OrderedDict([
                                                                                        ('route_map', (YLeaf(YType.str, 'route-map'), ['str'])),
                                                                                    ])
                                                                                    self.route_map = None
                                                                                    self._segment_path = lambda: "wan-fabric"
                                                                                    self._is_frozen = True

                                                                                def __setattr__(self, name, value):
                                                                                    self._perform_setattr(Native.FabricGroup.Fabric.Auto.ConfigFabricAuto.Domain.IwanFabric.ConfigFabricIwan.VirtualNetwork.Name.Word.Id.ConfigFabricIwanVirtualNetwork.PrefixGroup.Word_.Vrf.ConfigFabricIwanVirtualNetworkPrefixGroup.Prefix.Import.WanFabric, ['route_map'], name, value)


                                                                        class Ipv4(Entity):
                                                                            """
                                                                            IPv4 enterprise prefix\-list
                                                                            
                                                                            .. attribute:: prefix_list
                                                                            
                                                                            	Up to 19 character list name
                                                                            	**type**\: str
                                                                            
                                                                            

                                                                            """

                                                                            _prefix = 'ios-iwanfabric'
                                                                            _revision = '2017-11-27'

                                                                            def __init__(self):
                                                                                super(Native.FabricGroup.Fabric.Auto.ConfigFabricAuto.Domain.IwanFabric.ConfigFabricIwan.VirtualNetwork.Name.Word.Id.ConfigFabricIwanVirtualNetwork.PrefixGroup.Word_.Vrf.ConfigFabricIwanVirtualNetworkPrefixGroup.Prefix.Ipv4, self).__init__()

                                                                                self.yang_name = "ipv4"
                                                                                self.yang_parent_name = "prefix"
                                                                                self.is_top_level_class = False
                                                                                self.has_list_ancestor = True
                                                                                self.ylist_key_names = []
                                                                                self._child_classes = OrderedDict([])
                                                                                self._leafs = OrderedDict([
                                                                                    ('prefix_list', (YLeaf(YType.str, 'prefix-list'), ['str'])),
                                                                                ])
                                                                                self.prefix_list = None
                                                                                self._segment_path = lambda: "ipv4"
                                                                                self._is_frozen = True

                                                                            def __setattr__(self, name, value):
                                                                                self._perform_setattr(Native.FabricGroup.Fabric.Auto.ConfigFabricAuto.Domain.IwanFabric.ConfigFabricIwan.VirtualNetwork.Name.Word.Id.ConfigFabricIwanVirtualNetwork.PrefixGroup.Word_.Vrf.ConfigFabricIwanVirtualNetworkPrefixGroup.Prefix.Ipv4, ['prefix_list'], name, value)


                                                                        class Ipv6(Entity):
                                                                            """
                                                                            IPv6 enterprise prefix\-list
                                                                            
                                                                            .. attribute:: prefix_list
                                                                            
                                                                            	Up to 19 character list name
                                                                            	**type**\: str
                                                                            
                                                                            

                                                                            """

                                                                            _prefix = 'ios-iwanfabric'
                                                                            _revision = '2017-11-27'

                                                                            def __init__(self):
                                                                                super(Native.FabricGroup.Fabric.Auto.ConfigFabricAuto.Domain.IwanFabric.ConfigFabricIwan.VirtualNetwork.Name.Word.Id.ConfigFabricIwanVirtualNetwork.PrefixGroup.Word_.Vrf.ConfigFabricIwanVirtualNetworkPrefixGroup.Prefix.Ipv6, self).__init__()

                                                                                self.yang_name = "ipv6"
                                                                                self.yang_parent_name = "prefix"
                                                                                self.is_top_level_class = False
                                                                                self.has_list_ancestor = True
                                                                                self.ylist_key_names = []
                                                                                self._child_classes = OrderedDict([])
                                                                                self._leafs = OrderedDict([
                                                                                    ('prefix_list', (YLeaf(YType.str, 'prefix-list'), ['str'])),
                                                                                ])
                                                                                self.prefix_list = None
                                                                                self._segment_path = lambda: "ipv6"
                                                                                self._is_frozen = True

                                                                            def __setattr__(self, name, value):
                                                                                self._perform_setattr(Native.FabricGroup.Fabric.Auto.ConfigFabricAuto.Domain.IwanFabric.ConfigFabricIwan.VirtualNetwork.Name.Word.Id.ConfigFabricIwanVirtualNetwork.PrefixGroup.Word_.Vrf.ConfigFabricIwanVirtualNetworkPrefixGroup.Prefix.Ipv6, ['prefix_list'], name, value)


    class Coap(Entity):
        """
        CoAP Global Configuration Commands
        
        .. attribute:: http
        
        	CoAP http server
        	**type**\:  :py:class:`Http <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Coap.Http>`
        
        

        """

        _prefix = 'ios-coap'
        _revision = '2017-02-07'

        def __init__(self):
            super(Native.Coap, self).__init__()

            self.yang_name = "coap"
            self.yang_parent_name = "native"
            self.is_top_level_class = False
            self.has_list_ancestor = False
            self.ylist_key_names = []
            self._child_classes = OrderedDict([("http", ("http", Native.Coap.Http))])
            self._leafs = OrderedDict()

            self.http = Native.Coap.Http()
            self.http.parent = self
            self._children_name_map["http"] = "http"
            self._segment_path = lambda: "Cisco-IOS-XE-coap:coap"
            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/%s" % self._segment_path()
            self._is_frozen = True

        def __setattr__(self, name, value):
            self._perform_setattr(Native.Coap, [], name, value)


        class Http(Entity):
            """
            CoAP http server
            
            .. attribute:: enable
            
            	CoAP http server enable
            	**type**\: :py:class:`Empty<ydk.types.Empty>`
            
            

            """

            _prefix = 'ios-coap'
            _revision = '2017-02-07'

            def __init__(self):
                super(Native.Coap.Http, self).__init__()

                self.yang_name = "http"
                self.yang_parent_name = "coap"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = []
                self._child_classes = OrderedDict([])
                self._leafs = OrderedDict([
                    ('enable', (YLeaf(YType.empty, 'enable'), ['Empty'])),
                ])
                self.enable = None
                self._segment_path = lambda: "http"
                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/Cisco-IOS-XE-coap:coap/%s" % self._segment_path()
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(Native.Coap.Http, ['enable'], name, value)


    class Voice(Entity):
        """
        Global voice configuration
        
        .. attribute:: service
        
        	Global packet telephony service commands
        	**type**\: list of  		 :py:class:`Service <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Voice.Service>`
        
        

        """

        _prefix = 'ios-voice'
        _revision = '2017-02-07'

        def __init__(self):
            super(Native.Voice, self).__init__()

            self.yang_name = "voice"
            self.yang_parent_name = "native"
            self.is_top_level_class = False
            self.has_list_ancestor = False
            self.ylist_key_names = []
            self._child_classes = OrderedDict([("service", ("service", Native.Voice.Service))])
            self._leafs = OrderedDict()

            self.service = YList(self)
            self._segment_path = lambda: "Cisco-IOS-XE-voice:voice"
            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/%s" % self._segment_path()
            self._is_frozen = True

        def __setattr__(self, name, value):
            self._perform_setattr(Native.Voice, [], name, value)


        class Service(Entity):
            """
            Global packet telephony service commands
            
            .. attribute:: type  (key)
            
            	
            	**type**\:  :py:class:`Type <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Voice.Service.Type>`
            
            .. attribute:: fax
            
            	Global fax commands
            	**type**\:  :py:class:`Fax <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Voice.Service.Fax>`
            
            

            """

            _prefix = 'ios-voice'
            _revision = '2017-02-07'

            def __init__(self):
                super(Native.Voice.Service, self).__init__()

                self.yang_name = "service"
                self.yang_parent_name = "voice"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = ['type']
                self._child_classes = OrderedDict([("fax", ("fax", Native.Voice.Service.Fax))])
                self._leafs = OrderedDict([
                    ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Voice.Service.Type')])),
                ])
                self.type = None

                self.fax = Native.Voice.Service.Fax()
                self.fax.parent = self
                self._children_name_map["fax"] = "fax"
                self._segment_path = lambda: "service" + "[type='" + str(self.type) + "']"
                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/Cisco-IOS-XE-voice:voice/%s" % self._segment_path()
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(Native.Voice.Service, ['type'], name, value)

            class Type(Enum):
                """
                Type (Enum Class)

                .. data:: pots = 0

                .. data:: saf = 1

                .. data:: voatm = 2

                .. data:: vofr = 3

                .. data:: voip = 4

                """

                pots = Enum.YLeaf(0, "pots")

                saf = Enum.YLeaf(1, "saf")

                voatm = Enum.YLeaf(2, "voatm")

                vofr = Enum.YLeaf(3, "vofr")

                voip = Enum.YLeaf(4, "voip")



            class Fax(Entity):
                """
                Global fax commands
                
                .. attribute:: protocol
                
                	The system\-wide fax protocol type
                	**type**\:  :py:class:`Protocol <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Voice.Service.Fax.Protocol>`
                
                .. attribute:: fallback
                
                	fax transport to use if T.38 unsupported on far end
                	**type**\:  :py:class:`Fallback <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Voice.Service.Fax.Fallback>`
                
                .. attribute:: codec
                
                	
                	**type**\:  :py:class:`Codec <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Voice.Service.Fax.Codec>`
                
                .. attribute:: ls_redundancy
                
                	t38 low speed redundancy
                	**type**\: int
                
                	**range:** 0..5
                
                .. attribute:: hs_redundancy
                
                	t38 high speed redundancy
                	**type**\: int
                
                	**range:** 0..2
                
                .. attribute:: version
                
                	t38 fax version
                	**type**\:  :py:class:`Version <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Voice.Service.Fax.Version>`
                
                

                """

                _prefix = 'ios-voice'
                _revision = '2017-02-07'

                def __init__(self):
                    super(Native.Voice.Service.Fax, self).__init__()

                    self.yang_name = "fax"
                    self.yang_parent_name = "service"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('protocol', (YLeaf(YType.enumeration, 'protocol'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Voice.Service.Fax.Protocol')])),
                        ('fallback', (YLeaf(YType.enumeration, 'fallback'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Voice.Service.Fax.Fallback')])),
                        ('codec', (YLeaf(YType.enumeration, 'codec'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Voice.Service.Fax.Codec')])),
                        ('ls_redundancy', (YLeaf(YType.uint8, 'ls-redundancy'), ['int'])),
                        ('hs_redundancy', (YLeaf(YType.uint8, 'hs-redundancy'), ['int'])),
                        ('version', (YLeaf(YType.enumeration, 'version'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Voice.Service.Fax.Version')])),
                    ])
                    self.protocol = None
                    self.fallback = None
                    self.codec = None
                    self.ls_redundancy = None
                    self.hs_redundancy = None
                    self.version = None
                    self._segment_path = lambda: "fax"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Voice.Service.Fax, ['protocol', 'fallback', 'codec', 'ls_redundancy', 'hs_redundancy', 'version'], name, value)

                class Codec(Enum):
                    """
                    Codec (Enum Class)

                    .. data:: g711alaw = 0

                    .. data:: g711ulaw = 1

                    """

                    g711alaw = Enum.YLeaf(0, "g711alaw")

                    g711ulaw = Enum.YLeaf(1, "g711ulaw")


                class Fallback(Enum):
                    """
                    Fallback (Enum Class)

                    fax transport to use if T.38 unsupported on far end

                    .. data:: cisco = 0

                    .. data:: none = 1

                    .. data:: pass_through = 2

                    """

                    cisco = Enum.YLeaf(0, "cisco")

                    none = Enum.YLeaf(1, "none")

                    pass_through = Enum.YLeaf(2, "pass-through")


                class Protocol(Enum):
                    """
                    Protocol (Enum Class)

                    The system\-wide fax protocol type

                    .. data:: cisco = 0

                    .. data:: none = 1

                    .. data:: pass_through = 2

                    .. data:: t38 = 3

                    """

                    cisco = Enum.YLeaf(0, "cisco")

                    none = Enum.YLeaf(1, "none")

                    pass_through = Enum.YLeaf(2, "pass-through")

                    t38 = Enum.YLeaf(3, "t38")


                class Version(Enum):
                    """
                    Version (Enum Class)

                    t38 fax version

                    .. data:: Y_0 = 0

                    .. data:: Y_3 = 1

                    """

                    Y_0 = Enum.YLeaf(0, "0")

                    Y_3 = Enum.YLeaf(1, "3")



    class VoiceCard(Entity):
        """
        Configure a specific voice\-card
        
        .. attribute:: slot  (key)
        
        	
        	**type**\: int
        
        	**range:** 0..2
        
        

        """

        _prefix = 'ios-voice'
        _revision = '2017-02-07'

        def __init__(self):
            super(Native.VoiceCard, self).__init__()

            self.yang_name = "voice-card"
            self.yang_parent_name = "native"
            self.is_top_level_class = False
            self.has_list_ancestor = False
            self.ylist_key_names = ['slot']
            self._child_classes = OrderedDict([])
            self._leafs = OrderedDict([
                ('slot', (YLeaf(YType.uint8, 'slot'), ['int'])),
            ])
            self.slot = None
            self._segment_path = lambda: "Cisco-IOS-XE-voice:voice-card" + "[slot='" + str(self.slot) + "']"
            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/%s" % self._segment_path()
            self._is_frozen = True

        def __setattr__(self, name, value):
            self._perform_setattr(Native.VoiceCard, ['slot'], name, value)


    class Power(Entity):
        """
        Power configure
        
        .. attribute:: inline
        
        	Inline power configuration
        	**type**\:  :py:class:`Inline <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Power.Inline>`
        
        	**presence node**\: True
        
        .. attribute:: redundancy_mode
        
        	set power supply redundancy mode
        	**type**\:  :py:class:`RedundancyMode <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Power.RedundancyMode>`
        
        .. attribute:: max_min
        
        	
        	**type**\:  :py:class:`MaxMin <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Power.MaxMin>`
        
        .. attribute:: inputs
        
        	
        	**type**\: int
        
        	**range:** 0..255
        
        

        """

        _prefix = 'ios-power'
        _revision = '2017-11-27'

        def __init__(self):
            super(Native.Power, self).__init__()

            self.yang_name = "power"
            self.yang_parent_name = "native"
            self.is_top_level_class = False
            self.has_list_ancestor = False
            self.ylist_key_names = []
            self._child_classes = OrderedDict([("inline", ("inline", Native.Power.Inline))])
            self._leafs = OrderedDict([
                ('redundancy_mode', (YLeaf(YType.enumeration, 'redundancy-mode'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Power.RedundancyMode')])),
                ('max_min', (YLeaf(YType.enumeration, 'max-min'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Power.MaxMin')])),
                ('inputs', (YLeaf(YType.uint8, 'inputs'), ['int'])),
            ])
            self.redundancy_mode = None
            self.max_min = None
            self.inputs = None

            self.inline = None
            self._children_name_map["inline"] = "inline"
            self._segment_path = lambda: "Cisco-IOS-XE-power:power"
            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/%s" % self._segment_path()
            self._is_frozen = True

        def __setattr__(self, name, value):
            self._perform_setattr(Native.Power, ['redundancy_mode', 'max_min', 'inputs'], name, value)

        class MaxMin(Enum):
            """
            MaxMin (Enum Class)

            .. data:: max = 0

            """

            max = Enum.YLeaf(0, "max")


        class RedundancyMode(Enum):
            """
            RedundancyMode (Enum Class)

            set power supply redundancy mode

            .. data:: combined = 0

            .. data:: redundant = 1

            """

            combined = Enum.YLeaf(0, "combined")

            redundant = Enum.YLeaf(1, "redundant")



        class Inline(Entity):
            """
            Inline power configuration
            
            .. attribute:: consumption
            
            	Inline device power consumption
            	**type**\:  :py:class:`Consumption <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Power.Inline.Consumption>`
            
            .. attribute:: logging
            
            	Inline power logging messages
            	**type**\:  :py:class:`Logging <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Power.Inline.Logging>`
            
            

            This class is a :ref:`presence class<presence-class>`

            """

            _prefix = 'ios-power'
            _revision = '2017-11-27'

            def __init__(self):
                super(Native.Power.Inline, self).__init__()

                self.yang_name = "inline"
                self.yang_parent_name = "power"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = []
                self._child_classes = OrderedDict([("consumption", ("consumption", Native.Power.Inline.Consumption)), ("logging", ("logging", Native.Power.Inline.Logging))])
                self.is_presence_container = True
                self._leafs = OrderedDict()

                self.consumption = Native.Power.Inline.Consumption()
                self.consumption.parent = self
                self._children_name_map["consumption"] = "consumption"

                self.logging = Native.Power.Inline.Logging()
                self.logging.parent = self
                self._children_name_map["logging"] = "logging"
                self._segment_path = lambda: "inline"
                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/Cisco-IOS-XE-power:power/%s" % self._segment_path()
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(Native.Power.Inline, [], name, value)


            class Consumption(Entity):
                """
                Inline device power consumption
                
                .. attribute:: default
                
                	Inline device power consumption
                	**type**\: int
                
                	**range:** 4000..15400
                
                

                """

                _prefix = 'ios-power'
                _revision = '2017-11-27'

                def __init__(self):
                    super(Native.Power.Inline.Consumption, self).__init__()

                    self.yang_name = "consumption"
                    self.yang_parent_name = "inline"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('default', (YLeaf(YType.uint16, 'default'), ['int'])),
                    ])
                    self.default = None
                    self._segment_path = lambda: "consumption"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/Cisco-IOS-XE-power:power/inline/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Power.Inline.Consumption, ['default'], name, value)


            class Logging(Entity):
                """
                Inline power logging messages
                
                .. attribute:: global_
                
                	Enable global inline power logging messages
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                

                """

                _prefix = 'ios-power'
                _revision = '2017-11-27'

                def __init__(self):
                    super(Native.Power.Inline.Logging, self).__init__()

                    self.yang_name = "logging"
                    self.yang_parent_name = "inline"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('global_', (YLeaf(YType.empty, 'global'), ['Empty'])),
                    ])
                    self.global_ = None
                    self._segment_path = lambda: "logging"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/Cisco-IOS-XE-power:power/inline/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Power.Inline.Logging, ['global_'], name, value)


    class DeviceSensor(Entity):
        """
        IOS Sensor Commands
        
        .. attribute:: accounting
        
        	Trigger accounting updates with sensor TLVs/Options
        	**type**\: :py:class:`Empty<ydk.types.Empty>`
        
        .. attribute:: notify
        
        	Options for when to trigger identity update events
        	**type**\:  :py:class:`Notify <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.DeviceSensor.Notify>`
        
        

        """

        _prefix = 'ios-ds'
        _revision = '2017-02-07'

        def __init__(self):
            super(Native.DeviceSensor, self).__init__()

            self.yang_name = "device-sensor"
            self.yang_parent_name = "native"
            self.is_top_level_class = False
            self.has_list_ancestor = False
            self.ylist_key_names = []
            self._child_classes = OrderedDict([("notify", ("notify", Native.DeviceSensor.Notify))])
            self._leafs = OrderedDict([
                ('accounting', (YLeaf(YType.empty, 'accounting'), ['Empty'])),
            ])
            self.accounting = None

            self.notify = Native.DeviceSensor.Notify()
            self.notify.parent = self
            self._children_name_map["notify"] = "notify"
            self._segment_path = lambda: "Cisco-IOS-XE-device-sensor:device-sensor"
            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/%s" % self._segment_path()
            self._is_frozen = True

        def __setattr__(self, name, value):
            self._perform_setattr(Native.DeviceSensor, ['accounting'], name, value)


        class Notify(Entity):
            """
            Options for when to trigger identity update events
            
            .. attribute:: all_changes
            
            	Trigger identity update when TLVs are added/modified/removed
            	**type**\: :py:class:`Empty<ydk.types.Empty>`
            
            

            """

            _prefix = 'ios-ds'
            _revision = '2017-02-07'

            def __init__(self):
                super(Native.DeviceSensor.Notify, self).__init__()

                self.yang_name = "notify"
                self.yang_parent_name = "device-sensor"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = []
                self._child_classes = OrderedDict([])
                self._leafs = OrderedDict([
                    ('all_changes', (YLeaf(YType.empty, 'all-changes'), ['Empty'])),
                ])
                self.all_changes = None
                self._segment_path = lambda: "notify"
                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/Cisco-IOS-XE-device-sensor:device-sensor/%s" % self._segment_path()
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(Native.DeviceSensor.Notify, ['all_changes'], name, value)


    class ServiceList(Entity):
        """
        Enter the service list
        
        .. attribute:: mdns_sd
        
        	Service\-list for mdns\-sd
        	**type**\: list of  		 :py:class:`MdnsSd <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.ServiceList.MdnsSd>`
        
        

        """

        _prefix = 'ios-sd'
        _revision = '2017-02-07'

        def __init__(self):
            super(Native.ServiceList, self).__init__()

            self.yang_name = "service-list"
            self.yang_parent_name = "native"
            self.is_top_level_class = False
            self.has_list_ancestor = False
            self.ylist_key_names = []
            self._child_classes = OrderedDict([("mdns-sd", ("mdns_sd", Native.ServiceList.MdnsSd))])
            self._leafs = OrderedDict()

            self.mdns_sd = YList(self)
            self._segment_path = lambda: "Cisco-IOS-XE-service-discovery:service-list"
            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/%s" % self._segment_path()
            self._is_frozen = True

        def __setattr__(self, name, value):
            self._perform_setattr(Native.ServiceList, [], name, value)


        class MdnsSd(Entity):
            """
            Service\-list for mdns\-sd
            
            .. attribute:: service_list_name  (key)
            
            	service\-list name
            	**type**\: str
            
            .. attribute:: deny
            
            	Specify packets to reject
            	**type**\: list of  		 :py:class:`Deny <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.ServiceList.MdnsSd.Deny>`
            
            .. attribute:: permit
            
            	Specify packets to forward
            	**type**\: list of  		 :py:class:`Permit <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.ServiceList.MdnsSd.Permit>`
            
            .. attribute:: query
            
            	Service\-list Query for mdns\-sd
            	**type**\:  :py:class:`Query <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.ServiceList.MdnsSd.Query>`
            
            

            """

            _prefix = 'ios-sd'
            _revision = '2017-02-07'

            def __init__(self):
                super(Native.ServiceList.MdnsSd, self).__init__()

                self.yang_name = "mdns-sd"
                self.yang_parent_name = "service-list"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = ['service_list_name']
                self._child_classes = OrderedDict([("deny", ("deny", Native.ServiceList.MdnsSd.Deny)), ("permit", ("permit", Native.ServiceList.MdnsSd.Permit)), ("query", ("query", Native.ServiceList.MdnsSd.Query))])
                self._leafs = OrderedDict([
                    ('service_list_name', (YLeaf(YType.str, 'service-list-name'), ['str'])),
                ])
                self.service_list_name = None

                self.query = Native.ServiceList.MdnsSd.Query()
                self.query.parent = self
                self._children_name_map["query"] = "query"

                self.deny = YList(self)
                self.permit = YList(self)
                self._segment_path = lambda: "mdns-sd" + "[service-list-name='" + str(self.service_list_name) + "']"
                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/Cisco-IOS-XE-service-discovery:service-list/%s" % self._segment_path()
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(Native.ServiceList.MdnsSd, ['service_list_name'], name, value)


            class Deny(Entity):
                """
                Specify packets to reject
                
                .. attribute:: deny_pack  (key)
                
                	
                	**type**\: int
                
                	**range:** 0..100
                
                .. attribute:: match
                
                	Configure parameters for service\-list name
                	**type**\:  :py:class:`Match <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.ServiceList.MdnsSd.Deny.Match>`
                
                

                """

                _prefix = 'ios-sd'
                _revision = '2017-02-07'

                def __init__(self):
                    super(Native.ServiceList.MdnsSd.Deny, self).__init__()

                    self.yang_name = "deny"
                    self.yang_parent_name = "mdns-sd"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = ['deny_pack']
                    self._child_classes = OrderedDict([("match", ("match", Native.ServiceList.MdnsSd.Deny.Match))])
                    self._leafs = OrderedDict([
                        ('deny_pack', (YLeaf(YType.uint8, 'deny-pack'), ['int'])),
                    ])
                    self.deny_pack = None

                    self.match = Native.ServiceList.MdnsSd.Deny.Match()
                    self.match.parent = self
                    self._children_name_map["match"] = "match"
                    self._segment_path = lambda: "deny" + "[deny-pack='" + str(self.deny_pack) + "']"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.ServiceList.MdnsSd.Deny, ['deny_pack'], name, value)


                class Match(Entity):
                    """
                    Configure parameters for service\-list name
                    
                    .. attribute:: learnt_interface
                    
                    	match the interface where service is learnt
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: location
                    
                    	match location information
                    	**type**\:  :py:class:`Location <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.ServiceList.MdnsSd.Deny.Match.Location>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: message_type
                    
                    	To set the message type
                    	**type**\:  :py:class:`MessageType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.ServiceList.MdnsSd.Deny.Match.MessageType>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: service_instance
                    
                    	To set the Service Instance
                    	**type**\: str
                    
                    .. attribute:: service_type
                    
                    	match mDNS service type string
                    	**type**\: str
                    
                    

                    """

                    _prefix = 'ios-sd'
                    _revision = '2017-02-07'

                    def __init__(self):
                        super(Native.ServiceList.MdnsSd.Deny.Match, self).__init__()

                        self.yang_name = "match"
                        self.yang_parent_name = "deny"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("location", ("location", Native.ServiceList.MdnsSd.Deny.Match.Location)), ("message-type", ("message_type", Native.ServiceList.MdnsSd.Deny.Match.MessageType))])
                        self._leafs = OrderedDict([
                            ('learnt_interface', (YLeaf(YType.empty, 'learnt-interface'), ['Empty'])),
                            ('service_instance', (YLeaf(YType.str, 'service-instance'), ['str'])),
                            ('service_type', (YLeaf(YType.str, 'service-type'), ['str'])),
                        ])
                        self.learnt_interface = None
                        self.service_instance = None
                        self.service_type = None

                        self.location = None
                        self._children_name_map["location"] = "location"

                        self.message_type = None
                        self._children_name_map["message_type"] = "message-type"
                        self._segment_path = lambda: "match"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.ServiceList.MdnsSd.Deny.Match, ['learnt_interface', 'service_instance', 'service_type'], name, value)


                    class Location(Entity):
                        """
                        match location information
                        
                        .. attribute:: civic
                        
                        	Civic location
                        	**type**\: str
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-sd'
                        _revision = '2017-02-07'

                        def __init__(self):
                            super(Native.ServiceList.MdnsSd.Deny.Match.Location, self).__init__()

                            self.yang_name = "location"
                            self.yang_parent_name = "match"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('civic', (YLeaf(YType.str, 'civic'), ['str'])),
                            ])
                            self.civic = None
                            self._segment_path = lambda: "location"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.ServiceList.MdnsSd.Deny.Match.Location, ['civic'], name, value)


                    class MessageType(Entity):
                        """
                        To set the message type
                        
                        .. attribute:: announcement
                        
                        	Match Announcement/Responses
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: query
                        
                        	Match Query
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: any
                        
                        	Match Any
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-sd'
                        _revision = '2017-02-07'

                        def __init__(self):
                            super(Native.ServiceList.MdnsSd.Deny.Match.MessageType, self).__init__()

                            self.yang_name = "message-type"
                            self.yang_parent_name = "match"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('announcement', (YLeaf(YType.empty, 'announcement'), ['Empty'])),
                                ('query', (YLeaf(YType.empty, 'query'), ['Empty'])),
                                ('any', (YLeaf(YType.empty, 'any'), ['Empty'])),
                            ])
                            self.announcement = None
                            self.query = None
                            self.any = None
                            self._segment_path = lambda: "message-type"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.ServiceList.MdnsSd.Deny.Match.MessageType, ['announcement', 'query', 'any'], name, value)


            class Permit(Entity):
                """
                Specify packets to forward
                
                .. attribute:: deny_pack  (key)
                
                	
                	**type**\: int
                
                	**range:** 0..100
                
                .. attribute:: match
                
                	Configure parameters for service\-list name
                	**type**\:  :py:class:`Match <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.ServiceList.MdnsSd.Permit.Match>`
                
                

                """

                _prefix = 'ios-sd'
                _revision = '2017-02-07'

                def __init__(self):
                    super(Native.ServiceList.MdnsSd.Permit, self).__init__()

                    self.yang_name = "permit"
                    self.yang_parent_name = "mdns-sd"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = ['deny_pack']
                    self._child_classes = OrderedDict([("match", ("match", Native.ServiceList.MdnsSd.Permit.Match))])
                    self._leafs = OrderedDict([
                        ('deny_pack', (YLeaf(YType.uint8, 'deny-pack'), ['int'])),
                    ])
                    self.deny_pack = None

                    self.match = Native.ServiceList.MdnsSd.Permit.Match()
                    self.match.parent = self
                    self._children_name_map["match"] = "match"
                    self._segment_path = lambda: "permit" + "[deny-pack='" + str(self.deny_pack) + "']"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.ServiceList.MdnsSd.Permit, ['deny_pack'], name, value)


                class Match(Entity):
                    """
                    Configure parameters for service\-list name
                    
                    .. attribute:: learnt_interface
                    
                    	match the interface where service is learnt
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: location
                    
                    	match location information
                    	**type**\:  :py:class:`Location <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.ServiceList.MdnsSd.Permit.Match.Location>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: message_type
                    
                    	To set the message type
                    	**type**\:  :py:class:`MessageType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.ServiceList.MdnsSd.Permit.Match.MessageType>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: service_instance
                    
                    	To set the Service Instance
                    	**type**\: str
                    
                    .. attribute:: service_type
                    
                    	match mDNS service type string
                    	**type**\: str
                    
                    

                    """

                    _prefix = 'ios-sd'
                    _revision = '2017-02-07'

                    def __init__(self):
                        super(Native.ServiceList.MdnsSd.Permit.Match, self).__init__()

                        self.yang_name = "match"
                        self.yang_parent_name = "permit"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("location", ("location", Native.ServiceList.MdnsSd.Permit.Match.Location)), ("message-type", ("message_type", Native.ServiceList.MdnsSd.Permit.Match.MessageType))])
                        self._leafs = OrderedDict([
                            ('learnt_interface', (YLeaf(YType.empty, 'learnt-interface'), ['Empty'])),
                            ('service_instance', (YLeaf(YType.str, 'service-instance'), ['str'])),
                            ('service_type', (YLeaf(YType.str, 'service-type'), ['str'])),
                        ])
                        self.learnt_interface = None
                        self.service_instance = None
                        self.service_type = None

                        self.location = None
                        self._children_name_map["location"] = "location"

                        self.message_type = None
                        self._children_name_map["message_type"] = "message-type"
                        self._segment_path = lambda: "match"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.ServiceList.MdnsSd.Permit.Match, ['learnt_interface', 'service_instance', 'service_type'], name, value)


                    class Location(Entity):
                        """
                        match location information
                        
                        .. attribute:: civic
                        
                        	Civic location
                        	**type**\: str
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-sd'
                        _revision = '2017-02-07'

                        def __init__(self):
                            super(Native.ServiceList.MdnsSd.Permit.Match.Location, self).__init__()

                            self.yang_name = "location"
                            self.yang_parent_name = "match"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('civic', (YLeaf(YType.str, 'civic'), ['str'])),
                            ])
                            self.civic = None
                            self._segment_path = lambda: "location"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.ServiceList.MdnsSd.Permit.Match.Location, ['civic'], name, value)


                    class MessageType(Entity):
                        """
                        To set the message type
                        
                        .. attribute:: announcement
                        
                        	Match Announcement/Responses
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: query
                        
                        	Match Query
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: any
                        
                        	Match Any
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-sd'
                        _revision = '2017-02-07'

                        def __init__(self):
                            super(Native.ServiceList.MdnsSd.Permit.Match.MessageType, self).__init__()

                            self.yang_name = "message-type"
                            self.yang_parent_name = "match"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('announcement', (YLeaf(YType.empty, 'announcement'), ['Empty'])),
                                ('query', (YLeaf(YType.empty, 'query'), ['Empty'])),
                                ('any', (YLeaf(YType.empty, 'any'), ['Empty'])),
                            ])
                            self.announcement = None
                            self.query = None
                            self.any = None
                            self._segment_path = lambda: "message-type"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.ServiceList.MdnsSd.Permit.Match.MessageType, ['announcement', 'query', 'any'], name, value)


            class Query(Entity):
                """
                Service\-list Query for mdns\-sd
                
                .. attribute:: service_type
                
                	Configure periodicity for each service\-type
                	**type**\: str
                
                

                """

                _prefix = 'ios-sd'
                _revision = '2017-02-07'

                def __init__(self):
                    super(Native.ServiceList.MdnsSd.Query, self).__init__()

                    self.yang_name = "query"
                    self.yang_parent_name = "mdns-sd"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('service_type', (YLeaf(YType.str, 'service-type'), ['str'])),
                    ])
                    self.service_type = None
                    self._segment_path = lambda: "query"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.ServiceList.MdnsSd.Query, ['service_type'], name, value)


    class AccessSession(Entity):
        """
        Access Sesion Global Configuration Commands
        
        .. attribute:: attributes
        
        	Attributes Filter List Configuration
        	**type**\:  :py:class:`Attributes <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.AccessSession.Attributes>`
        
        .. attribute:: mac_move
        
        	Set required action when a MAC move is detected
        	**type**\:  :py:class:`MacMove <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.AccessSession.MacMove>`
        
        

        """

        _prefix = 'ios-sanet'
        _revision = '2017-11-27'

        def __init__(self):
            super(Native.AccessSession, self).__init__()

            self.yang_name = "access-session"
            self.yang_parent_name = "native"
            self.is_top_level_class = False
            self.has_list_ancestor = False
            self.ylist_key_names = []
            self._child_classes = OrderedDict([("attributes", ("attributes", Native.AccessSession.Attributes)), ("mac-move", ("mac_move", Native.AccessSession.MacMove))])
            self._leafs = OrderedDict()

            self.attributes = Native.AccessSession.Attributes()
            self.attributes.parent = self
            self._children_name_map["attributes"] = "attributes"

            self.mac_move = Native.AccessSession.MacMove()
            self.mac_move.parent = self
            self._children_name_map["mac_move"] = "mac-move"
            self._segment_path = lambda: "Cisco-IOS-XE-sanet:access-session"
            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/%s" % self._segment_path()
            self._is_frozen = True

        def __setattr__(self, name, value):
            self._perform_setattr(Native.AccessSession, [], name, value)


        class Attributes(Entity):
            """
            Attributes Filter List Configuration
            
            .. attribute:: filter_list
            
            	Filter List Configuration
            	**type**\:  :py:class:`FilterList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.AccessSession.Attributes.FilterList>`
            
            

            """

            _prefix = 'ios-sanet'
            _revision = '2017-11-27'

            def __init__(self):
                super(Native.AccessSession.Attributes, self).__init__()

                self.yang_name = "attributes"
                self.yang_parent_name = "access-session"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = []
                self._child_classes = OrderedDict([("filter-list", ("filter_list", Native.AccessSession.Attributes.FilterList))])
                self._leafs = OrderedDict()

                self.filter_list = Native.AccessSession.Attributes.FilterList()
                self.filter_list.parent = self
                self._children_name_map["filter_list"] = "filter-list"
                self._segment_path = lambda: "attributes"
                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/Cisco-IOS-XE-sanet:access-session/%s" % self._segment_path()
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(Native.AccessSession.Attributes, [], name, value)


            class FilterList(Entity):
                """
                Filter List Configuration
                
                .. attribute:: list
                
                	Filter List
                	**type**\: list of  		 :py:class:`List <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.AccessSession.Attributes.FilterList.List>`
                
                

                """

                _prefix = 'ios-sanet'
                _revision = '2017-11-27'

                def __init__(self):
                    super(Native.AccessSession.Attributes.FilterList, self).__init__()

                    self.yang_name = "filter-list"
                    self.yang_parent_name = "attributes"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("list", ("list", Native.AccessSession.Attributes.FilterList.List))])
                    self._leafs = OrderedDict()

                    self.list = YList(self)
                    self._segment_path = lambda: "filter-list"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/Cisco-IOS-XE-sanet:access-session/attributes/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.AccessSession.Attributes.FilterList, [], name, value)


                class List(Entity):
                    """
                    Filter List
                    
                    .. attribute:: name  (key)
                    
                    	
                    	**type**\: str
                    
                    .. attribute:: cdp
                    
                    	Include CDP Protocl attributes
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: dhcp
                    
                    	Include DHCP Protocl attributes
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: lldp
                    
                    	Include LLDP Protocl attributes
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios-sanet'
                    _revision = '2017-11-27'

                    def __init__(self):
                        super(Native.AccessSession.Attributes.FilterList.List, self).__init__()

                        self.yang_name = "list"
                        self.yang_parent_name = "filter-list"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = ['name']
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('name', (YLeaf(YType.str, 'name'), ['str'])),
                            ('cdp', (YLeaf(YType.empty, 'cdp'), ['Empty'])),
                            ('dhcp', (YLeaf(YType.empty, 'dhcp'), ['Empty'])),
                            ('lldp', (YLeaf(YType.empty, 'lldp'), ['Empty'])),
                        ])
                        self.name = None
                        self.cdp = None
                        self.dhcp = None
                        self.lldp = None
                        self._segment_path = lambda: "list" + "[name='" + str(self.name) + "']"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/Cisco-IOS-XE-sanet:access-session/attributes/filter-list/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.AccessSession.Attributes.FilterList.List, ['name', 'cdp', 'dhcp', 'lldp'], name, value)


        class MacMove(Entity):
            """
            Set required action when a MAC move is detected
            
            .. attribute:: deny
            
            	DENY MAC moves (clears existing session)
            	**type**\: :py:class:`Empty<ydk.types.Empty>`
            
            

            """

            _prefix = 'ios-sanet'
            _revision = '2017-11-27'

            def __init__(self):
                super(Native.AccessSession.MacMove, self).__init__()

                self.yang_name = "mac-move"
                self.yang_parent_name = "access-session"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = []
                self._child_classes = OrderedDict([])
                self._leafs = OrderedDict([
                    ('deny', (YLeaf(YType.empty, 'deny'), ['Empty'])),
                ])
                self.deny = None
                self._segment_path = lambda: "mac-move"
                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/Cisco-IOS-XE-sanet:access-session/%s" % self._segment_path()
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(Native.AccessSession.MacMove, ['deny'], name, value)


    class Authentication(Entity):
        """
        Auth Manager Global Configuration Commands
        
        .. attribute:: command
        
        	Allow the following CoA commands to be ignored by the switch
        	**type**\:  :py:class:`Command <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Authentication.Command>`
        
        .. attribute:: critical
        
        	Set Critical Authentication parameters
        	**type**\:  :py:class:`Critical <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Authentication.Critical>`
        
        .. attribute:: mac_move
        
        	Set required action when a MAC move is detected
        	**type**\:  :py:class:`MacMove <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Authentication.MacMove>`
        
        

        """

        _prefix = 'ios-sanet'
        _revision = '2017-11-27'

        def __init__(self):
            super(Native.Authentication, self).__init__()

            self.yang_name = "authentication"
            self.yang_parent_name = "native"
            self.is_top_level_class = False
            self.has_list_ancestor = False
            self.ylist_key_names = []
            self._child_classes = OrderedDict([("command", ("command", Native.Authentication.Command)), ("critical", ("critical", Native.Authentication.Critical)), ("mac-move", ("mac_move", Native.Authentication.MacMove))])
            self._leafs = OrderedDict()

            self.command = Native.Authentication.Command()
            self.command.parent = self
            self._children_name_map["command"] = "command"

            self.critical = Native.Authentication.Critical()
            self.critical.parent = self
            self._children_name_map["critical"] = "critical"

            self.mac_move = Native.Authentication.MacMove()
            self.mac_move.parent = self
            self._children_name_map["mac_move"] = "mac-move"
            self._segment_path = lambda: "Cisco-IOS-XE-sanet:authentication"
            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/%s" % self._segment_path()
            self._is_frozen = True

        def __setattr__(self, name, value):
            self._perform_setattr(Native.Authentication, [], name, value)


        class Command(Entity):
            """
            Allow the following CoA commands to be ignored by the switch
            
            .. attribute:: bounce_port
            
            	CoA bounce\-port command
            	**type**\:  :py:class:`BouncePort <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Authentication.Command.BouncePort>`
            
            .. attribute:: disable_port
            
            	CoA disable\-port command
            	**type**\:  :py:class:`DisablePort <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Authentication.Command.DisablePort>`
            
            

            """

            _prefix = 'ios-sanet'
            _revision = '2017-11-27'

            def __init__(self):
                super(Native.Authentication.Command, self).__init__()

                self.yang_name = "command"
                self.yang_parent_name = "authentication"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = []
                self._child_classes = OrderedDict([("bounce-port", ("bounce_port", Native.Authentication.Command.BouncePort)), ("disable-port", ("disable_port", Native.Authentication.Command.DisablePort))])
                self._leafs = OrderedDict()

                self.bounce_port = Native.Authentication.Command.BouncePort()
                self.bounce_port.parent = self
                self._children_name_map["bounce_port"] = "bounce-port"

                self.disable_port = Native.Authentication.Command.DisablePort()
                self.disable_port.parent = self
                self._children_name_map["disable_port"] = "disable-port"
                self._segment_path = lambda: "command"
                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/Cisco-IOS-XE-sanet:authentication/%s" % self._segment_path()
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(Native.Authentication.Command, [], name, value)


            class BouncePort(Entity):
                """
                CoA bounce\-port command
                
                .. attribute:: ignore
                
                	ignore disable\-port CoA command
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                

                """

                _prefix = 'ios-sanet'
                _revision = '2017-11-27'

                def __init__(self):
                    super(Native.Authentication.Command.BouncePort, self).__init__()

                    self.yang_name = "bounce-port"
                    self.yang_parent_name = "command"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('ignore', (YLeaf(YType.empty, 'ignore'), ['Empty'])),
                    ])
                    self.ignore = None
                    self._segment_path = lambda: "bounce-port"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/Cisco-IOS-XE-sanet:authentication/command/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Authentication.Command.BouncePort, ['ignore'], name, value)


            class DisablePort(Entity):
                """
                CoA disable\-port command
                
                .. attribute:: ignore
                
                	
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                

                """

                _prefix = 'ios-sanet'
                _revision = '2017-11-27'

                def __init__(self):
                    super(Native.Authentication.Command.DisablePort, self).__init__()

                    self.yang_name = "disable-port"
                    self.yang_parent_name = "command"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('ignore', (YLeaf(YType.empty, 'ignore'), ['Empty'])),
                    ])
                    self.ignore = None
                    self._segment_path = lambda: "disable-port"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/Cisco-IOS-XE-sanet:authentication/command/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Authentication.Command.DisablePort, ['ignore'], name, value)


        class Critical(Entity):
            """
            Set Critical Authentication parameters
            
            .. attribute:: recovery
            
            	Set Critical Authentication Recovery parameters
            	**type**\:  :py:class:`Recovery <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Authentication.Critical.Recovery>`
            
            

            """

            _prefix = 'ios-sanet'
            _revision = '2017-11-27'

            def __init__(self):
                super(Native.Authentication.Critical, self).__init__()

                self.yang_name = "critical"
                self.yang_parent_name = "authentication"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = []
                self._child_classes = OrderedDict([("recovery", ("recovery", Native.Authentication.Critical.Recovery))])
                self._leafs = OrderedDict()

                self.recovery = Native.Authentication.Critical.Recovery()
                self.recovery.parent = self
                self._children_name_map["recovery"] = "recovery"
                self._segment_path = lambda: "critical"
                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/Cisco-IOS-XE-sanet:authentication/%s" % self._segment_path()
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(Native.Authentication.Critical, [], name, value)


            class Recovery(Entity):
                """
                Set Critical Authentication Recovery parameters
                
                .. attribute:: delay
                
                	Set Critical Authentication Recovery Delay period
                	**type**\: int
                
                	**range:** 1..10000
                
                

                """

                _prefix = 'ios-sanet'
                _revision = '2017-11-27'

                def __init__(self):
                    super(Native.Authentication.Critical.Recovery, self).__init__()

                    self.yang_name = "recovery"
                    self.yang_parent_name = "critical"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('delay', (YLeaf(YType.uint32, 'delay'), ['int'])),
                    ])
                    self.delay = None
                    self._segment_path = lambda: "recovery"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/Cisco-IOS-XE-sanet:authentication/critical/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Authentication.Critical.Recovery, ['delay'], name, value)


        class MacMove(Entity):
            """
            Set required action when a MAC move is detected
            
            .. attribute:: permit
            
            	PERMIT MAC moves (clears existing session)
            	**type**\: :py:class:`Empty<ydk.types.Empty>`
            
            

            """

            _prefix = 'ios-sanet'
            _revision = '2017-11-27'

            def __init__(self):
                super(Native.Authentication.MacMove, self).__init__()

                self.yang_name = "mac-move"
                self.yang_parent_name = "authentication"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = []
                self._child_classes = OrderedDict([])
                self._leafs = OrderedDict([
                    ('permit', (YLeaf(YType.empty, 'permit'), ['Empty'])),
                ])
                self.permit = None
                self._segment_path = lambda: "mac-move"
                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/Cisco-IOS-XE-sanet:authentication/%s" % self._segment_path()
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(Native.Authentication.MacMove, ['permit'], name, value)


    class ServiceRouting(Entity):
        """
        Configure service\-routing
        
        .. attribute:: capabilities_manager
        
        	Service\-Routing Capabilities Manager configuration
        	**type**\: bool
        
        .. attribute:: mdns_sd
        
        	Service\-Routing MDNS configuration
        	**type**\:  :py:class:`MdnsSd <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.ServiceRouting.MdnsSd>`
        
        	**presence node**\: True
        
        

        """

        _prefix = 'ios-sr'
        _revision = '2017-07-24'

        def __init__(self):
            super(Native.ServiceRouting, self).__init__()

            self.yang_name = "service-routing"
            self.yang_parent_name = "native"
            self.is_top_level_class = False
            self.has_list_ancestor = False
            self.ylist_key_names = []
            self._child_classes = OrderedDict([("mdns-sd", ("mdns_sd", Native.ServiceRouting.MdnsSd))])
            self._leafs = OrderedDict([
                ('capabilities_manager', (YLeaf(YType.boolean, 'capabilities-manager'), ['bool'])),
            ])
            self.capabilities_manager = None

            self.mdns_sd = None
            self._children_name_map["mdns_sd"] = "mdns-sd"
            self._segment_path = lambda: "Cisco-IOS-XE-service-routing:service-routing"
            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/%s" % self._segment_path()
            self._is_frozen = True

        def __setattr__(self, name, value):
            self._perform_setattr(Native.ServiceRouting, [u'capabilities_manager'], name, value)


        class MdnsSd(Entity):
            """
            Service\-Routing MDNS configuration
            
            .. attribute:: service_policy
            
            	
            	**type**\: list of  		 :py:class:`ServicePolicy <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.ServiceRouting.MdnsSd.ServicePolicy>`
            
            

            This class is a :ref:`presence class<presence-class>`

            """

            _prefix = 'ios-sr'
            _revision = '2017-07-24'

            def __init__(self):
                super(Native.ServiceRouting.MdnsSd, self).__init__()

                self.yang_name = "mdns-sd"
                self.yang_parent_name = "service-routing"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = []
                self._child_classes = OrderedDict([("service-policy", ("service_policy", Native.ServiceRouting.MdnsSd.ServicePolicy))])
                self.is_presence_container = True
                self._leafs = OrderedDict()

                self.service_policy = YList(self)
                self._segment_path = lambda: "mdns-sd"
                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/Cisco-IOS-XE-service-routing:service-routing/%s" % self._segment_path()
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(Native.ServiceRouting.MdnsSd, [], name, value)


            class ServicePolicy(Entity):
                """
                
                
                .. attribute:: direction  (key)
                
                	
                	**type**\:  :py:class:`Direction <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.ServiceRouting.MdnsSd.ServicePolicy.Direction>`
                
                .. attribute:: policy_name
                
                	
                	**type**\: str
                
                

                """

                _prefix = 'ios-sr'
                _revision = '2017-07-24'

                def __init__(self):
                    super(Native.ServiceRouting.MdnsSd.ServicePolicy, self).__init__()

                    self.yang_name = "service-policy"
                    self.yang_parent_name = "mdns-sd"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = ['direction']
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('direction', (YLeaf(YType.enumeration, 'direction'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'ServiceRouting.MdnsSd.ServicePolicy.Direction')])),
                        ('policy_name', (YLeaf(YType.str, 'policy-name'), ['str'])),
                    ])
                    self.direction = None
                    self.policy_name = None
                    self._segment_path = lambda: "service-policy" + "[direction='" + str(self.direction) + "']"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/Cisco-IOS-XE-service-routing:service-routing/mdns-sd/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.ServiceRouting.MdnsSd.ServicePolicy, [u'direction', u'policy_name'], name, value)

                class Direction(Enum):
                    """
                    Direction (Enum Class)

                    .. data:: IN = 0

                    .. data:: OUT = 1

                    """

                    IN = Enum.YLeaf(0, "IN")

                    OUT = Enum.YLeaf(1, "OUT")



    class MaintenanceTemplate(Entity):
        """
        maintenance\-template configuration
        
        .. attribute:: templ_name  (key)
        
        	maintenance\-template name
        	**type**\: str
        
        .. attribute:: config_maintenance_templ
        
        	
        	**type**\:  :py:class:`ConfigMaintenanceTempl <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.MaintenanceTemplate.ConfigMaintenanceTempl>`
        
        

        """

        _prefix = 'ios-mmode'
        _revision = '2017-11-29'

        def __init__(self):
            super(Native.MaintenanceTemplate, self).__init__()

            self.yang_name = "maintenance-template"
            self.yang_parent_name = "native"
            self.is_top_level_class = False
            self.has_list_ancestor = False
            self.ylist_key_names = ['templ_name']
            self._child_classes = OrderedDict([("config-maintenance-templ", ("config_maintenance_templ", Native.MaintenanceTemplate.ConfigMaintenanceTempl))])
            self._leafs = OrderedDict([
                ('templ_name', (YLeaf(YType.str, 'templ-name'), ['str'])),
            ])
            self.templ_name = None

            self.config_maintenance_templ = Native.MaintenanceTemplate.ConfigMaintenanceTempl()
            self.config_maintenance_templ.parent = self
            self._children_name_map["config_maintenance_templ"] = "config-maintenance-templ"
            self._segment_path = lambda: "Cisco-IOS-XE-mmode:maintenance-template" + "[templ-name='" + str(self.templ_name) + "']"
            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/%s" % self._segment_path()
            self._is_frozen = True

        def __setattr__(self, name, value):
            self._perform_setattr(Native.MaintenanceTemplate, ['templ_name'], name, value)


        class ConfigMaintenanceTempl(Entity):
            """
            
            
            .. attribute:: router
            
            	routing protocol
            	**type**\:  :py:class:`Router <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.MaintenanceTemplate.ConfigMaintenanceTempl.Router>`
            
            .. attribute:: hsrp
            
            	HSRP protocol instance
            	**type**\: list of  		 :py:class:`Hsrp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.MaintenanceTemplate.ConfigMaintenanceTempl.Hsrp>`
            
            .. attribute:: vrrp
            
            	VRRP protocol instance
            	**type**\: list of  		 :py:class:`Vrrp <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.MaintenanceTemplate.ConfigMaintenanceTempl.Vrrp>`
            
            .. attribute:: vrrpv3
            
            	VRRPv3 protocol
            	**type**\: list of  		 :py:class:`Vrrpv3 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.MaintenanceTemplate.ConfigMaintenanceTempl.Vrrpv3>`
            
            .. attribute:: shutdown
            
            	shutdown
            	**type**\:  :py:class:`Shutdown <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.MaintenanceTemplate.ConfigMaintenanceTempl.Shutdown>`
            
            .. attribute:: ipmulticast
            
            	ipmulticast
            	**type**\:  :py:class:`Ipmulticast <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.MaintenanceTemplate.ConfigMaintenanceTempl.Ipmulticast>`
            
            

            """

            _prefix = 'ios-mmode'
            _revision = '2017-11-29'

            def __init__(self):
                super(Native.MaintenanceTemplate.ConfigMaintenanceTempl, self).__init__()

                self.yang_name = "config-maintenance-templ"
                self.yang_parent_name = "maintenance-template"
                self.is_top_level_class = False
                self.has_list_ancestor = True
                self.ylist_key_names = []
                self._child_classes = OrderedDict([("router", ("router", Native.MaintenanceTemplate.ConfigMaintenanceTempl.Router)), ("hsrp", ("hsrp", Native.MaintenanceTemplate.ConfigMaintenanceTempl.Hsrp)), ("vrrp", ("vrrp", Native.MaintenanceTemplate.ConfigMaintenanceTempl.Vrrp)), ("vrrpv3", ("vrrpv3", Native.MaintenanceTemplate.ConfigMaintenanceTempl.Vrrpv3)), ("shutdown", ("shutdown", Native.MaintenanceTemplate.ConfigMaintenanceTempl.Shutdown)), ("ipmulticast", ("ipmulticast", Native.MaintenanceTemplate.ConfigMaintenanceTempl.Ipmulticast))])
                self._leafs = OrderedDict()

                self.router = Native.MaintenanceTemplate.ConfigMaintenanceTempl.Router()
                self.router.parent = self
                self._children_name_map["router"] = "router"

                self.shutdown = Native.MaintenanceTemplate.ConfigMaintenanceTempl.Shutdown()
                self.shutdown.parent = self
                self._children_name_map["shutdown"] = "shutdown"

                self.ipmulticast = Native.MaintenanceTemplate.ConfigMaintenanceTempl.Ipmulticast()
                self.ipmulticast.parent = self
                self._children_name_map["ipmulticast"] = "ipmulticast"

                self.hsrp = YList(self)
                self.vrrp = YList(self)
                self.vrrpv3 = YList(self)
                self._segment_path = lambda: "config-maintenance-templ"
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(Native.MaintenanceTemplate.ConfigMaintenanceTempl, [], name, value)


            class Router(Entity):
                """
                routing protocol
                
                .. attribute:: routing_protocol
                
                	
                	**type**\: list of  		 :py:class:`RoutingProtocol <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.MaintenanceTemplate.ConfigMaintenanceTempl.Router.RoutingProtocol>`
                
                

                """

                _prefix = 'ios-mmode'
                _revision = '2017-11-29'

                def __init__(self):
                    super(Native.MaintenanceTemplate.ConfigMaintenanceTempl.Router, self).__init__()

                    self.yang_name = "router"
                    self.yang_parent_name = "config-maintenance-templ"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("routing-protocol", ("routing_protocol", Native.MaintenanceTemplate.ConfigMaintenanceTempl.Router.RoutingProtocol))])
                    self._leafs = OrderedDict()

                    self.routing_protocol = YList(self)
                    self._segment_path = lambda: "router"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.MaintenanceTemplate.ConfigMaintenanceTempl.Router, [], name, value)


                class RoutingProtocol(Entity):
                    """
                    
                    
                    .. attribute:: protocol  (key)
                    
                    	isolate protocol
                    	**type**\:  :py:class:`Protocol <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.MaintenanceTemplate.ConfigMaintenanceTempl.Router.RoutingProtocol.Protocol>`
                    
                    .. attribute:: instance  (key)
                    
                    	instance/AS number
                    	**type**\: int
                    
                    	**range:** 1..65535
                    
                    

                    """

                    _prefix = 'ios-mmode'
                    _revision = '2017-11-29'

                    def __init__(self):
                        super(Native.MaintenanceTemplate.ConfigMaintenanceTempl.Router.RoutingProtocol, self).__init__()

                        self.yang_name = "routing-protocol"
                        self.yang_parent_name = "router"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = ['protocol','instance']
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('protocol', (YLeaf(YType.enumeration, 'protocol'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'MaintenanceTemplate.ConfigMaintenanceTempl.Router.RoutingProtocol.Protocol')])),
                            ('instance', (YLeaf(YType.uint16, 'instance'), ['int'])),
                        ])
                        self.protocol = None
                        self.instance = None
                        self._segment_path = lambda: "routing-protocol" + "[protocol='" + str(self.protocol) + "']" + "[instance='" + str(self.instance) + "']"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.MaintenanceTemplate.ConfigMaintenanceTempl.Router.RoutingProtocol, ['protocol', 'instance'], name, value)

                    class Protocol(Enum):
                        """
                        Protocol (Enum Class)

                        isolate protocol

                        .. data:: bgp = 0

                        .. data:: isis = 1

                        .. data:: ospf = 2

                        .. data:: ospfv3 = 3

                        """

                        bgp = Enum.YLeaf(0, "bgp")

                        isis = Enum.YLeaf(1, "isis")

                        ospf = Enum.YLeaf(2, "ospf")

                        ospfv3 = Enum.YLeaf(3, "ospfv3")



            class Hsrp(Entity):
                """
                HSRP protocol instance
                
                .. attribute:: interface  (key)
                
                	full interface name and number (Note\: the device will accept both full and short interface names, but the names in running config will be shown in full form)
                	**type**\: str
                
                .. attribute:: group_number  (key)
                
                	HSRP group number
                	**type**\: int
                
                	**range:** 0..255
                
                

                """

                _prefix = 'ios-mmode'
                _revision = '2017-11-29'

                def __init__(self):
                    super(Native.MaintenanceTemplate.ConfigMaintenanceTempl.Hsrp, self).__init__()

                    self.yang_name = "hsrp"
                    self.yang_parent_name = "config-maintenance-templ"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = ['interface','group_number']
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('interface', (YLeaf(YType.str, 'interface'), ['str'])),
                        ('group_number', (YLeaf(YType.uint16, 'group-number'), ['int'])),
                    ])
                    self.interface = None
                    self.group_number = None
                    self._segment_path = lambda: "hsrp" + "[interface='" + str(self.interface) + "']" + "[group-number='" + str(self.group_number) + "']"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.MaintenanceTemplate.ConfigMaintenanceTempl.Hsrp, ['interface', 'group_number'], name, value)


            class Vrrp(Entity):
                """
                VRRP protocol instance
                
                .. attribute:: interface  (key)
                
                	full interface name and number (Note\: the device will accept both full and short interface names, but the names in running config will be shown in full form)
                	**type**\: str
                
                .. attribute:: group_number  (key)
                
                	VRRP group number
                	**type**\: int
                
                	**range:** 0..255
                
                

                """

                _prefix = 'ios-mmode'
                _revision = '2017-11-29'

                def __init__(self):
                    super(Native.MaintenanceTemplate.ConfigMaintenanceTempl.Vrrp, self).__init__()

                    self.yang_name = "vrrp"
                    self.yang_parent_name = "config-maintenance-templ"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = ['interface','group_number']
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('interface', (YLeaf(YType.str, 'interface'), ['str'])),
                        ('group_number', (YLeaf(YType.uint16, 'group-number'), ['int'])),
                    ])
                    self.interface = None
                    self.group_number = None
                    self._segment_path = lambda: "vrrp" + "[interface='" + str(self.interface) + "']" + "[group-number='" + str(self.group_number) + "']"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.MaintenanceTemplate.ConfigMaintenanceTempl.Vrrp, ['interface', 'group_number'], name, value)


            class Vrrpv3(Entity):
                """
                VRRPv3 protocol
                
                .. attribute:: interface  (key)
                
                	full interface name and number (Note\: the device will accept both full and short interface names, but the names in running config will be shown in full form)
                	**type**\: str
                
                .. attribute:: group_number  (key)
                
                	VRRP group number
                	**type**\: int
                
                	**range:** 0..255
                
                .. attribute:: address_family  (key)
                
                	address family
                	**type**\:  :py:class:`AddressFamily <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.MaintenanceTemplate.ConfigMaintenanceTempl.Vrrpv3.AddressFamily>`
                
                

                """

                _prefix = 'ios-mmode'
                _revision = '2017-11-29'

                def __init__(self):
                    super(Native.MaintenanceTemplate.ConfigMaintenanceTempl.Vrrpv3, self).__init__()

                    self.yang_name = "vrrpv3"
                    self.yang_parent_name = "config-maintenance-templ"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = ['interface','group_number','address_family']
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('interface', (YLeaf(YType.str, 'interface'), ['str'])),
                        ('group_number', (YLeaf(YType.uint16, 'group-number'), ['int'])),
                        ('address_family', (YLeaf(YType.enumeration, 'address-family'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'MaintenanceTemplate.ConfigMaintenanceTempl.Vrrpv3.AddressFamily')])),
                    ])
                    self.interface = None
                    self.group_number = None
                    self.address_family = None
                    self._segment_path = lambda: "vrrpv3" + "[interface='" + str(self.interface) + "']" + "[group-number='" + str(self.group_number) + "']" + "[address-family='" + str(self.address_family) + "']"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.MaintenanceTemplate.ConfigMaintenanceTempl.Vrrpv3, ['interface', 'group_number', 'address_family'], name, value)

                class AddressFamily(Enum):
                    """
                    AddressFamily (Enum Class)

                    address family

                    .. data:: ipv4 = 0

                    .. data:: ipv6 = 1

                    """

                    ipv4 = Enum.YLeaf(0, "ipv4")

                    ipv6 = Enum.YLeaf(1, "ipv6")



            class Shutdown(Entity):
                """
                shutdown
                
                .. attribute:: l2
                
                	shutdown all L2 interfaces
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                

                """

                _prefix = 'ios-mmode'
                _revision = '2017-11-29'

                def __init__(self):
                    super(Native.MaintenanceTemplate.ConfigMaintenanceTempl.Shutdown, self).__init__()

                    self.yang_name = "shutdown"
                    self.yang_parent_name = "config-maintenance-templ"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('l2', (YLeaf(YType.empty, 'l2'), ['Empty'])),
                    ])
                    self.l2 = None
                    self._segment_path = lambda: "shutdown"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.MaintenanceTemplate.ConfigMaintenanceTempl.Shutdown, ['l2'], name, value)


            class Ipmulticast(Entity):
                """
                ipmulticast
                
                .. attribute:: vrf
                
                	vrf instance name
                	**type**\: list of str
                
                

                """

                _prefix = 'ios-mmode'
                _revision = '2017-11-29'

                def __init__(self):
                    super(Native.MaintenanceTemplate.ConfigMaintenanceTempl.Ipmulticast, self).__init__()

                    self.yang_name = "ipmulticast"
                    self.yang_parent_name = "config-maintenance-templ"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('vrf', (YLeafList(YType.str, 'vrf'), ['str'])),
                    ])
                    self.vrf = []
                    self._segment_path = lambda: "ipmulticast"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.MaintenanceTemplate.ConfigMaintenanceTempl.Ipmulticast, ['vrf'], name, value)


    class Lldp(Entity):
        """
        Enables LLDP globally.
        
        .. attribute:: run
        
        	Enable LLDP
        	**type**\: :py:class:`Empty<ydk.types.Empty>`
        
        

        """

        _prefix = 'ios-lldp'
        _revision = '2017-11-27'

        def __init__(self):
            super(Native.Lldp, self).__init__()

            self.yang_name = "lldp"
            self.yang_parent_name = "native"
            self.is_top_level_class = False
            self.has_list_ancestor = False
            self.ylist_key_names = []
            self._child_classes = OrderedDict([])
            self._leafs = OrderedDict([
                ('run', (YLeaf(YType.empty, 'run'), ['Empty'])),
            ])
            self.run = None
            self._segment_path = lambda: "Cisco-IOS-XE-lldp:lldp"
            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/%s" % self._segment_path()
            self._is_frozen = True

        def __setattr__(self, name, value):
            self._perform_setattr(Native.Lldp, ['run'], name, value)


    class Diagnostic(Entity):
        """
        Configure diagnostic information
        
        .. attribute:: bootup
        
        	Configure diagnostic for bootup
        	**type**\:  :py:class:`Bootup <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Diagnostic.Bootup>`
        
        .. attribute:: event_log
        
        	Configure diagnostic event log
        	**type**\:  :py:class:`EventLog <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Diagnostic.EventLog>`
        
        .. attribute:: monitor
        
        	Configure diagnostic monitoring tests
        	**type**\:  :py:class:`Monitor <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Diagnostic.Monitor>`
        
        .. attribute:: schedule
        
        	Configure diagnostic schedule for a card
        	**type**\:  :py:class:`Schedule <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Diagnostic.Schedule>`
        
        

        """

        _prefix = 'ios-diag'
        _revision = '2017-02-07'

        def __init__(self):
            super(Native.Diagnostic, self).__init__()

            self.yang_name = "diagnostic"
            self.yang_parent_name = "native"
            self.is_top_level_class = False
            self.has_list_ancestor = False
            self.ylist_key_names = []
            self._child_classes = OrderedDict([("bootup", ("bootup", Native.Diagnostic.Bootup)), ("event-log", ("event_log", Native.Diagnostic.EventLog)), ("monitor", ("monitor", Native.Diagnostic.Monitor)), ("schedule", ("schedule", Native.Diagnostic.Schedule))])
            self._leafs = OrderedDict()

            self.bootup = Native.Diagnostic.Bootup()
            self.bootup.parent = self
            self._children_name_map["bootup"] = "bootup"

            self.event_log = Native.Diagnostic.EventLog()
            self.event_log.parent = self
            self._children_name_map["event_log"] = "event-log"

            self.monitor = Native.Diagnostic.Monitor()
            self.monitor.parent = self
            self._children_name_map["monitor"] = "monitor"

            self.schedule = Native.Diagnostic.Schedule()
            self.schedule.parent = self
            self._children_name_map["schedule"] = "schedule"
            self._segment_path = lambda: "Cisco-IOS-XE-diagnostics:diagnostic"
            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/%s" % self._segment_path()
            self._is_frozen = True

        def __setattr__(self, name, value):
            self._perform_setattr(Native.Diagnostic, [], name, value)


        class Bootup(Entity):
            """
            Configure diagnostic for bootup
            
            .. attribute:: level
            
            	Select diagnostic level
            	**type**\:  :py:class:`Level <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Diagnostic.Bootup.Level>`
            
            

            """

            _prefix = 'ios-diag'
            _revision = '2017-02-07'

            def __init__(self):
                super(Native.Diagnostic.Bootup, self).__init__()

                self.yang_name = "bootup"
                self.yang_parent_name = "diagnostic"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = []
                self._child_classes = OrderedDict([])
                self._leafs = OrderedDict([
                    ('level', (YLeaf(YType.enumeration, 'level'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Diagnostic.Bootup.Level')])),
                ])
                self.level = None
                self._segment_path = lambda: "bootup"
                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/Cisco-IOS-XE-diagnostics:diagnostic/%s" % self._segment_path()
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(Native.Diagnostic.Bootup, ['level'], name, value)

            class Level(Enum):
                """
                Level (Enum Class)

                Select diagnostic level

                .. data:: complete = 0

                .. data:: minimal = 1

                """

                complete = Enum.YLeaf(0, "complete")

                minimal = Enum.YLeaf(1, "minimal")



        class EventLog(Entity):
            """
            Configure diagnostic event log
            
            .. attribute:: size
            
            	Configure event log size Number of entries <1\-10000>
            	**type**\: int
            
            	**range:** 1..10000
            
            

            """

            _prefix = 'ios-diag'
            _revision = '2017-02-07'

            def __init__(self):
                super(Native.Diagnostic.EventLog, self).__init__()

                self.yang_name = "event-log"
                self.yang_parent_name = "diagnostic"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = []
                self._child_classes = OrderedDict([])
                self._leafs = OrderedDict([
                    ('size', (YLeaf(YType.uint16, 'size'), ['int'])),
                ])
                self.size = None
                self._segment_path = lambda: "event-log"
                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/Cisco-IOS-XE-diagnostics:diagnostic/%s" % self._segment_path()
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(Native.Diagnostic.EventLog, ['size'], name, value)


        class Monitor(Entity):
            """
            Configure diagnostic monitoring tests
            
            .. attribute:: interval
            
            	Configure diagnostic monitoring tests interval
            	**type**\:  :py:class:`Interval <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Diagnostic.Monitor.Interval>`
            
            .. attribute:: switch
            
            	Configure diagnostic monitoring tests on selected switch
            	**type**\: list of  		 :py:class:`Switch <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Diagnostic.Monitor.Switch>`
            
            .. attribute:: syslog
            
            	Configure diagnostic monitoring syslog
            	**type**\: :py:class:`Empty<ydk.types.Empty>`
            
            .. attribute:: threshold
            
            	Configure diagnostic monitoring failure threshold
            	**type**\:  :py:class:`Threshold <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Diagnostic.Monitor.Threshold>`
            
            

            """

            _prefix = 'ios-diag'
            _revision = '2017-02-07'

            def __init__(self):
                super(Native.Diagnostic.Monitor, self).__init__()

                self.yang_name = "monitor"
                self.yang_parent_name = "diagnostic"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = []
                self._child_classes = OrderedDict([("interval", ("interval", Native.Diagnostic.Monitor.Interval)), ("switch", ("switch", Native.Diagnostic.Monitor.Switch)), ("threshold", ("threshold", Native.Diagnostic.Monitor.Threshold))])
                self._leafs = OrderedDict([
                    ('syslog', (YLeaf(YType.empty, 'syslog'), ['Empty'])),
                ])
                self.syslog = None

                self.interval = Native.Diagnostic.Monitor.Interval()
                self.interval.parent = self
                self._children_name_map["interval"] = "interval"

                self.threshold = Native.Diagnostic.Monitor.Threshold()
                self.threshold.parent = self
                self._children_name_map["threshold"] = "threshold"

                self.switch = YList(self)
                self._segment_path = lambda: "monitor"
                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/Cisco-IOS-XE-diagnostics:diagnostic/%s" % self._segment_path()
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(Native.Diagnostic.Monitor, ['syslog'], name, value)


            class Interval(Entity):
                """
                Configure diagnostic monitoring tests interval
                
                .. attribute:: switch
                
                	Configure diagnostic monitoring tests interval on selected switch
                	**type**\:  :py:class:`Switch <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Diagnostic.Monitor.Interval.Switch>`
                
                

                """

                _prefix = 'ios-diag'
                _revision = '2017-02-07'

                def __init__(self):
                    super(Native.Diagnostic.Monitor.Interval, self).__init__()

                    self.yang_name = "interval"
                    self.yang_parent_name = "monitor"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("switch", ("switch", Native.Diagnostic.Monitor.Interval.Switch))])
                    self._leafs = OrderedDict()

                    self.switch = Native.Diagnostic.Monitor.Interval.Switch()
                    self.switch.parent = self
                    self._children_name_map["switch"] = "switch"
                    self._segment_path = lambda: "interval"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/Cisco-IOS-XE-diagnostics:diagnostic/monitor/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Diagnostic.Monitor.Interval, [], name, value)


                class Switch(Entity):
                    """
                    Configure diagnostic monitoring tests interval on selected switch
                    
                    .. attribute:: switch
                    
                    	Configure diagnostic monitoring tests on selected switch
                    	**type**\: list of  		 :py:class:`Switch_ <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Diagnostic.Monitor.Interval.Switch.Switch_>`
                    
                    

                    """

                    _prefix = 'ios-diag'
                    _revision = '2017-02-07'

                    def __init__(self):
                        super(Native.Diagnostic.Monitor.Interval.Switch, self).__init__()

                        self.yang_name = "switch"
                        self.yang_parent_name = "interval"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("switch", ("switch", Native.Diagnostic.Monitor.Interval.Switch.Switch_))])
                        self._leafs = OrderedDict()

                        self.switch = YList(self)
                        self._segment_path = lambda: "switch"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/Cisco-IOS-XE-diagnostics:diagnostic/monitor/interval/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Diagnostic.Monitor.Interval.Switch, [], name, value)


                    class Switch_(Entity):
                        """
                        Configure diagnostic monitoring tests on selected switch
                        
                        .. attribute:: number  (key)
                        
                        	switch number
                        	**type**\: int
                        
                        	**range:** 1..9
                        
                        .. attribute:: test
                        
                        	Diagnostic test selection Diagnostics test suite attributes\: M/C/\* \- Minimal bootup level test / Complete bootup level test / NA B/\* \- Basic ondemand test / NA P/V/\* \- Per port test / Per device test / NA D/N/\* \- Disruptive test / Non\-disruptive test / NA S/\* \- Only applicable to standby unit / NA X/\* \- Not a health monitoring test / NA F/\* \- Fixed monitoring interval test / NA E/\* \- Always enabled monitoring test / NA A/I \- Monitoring is active / Monitoring is inactive                                                 Test Interval   Thre\- ID   Test Name                          Attributes     day hh\:mm\:ss.ms shold ==== ================================  ============   =============== ===== 1) DiagGoldPktTest \-\-\-\-\-\-\-\-\-\-\-\-\-\-\-\-\->  \*BPN\*X\*\*I       not configured    n/a 2) DiagThermalTest \-\-\-\-\-\-\-\-\-\-\-\-\-\-\-\-\->  \*B\*N\*\*\*\*A       000 00\:01\:30.00   5 3) DiagFanTest \-\-\-\-\-\-\-\-\-\-\-\-\-\-\-\-\-\-\-\-\->  \*B\*N\*\*\*\*A       000 00\:01\:30.00   5 4) DiagPhyLoopbackTest \-\-\-\-\-\-\-\-\-\-\-\-\->  \*BPD\*X\*\*I       not configured    n/a 5) DiagScratchRegisterTest \-\-\-\-\-\-\-\-\->  \*B\*N\*\*\*\*A       000 00\:01\:30.00   5 6) DiagPoETest \-\-\-\-\-\-\-\-\-\-\-\-\-\-\-\-\-\-\-\-\->  \*\*\*D\*X\*\*I       not configured    n/a 7) DiagStackCableTest \-\-\-\-\-\-\-\-\-\-\-\-\-\->  \*\*\*D\*X\*\*I       not configured    n/a 8) DiagMemoryTest \-\-\-\-\-\-\-\-\-\-\-\-\-\-\-\-\-\->  \*B\*D\*X\*\*I       not configured    n/a 
                        	**type**\:  :py:class:`Test <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Diagnostic.Monitor.Interval.Switch.Switch_.Test>`
                        
                        

                        """

                        _prefix = 'ios-diag'
                        _revision = '2017-02-07'

                        def __init__(self):
                            super(Native.Diagnostic.Monitor.Interval.Switch.Switch_, self).__init__()

                            self.yang_name = "switch"
                            self.yang_parent_name = "switch"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = ['number']
                            self._child_classes = OrderedDict([("test", ("test", Native.Diagnostic.Monitor.Interval.Switch.Switch_.Test))])
                            self._leafs = OrderedDict([
                                ('number', (YLeaf(YType.uint8, 'number'), ['int'])),
                            ])
                            self.number = None

                            self.test = Native.Diagnostic.Monitor.Interval.Switch.Switch_.Test()
                            self.test.parent = self
                            self._children_name_map["test"] = "test"
                            self._segment_path = lambda: "switch" + "[number='" + str(self.number) + "']"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/Cisco-IOS-XE-diagnostics:diagnostic/monitor/interval/switch/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Diagnostic.Monitor.Interval.Switch.Switch_, ['number'], name, value)


                        class Test(Entity):
                            """
                            Diagnostic test selection
                            Diagnostics test suite attributes\:
                            M/C/\* \- Minimal bootup level test / Complete bootup level test / NA
                            B/\* \- Basic ondemand test / NA
                            P/V/\* \- Per port test / Per device test / NA
                            D/N/\* \- Disruptive test / Non\-disruptive test / NA
                            S/\* \- Only applicable to standby unit / NA
                            X/\* \- Not a health monitoring test / NA
                            F/\* \- Fixed monitoring interval test / NA
                            E/\* \- Always enabled monitoring test / NA
                            A/I \- Monitoring is active / Monitoring is inactive
                            
                                                                           Test Interval   Thre\-
                            ID   Test Name                          Attributes     day hh\:mm\:ss.ms shold
                            ==== ================================  ============   =============== =====
                            1) DiagGoldPktTest \-\-\-\-\-\-\-\-\-\-\-\-\-\-\-\-\->  \*BPN\*X\*\*I       not configured    n/a
                            2) DiagThermalTest \-\-\-\-\-\-\-\-\-\-\-\-\-\-\-\-\->  \*B\*N\*\*\*\*A       000 00\:01\:30.00   5
                            3) DiagFanTest \-\-\-\-\-\-\-\-\-\-\-\-\-\-\-\-\-\-\-\-\->  \*B\*N\*\*\*\*A       000 00\:01\:30.00   5
                            4) DiagPhyLoopbackTest \-\-\-\-\-\-\-\-\-\-\-\-\->  \*BPD\*X\*\*I       not configured    n/a
                            5) DiagScratchRegisterTest \-\-\-\-\-\-\-\-\->  \*B\*N\*\*\*\*A       000 00\:01\:30.00   5
                            6) DiagPoETest \-\-\-\-\-\-\-\-\-\-\-\-\-\-\-\-\-\-\-\-\->  \*\*\*D\*X\*\*I       not configured    n/a
                            7) DiagStackCableTest \-\-\-\-\-\-\-\-\-\-\-\-\-\->  \*\*\*D\*X\*\*I       not configured    n/a
                            8) DiagMemoryTest \-\-\-\-\-\-\-\-\-\-\-\-\-\-\-\-\-\->  \*B\*D\*X\*\*I       not configured    n/a 
                            
                            .. attribute:: test_ids
                            
                            	
                            	**type**\: list of  		 :py:class:`TestIds <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Diagnostic.Monitor.Interval.Switch.Switch_.Test.TestIds>`
                            
                            .. attribute:: all
                            
                            	Select all test ID 
                            	**type**\:  :py:class:`All <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Diagnostic.Monitor.Interval.Switch.Switch_.Test.All>`
                            
                            

                            """

                            _prefix = 'ios-diag'
                            _revision = '2017-02-07'

                            def __init__(self):
                                super(Native.Diagnostic.Monitor.Interval.Switch.Switch_.Test, self).__init__()

                                self.yang_name = "test"
                                self.yang_parent_name = "switch"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("test-ids", ("test_ids", Native.Diagnostic.Monitor.Interval.Switch.Switch_.Test.TestIds)), ("all", ("all", Native.Diagnostic.Monitor.Interval.Switch.Switch_.Test.All))])
                                self._leafs = OrderedDict()

                                self.all = Native.Diagnostic.Monitor.Interval.Switch.Switch_.Test.All()
                                self.all.parent = self
                                self._children_name_map["all"] = "all"

                                self.test_ids = YList(self)
                                self._segment_path = lambda: "test"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Diagnostic.Monitor.Interval.Switch.Switch_.Test, [], name, value)


                            class TestIds(Entity):
                                """
                                
                                
                                .. attribute:: id  (key)
                                
                                	Test ID list (e.g. 1,3\-6) or Test Name
                                	**type**\: str
                                
                                .. attribute:: hh_mm_ss
                                
                                	Monitoring interval in hh\:mm\:ss format
                                	**type**\: str
                                
                                	**pattern:** ([0\-1]?[0\-9]\|2[0\-4])\:([0\-5][0\-9])\:([0\-5][0\-9])
                                
                                .. attribute:: milli_seconds
                                
                                	Number of milli\-seconds [0\-999]
                                	**type**\: int
                                
                                	**range:** 0..999
                                
                                .. attribute:: number_of_days
                                
                                	Number of days [0\-20]
                                	**type**\: int
                                
                                	**range:** 0..20
                                
                                

                                """

                                _prefix = 'ios-diag'
                                _revision = '2017-02-07'

                                def __init__(self):
                                    super(Native.Diagnostic.Monitor.Interval.Switch.Switch_.Test.TestIds, self).__init__()

                                    self.yang_name = "test-ids"
                                    self.yang_parent_name = "test"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = ['id']
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('id', (YLeaf(YType.str, 'id'), ['str'])),
                                        ('hh_mm_ss', (YLeaf(YType.str, 'hh-mm-ss'), ['str'])),
                                        ('milli_seconds', (YLeaf(YType.uint16, 'milli-seconds'), ['int'])),
                                        ('number_of_days', (YLeaf(YType.uint16, 'number-of-days'), ['int'])),
                                    ])
                                    self.id = None
                                    self.hh_mm_ss = None
                                    self.milli_seconds = None
                                    self.number_of_days = None
                                    self._segment_path = lambda: "test-ids" + "[id='" + str(self.id) + "']"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Diagnostic.Monitor.Interval.Switch.Switch_.Test.TestIds, ['id', 'hh_mm_ss', 'milli_seconds', 'number_of_days'], name, value)


                            class All(Entity):
                                """
                                Select all test ID 
                                
                                .. attribute:: hh_mm_ss
                                
                                	Monitoring interval in hh\:mm\:ss format
                                	**type**\: str
                                
                                	**pattern:** ([0\-1]?[0\-9]\|2[0\-4])\:([0\-5][0\-9])\:([0\-5][0\-9])
                                
                                .. attribute:: milli_seconds
                                
                                	Number of milli\-seconds [0\-999]
                                	**type**\: int
                                
                                	**range:** 0..999
                                
                                .. attribute:: number_of_days
                                
                                	Number of days [0\-20]
                                	**type**\: int
                                
                                	**range:** 0..20
                                
                                

                                """

                                _prefix = 'ios-diag'
                                _revision = '2017-02-07'

                                def __init__(self):
                                    super(Native.Diagnostic.Monitor.Interval.Switch.Switch_.Test.All, self).__init__()

                                    self.yang_name = "all"
                                    self.yang_parent_name = "test"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('hh_mm_ss', (YLeaf(YType.str, 'hh-mm-ss'), ['str'])),
                                        ('milli_seconds', (YLeaf(YType.uint16, 'milli-seconds'), ['int'])),
                                        ('number_of_days', (YLeaf(YType.uint16, 'number-of-days'), ['int'])),
                                    ])
                                    self.hh_mm_ss = None
                                    self.milli_seconds = None
                                    self.number_of_days = None
                                    self._segment_path = lambda: "all"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Diagnostic.Monitor.Interval.Switch.Switch_.Test.All, ['hh_mm_ss', 'milli_seconds', 'number_of_days'], name, value)


            class Switch(Entity):
                """
                Configure diagnostic monitoring tests on selected switch
                
                .. attribute:: number  (key)
                
                	switch number
                	**type**\: int
                
                	**range:** 1..9
                
                .. attribute:: test
                
                	Diagnostic test selection Diagnostics test suite attributes\: M/C/\* \- Minimal bootup level test / Complete bootup level test / NA B/\* \- Basic ondemand test / NA P/V/\* \- Per port test / Per device test / NA D/N/\* \- Disruptive test / Non\-disruptive test / NA S/\* \- Only applicable to standby unit / NA X/\* \- Not a health monitoring test / NA F/\* \- Fixed monitoring interval test / NA E/\* \- Always enabled monitoring test / NA A/I \- Monitoring is active / Monitoring is inactive  Test                                                  Test Interval  Thre\- ID   Test Name                          Attributes      day hh\:mm\:ss.ms shold ==== ================================== ============    =============== ===== 1) DiagGoldPktTest \-\-\-\-\-\-\-\-\-\-\-\-\-\-\-\-\-> \*BPN\*X\*\*I       not configured    n/a 2) DiagThermalTest \-\-\-\-\-\-\-\-\-\-\-\-\-\-\-\-\-> \*B\*N\*\*\*\*A       000 00\:01\:30.00   5 3) DiagFanTest \-\-\-\-\-\-\-\-\-\-\-\-\-\-\-\-\-\-\-\-\-> \*B\*N\*\*\*\*A       000 00\:01\:30.00   5 4) DiagPhyLoopbackTest \-\-\-\-\-\-\-\-\-\-\-\-\-> \*BPD\*X\*\*I       not configured    n/a 5) DiagScratchRegisterTest \-\-\-\-\-\-\-\-\-> \*B\*N\*\*\*\*A       000 00\:01\:30.00   5 6) DiagPoETest \-\-\-\-\-\-\-\-\-\-\-\-\-\-\-\-\-\-\-\-\-> \*\*\*D\*X\*\*I       not configured    n/a 7) DiagStackCableTest \-\-\-\-\-\-\-\-\-\-\-\-\-\-> \*\*\*D\*X\*\*I       not configured    n/a 8) DiagMemoryTest \-\-\-\-\-\-\-\-\-\-\-\-\-\-\-\-\-\-> \*B\*D\*X\*\*I       not configured    n/a 
                	**type**\:  :py:class:`Test <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Diagnostic.Monitor.Switch.Test>`
                
                

                """

                _prefix = 'ios-diag'
                _revision = '2017-02-07'

                def __init__(self):
                    super(Native.Diagnostic.Monitor.Switch, self).__init__()

                    self.yang_name = "switch"
                    self.yang_parent_name = "monitor"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = ['number']
                    self._child_classes = OrderedDict([("test", ("test", Native.Diagnostic.Monitor.Switch.Test))])
                    self._leafs = OrderedDict([
                        ('number', (YLeaf(YType.uint8, 'number'), ['int'])),
                    ])
                    self.number = None

                    self.test = Native.Diagnostic.Monitor.Switch.Test()
                    self.test.parent = self
                    self._children_name_map["test"] = "test"
                    self._segment_path = lambda: "switch" + "[number='" + str(self.number) + "']"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/Cisco-IOS-XE-diagnostics:diagnostic/monitor/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Diagnostic.Monitor.Switch, ['number'], name, value)


                class Test(Entity):
                    """
                    Diagnostic test selection
                    Diagnostics test suite attributes\:
                    M/C/\* \- Minimal bootup level test / Complete bootup level test / NA
                    B/\* \- Basic ondemand test / NA
                    P/V/\* \- Per port test / Per device test / NA
                    D/N/\* \- Disruptive test / Non\-disruptive test / NA
                    S/\* \- Only applicable to standby unit / NA
                    X/\* \- Not a health monitoring test / NA
                    F/\* \- Fixed monitoring interval test / NA
                    E/\* \- Always enabled monitoring test / NA
                    A/I \- Monitoring is active / Monitoring is inactive
                    
                    Test                                                  Test Interval  Thre\-
                    ID   Test Name                          Attributes      day hh\:mm\:ss.ms shold
                    ==== ================================== ============    =============== =====
                    1) DiagGoldPktTest \-\-\-\-\-\-\-\-\-\-\-\-\-\-\-\-\-> \*BPN\*X\*\*I       not configured    n/a
                    2) DiagThermalTest \-\-\-\-\-\-\-\-\-\-\-\-\-\-\-\-\-> \*B\*N\*\*\*\*A       000 00\:01\:30.00   5
                    3) DiagFanTest \-\-\-\-\-\-\-\-\-\-\-\-\-\-\-\-\-\-\-\-\-> \*B\*N\*\*\*\*A       000 00\:01\:30.00   5
                    4) DiagPhyLoopbackTest \-\-\-\-\-\-\-\-\-\-\-\-\-> \*BPD\*X\*\*I       not configured    n/a
                    5) DiagScratchRegisterTest \-\-\-\-\-\-\-\-\-> \*B\*N\*\*\*\*A       000 00\:01\:30.00   5
                    6) DiagPoETest \-\-\-\-\-\-\-\-\-\-\-\-\-\-\-\-\-\-\-\-\-> \*\*\*D\*X\*\*I       not configured    n/a
                    7) DiagStackCableTest \-\-\-\-\-\-\-\-\-\-\-\-\-\-> \*\*\*D\*X\*\*I       not configured    n/a
                    8) DiagMemoryTest \-\-\-\-\-\-\-\-\-\-\-\-\-\-\-\-\-\-> \*B\*D\*X\*\*I       not configured    n/a 
                    
                    .. attribute:: id
                    
                    	Test ID list (e.g. 1,3\-6) or Test Name
                    	**type**\: str
                    
                    .. attribute:: all
                    
                    	Select all test ID 
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios-diag'
                    _revision = '2017-02-07'

                    def __init__(self):
                        super(Native.Diagnostic.Monitor.Switch.Test, self).__init__()

                        self.yang_name = "test"
                        self.yang_parent_name = "switch"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('id', (YLeaf(YType.str, 'id'), ['str'])),
                            ('all', (YLeaf(YType.empty, 'all'), ['Empty'])),
                        ])
                        self.id = None
                        self.all = None
                        self._segment_path = lambda: "test"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Diagnostic.Monitor.Switch.Test, ['id', 'all'], name, value)


            class Threshold(Entity):
                """
                Configure diagnostic monitoring failure threshold
                
                .. attribute:: switch
                
                	Configure diagnostic monitoring tests threshold on selected switch
                	**type**\: list of  		 :py:class:`Switch <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Diagnostic.Monitor.Threshold.Switch>`
                
                

                """

                _prefix = 'ios-diag'
                _revision = '2017-02-07'

                def __init__(self):
                    super(Native.Diagnostic.Monitor.Threshold, self).__init__()

                    self.yang_name = "threshold"
                    self.yang_parent_name = "monitor"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("switch", ("switch", Native.Diagnostic.Monitor.Threshold.Switch))])
                    self._leafs = OrderedDict()

                    self.switch = YList(self)
                    self._segment_path = lambda: "threshold"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/Cisco-IOS-XE-diagnostics:diagnostic/monitor/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Diagnostic.Monitor.Threshold, [], name, value)


                class Switch(Entity):
                    """
                    Configure diagnostic monitoring tests threshold on selected switch
                    
                    .. attribute:: number  (key)
                    
                    	switch number
                    	**type**\: int
                    
                    	**range:** 1..9
                    
                    .. attribute:: test
                    
                    	Diagnostic test selection Diagnostics test suite attributes\: M/C/\* \- Minimal bootup level test / Complete bootup level test / NA B/\* \- Basic ondemand test / NA P/V/\* \- Per port test / Per device test / NA D/N/\* \- Disruptive test / Non\-disruptive test / NA S/\* \- Only applicable to standby unit / NA X/\* \- Not a health monitoring test / NA F/\* \- Fixed monitoring interval test / NA E/\* \- Always enabled monitoring test / NA A/I \- Monitoring is active / Monitoring is inactive                                                     Test Interval  Thres\- ID   Test Name                          Attributes        day hh\:mm\:ss.ms shold ==== ================================== ============   =============== ===== 1) DiagGoldPktTest \-\-\-\-\-\-\-\-\-\-\-\-\-\-\-\-\->  \*BPN\*X\*\*I          not configured  n/a 2) DiagThermalTest \-\-\-\-\-\-\-\-\-\-\-\-\-\-\-\-\->  \*B\*N\*\*\*\*A          000 00\:01\:30.00 5 3) DiagFanTest \-\-\-\-\-\-\-\-\-\-\-\-\-\-\-\-\-\-\-\-\->  \*B\*N\*\*\*\*A          000 00\:01\:30.00 5 4) DiagPhyLoopbackTest \-\-\-\-\-\-\-\-\-\-\-\-\->  \*BPD\*X\*\*I          not configured  n/a 5) DiagScratchRegisterTest \-\-\-\-\-\-\-\-\->  \*B\*N\*\*\*\*A          000 00\:01\:30.00 5 6) DiagPoETest \-\-\-\-\-\-\-\-\-\-\-\-\-\-\-\-\-\-\-\-\->  \*\*\*D\*X\*\*I          not configured  n/a 7) DiagStackCableTest \-\-\-\-\-\-\-\-\-\-\-\-\-\->  \*\*\*D\*X\*\*I          not configured  n/a 8) DiagMemoryTest \-\-\-\-\-\-\-\-\-\-\-\-\-\-\-\-\-\->  \*B\*D\*X\*\*I          not configured  n/a 
                    	**type**\:  :py:class:`Test <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Diagnostic.Monitor.Threshold.Switch.Test>`
                    
                    

                    """

                    _prefix = 'ios-diag'
                    _revision = '2017-02-07'

                    def __init__(self):
                        super(Native.Diagnostic.Monitor.Threshold.Switch, self).__init__()

                        self.yang_name = "switch"
                        self.yang_parent_name = "threshold"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = ['number']
                        self._child_classes = OrderedDict([("test", ("test", Native.Diagnostic.Monitor.Threshold.Switch.Test))])
                        self._leafs = OrderedDict([
                            ('number', (YLeaf(YType.uint8, 'number'), ['int'])),
                        ])
                        self.number = None

                        self.test = Native.Diagnostic.Monitor.Threshold.Switch.Test()
                        self.test.parent = self
                        self._children_name_map["test"] = "test"
                        self._segment_path = lambda: "switch" + "[number='" + str(self.number) + "']"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/Cisco-IOS-XE-diagnostics:diagnostic/monitor/threshold/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Diagnostic.Monitor.Threshold.Switch, ['number'], name, value)


                    class Test(Entity):
                        """
                        Diagnostic test selection
                        Diagnostics test suite attributes\:
                        M/C/\* \- Minimal bootup level test / Complete bootup level test / NA
                        B/\* \- Basic ondemand test / NA
                        P/V/\* \- Per port test / Per device test / NA
                        D/N/\* \- Disruptive test / Non\-disruptive test / NA
                        S/\* \- Only applicable to standby unit / NA
                        X/\* \- Not a health monitoring test / NA
                        F/\* \- Fixed monitoring interval test / NA
                        E/\* \- Always enabled monitoring test / NA
                        A/I \- Monitoring is active / Monitoring is inactive
                        
                                                                           Test Interval  Thres\-
                        ID   Test Name                          Attributes        day hh\:mm\:ss.ms shold
                        ==== ================================== ============   =============== =====
                        1) DiagGoldPktTest \-\-\-\-\-\-\-\-\-\-\-\-\-\-\-\-\->  \*BPN\*X\*\*I          not configured  n/a
                        2) DiagThermalTest \-\-\-\-\-\-\-\-\-\-\-\-\-\-\-\-\->  \*B\*N\*\*\*\*A          000 00\:01\:30.00 5
                        3) DiagFanTest \-\-\-\-\-\-\-\-\-\-\-\-\-\-\-\-\-\-\-\-\->  \*B\*N\*\*\*\*A          000 00\:01\:30.00 5
                        4) DiagPhyLoopbackTest \-\-\-\-\-\-\-\-\-\-\-\-\->  \*BPD\*X\*\*I          not configured  n/a
                        5) DiagScratchRegisterTest \-\-\-\-\-\-\-\-\->  \*B\*N\*\*\*\*A          000 00\:01\:30.00 5
                        6) DiagPoETest \-\-\-\-\-\-\-\-\-\-\-\-\-\-\-\-\-\-\-\-\->  \*\*\*D\*X\*\*I          not configured  n/a
                        7) DiagStackCableTest \-\-\-\-\-\-\-\-\-\-\-\-\-\->  \*\*\*D\*X\*\*I          not configured  n/a
                        8) DiagMemoryTest \-\-\-\-\-\-\-\-\-\-\-\-\-\-\-\-\-\->  \*B\*D\*X\*\*I          not configured  n/a 
                        
                        .. attribute:: test_ids
                        
                        	
                        	**type**\: list of  		 :py:class:`TestIds <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Diagnostic.Monitor.Threshold.Switch.Test.TestIds>`
                        
                        .. attribute:: all
                        
                        	Select all test ID 
                        	**type**\:  :py:class:`All <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Diagnostic.Monitor.Threshold.Switch.Test.All>`
                        
                        

                        """

                        _prefix = 'ios-diag'
                        _revision = '2017-02-07'

                        def __init__(self):
                            super(Native.Diagnostic.Monitor.Threshold.Switch.Test, self).__init__()

                            self.yang_name = "test"
                            self.yang_parent_name = "switch"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("test-ids", ("test_ids", Native.Diagnostic.Monitor.Threshold.Switch.Test.TestIds)), ("all", ("all", Native.Diagnostic.Monitor.Threshold.Switch.Test.All))])
                            self._leafs = OrderedDict()

                            self.all = Native.Diagnostic.Monitor.Threshold.Switch.Test.All()
                            self.all.parent = self
                            self._children_name_map["all"] = "all"

                            self.test_ids = YList(self)
                            self._segment_path = lambda: "test"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Diagnostic.Monitor.Threshold.Switch.Test, [], name, value)


                        class TestIds(Entity):
                            """
                            
                            
                            .. attribute:: id  (key)
                            
                            	Test ID list (e.g. 1,3\-6) or Test Name
                            	**type**\: str
                            
                            .. attribute:: failure
                            
                            	Setting failure threshold
                            	**type**\:  :py:class:`Failure <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Diagnostic.Monitor.Threshold.Switch.Test.TestIds.Failure>`
                            
                            

                            """

                            _prefix = 'ios-diag'
                            _revision = '2017-02-07'

                            def __init__(self):
                                super(Native.Diagnostic.Monitor.Threshold.Switch.Test.TestIds, self).__init__()

                                self.yang_name = "test-ids"
                                self.yang_parent_name = "test"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = ['id']
                                self._child_classes = OrderedDict([("failure", ("failure", Native.Diagnostic.Monitor.Threshold.Switch.Test.TestIds.Failure))])
                                self._leafs = OrderedDict([
                                    ('id', (YLeaf(YType.str, 'id'), ['str'])),
                                ])
                                self.id = None

                                self.failure = Native.Diagnostic.Monitor.Threshold.Switch.Test.TestIds.Failure()
                                self.failure.parent = self
                                self._children_name_map["failure"] = "failure"
                                self._segment_path = lambda: "test-ids" + "[id='" + str(self.id) + "']"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Diagnostic.Monitor.Threshold.Switch.Test.TestIds, ['id'], name, value)


                            class Failure(Entity):
                                """
                                Setting failure threshold
                                
                                .. attribute:: count
                                
                                	Setting failure threshold count
                                	**type**\: list of  		 :py:class:`Count <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Diagnostic.Monitor.Threshold.Switch.Test.TestIds.Failure.Count>`
                                
                                

                                """

                                _prefix = 'ios-diag'
                                _revision = '2017-02-07'

                                def __init__(self):
                                    super(Native.Diagnostic.Monitor.Threshold.Switch.Test.TestIds.Failure, self).__init__()

                                    self.yang_name = "failure"
                                    self.yang_parent_name = "test-ids"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("count", ("count", Native.Diagnostic.Monitor.Threshold.Switch.Test.TestIds.Failure.Count))])
                                    self._leafs = OrderedDict()

                                    self.count = YList(self)
                                    self._segment_path = lambda: "failure"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Diagnostic.Monitor.Threshold.Switch.Test.TestIds.Failure, [], name, value)


                                class Count(Entity):
                                    """
                                    Setting failure threshold count
                                    
                                    .. attribute:: range  (key)
                                    
                                    	Number of allowable failures [1\-1000]
                                    	**type**\: int
                                    
                                    	**range:** 1..1000
                                    
                                    .. attribute:: days
                                    
                                    	Set failure history window in days <1\-1000000>
                                    	**type**\: int
                                    
                                    	**range:** 1..1000000
                                    
                                    .. attribute:: hours
                                    
                                    	Set failure history window in hours <1\-1000000>
                                    	**type**\: int
                                    
                                    	**range:** 1..1000000
                                    
                                    .. attribute:: milli_seconds
                                    
                                    	Set failure history window in milli\-seconds <15\-1000000>
                                    	**type**\: int
                                    
                                    	**range:** 15..1000000
                                    
                                    .. attribute:: minutes
                                    
                                    	Set failure history window in minutes
                                    	**type**\: int
                                    
                                    	**range:** 1..1000000
                                    
                                    .. attribute:: runs
                                    
                                    	Set failure history window in test\-run count
                                    	**type**\: int
                                    
                                    	**range:** 1..5000
                                    
                                    .. attribute:: seconds
                                    
                                    	Set failure history window in seconds
                                    	**type**\: int
                                    
                                    	**range:** 1..1000000
                                    
                                    

                                    """

                                    _prefix = 'ios-diag'
                                    _revision = '2017-02-07'

                                    def __init__(self):
                                        super(Native.Diagnostic.Monitor.Threshold.Switch.Test.TestIds.Failure.Count, self).__init__()

                                        self.yang_name = "count"
                                        self.yang_parent_name = "failure"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = ['range']
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('range', (YLeaf(YType.uint16, 'range'), ['int'])),
                                            ('days', (YLeaf(YType.uint32, 'days'), ['int'])),
                                            ('hours', (YLeaf(YType.uint32, 'hours'), ['int'])),
                                            ('milli_seconds', (YLeaf(YType.uint32, 'milli-seconds'), ['int'])),
                                            ('minutes', (YLeaf(YType.uint32, 'minutes'), ['int'])),
                                            ('runs', (YLeaf(YType.uint16, 'runs'), ['int'])),
                                            ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                        ])
                                        self.range = None
                                        self.days = None
                                        self.hours = None
                                        self.milli_seconds = None
                                        self.minutes = None
                                        self.runs = None
                                        self.seconds = None
                                        self._segment_path = lambda: "count" + "[range='" + str(self.range) + "']"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Diagnostic.Monitor.Threshold.Switch.Test.TestIds.Failure.Count, ['range', 'days', 'hours', 'milli_seconds', 'minutes', 'runs', 'seconds'], name, value)


                        class All(Entity):
                            """
                            Select all test ID 
                            
                            .. attribute:: failure
                            
                            	Setting failure threshold
                            	**type**\:  :py:class:`Failure <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Diagnostic.Monitor.Threshold.Switch.Test.All.Failure>`
                            
                            

                            """

                            _prefix = 'ios-diag'
                            _revision = '2017-02-07'

                            def __init__(self):
                                super(Native.Diagnostic.Monitor.Threshold.Switch.Test.All, self).__init__()

                                self.yang_name = "all"
                                self.yang_parent_name = "test"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("failure", ("failure", Native.Diagnostic.Monitor.Threshold.Switch.Test.All.Failure))])
                                self._leafs = OrderedDict()

                                self.failure = Native.Diagnostic.Monitor.Threshold.Switch.Test.All.Failure()
                                self.failure.parent = self
                                self._children_name_map["failure"] = "failure"
                                self._segment_path = lambda: "all"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Diagnostic.Monitor.Threshold.Switch.Test.All, [], name, value)


                            class Failure(Entity):
                                """
                                Setting failure threshold
                                
                                .. attribute:: count
                                
                                	Setting failure threshold count
                                	**type**\: list of  		 :py:class:`Count <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Diagnostic.Monitor.Threshold.Switch.Test.All.Failure.Count>`
                                
                                

                                """

                                _prefix = 'ios-diag'
                                _revision = '2017-02-07'

                                def __init__(self):
                                    super(Native.Diagnostic.Monitor.Threshold.Switch.Test.All.Failure, self).__init__()

                                    self.yang_name = "failure"
                                    self.yang_parent_name = "all"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("count", ("count", Native.Diagnostic.Monitor.Threshold.Switch.Test.All.Failure.Count))])
                                    self._leafs = OrderedDict()

                                    self.count = YList(self)
                                    self._segment_path = lambda: "failure"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Diagnostic.Monitor.Threshold.Switch.Test.All.Failure, [], name, value)


                                class Count(Entity):
                                    """
                                    Setting failure threshold count
                                    
                                    .. attribute:: range  (key)
                                    
                                    	Number of allowable failures [1\-1000]
                                    	**type**\: int
                                    
                                    	**range:** 1..1000
                                    
                                    .. attribute:: days
                                    
                                    	Set failure history window in days
                                    	**type**\: int
                                    
                                    	**range:** 1..1000000
                                    
                                    .. attribute:: hours
                                    
                                    	Set failure history window in hours
                                    	**type**\: int
                                    
                                    	**range:** 1..1000000
                                    
                                    .. attribute:: milli_seconds
                                    
                                    	Set failure history window in milli\-seconds
                                    	**type**\: int
                                    
                                    	**range:** 15..1000000
                                    
                                    .. attribute:: minutes
                                    
                                    	Set failure history window in minutes
                                    	**type**\: int
                                    
                                    	**range:** 1..1000000
                                    
                                    .. attribute:: runs
                                    
                                    	Set failure history window in test\-run count
                                    	**type**\: int
                                    
                                    	**range:** 1..5000
                                    
                                    .. attribute:: seconds
                                    
                                    	Set failure history window in seconds
                                    	**type**\: int
                                    
                                    	**range:** 1..1000000
                                    
                                    

                                    """

                                    _prefix = 'ios-diag'
                                    _revision = '2017-02-07'

                                    def __init__(self):
                                        super(Native.Diagnostic.Monitor.Threshold.Switch.Test.All.Failure.Count, self).__init__()

                                        self.yang_name = "count"
                                        self.yang_parent_name = "failure"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = ['range']
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('range', (YLeaf(YType.uint16, 'range'), ['int'])),
                                            ('days', (YLeaf(YType.uint32, 'days'), ['int'])),
                                            ('hours', (YLeaf(YType.uint32, 'hours'), ['int'])),
                                            ('milli_seconds', (YLeaf(YType.uint32, 'milli-seconds'), ['int'])),
                                            ('minutes', (YLeaf(YType.uint32, 'minutes'), ['int'])),
                                            ('runs', (YLeaf(YType.uint16, 'runs'), ['int'])),
                                            ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                        ])
                                        self.range = None
                                        self.days = None
                                        self.hours = None
                                        self.milli_seconds = None
                                        self.minutes = None
                                        self.runs = None
                                        self.seconds = None
                                        self._segment_path = lambda: "count" + "[range='" + str(self.range) + "']"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Diagnostic.Monitor.Threshold.Switch.Test.All.Failure.Count, ['range', 'days', 'hours', 'milli_seconds', 'minutes', 'runs', 'seconds'], name, value)


        class Schedule(Entity):
            """
            Configure diagnostic schedule for a card
            
            .. attribute:: switch
            
            	Configure diagnostic monitoring tests interval on selected switch
            	**type**\: list of  		 :py:class:`Switch <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Diagnostic.Schedule.Switch>`
            
            

            """

            _prefix = 'ios-diag'
            _revision = '2017-02-07'

            def __init__(self):
                super(Native.Diagnostic.Schedule, self).__init__()

                self.yang_name = "schedule"
                self.yang_parent_name = "diagnostic"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = []
                self._child_classes = OrderedDict([("switch", ("switch", Native.Diagnostic.Schedule.Switch))])
                self._leafs = OrderedDict()

                self.switch = YList(self)
                self._segment_path = lambda: "schedule"
                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/Cisco-IOS-XE-diagnostics:diagnostic/%s" % self._segment_path()
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(Native.Diagnostic.Schedule, [], name, value)


            class Switch(Entity):
                """
                Configure diagnostic monitoring tests interval on selected switch
                
                .. attribute:: switch_number  (key)
                
                	switch number
                	**type**\: int
                
                	**range:** 1..9
                
                .. attribute:: test
                
                	Diagnostic test selection Diagnostics test suite attributes\: M/C/\* \- Minimal bootup level test / Complete bootup level test / NA B/\* \- Basic ondemand test / NA P/V/\* \- Per port test / Per device test / NA D/N/\* \- Disruptive test / Non\-disruptive test / NA S/\* \- Only applicable to standby unit / NA X/\* \- Not a health monitoring test / NA F/\* \- Fixed monitoring interval test / NA E/\* \- Always enabled monitoring test / NA A/I \- Monitoring is active / Monitoring is inactive                                                     Test Interval   Thre\- ID   Test Name                          Attributes      day hh\:mm\:ss.ms shold ==== ================================== ============    ===============  ===== 1)   DiagGoldPktTest \-\-\-\-\-\-\-\-\-\-\-\-\-\-\-\-\-> \*BPN\*X\*\*I       not configured   n/a 2)   DiagThermalTest \-\-\-\-\-\-\-\-\-\-\-\-\-\-\-\-\-> \*B\*N\*\*\*\*A       000 00\:01\:30.0   5 3)   DiagFanTest \-\-\-\-\-\-\-\-\-\-\-\-\-\-\-\-\-\-\-\-\-> \*B\*N\*\*\*\*A       000 00\:01\:30.00  5 4)   DiagPhyLoopbackTest \-\-\-\-\-\-\-\-\-\-\-\-\-> \*BPD\*X\*\*I       not configured   n/a 5)   DiagScratchRegisterTest \-\-\-\-\-\-\-\-\-> \*B\*N\*\*\*\*A       000 00\:01\:30.00  5 6)   DiagPoETest \-\-\-\-\-\-\-\-\-\-\-\-\-\-\-\-\-\-\-\-\-> \*\*\*D\*X\*\*I       not configured   n/a 7)   DiagStackCableTest \-\-\-\-\-\-\-\-\-\-\-\-\-\-> \*\*\*D\*X\*\*I       not configured   n/a 8)   DiagMemoryTest \-\-\-\-\-\-\-\-\-\-\-\-\-\-\-\-\-\-> \*B\*D\*X\*\*I       not configured   n/a 
                	**type**\:  :py:class:`Test <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Diagnostic.Schedule.Switch.Test>`
                
                

                """

                _prefix = 'ios-diag'
                _revision = '2017-02-07'

                def __init__(self):
                    super(Native.Diagnostic.Schedule.Switch, self).__init__()

                    self.yang_name = "switch"
                    self.yang_parent_name = "schedule"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = ['switch_number']
                    self._child_classes = OrderedDict([("test", ("test", Native.Diagnostic.Schedule.Switch.Test))])
                    self._leafs = OrderedDict([
                        ('switch_number', (YLeaf(YType.uint8, 'switch-number'), ['int'])),
                    ])
                    self.switch_number = None

                    self.test = Native.Diagnostic.Schedule.Switch.Test()
                    self.test.parent = self
                    self._children_name_map["test"] = "test"
                    self._segment_path = lambda: "switch" + "[switch-number='" + str(self.switch_number) + "']"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/Cisco-IOS-XE-diagnostics:diagnostic/schedule/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Diagnostic.Schedule.Switch, ['switch_number'], name, value)


                class Test(Entity):
                    """
                    Diagnostic test selection
                    Diagnostics test suite attributes\:
                    M/C/\* \- Minimal bootup level test / Complete bootup level test / NA
                    B/\* \- Basic ondemand test / NA
                    P/V/\* \- Per port test / Per device test / NA
                    D/N/\* \- Disruptive test / Non\-disruptive test / NA
                    S/\* \- Only applicable to standby unit / NA
                    X/\* \- Not a health monitoring test / NA
                    F/\* \- Fixed monitoring interval test / NA
                    E/\* \- Always enabled monitoring test / NA
                    A/I \- Monitoring is active / Monitoring is inactive
                                                                        Test Interval   Thre\-
                    ID   Test Name                          Attributes      day hh\:mm\:ss.ms shold
                    ==== ================================== ============    ===============  =====
                    1)   DiagGoldPktTest \-\-\-\-\-\-\-\-\-\-\-\-\-\-\-\-\-> \*BPN\*X\*\*I       not configured   n/a
                    2)   DiagThermalTest \-\-\-\-\-\-\-\-\-\-\-\-\-\-\-\-\-> \*B\*N\*\*\*\*A       000 00\:01\:30.0   5
                    3)   DiagFanTest \-\-\-\-\-\-\-\-\-\-\-\-\-\-\-\-\-\-\-\-\-> \*B\*N\*\*\*\*A       000 00\:01\:30.00  5
                    4)   DiagPhyLoopbackTest \-\-\-\-\-\-\-\-\-\-\-\-\-> \*BPD\*X\*\*I       not configured   n/a
                    5)   DiagScratchRegisterTest \-\-\-\-\-\-\-\-\-> \*B\*N\*\*\*\*A       000 00\:01\:30.00  5
                    6)   DiagPoETest \-\-\-\-\-\-\-\-\-\-\-\-\-\-\-\-\-\-\-\-\-> \*\*\*D\*X\*\*I       not configured   n/a
                    7)   DiagStackCableTest \-\-\-\-\-\-\-\-\-\-\-\-\-\-> \*\*\*D\*X\*\*I       not configured   n/a
                    8)   DiagMemoryTest \-\-\-\-\-\-\-\-\-\-\-\-\-\-\-\-\-\-> \*B\*D\*X\*\*I       not configured   n/a 
                    
                    .. attribute:: test_ids
                    
                    	
                    	**type**\: list of  		 :py:class:`TestIds <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Diagnostic.Schedule.Switch.Test.TestIds>`
                    
                    .. attribute:: all
                    
                    	Select all test ID 
                    	**type**\:  :py:class:`All <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Diagnostic.Schedule.Switch.Test.All>`
                    
                    .. attribute:: basic
                    
                    	Select the Basic ondemand test suite [Attribute = B]
                    	**type**\:  :py:class:`Basic <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Diagnostic.Schedule.Switch.Test.Basic>`
                    
                    .. attribute:: complete
                    
                    	Select the Complete bootup test suite [Attribute = C]
                    	**type**\:  :py:class:`Complete <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Diagnostic.Schedule.Switch.Test.Complete>`
                    
                    .. attribute:: minimal
                    
                    	Select the Minimal bootup test suite [Attribute = M]
                    	**type**\:  :py:class:`Minimal <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Diagnostic.Schedule.Switch.Test.Minimal>`
                    
                    .. attribute:: non_disruptive
                    
                    	Select the Non\-Disruptive test suite [Attribute = N]
                    	**type**\:  :py:class:`NonDisruptive <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Diagnostic.Schedule.Switch.Test.NonDisruptive>`
                    
                    .. attribute:: per_port
                    
                    	Select the Per\-Port test suite [Attribute = P]
                    	**type**\:  :py:class:`PerPort <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Diagnostic.Schedule.Switch.Test.PerPort>`
                    
                    

                    """

                    _prefix = 'ios-diag'
                    _revision = '2017-02-07'

                    def __init__(self):
                        super(Native.Diagnostic.Schedule.Switch.Test, self).__init__()

                        self.yang_name = "test"
                        self.yang_parent_name = "switch"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("test-ids", ("test_ids", Native.Diagnostic.Schedule.Switch.Test.TestIds)), ("all", ("all", Native.Diagnostic.Schedule.Switch.Test.All)), ("basic", ("basic", Native.Diagnostic.Schedule.Switch.Test.Basic)), ("complete", ("complete", Native.Diagnostic.Schedule.Switch.Test.Complete)), ("minimal", ("minimal", Native.Diagnostic.Schedule.Switch.Test.Minimal)), ("non-disruptive", ("non_disruptive", Native.Diagnostic.Schedule.Switch.Test.NonDisruptive)), ("per-port", ("per_port", Native.Diagnostic.Schedule.Switch.Test.PerPort))])
                        self._leafs = OrderedDict()

                        self.all = Native.Diagnostic.Schedule.Switch.Test.All()
                        self.all.parent = self
                        self._children_name_map["all"] = "all"

                        self.basic = Native.Diagnostic.Schedule.Switch.Test.Basic()
                        self.basic.parent = self
                        self._children_name_map["basic"] = "basic"

                        self.complete = Native.Diagnostic.Schedule.Switch.Test.Complete()
                        self.complete.parent = self
                        self._children_name_map["complete"] = "complete"

                        self.minimal = Native.Diagnostic.Schedule.Switch.Test.Minimal()
                        self.minimal.parent = self
                        self._children_name_map["minimal"] = "minimal"

                        self.non_disruptive = Native.Diagnostic.Schedule.Switch.Test.NonDisruptive()
                        self.non_disruptive.parent = self
                        self._children_name_map["non_disruptive"] = "non-disruptive"

                        self.per_port = Native.Diagnostic.Schedule.Switch.Test.PerPort()
                        self.per_port.parent = self
                        self._children_name_map["per_port"] = "per-port"

                        self.test_ids = YList(self)
                        self._segment_path = lambda: "test"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.Diagnostic.Schedule.Switch.Test, [], name, value)


                    class TestIds(Entity):
                        """
                        
                        
                        .. attribute:: id  (key)
                        
                        	Test ID list (e.g. 1,3\-6) or Test Name
                        	**type**\: str
                        
                        .. attribute:: daily
                        
                        	 Daily Schedule 
                        	**type**\:  :py:class:`Daily <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Diagnostic.Schedule.Switch.Test.TestIds.Daily>`
                        
                        .. attribute:: on
                        
                        	 Absolute Schedule 
                        	**type**\:  :py:class:`On <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Diagnostic.Schedule.Switch.Test.TestIds.On>`
                        
                        .. attribute:: weekly
                        
                        	Weekly schedule
                        	**type**\:  :py:class:`Weekly <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Diagnostic.Schedule.Switch.Test.TestIds.Weekly>`
                        
                        .. attribute:: port
                        
                        	Interface port selection
                        	**type**\:  :py:class:`Port <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Diagnostic.Schedule.Switch.Test.TestIds.Port>`
                        
                        

                        """

                        _prefix = 'ios-diag'
                        _revision = '2017-02-07'

                        def __init__(self):
                            super(Native.Diagnostic.Schedule.Switch.Test.TestIds, self).__init__()

                            self.yang_name = "test-ids"
                            self.yang_parent_name = "test"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['id']
                            self._child_classes = OrderedDict([("daily", ("daily", Native.Diagnostic.Schedule.Switch.Test.TestIds.Daily)), ("on", ("on", Native.Diagnostic.Schedule.Switch.Test.TestIds.On)), ("weekly", ("weekly", Native.Diagnostic.Schedule.Switch.Test.TestIds.Weekly)), ("port", ("port", Native.Diagnostic.Schedule.Switch.Test.TestIds.Port))])
                            self._leafs = OrderedDict([
                                ('id', (YLeaf(YType.str, 'id'), ['str'])),
                            ])
                            self.id = None

                            self.daily = Native.Diagnostic.Schedule.Switch.Test.TestIds.Daily()
                            self.daily.parent = self
                            self._children_name_map["daily"] = "daily"

                            self.on = Native.Diagnostic.Schedule.Switch.Test.TestIds.On()
                            self.on.parent = self
                            self._children_name_map["on"] = "on"

                            self.weekly = Native.Diagnostic.Schedule.Switch.Test.TestIds.Weekly()
                            self.weekly.parent = self
                            self._children_name_map["weekly"] = "weekly"

                            self.port = Native.Diagnostic.Schedule.Switch.Test.TestIds.Port()
                            self.port.parent = self
                            self._children_name_map["port"] = "port"
                            self._segment_path = lambda: "test-ids" + "[id='" + str(self.id) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Diagnostic.Schedule.Switch.Test.TestIds, ['id'], name, value)


                        class Daily(Entity):
                            """
                             Daily Schedule 
                            
                            .. attribute:: hh_mm
                            
                            	Begin Time hh\:mm
                            	**type**\: str
                            
                            	**pattern:** ([0\-1]?[0\-9]\|2[0\-4])\:([0\-5][0\-9])(\:[0\-5][0\-9])?
                            
                            

                            """

                            _prefix = 'ios-diag'
                            _revision = '2017-02-07'

                            def __init__(self):
                                super(Native.Diagnostic.Schedule.Switch.Test.TestIds.Daily, self).__init__()

                                self.yang_name = "daily"
                                self.yang_parent_name = "test-ids"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('hh_mm', (YLeaf(YType.str, 'hh-mm'), ['str'])),
                                ])
                                self.hh_mm = None
                                self._segment_path = lambda: "daily"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Diagnostic.Schedule.Switch.Test.TestIds.Daily, ['hh_mm'], name, value)


                        class On(Entity):
                            """
                             Absolute Schedule 
                            
                            .. attribute:: month
                            
                            	Enter month \-> Jan\|Feb\|Mar\|Apr\|May\|Jun\|Jul\|Aug\|Sep\|Oct\|Nov\|Dec
                            	**type**\:  :py:class:`MonthType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_types.MonthType>`
                            
                            .. attribute:: day_of_month
                            
                            	 <1\-31>  Day of month 
                            	**type**\: int
                            
                            	**range:** 1..31
                            
                            .. attribute:: year
                            
                            	Enter Year <1993\-2035>
                            	**type**\: int
                            
                            	**range:** 1993..2035
                            
                            .. attribute:: hh_mm
                            
                            	Begin Time hh\:mm
                            	**type**\: str
                            
                            	**pattern:** ([0\-1]?[0\-9]\|2[0\-4])\:([0\-5][0\-9])(\:[0\-5][0\-9])?
                            
                            

                            """

                            _prefix = 'ios-diag'
                            _revision = '2017-02-07'

                            def __init__(self):
                                super(Native.Diagnostic.Schedule.Switch.Test.TestIds.On, self).__init__()

                                self.yang_name = "on"
                                self.yang_parent_name = "test-ids"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('month', (YLeaf(YType.enumeration, 'month'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_types', 'MonthType', '')])),
                                    ('day_of_month', (YLeaf(YType.uint16, 'day-of-month'), ['int'])),
                                    ('year', (YLeaf(YType.uint16, 'Year'), ['int'])),
                                    ('hh_mm', (YLeaf(YType.str, 'hh-mm'), ['str'])),
                                ])
                                self.month = None
                                self.day_of_month = None
                                self.year = None
                                self.hh_mm = None
                                self._segment_path = lambda: "on"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Diagnostic.Schedule.Switch.Test.TestIds.On, ['month', 'day_of_month', 'year', 'hh_mm'], name, value)


                        class Weekly(Entity):
                            """
                            Weekly schedule
                            
                            .. attribute:: day
                            
                            	Enter Day of the week   Mon\|Tue\|Wed\|Thu\|Fri\|Sat\|Sun
                            	**type**\:  :py:class:`WeekdayType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_types.WeekdayType>`
                            
                            .. attribute:: hh_mm
                            
                            	Begin Time hh\:mm
                            	**type**\: str
                            
                            	**pattern:** ([0\-1]?[0\-9]\|2[0\-4])\:([0\-5][0\-9])(\:[0\-5][0\-9])?
                            
                            

                            """

                            _prefix = 'ios-diag'
                            _revision = '2017-02-07'

                            def __init__(self):
                                super(Native.Diagnostic.Schedule.Switch.Test.TestIds.Weekly, self).__init__()

                                self.yang_name = "weekly"
                                self.yang_parent_name = "test-ids"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('day', (YLeaf(YType.enumeration, 'day'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_types', 'WeekdayType', '')])),
                                    ('hh_mm', (YLeaf(YType.str, 'hh-mm'), ['str'])),
                                ])
                                self.day = None
                                self.hh_mm = None
                                self._segment_path = lambda: "weekly"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Diagnostic.Schedule.Switch.Test.TestIds.Weekly, ['day', 'hh_mm'], name, value)


                        class Port(Entity):
                            """
                            Interface port selection
                            
                            .. attribute:: interface_port_number
                            
                            	Interface port number
                            	**type**\: list of  		 :py:class:`InterfacePortNumber <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Diagnostic.Schedule.Switch.Test.TestIds.Port.InterfacePortNumber>`
                            
                            .. attribute:: port_number_list
                            
                            	Port number list (e.g. 2,4\-7)
                            	**type**\: list of  		 :py:class:`PortNumberList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Diagnostic.Schedule.Switch.Test.TestIds.Port.PortNumberList>`
                            
                            .. attribute:: all
                            
                            	Select all ports
                            	**type**\:  :py:class:`All <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Diagnostic.Schedule.Switch.Test.TestIds.Port.All>`
                            
                            

                            """

                            _prefix = 'ios-diag'
                            _revision = '2017-02-07'

                            def __init__(self):
                                super(Native.Diagnostic.Schedule.Switch.Test.TestIds.Port, self).__init__()

                                self.yang_name = "port"
                                self.yang_parent_name = "test-ids"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("interface-port-number", ("interface_port_number", Native.Diagnostic.Schedule.Switch.Test.TestIds.Port.InterfacePortNumber)), ("port-number-list", ("port_number_list", Native.Diagnostic.Schedule.Switch.Test.TestIds.Port.PortNumberList)), ("all", ("all", Native.Diagnostic.Schedule.Switch.Test.TestIds.Port.All))])
                                self._leafs = OrderedDict()

                                self.all = Native.Diagnostic.Schedule.Switch.Test.TestIds.Port.All()
                                self.all.parent = self
                                self._children_name_map["all"] = "all"

                                self.interface_port_number = YList(self)
                                self.port_number_list = YList(self)
                                self._segment_path = lambda: "port"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Diagnostic.Schedule.Switch.Test.TestIds.Port, [], name, value)


                            class InterfacePortNumber(Entity):
                                """
                                Interface port number
                                
                                .. attribute:: number  (key)
                                
                                	
                                	**type**\: int
                                
                                	**range:** 1..32
                                
                                .. attribute:: daily
                                
                                	 Daily Schedule 
                                	**type**\:  :py:class:`Daily <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Diagnostic.Schedule.Switch.Test.TestIds.Port.InterfacePortNumber.Daily>`
                                
                                .. attribute:: on
                                
                                	 Absolute Schedule 
                                	**type**\:  :py:class:`On <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Diagnostic.Schedule.Switch.Test.TestIds.Port.InterfacePortNumber.On>`
                                
                                .. attribute:: weekly
                                
                                	Weekly schedule
                                	**type**\:  :py:class:`Weekly <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Diagnostic.Schedule.Switch.Test.TestIds.Port.InterfacePortNumber.Weekly>`
                                
                                

                                """

                                _prefix = 'ios-diag'
                                _revision = '2017-02-07'

                                def __init__(self):
                                    super(Native.Diagnostic.Schedule.Switch.Test.TestIds.Port.InterfacePortNumber, self).__init__()

                                    self.yang_name = "interface-port-number"
                                    self.yang_parent_name = "port"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = ['number']
                                    self._child_classes = OrderedDict([("daily", ("daily", Native.Diagnostic.Schedule.Switch.Test.TestIds.Port.InterfacePortNumber.Daily)), ("on", ("on", Native.Diagnostic.Schedule.Switch.Test.TestIds.Port.InterfacePortNumber.On)), ("weekly", ("weekly", Native.Diagnostic.Schedule.Switch.Test.TestIds.Port.InterfacePortNumber.Weekly))])
                                    self._leafs = OrderedDict([
                                        ('number', (YLeaf(YType.uint8, 'number'), ['int'])),
                                    ])
                                    self.number = None

                                    self.daily = Native.Diagnostic.Schedule.Switch.Test.TestIds.Port.InterfacePortNumber.Daily()
                                    self.daily.parent = self
                                    self._children_name_map["daily"] = "daily"

                                    self.on = Native.Diagnostic.Schedule.Switch.Test.TestIds.Port.InterfacePortNumber.On()
                                    self.on.parent = self
                                    self._children_name_map["on"] = "on"

                                    self.weekly = Native.Diagnostic.Schedule.Switch.Test.TestIds.Port.InterfacePortNumber.Weekly()
                                    self.weekly.parent = self
                                    self._children_name_map["weekly"] = "weekly"
                                    self._segment_path = lambda: "interface-port-number" + "[number='" + str(self.number) + "']"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Diagnostic.Schedule.Switch.Test.TestIds.Port.InterfacePortNumber, ['number'], name, value)


                                class Daily(Entity):
                                    """
                                     Daily Schedule 
                                    
                                    .. attribute:: hh_mm
                                    
                                    	Begin Time hh\:mm
                                    	**type**\: str
                                    
                                    	**pattern:** ([0\-1]?[0\-9]\|2[0\-4])\:([0\-5][0\-9])(\:[0\-5][0\-9])?
                                    
                                    

                                    """

                                    _prefix = 'ios-diag'
                                    _revision = '2017-02-07'

                                    def __init__(self):
                                        super(Native.Diagnostic.Schedule.Switch.Test.TestIds.Port.InterfacePortNumber.Daily, self).__init__()

                                        self.yang_name = "daily"
                                        self.yang_parent_name = "interface-port-number"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('hh_mm', (YLeaf(YType.str, 'hh-mm'), ['str'])),
                                        ])
                                        self.hh_mm = None
                                        self._segment_path = lambda: "daily"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Diagnostic.Schedule.Switch.Test.TestIds.Port.InterfacePortNumber.Daily, ['hh_mm'], name, value)


                                class On(Entity):
                                    """
                                     Absolute Schedule 
                                    
                                    .. attribute:: month
                                    
                                    	Enter month \-> Jan\|Feb\|Mar\|Apr\|May\|Jun\|Jul\|Aug\|Sep\|Oct\|Nov\|Dec
                                    	**type**\:  :py:class:`MonthType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_types.MonthType>`
                                    
                                    .. attribute:: day_of_month
                                    
                                    	 <1\-31>  Day of month 
                                    	**type**\: int
                                    
                                    	**range:** 1..31
                                    
                                    .. attribute:: year
                                    
                                    	Enter Year <1993\-2035>
                                    	**type**\: int
                                    
                                    	**range:** 1993..2035
                                    
                                    .. attribute:: hh_mm
                                    
                                    	Begin Time hh\:mm
                                    	**type**\: str
                                    
                                    	**pattern:** ([0\-1]?[0\-9]\|2[0\-4])\:([0\-5][0\-9])(\:[0\-5][0\-9])?
                                    
                                    

                                    """

                                    _prefix = 'ios-diag'
                                    _revision = '2017-02-07'

                                    def __init__(self):
                                        super(Native.Diagnostic.Schedule.Switch.Test.TestIds.Port.InterfacePortNumber.On, self).__init__()

                                        self.yang_name = "on"
                                        self.yang_parent_name = "interface-port-number"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('month', (YLeaf(YType.enumeration, 'month'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_types', 'MonthType', '')])),
                                            ('day_of_month', (YLeaf(YType.uint16, 'day-of-month'), ['int'])),
                                            ('year', (YLeaf(YType.uint16, 'Year'), ['int'])),
                                            ('hh_mm', (YLeaf(YType.str, 'hh-mm'), ['str'])),
                                        ])
                                        self.month = None
                                        self.day_of_month = None
                                        self.year = None
                                        self.hh_mm = None
                                        self._segment_path = lambda: "on"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Diagnostic.Schedule.Switch.Test.TestIds.Port.InterfacePortNumber.On, ['month', 'day_of_month', 'year', 'hh_mm'], name, value)


                                class Weekly(Entity):
                                    """
                                    Weekly schedule
                                    
                                    .. attribute:: day
                                    
                                    	Enter Day of the week   Mon\|Tue\|Wed\|Thu\|Fri\|Sat\|Sun
                                    	**type**\:  :py:class:`WeekdayType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_types.WeekdayType>`
                                    
                                    .. attribute:: hh_mm
                                    
                                    	Begin Time hh\:mm
                                    	**type**\: str
                                    
                                    	**pattern:** ([0\-1]?[0\-9]\|2[0\-4])\:([0\-5][0\-9])(\:[0\-5][0\-9])?
                                    
                                    

                                    """

                                    _prefix = 'ios-diag'
                                    _revision = '2017-02-07'

                                    def __init__(self):
                                        super(Native.Diagnostic.Schedule.Switch.Test.TestIds.Port.InterfacePortNumber.Weekly, self).__init__()

                                        self.yang_name = "weekly"
                                        self.yang_parent_name = "interface-port-number"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('day', (YLeaf(YType.enumeration, 'day'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_types', 'WeekdayType', '')])),
                                            ('hh_mm', (YLeaf(YType.str, 'hh-mm'), ['str'])),
                                        ])
                                        self.day = None
                                        self.hh_mm = None
                                        self._segment_path = lambda: "weekly"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Diagnostic.Schedule.Switch.Test.TestIds.Port.InterfacePortNumber.Weekly, ['day', 'hh_mm'], name, value)


                            class PortNumberList(Entity):
                                """
                                Port number list (e.g. 2,4\-7)
                                
                                .. attribute:: number_list  (key)
                                
                                	Port number list (e.g. 2,4\-7)
                                	**type**\: str
                                
                                .. attribute:: daily
                                
                                	 Daily Schedule 
                                	**type**\:  :py:class:`Daily <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Diagnostic.Schedule.Switch.Test.TestIds.Port.PortNumberList.Daily>`
                                
                                .. attribute:: on
                                
                                	 Absolute Schedule 
                                	**type**\:  :py:class:`On <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Diagnostic.Schedule.Switch.Test.TestIds.Port.PortNumberList.On>`
                                
                                .. attribute:: weekly
                                
                                	Weekly schedule
                                	**type**\:  :py:class:`Weekly <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Diagnostic.Schedule.Switch.Test.TestIds.Port.PortNumberList.Weekly>`
                                
                                

                                """

                                _prefix = 'ios-diag'
                                _revision = '2017-02-07'

                                def __init__(self):
                                    super(Native.Diagnostic.Schedule.Switch.Test.TestIds.Port.PortNumberList, self).__init__()

                                    self.yang_name = "port-number-list"
                                    self.yang_parent_name = "port"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = ['number_list']
                                    self._child_classes = OrderedDict([("daily", ("daily", Native.Diagnostic.Schedule.Switch.Test.TestIds.Port.PortNumberList.Daily)), ("on", ("on", Native.Diagnostic.Schedule.Switch.Test.TestIds.Port.PortNumberList.On)), ("weekly", ("weekly", Native.Diagnostic.Schedule.Switch.Test.TestIds.Port.PortNumberList.Weekly))])
                                    self._leafs = OrderedDict([
                                        ('number_list', (YLeaf(YType.str, 'number-list'), ['str'])),
                                    ])
                                    self.number_list = None

                                    self.daily = Native.Diagnostic.Schedule.Switch.Test.TestIds.Port.PortNumberList.Daily()
                                    self.daily.parent = self
                                    self._children_name_map["daily"] = "daily"

                                    self.on = Native.Diagnostic.Schedule.Switch.Test.TestIds.Port.PortNumberList.On()
                                    self.on.parent = self
                                    self._children_name_map["on"] = "on"

                                    self.weekly = Native.Diagnostic.Schedule.Switch.Test.TestIds.Port.PortNumberList.Weekly()
                                    self.weekly.parent = self
                                    self._children_name_map["weekly"] = "weekly"
                                    self._segment_path = lambda: "port-number-list" + "[number-list='" + str(self.number_list) + "']"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Diagnostic.Schedule.Switch.Test.TestIds.Port.PortNumberList, ['number_list'], name, value)


                                class Daily(Entity):
                                    """
                                     Daily Schedule 
                                    
                                    .. attribute:: hh_mm
                                    
                                    	Begin Time hh\:mm
                                    	**type**\: str
                                    
                                    	**pattern:** ([0\-1]?[0\-9]\|2[0\-4])\:([0\-5][0\-9])(\:[0\-5][0\-9])?
                                    
                                    

                                    """

                                    _prefix = 'ios-diag'
                                    _revision = '2017-02-07'

                                    def __init__(self):
                                        super(Native.Diagnostic.Schedule.Switch.Test.TestIds.Port.PortNumberList.Daily, self).__init__()

                                        self.yang_name = "daily"
                                        self.yang_parent_name = "port-number-list"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('hh_mm', (YLeaf(YType.str, 'hh-mm'), ['str'])),
                                        ])
                                        self.hh_mm = None
                                        self._segment_path = lambda: "daily"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Diagnostic.Schedule.Switch.Test.TestIds.Port.PortNumberList.Daily, ['hh_mm'], name, value)


                                class On(Entity):
                                    """
                                     Absolute Schedule 
                                    
                                    .. attribute:: month
                                    
                                    	Enter month \-> Jan\|Feb\|Mar\|Apr\|May\|Jun\|Jul\|Aug\|Sep\|Oct\|Nov\|Dec
                                    	**type**\:  :py:class:`MonthType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_types.MonthType>`
                                    
                                    .. attribute:: day_of_month
                                    
                                    	 <1\-31>  Day of month 
                                    	**type**\: int
                                    
                                    	**range:** 1..31
                                    
                                    .. attribute:: year
                                    
                                    	Enter Year <1993\-2035>
                                    	**type**\: int
                                    
                                    	**range:** 1993..2035
                                    
                                    .. attribute:: hh_mm
                                    
                                    	Begin Time hh\:mm
                                    	**type**\: str
                                    
                                    	**pattern:** ([0\-1]?[0\-9]\|2[0\-4])\:([0\-5][0\-9])(\:[0\-5][0\-9])?
                                    
                                    

                                    """

                                    _prefix = 'ios-diag'
                                    _revision = '2017-02-07'

                                    def __init__(self):
                                        super(Native.Diagnostic.Schedule.Switch.Test.TestIds.Port.PortNumberList.On, self).__init__()

                                        self.yang_name = "on"
                                        self.yang_parent_name = "port-number-list"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('month', (YLeaf(YType.enumeration, 'month'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_types', 'MonthType', '')])),
                                            ('day_of_month', (YLeaf(YType.uint16, 'day-of-month'), ['int'])),
                                            ('year', (YLeaf(YType.uint16, 'Year'), ['int'])),
                                            ('hh_mm', (YLeaf(YType.str, 'hh-mm'), ['str'])),
                                        ])
                                        self.month = None
                                        self.day_of_month = None
                                        self.year = None
                                        self.hh_mm = None
                                        self._segment_path = lambda: "on"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Diagnostic.Schedule.Switch.Test.TestIds.Port.PortNumberList.On, ['month', 'day_of_month', 'year', 'hh_mm'], name, value)


                                class Weekly(Entity):
                                    """
                                    Weekly schedule
                                    
                                    .. attribute:: day
                                    
                                    	Enter Day of the week   Mon\|Tue\|Wed\|Thu\|Fri\|Sat\|Sun
                                    	**type**\:  :py:class:`WeekdayType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_types.WeekdayType>`
                                    
                                    .. attribute:: hh_mm
                                    
                                    	Begin Time hh\:mm
                                    	**type**\: str
                                    
                                    	**pattern:** ([0\-1]?[0\-9]\|2[0\-4])\:([0\-5][0\-9])(\:[0\-5][0\-9])?
                                    
                                    

                                    """

                                    _prefix = 'ios-diag'
                                    _revision = '2017-02-07'

                                    def __init__(self):
                                        super(Native.Diagnostic.Schedule.Switch.Test.TestIds.Port.PortNumberList.Weekly, self).__init__()

                                        self.yang_name = "weekly"
                                        self.yang_parent_name = "port-number-list"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('day', (YLeaf(YType.enumeration, 'day'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_types', 'WeekdayType', '')])),
                                            ('hh_mm', (YLeaf(YType.str, 'hh-mm'), ['str'])),
                                        ])
                                        self.day = None
                                        self.hh_mm = None
                                        self._segment_path = lambda: "weekly"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Diagnostic.Schedule.Switch.Test.TestIds.Port.PortNumberList.Weekly, ['day', 'hh_mm'], name, value)


                            class All(Entity):
                                """
                                Select all ports
                                
                                .. attribute:: daily
                                
                                	 Daily Schedule 
                                	**type**\:  :py:class:`Daily <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Diagnostic.Schedule.Switch.Test.TestIds.Port.All.Daily>`
                                
                                .. attribute:: on
                                
                                	 Absolute Schedule 
                                	**type**\:  :py:class:`On <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Diagnostic.Schedule.Switch.Test.TestIds.Port.All.On>`
                                
                                .. attribute:: weekly
                                
                                	Weekly schedule
                                	**type**\:  :py:class:`Weekly <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Diagnostic.Schedule.Switch.Test.TestIds.Port.All.Weekly>`
                                
                                

                                """

                                _prefix = 'ios-diag'
                                _revision = '2017-02-07'

                                def __init__(self):
                                    super(Native.Diagnostic.Schedule.Switch.Test.TestIds.Port.All, self).__init__()

                                    self.yang_name = "all"
                                    self.yang_parent_name = "port"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("daily", ("daily", Native.Diagnostic.Schedule.Switch.Test.TestIds.Port.All.Daily)), ("on", ("on", Native.Diagnostic.Schedule.Switch.Test.TestIds.Port.All.On)), ("weekly", ("weekly", Native.Diagnostic.Schedule.Switch.Test.TestIds.Port.All.Weekly))])
                                    self._leafs = OrderedDict()

                                    self.daily = Native.Diagnostic.Schedule.Switch.Test.TestIds.Port.All.Daily()
                                    self.daily.parent = self
                                    self._children_name_map["daily"] = "daily"

                                    self.on = Native.Diagnostic.Schedule.Switch.Test.TestIds.Port.All.On()
                                    self.on.parent = self
                                    self._children_name_map["on"] = "on"

                                    self.weekly = Native.Diagnostic.Schedule.Switch.Test.TestIds.Port.All.Weekly()
                                    self.weekly.parent = self
                                    self._children_name_map["weekly"] = "weekly"
                                    self._segment_path = lambda: "all"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Diagnostic.Schedule.Switch.Test.TestIds.Port.All, [], name, value)


                                class Daily(Entity):
                                    """
                                     Daily Schedule 
                                    
                                    .. attribute:: hh_mm
                                    
                                    	Begin Time hh\:mm
                                    	**type**\: str
                                    
                                    	**pattern:** ([0\-1]?[0\-9]\|2[0\-4])\:([0\-5][0\-9])(\:[0\-5][0\-9])?
                                    
                                    

                                    """

                                    _prefix = 'ios-diag'
                                    _revision = '2017-02-07'

                                    def __init__(self):
                                        super(Native.Diagnostic.Schedule.Switch.Test.TestIds.Port.All.Daily, self).__init__()

                                        self.yang_name = "daily"
                                        self.yang_parent_name = "all"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('hh_mm', (YLeaf(YType.str, 'hh-mm'), ['str'])),
                                        ])
                                        self.hh_mm = None
                                        self._segment_path = lambda: "daily"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Diagnostic.Schedule.Switch.Test.TestIds.Port.All.Daily, ['hh_mm'], name, value)


                                class On(Entity):
                                    """
                                     Absolute Schedule 
                                    
                                    .. attribute:: month
                                    
                                    	Enter month \-> Jan\|Feb\|Mar\|Apr\|May\|Jun\|Jul\|Aug\|Sep\|Oct\|Nov\|Dec
                                    	**type**\:  :py:class:`MonthType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_types.MonthType>`
                                    
                                    .. attribute:: day_of_month
                                    
                                    	 <1\-31>  Day of month 
                                    	**type**\: int
                                    
                                    	**range:** 1..31
                                    
                                    .. attribute:: year
                                    
                                    	Enter Year <1993\-2035>
                                    	**type**\: int
                                    
                                    	**range:** 1993..2035
                                    
                                    .. attribute:: hh_mm
                                    
                                    	Begin Time hh\:mm
                                    	**type**\: str
                                    
                                    	**pattern:** ([0\-1]?[0\-9]\|2[0\-4])\:([0\-5][0\-9])(\:[0\-5][0\-9])?
                                    
                                    

                                    """

                                    _prefix = 'ios-diag'
                                    _revision = '2017-02-07'

                                    def __init__(self):
                                        super(Native.Diagnostic.Schedule.Switch.Test.TestIds.Port.All.On, self).__init__()

                                        self.yang_name = "on"
                                        self.yang_parent_name = "all"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('month', (YLeaf(YType.enumeration, 'month'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_types', 'MonthType', '')])),
                                            ('day_of_month', (YLeaf(YType.uint16, 'day-of-month'), ['int'])),
                                            ('year', (YLeaf(YType.uint16, 'Year'), ['int'])),
                                            ('hh_mm', (YLeaf(YType.str, 'hh-mm'), ['str'])),
                                        ])
                                        self.month = None
                                        self.day_of_month = None
                                        self.year = None
                                        self.hh_mm = None
                                        self._segment_path = lambda: "on"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Diagnostic.Schedule.Switch.Test.TestIds.Port.All.On, ['month', 'day_of_month', 'year', 'hh_mm'], name, value)


                                class Weekly(Entity):
                                    """
                                    Weekly schedule
                                    
                                    .. attribute:: day
                                    
                                    	Enter Day of the week   Mon\|Tue\|Wed\|Thu\|Fri\|Sat\|Sun
                                    	**type**\:  :py:class:`WeekdayType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_types.WeekdayType>`
                                    
                                    .. attribute:: hh_mm
                                    
                                    	Begin Time hh\:mm
                                    	**type**\: str
                                    
                                    	**pattern:** ([0\-1]?[0\-9]\|2[0\-4])\:([0\-5][0\-9])(\:[0\-5][0\-9])?
                                    
                                    

                                    """

                                    _prefix = 'ios-diag'
                                    _revision = '2017-02-07'

                                    def __init__(self):
                                        super(Native.Diagnostic.Schedule.Switch.Test.TestIds.Port.All.Weekly, self).__init__()

                                        self.yang_name = "weekly"
                                        self.yang_parent_name = "all"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('day', (YLeaf(YType.enumeration, 'day'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_types', 'WeekdayType', '')])),
                                            ('hh_mm', (YLeaf(YType.str, 'hh-mm'), ['str'])),
                                        ])
                                        self.day = None
                                        self.hh_mm = None
                                        self._segment_path = lambda: "weekly"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Diagnostic.Schedule.Switch.Test.TestIds.Port.All.Weekly, ['day', 'hh_mm'], name, value)


                    class All(Entity):
                        """
                        Select all test ID 
                        
                        .. attribute:: daily
                        
                        	 Daily Schedule 
                        	**type**\:  :py:class:`Daily <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Diagnostic.Schedule.Switch.Test.All.Daily>`
                        
                        .. attribute:: on
                        
                        	 Absolute Schedule 
                        	**type**\:  :py:class:`On <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Diagnostic.Schedule.Switch.Test.All.On>`
                        
                        .. attribute:: weekly
                        
                        	Weekly schedule
                        	**type**\:  :py:class:`Weekly <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Diagnostic.Schedule.Switch.Test.All.Weekly>`
                        
                        .. attribute:: port
                        
                        	Interface port selection
                        	**type**\:  :py:class:`Port <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Diagnostic.Schedule.Switch.Test.All.Port>`
                        
                        

                        """

                        _prefix = 'ios-diag'
                        _revision = '2017-02-07'

                        def __init__(self):
                            super(Native.Diagnostic.Schedule.Switch.Test.All, self).__init__()

                            self.yang_name = "all"
                            self.yang_parent_name = "test"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("daily", ("daily", Native.Diagnostic.Schedule.Switch.Test.All.Daily)), ("on", ("on", Native.Diagnostic.Schedule.Switch.Test.All.On)), ("weekly", ("weekly", Native.Diagnostic.Schedule.Switch.Test.All.Weekly)), ("port", ("port", Native.Diagnostic.Schedule.Switch.Test.All.Port))])
                            self._leafs = OrderedDict()

                            self.daily = Native.Diagnostic.Schedule.Switch.Test.All.Daily()
                            self.daily.parent = self
                            self._children_name_map["daily"] = "daily"

                            self.on = Native.Diagnostic.Schedule.Switch.Test.All.On()
                            self.on.parent = self
                            self._children_name_map["on"] = "on"

                            self.weekly = Native.Diagnostic.Schedule.Switch.Test.All.Weekly()
                            self.weekly.parent = self
                            self._children_name_map["weekly"] = "weekly"

                            self.port = Native.Diagnostic.Schedule.Switch.Test.All.Port()
                            self.port.parent = self
                            self._children_name_map["port"] = "port"
                            self._segment_path = lambda: "all"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Diagnostic.Schedule.Switch.Test.All, [], name, value)


                        class Daily(Entity):
                            """
                             Daily Schedule 
                            
                            .. attribute:: hh_mm
                            
                            	Begin Time hh\:mm
                            	**type**\: str
                            
                            	**pattern:** ([0\-1]?[0\-9]\|2[0\-4])\:([0\-5][0\-9])(\:[0\-5][0\-9])?
                            
                            

                            """

                            _prefix = 'ios-diag'
                            _revision = '2017-02-07'

                            def __init__(self):
                                super(Native.Diagnostic.Schedule.Switch.Test.All.Daily, self).__init__()

                                self.yang_name = "daily"
                                self.yang_parent_name = "all"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('hh_mm', (YLeaf(YType.str, 'hh-mm'), ['str'])),
                                ])
                                self.hh_mm = None
                                self._segment_path = lambda: "daily"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Diagnostic.Schedule.Switch.Test.All.Daily, ['hh_mm'], name, value)


                        class On(Entity):
                            """
                             Absolute Schedule 
                            
                            .. attribute:: month
                            
                            	Enter month \-> Jan\|Feb\|Mar\|Apr\|May\|Jun\|Jul\|Aug\|Sep\|Oct\|Nov\|Dec
                            	**type**\:  :py:class:`MonthType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_types.MonthType>`
                            
                            .. attribute:: day_of_month
                            
                            	 <1\-31>  Day of month 
                            	**type**\: int
                            
                            	**range:** 1..31
                            
                            .. attribute:: year
                            
                            	Enter Year <1993\-2035>
                            	**type**\: int
                            
                            	**range:** 1993..2035
                            
                            .. attribute:: hh_mm
                            
                            	Begin Time hh\:mm
                            	**type**\: str
                            
                            	**pattern:** ([0\-1]?[0\-9]\|2[0\-4])\:([0\-5][0\-9])(\:[0\-5][0\-9])?
                            
                            

                            """

                            _prefix = 'ios-diag'
                            _revision = '2017-02-07'

                            def __init__(self):
                                super(Native.Diagnostic.Schedule.Switch.Test.All.On, self).__init__()

                                self.yang_name = "on"
                                self.yang_parent_name = "all"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('month', (YLeaf(YType.enumeration, 'month'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_types', 'MonthType', '')])),
                                    ('day_of_month', (YLeaf(YType.uint16, 'day-of-month'), ['int'])),
                                    ('year', (YLeaf(YType.uint16, 'Year'), ['int'])),
                                    ('hh_mm', (YLeaf(YType.str, 'hh-mm'), ['str'])),
                                ])
                                self.month = None
                                self.day_of_month = None
                                self.year = None
                                self.hh_mm = None
                                self._segment_path = lambda: "on"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Diagnostic.Schedule.Switch.Test.All.On, ['month', 'day_of_month', 'year', 'hh_mm'], name, value)


                        class Weekly(Entity):
                            """
                            Weekly schedule
                            
                            .. attribute:: day
                            
                            	Enter Day of the week   Mon\|Tue\|Wed\|Thu\|Fri\|Sat\|Sun
                            	**type**\:  :py:class:`WeekdayType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_types.WeekdayType>`
                            
                            .. attribute:: hh_mm
                            
                            	Begin Time hh\:mm
                            	**type**\: str
                            
                            	**pattern:** ([0\-1]?[0\-9]\|2[0\-4])\:([0\-5][0\-9])(\:[0\-5][0\-9])?
                            
                            

                            """

                            _prefix = 'ios-diag'
                            _revision = '2017-02-07'

                            def __init__(self):
                                super(Native.Diagnostic.Schedule.Switch.Test.All.Weekly, self).__init__()

                                self.yang_name = "weekly"
                                self.yang_parent_name = "all"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('day', (YLeaf(YType.enumeration, 'day'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_types', 'WeekdayType', '')])),
                                    ('hh_mm', (YLeaf(YType.str, 'hh-mm'), ['str'])),
                                ])
                                self.day = None
                                self.hh_mm = None
                                self._segment_path = lambda: "weekly"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Diagnostic.Schedule.Switch.Test.All.Weekly, ['day', 'hh_mm'], name, value)


                        class Port(Entity):
                            """
                            Interface port selection
                            
                            .. attribute:: interface_port_number
                            
                            	Interface port number
                            	**type**\: list of  		 :py:class:`InterfacePortNumber <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Diagnostic.Schedule.Switch.Test.All.Port.InterfacePortNumber>`
                            
                            .. attribute:: port_number_list
                            
                            	Port number list (e.g. 2,4\-7)
                            	**type**\: list of  		 :py:class:`PortNumberList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Diagnostic.Schedule.Switch.Test.All.Port.PortNumberList>`
                            
                            .. attribute:: all
                            
                            	Select all ports
                            	**type**\:  :py:class:`All_ <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Diagnostic.Schedule.Switch.Test.All.Port.All_>`
                            
                            

                            """

                            _prefix = 'ios-diag'
                            _revision = '2017-02-07'

                            def __init__(self):
                                super(Native.Diagnostic.Schedule.Switch.Test.All.Port, self).__init__()

                                self.yang_name = "port"
                                self.yang_parent_name = "all"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("interface-port-number", ("interface_port_number", Native.Diagnostic.Schedule.Switch.Test.All.Port.InterfacePortNumber)), ("port-number-list", ("port_number_list", Native.Diagnostic.Schedule.Switch.Test.All.Port.PortNumberList)), ("all", ("all", Native.Diagnostic.Schedule.Switch.Test.All.Port.All_))])
                                self._leafs = OrderedDict()

                                self.all = Native.Diagnostic.Schedule.Switch.Test.All.Port.All_()
                                self.all.parent = self
                                self._children_name_map["all"] = "all"

                                self.interface_port_number = YList(self)
                                self.port_number_list = YList(self)
                                self._segment_path = lambda: "port"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Diagnostic.Schedule.Switch.Test.All.Port, [], name, value)


                            class InterfacePortNumber(Entity):
                                """
                                Interface port number
                                
                                .. attribute:: number  (key)
                                
                                	
                                	**type**\: int
                                
                                	**range:** 1..32
                                
                                .. attribute:: daily
                                
                                	 Daily Schedule 
                                	**type**\:  :py:class:`Daily <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Diagnostic.Schedule.Switch.Test.All.Port.InterfacePortNumber.Daily>`
                                
                                .. attribute:: on
                                
                                	 Absolute Schedule 
                                	**type**\:  :py:class:`On <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Diagnostic.Schedule.Switch.Test.All.Port.InterfacePortNumber.On>`
                                
                                .. attribute:: weekly
                                
                                	Weekly schedule
                                	**type**\:  :py:class:`Weekly <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Diagnostic.Schedule.Switch.Test.All.Port.InterfacePortNumber.Weekly>`
                                
                                

                                """

                                _prefix = 'ios-diag'
                                _revision = '2017-02-07'

                                def __init__(self):
                                    super(Native.Diagnostic.Schedule.Switch.Test.All.Port.InterfacePortNumber, self).__init__()

                                    self.yang_name = "interface-port-number"
                                    self.yang_parent_name = "port"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = ['number']
                                    self._child_classes = OrderedDict([("daily", ("daily", Native.Diagnostic.Schedule.Switch.Test.All.Port.InterfacePortNumber.Daily)), ("on", ("on", Native.Diagnostic.Schedule.Switch.Test.All.Port.InterfacePortNumber.On)), ("weekly", ("weekly", Native.Diagnostic.Schedule.Switch.Test.All.Port.InterfacePortNumber.Weekly))])
                                    self._leafs = OrderedDict([
                                        ('number', (YLeaf(YType.uint8, 'number'), ['int'])),
                                    ])
                                    self.number = None

                                    self.daily = Native.Diagnostic.Schedule.Switch.Test.All.Port.InterfacePortNumber.Daily()
                                    self.daily.parent = self
                                    self._children_name_map["daily"] = "daily"

                                    self.on = Native.Diagnostic.Schedule.Switch.Test.All.Port.InterfacePortNumber.On()
                                    self.on.parent = self
                                    self._children_name_map["on"] = "on"

                                    self.weekly = Native.Diagnostic.Schedule.Switch.Test.All.Port.InterfacePortNumber.Weekly()
                                    self.weekly.parent = self
                                    self._children_name_map["weekly"] = "weekly"
                                    self._segment_path = lambda: "interface-port-number" + "[number='" + str(self.number) + "']"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Diagnostic.Schedule.Switch.Test.All.Port.InterfacePortNumber, ['number'], name, value)


                                class Daily(Entity):
                                    """
                                     Daily Schedule 
                                    
                                    .. attribute:: hh_mm
                                    
                                    	Begin Time hh\:mm
                                    	**type**\: str
                                    
                                    	**pattern:** ([0\-1]?[0\-9]\|2[0\-4])\:([0\-5][0\-9])(\:[0\-5][0\-9])?
                                    
                                    

                                    """

                                    _prefix = 'ios-diag'
                                    _revision = '2017-02-07'

                                    def __init__(self):
                                        super(Native.Diagnostic.Schedule.Switch.Test.All.Port.InterfacePortNumber.Daily, self).__init__()

                                        self.yang_name = "daily"
                                        self.yang_parent_name = "interface-port-number"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('hh_mm', (YLeaf(YType.str, 'hh-mm'), ['str'])),
                                        ])
                                        self.hh_mm = None
                                        self._segment_path = lambda: "daily"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Diagnostic.Schedule.Switch.Test.All.Port.InterfacePortNumber.Daily, ['hh_mm'], name, value)


                                class On(Entity):
                                    """
                                     Absolute Schedule 
                                    
                                    .. attribute:: month
                                    
                                    	Enter month \-> Jan\|Feb\|Mar\|Apr\|May\|Jun\|Jul\|Aug\|Sep\|Oct\|Nov\|Dec
                                    	**type**\:  :py:class:`MonthType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_types.MonthType>`
                                    
                                    .. attribute:: day_of_month
                                    
                                    	 <1\-31>  Day of month 
                                    	**type**\: int
                                    
                                    	**range:** 1..31
                                    
                                    .. attribute:: year
                                    
                                    	Enter Year <1993\-2035>
                                    	**type**\: int
                                    
                                    	**range:** 1993..2035
                                    
                                    .. attribute:: hh_mm
                                    
                                    	Begin Time hh\:mm
                                    	**type**\: str
                                    
                                    	**pattern:** ([0\-1]?[0\-9]\|2[0\-4])\:([0\-5][0\-9])(\:[0\-5][0\-9])?
                                    
                                    

                                    """

                                    _prefix = 'ios-diag'
                                    _revision = '2017-02-07'

                                    def __init__(self):
                                        super(Native.Diagnostic.Schedule.Switch.Test.All.Port.InterfacePortNumber.On, self).__init__()

                                        self.yang_name = "on"
                                        self.yang_parent_name = "interface-port-number"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('month', (YLeaf(YType.enumeration, 'month'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_types', 'MonthType', '')])),
                                            ('day_of_month', (YLeaf(YType.uint16, 'day-of-month'), ['int'])),
                                            ('year', (YLeaf(YType.uint16, 'Year'), ['int'])),
                                            ('hh_mm', (YLeaf(YType.str, 'hh-mm'), ['str'])),
                                        ])
                                        self.month = None
                                        self.day_of_month = None
                                        self.year = None
                                        self.hh_mm = None
                                        self._segment_path = lambda: "on"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Diagnostic.Schedule.Switch.Test.All.Port.InterfacePortNumber.On, ['month', 'day_of_month', 'year', 'hh_mm'], name, value)


                                class Weekly(Entity):
                                    """
                                    Weekly schedule
                                    
                                    .. attribute:: day
                                    
                                    	Enter Day of the week   Mon\|Tue\|Wed\|Thu\|Fri\|Sat\|Sun
                                    	**type**\:  :py:class:`WeekdayType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_types.WeekdayType>`
                                    
                                    .. attribute:: hh_mm
                                    
                                    	Begin Time hh\:mm
                                    	**type**\: str
                                    
                                    	**pattern:** ([0\-1]?[0\-9]\|2[0\-4])\:([0\-5][0\-9])(\:[0\-5][0\-9])?
                                    
                                    

                                    """

                                    _prefix = 'ios-diag'
                                    _revision = '2017-02-07'

                                    def __init__(self):
                                        super(Native.Diagnostic.Schedule.Switch.Test.All.Port.InterfacePortNumber.Weekly, self).__init__()

                                        self.yang_name = "weekly"
                                        self.yang_parent_name = "interface-port-number"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('day', (YLeaf(YType.enumeration, 'day'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_types', 'WeekdayType', '')])),
                                            ('hh_mm', (YLeaf(YType.str, 'hh-mm'), ['str'])),
                                        ])
                                        self.day = None
                                        self.hh_mm = None
                                        self._segment_path = lambda: "weekly"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Diagnostic.Schedule.Switch.Test.All.Port.InterfacePortNumber.Weekly, ['day', 'hh_mm'], name, value)


                            class PortNumberList(Entity):
                                """
                                Port number list (e.g. 2,4\-7)
                                
                                .. attribute:: number_list  (key)
                                
                                	Port number list (e.g. 2,4\-7)
                                	**type**\: str
                                
                                .. attribute:: daily
                                
                                	 Daily Schedule 
                                	**type**\:  :py:class:`Daily <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Diagnostic.Schedule.Switch.Test.All.Port.PortNumberList.Daily>`
                                
                                .. attribute:: on
                                
                                	 Absolute Schedule 
                                	**type**\:  :py:class:`On <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Diagnostic.Schedule.Switch.Test.All.Port.PortNumberList.On>`
                                
                                .. attribute:: weekly
                                
                                	Weekly schedule
                                	**type**\:  :py:class:`Weekly <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Diagnostic.Schedule.Switch.Test.All.Port.PortNumberList.Weekly>`
                                
                                

                                """

                                _prefix = 'ios-diag'
                                _revision = '2017-02-07'

                                def __init__(self):
                                    super(Native.Diagnostic.Schedule.Switch.Test.All.Port.PortNumberList, self).__init__()

                                    self.yang_name = "port-number-list"
                                    self.yang_parent_name = "port"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = ['number_list']
                                    self._child_classes = OrderedDict([("daily", ("daily", Native.Diagnostic.Schedule.Switch.Test.All.Port.PortNumberList.Daily)), ("on", ("on", Native.Diagnostic.Schedule.Switch.Test.All.Port.PortNumberList.On)), ("weekly", ("weekly", Native.Diagnostic.Schedule.Switch.Test.All.Port.PortNumberList.Weekly))])
                                    self._leafs = OrderedDict([
                                        ('number_list', (YLeaf(YType.str, 'number-list'), ['str'])),
                                    ])
                                    self.number_list = None

                                    self.daily = Native.Diagnostic.Schedule.Switch.Test.All.Port.PortNumberList.Daily()
                                    self.daily.parent = self
                                    self._children_name_map["daily"] = "daily"

                                    self.on = Native.Diagnostic.Schedule.Switch.Test.All.Port.PortNumberList.On()
                                    self.on.parent = self
                                    self._children_name_map["on"] = "on"

                                    self.weekly = Native.Diagnostic.Schedule.Switch.Test.All.Port.PortNumberList.Weekly()
                                    self.weekly.parent = self
                                    self._children_name_map["weekly"] = "weekly"
                                    self._segment_path = lambda: "port-number-list" + "[number-list='" + str(self.number_list) + "']"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Diagnostic.Schedule.Switch.Test.All.Port.PortNumberList, ['number_list'], name, value)


                                class Daily(Entity):
                                    """
                                     Daily Schedule 
                                    
                                    .. attribute:: hh_mm
                                    
                                    	Begin Time hh\:mm
                                    	**type**\: str
                                    
                                    	**pattern:** ([0\-1]?[0\-9]\|2[0\-4])\:([0\-5][0\-9])(\:[0\-5][0\-9])?
                                    
                                    

                                    """

                                    _prefix = 'ios-diag'
                                    _revision = '2017-02-07'

                                    def __init__(self):
                                        super(Native.Diagnostic.Schedule.Switch.Test.All.Port.PortNumberList.Daily, self).__init__()

                                        self.yang_name = "daily"
                                        self.yang_parent_name = "port-number-list"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('hh_mm', (YLeaf(YType.str, 'hh-mm'), ['str'])),
                                        ])
                                        self.hh_mm = None
                                        self._segment_path = lambda: "daily"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Diagnostic.Schedule.Switch.Test.All.Port.PortNumberList.Daily, ['hh_mm'], name, value)


                                class On(Entity):
                                    """
                                     Absolute Schedule 
                                    
                                    .. attribute:: month
                                    
                                    	Enter month \-> Jan\|Feb\|Mar\|Apr\|May\|Jun\|Jul\|Aug\|Sep\|Oct\|Nov\|Dec
                                    	**type**\:  :py:class:`MonthType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_types.MonthType>`
                                    
                                    .. attribute:: day_of_month
                                    
                                    	 <1\-31>  Day of month 
                                    	**type**\: int
                                    
                                    	**range:** 1..31
                                    
                                    .. attribute:: year
                                    
                                    	Enter Year <1993\-2035>
                                    	**type**\: int
                                    
                                    	**range:** 1993..2035
                                    
                                    .. attribute:: hh_mm
                                    
                                    	Begin Time hh\:mm
                                    	**type**\: str
                                    
                                    	**pattern:** ([0\-1]?[0\-9]\|2[0\-4])\:([0\-5][0\-9])(\:[0\-5][0\-9])?
                                    
                                    

                                    """

                                    _prefix = 'ios-diag'
                                    _revision = '2017-02-07'

                                    def __init__(self):
                                        super(Native.Diagnostic.Schedule.Switch.Test.All.Port.PortNumberList.On, self).__init__()

                                        self.yang_name = "on"
                                        self.yang_parent_name = "port-number-list"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('month', (YLeaf(YType.enumeration, 'month'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_types', 'MonthType', '')])),
                                            ('day_of_month', (YLeaf(YType.uint16, 'day-of-month'), ['int'])),
                                            ('year', (YLeaf(YType.uint16, 'Year'), ['int'])),
                                            ('hh_mm', (YLeaf(YType.str, 'hh-mm'), ['str'])),
                                        ])
                                        self.month = None
                                        self.day_of_month = None
                                        self.year = None
                                        self.hh_mm = None
                                        self._segment_path = lambda: "on"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Diagnostic.Schedule.Switch.Test.All.Port.PortNumberList.On, ['month', 'day_of_month', 'year', 'hh_mm'], name, value)


                                class Weekly(Entity):
                                    """
                                    Weekly schedule
                                    
                                    .. attribute:: day
                                    
                                    	Enter Day of the week   Mon\|Tue\|Wed\|Thu\|Fri\|Sat\|Sun
                                    	**type**\:  :py:class:`WeekdayType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_types.WeekdayType>`
                                    
                                    .. attribute:: hh_mm
                                    
                                    	Begin Time hh\:mm
                                    	**type**\: str
                                    
                                    	**pattern:** ([0\-1]?[0\-9]\|2[0\-4])\:([0\-5][0\-9])(\:[0\-5][0\-9])?
                                    
                                    

                                    """

                                    _prefix = 'ios-diag'
                                    _revision = '2017-02-07'

                                    def __init__(self):
                                        super(Native.Diagnostic.Schedule.Switch.Test.All.Port.PortNumberList.Weekly, self).__init__()

                                        self.yang_name = "weekly"
                                        self.yang_parent_name = "port-number-list"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('day', (YLeaf(YType.enumeration, 'day'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_types', 'WeekdayType', '')])),
                                            ('hh_mm', (YLeaf(YType.str, 'hh-mm'), ['str'])),
                                        ])
                                        self.day = None
                                        self.hh_mm = None
                                        self._segment_path = lambda: "weekly"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Diagnostic.Schedule.Switch.Test.All.Port.PortNumberList.Weekly, ['day', 'hh_mm'], name, value)


                            class All_(Entity):
                                """
                                Select all ports
                                
                                .. attribute:: daily
                                
                                	 Daily Schedule 
                                	**type**\:  :py:class:`Daily <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Diagnostic.Schedule.Switch.Test.All.Port.All_.Daily>`
                                
                                .. attribute:: on
                                
                                	 Absolute Schedule 
                                	**type**\:  :py:class:`On <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Diagnostic.Schedule.Switch.Test.All.Port.All_.On>`
                                
                                .. attribute:: weekly
                                
                                	Weekly schedule
                                	**type**\:  :py:class:`Weekly <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Diagnostic.Schedule.Switch.Test.All.Port.All_.Weekly>`
                                
                                

                                """

                                _prefix = 'ios-diag'
                                _revision = '2017-02-07'

                                def __init__(self):
                                    super(Native.Diagnostic.Schedule.Switch.Test.All.Port.All_, self).__init__()

                                    self.yang_name = "all"
                                    self.yang_parent_name = "port"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("daily", ("daily", Native.Diagnostic.Schedule.Switch.Test.All.Port.All_.Daily)), ("on", ("on", Native.Diagnostic.Schedule.Switch.Test.All.Port.All_.On)), ("weekly", ("weekly", Native.Diagnostic.Schedule.Switch.Test.All.Port.All_.Weekly))])
                                    self._leafs = OrderedDict()

                                    self.daily = Native.Diagnostic.Schedule.Switch.Test.All.Port.All_.Daily()
                                    self.daily.parent = self
                                    self._children_name_map["daily"] = "daily"

                                    self.on = Native.Diagnostic.Schedule.Switch.Test.All.Port.All_.On()
                                    self.on.parent = self
                                    self._children_name_map["on"] = "on"

                                    self.weekly = Native.Diagnostic.Schedule.Switch.Test.All.Port.All_.Weekly()
                                    self.weekly.parent = self
                                    self._children_name_map["weekly"] = "weekly"
                                    self._segment_path = lambda: "all"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Diagnostic.Schedule.Switch.Test.All.Port.All_, [], name, value)


                                class Daily(Entity):
                                    """
                                     Daily Schedule 
                                    
                                    .. attribute:: hh_mm
                                    
                                    	Begin Time hh\:mm
                                    	**type**\: str
                                    
                                    	**pattern:** ([0\-1]?[0\-9]\|2[0\-4])\:([0\-5][0\-9])(\:[0\-5][0\-9])?
                                    
                                    

                                    """

                                    _prefix = 'ios-diag'
                                    _revision = '2017-02-07'

                                    def __init__(self):
                                        super(Native.Diagnostic.Schedule.Switch.Test.All.Port.All_.Daily, self).__init__()

                                        self.yang_name = "daily"
                                        self.yang_parent_name = "all"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('hh_mm', (YLeaf(YType.str, 'hh-mm'), ['str'])),
                                        ])
                                        self.hh_mm = None
                                        self._segment_path = lambda: "daily"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Diagnostic.Schedule.Switch.Test.All.Port.All_.Daily, ['hh_mm'], name, value)


                                class On(Entity):
                                    """
                                     Absolute Schedule 
                                    
                                    .. attribute:: month
                                    
                                    	Enter month \-> Jan\|Feb\|Mar\|Apr\|May\|Jun\|Jul\|Aug\|Sep\|Oct\|Nov\|Dec
                                    	**type**\:  :py:class:`MonthType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_types.MonthType>`
                                    
                                    .. attribute:: day_of_month
                                    
                                    	 <1\-31>  Day of month 
                                    	**type**\: int
                                    
                                    	**range:** 1..31
                                    
                                    .. attribute:: year
                                    
                                    	Enter Year <1993\-2035>
                                    	**type**\: int
                                    
                                    	**range:** 1993..2035
                                    
                                    .. attribute:: hh_mm
                                    
                                    	Begin Time hh\:mm
                                    	**type**\: str
                                    
                                    	**pattern:** ([0\-1]?[0\-9]\|2[0\-4])\:([0\-5][0\-9])(\:[0\-5][0\-9])?
                                    
                                    

                                    """

                                    _prefix = 'ios-diag'
                                    _revision = '2017-02-07'

                                    def __init__(self):
                                        super(Native.Diagnostic.Schedule.Switch.Test.All.Port.All_.On, self).__init__()

                                        self.yang_name = "on"
                                        self.yang_parent_name = "all"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('month', (YLeaf(YType.enumeration, 'month'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_types', 'MonthType', '')])),
                                            ('day_of_month', (YLeaf(YType.uint16, 'day-of-month'), ['int'])),
                                            ('year', (YLeaf(YType.uint16, 'Year'), ['int'])),
                                            ('hh_mm', (YLeaf(YType.str, 'hh-mm'), ['str'])),
                                        ])
                                        self.month = None
                                        self.day_of_month = None
                                        self.year = None
                                        self.hh_mm = None
                                        self._segment_path = lambda: "on"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Diagnostic.Schedule.Switch.Test.All.Port.All_.On, ['month', 'day_of_month', 'year', 'hh_mm'], name, value)


                                class Weekly(Entity):
                                    """
                                    Weekly schedule
                                    
                                    .. attribute:: day
                                    
                                    	Enter Day of the week   Mon\|Tue\|Wed\|Thu\|Fri\|Sat\|Sun
                                    	**type**\:  :py:class:`WeekdayType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_types.WeekdayType>`
                                    
                                    .. attribute:: hh_mm
                                    
                                    	Begin Time hh\:mm
                                    	**type**\: str
                                    
                                    	**pattern:** ([0\-1]?[0\-9]\|2[0\-4])\:([0\-5][0\-9])(\:[0\-5][0\-9])?
                                    
                                    

                                    """

                                    _prefix = 'ios-diag'
                                    _revision = '2017-02-07'

                                    def __init__(self):
                                        super(Native.Diagnostic.Schedule.Switch.Test.All.Port.All_.Weekly, self).__init__()

                                        self.yang_name = "weekly"
                                        self.yang_parent_name = "all"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('day', (YLeaf(YType.enumeration, 'day'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_types', 'WeekdayType', '')])),
                                            ('hh_mm', (YLeaf(YType.str, 'hh-mm'), ['str'])),
                                        ])
                                        self.day = None
                                        self.hh_mm = None
                                        self._segment_path = lambda: "weekly"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Diagnostic.Schedule.Switch.Test.All.Port.All_.Weekly, ['day', 'hh_mm'], name, value)


                    class Basic(Entity):
                        """
                        Select the Basic ondemand test suite [Attribute = B]
                        
                        .. attribute:: daily
                        
                        	 Daily Schedule 
                        	**type**\:  :py:class:`Daily <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Diagnostic.Schedule.Switch.Test.Basic.Daily>`
                        
                        .. attribute:: on
                        
                        	 Absolute Schedule 
                        	**type**\:  :py:class:`On <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Diagnostic.Schedule.Switch.Test.Basic.On>`
                        
                        .. attribute:: weekly
                        
                        	Weekly schedule
                        	**type**\:  :py:class:`Weekly <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Diagnostic.Schedule.Switch.Test.Basic.Weekly>`
                        
                        .. attribute:: port
                        
                        	Interface port selection
                        	**type**\:  :py:class:`Port <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Diagnostic.Schedule.Switch.Test.Basic.Port>`
                        
                        

                        """

                        _prefix = 'ios-diag'
                        _revision = '2017-02-07'

                        def __init__(self):
                            super(Native.Diagnostic.Schedule.Switch.Test.Basic, self).__init__()

                            self.yang_name = "basic"
                            self.yang_parent_name = "test"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("daily", ("daily", Native.Diagnostic.Schedule.Switch.Test.Basic.Daily)), ("on", ("on", Native.Diagnostic.Schedule.Switch.Test.Basic.On)), ("weekly", ("weekly", Native.Diagnostic.Schedule.Switch.Test.Basic.Weekly)), ("port", ("port", Native.Diagnostic.Schedule.Switch.Test.Basic.Port))])
                            self._leafs = OrderedDict()

                            self.daily = Native.Diagnostic.Schedule.Switch.Test.Basic.Daily()
                            self.daily.parent = self
                            self._children_name_map["daily"] = "daily"

                            self.on = Native.Diagnostic.Schedule.Switch.Test.Basic.On()
                            self.on.parent = self
                            self._children_name_map["on"] = "on"

                            self.weekly = Native.Diagnostic.Schedule.Switch.Test.Basic.Weekly()
                            self.weekly.parent = self
                            self._children_name_map["weekly"] = "weekly"

                            self.port = Native.Diagnostic.Schedule.Switch.Test.Basic.Port()
                            self.port.parent = self
                            self._children_name_map["port"] = "port"
                            self._segment_path = lambda: "basic"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Diagnostic.Schedule.Switch.Test.Basic, [], name, value)


                        class Daily(Entity):
                            """
                             Daily Schedule 
                            
                            .. attribute:: hh_mm
                            
                            	Begin Time hh\:mm
                            	**type**\: str
                            
                            	**pattern:** ([0\-1]?[0\-9]\|2[0\-4])\:([0\-5][0\-9])(\:[0\-5][0\-9])?
                            
                            

                            """

                            _prefix = 'ios-diag'
                            _revision = '2017-02-07'

                            def __init__(self):
                                super(Native.Diagnostic.Schedule.Switch.Test.Basic.Daily, self).__init__()

                                self.yang_name = "daily"
                                self.yang_parent_name = "basic"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('hh_mm', (YLeaf(YType.str, 'hh-mm'), ['str'])),
                                ])
                                self.hh_mm = None
                                self._segment_path = lambda: "daily"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Diagnostic.Schedule.Switch.Test.Basic.Daily, ['hh_mm'], name, value)


                        class On(Entity):
                            """
                             Absolute Schedule 
                            
                            .. attribute:: month
                            
                            	Enter month \-> Jan\|Feb\|Mar\|Apr\|May\|Jun\|Jul\|Aug\|Sep\|Oct\|Nov\|Dec
                            	**type**\:  :py:class:`MonthType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_types.MonthType>`
                            
                            .. attribute:: day_of_month
                            
                            	 <1\-31>  Day of month 
                            	**type**\: int
                            
                            	**range:** 1..31
                            
                            .. attribute:: year
                            
                            	Enter Year <1993\-2035>
                            	**type**\: int
                            
                            	**range:** 1993..2035
                            
                            .. attribute:: hh_mm
                            
                            	Begin Time hh\:mm
                            	**type**\: str
                            
                            	**pattern:** ([0\-1]?[0\-9]\|2[0\-4])\:([0\-5][0\-9])(\:[0\-5][0\-9])?
                            
                            

                            """

                            _prefix = 'ios-diag'
                            _revision = '2017-02-07'

                            def __init__(self):
                                super(Native.Diagnostic.Schedule.Switch.Test.Basic.On, self).__init__()

                                self.yang_name = "on"
                                self.yang_parent_name = "basic"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('month', (YLeaf(YType.enumeration, 'month'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_types', 'MonthType', '')])),
                                    ('day_of_month', (YLeaf(YType.uint16, 'day-of-month'), ['int'])),
                                    ('year', (YLeaf(YType.uint16, 'Year'), ['int'])),
                                    ('hh_mm', (YLeaf(YType.str, 'hh-mm'), ['str'])),
                                ])
                                self.month = None
                                self.day_of_month = None
                                self.year = None
                                self.hh_mm = None
                                self._segment_path = lambda: "on"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Diagnostic.Schedule.Switch.Test.Basic.On, ['month', 'day_of_month', 'year', 'hh_mm'], name, value)


                        class Weekly(Entity):
                            """
                            Weekly schedule
                            
                            .. attribute:: day
                            
                            	Enter Day of the week   Mon\|Tue\|Wed\|Thu\|Fri\|Sat\|Sun
                            	**type**\:  :py:class:`WeekdayType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_types.WeekdayType>`
                            
                            .. attribute:: hh_mm
                            
                            	Begin Time hh\:mm
                            	**type**\: str
                            
                            	**pattern:** ([0\-1]?[0\-9]\|2[0\-4])\:([0\-5][0\-9])(\:[0\-5][0\-9])?
                            
                            

                            """

                            _prefix = 'ios-diag'
                            _revision = '2017-02-07'

                            def __init__(self):
                                super(Native.Diagnostic.Schedule.Switch.Test.Basic.Weekly, self).__init__()

                                self.yang_name = "weekly"
                                self.yang_parent_name = "basic"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('day', (YLeaf(YType.enumeration, 'day'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_types', 'WeekdayType', '')])),
                                    ('hh_mm', (YLeaf(YType.str, 'hh-mm'), ['str'])),
                                ])
                                self.day = None
                                self.hh_mm = None
                                self._segment_path = lambda: "weekly"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Diagnostic.Schedule.Switch.Test.Basic.Weekly, ['day', 'hh_mm'], name, value)


                        class Port(Entity):
                            """
                            Interface port selection
                            
                            .. attribute:: interface_port_number
                            
                            	Interface port number
                            	**type**\: list of  		 :py:class:`InterfacePortNumber <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Diagnostic.Schedule.Switch.Test.Basic.Port.InterfacePortNumber>`
                            
                            .. attribute:: port_number_list
                            
                            	Port number list (e.g. 2,4\-7)
                            	**type**\: list of  		 :py:class:`PortNumberList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Diagnostic.Schedule.Switch.Test.Basic.Port.PortNumberList>`
                            
                            .. attribute:: all
                            
                            	Select all ports
                            	**type**\:  :py:class:`All <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Diagnostic.Schedule.Switch.Test.Basic.Port.All>`
                            
                            

                            """

                            _prefix = 'ios-diag'
                            _revision = '2017-02-07'

                            def __init__(self):
                                super(Native.Diagnostic.Schedule.Switch.Test.Basic.Port, self).__init__()

                                self.yang_name = "port"
                                self.yang_parent_name = "basic"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("interface-port-number", ("interface_port_number", Native.Diagnostic.Schedule.Switch.Test.Basic.Port.InterfacePortNumber)), ("port-number-list", ("port_number_list", Native.Diagnostic.Schedule.Switch.Test.Basic.Port.PortNumberList)), ("all", ("all", Native.Diagnostic.Schedule.Switch.Test.Basic.Port.All))])
                                self._leafs = OrderedDict()

                                self.all = Native.Diagnostic.Schedule.Switch.Test.Basic.Port.All()
                                self.all.parent = self
                                self._children_name_map["all"] = "all"

                                self.interface_port_number = YList(self)
                                self.port_number_list = YList(self)
                                self._segment_path = lambda: "port"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Diagnostic.Schedule.Switch.Test.Basic.Port, [], name, value)


                            class InterfacePortNumber(Entity):
                                """
                                Interface port number
                                
                                .. attribute:: number  (key)
                                
                                	
                                	**type**\: int
                                
                                	**range:** 1..32
                                
                                .. attribute:: daily
                                
                                	 Daily Schedule 
                                	**type**\:  :py:class:`Daily <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Diagnostic.Schedule.Switch.Test.Basic.Port.InterfacePortNumber.Daily>`
                                
                                .. attribute:: on
                                
                                	 Absolute Schedule 
                                	**type**\:  :py:class:`On <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Diagnostic.Schedule.Switch.Test.Basic.Port.InterfacePortNumber.On>`
                                
                                .. attribute:: weekly
                                
                                	Weekly schedule
                                	**type**\:  :py:class:`Weekly <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Diagnostic.Schedule.Switch.Test.Basic.Port.InterfacePortNumber.Weekly>`
                                
                                

                                """

                                _prefix = 'ios-diag'
                                _revision = '2017-02-07'

                                def __init__(self):
                                    super(Native.Diagnostic.Schedule.Switch.Test.Basic.Port.InterfacePortNumber, self).__init__()

                                    self.yang_name = "interface-port-number"
                                    self.yang_parent_name = "port"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = ['number']
                                    self._child_classes = OrderedDict([("daily", ("daily", Native.Diagnostic.Schedule.Switch.Test.Basic.Port.InterfacePortNumber.Daily)), ("on", ("on", Native.Diagnostic.Schedule.Switch.Test.Basic.Port.InterfacePortNumber.On)), ("weekly", ("weekly", Native.Diagnostic.Schedule.Switch.Test.Basic.Port.InterfacePortNumber.Weekly))])
                                    self._leafs = OrderedDict([
                                        ('number', (YLeaf(YType.uint8, 'number'), ['int'])),
                                    ])
                                    self.number = None

                                    self.daily = Native.Diagnostic.Schedule.Switch.Test.Basic.Port.InterfacePortNumber.Daily()
                                    self.daily.parent = self
                                    self._children_name_map["daily"] = "daily"

                                    self.on = Native.Diagnostic.Schedule.Switch.Test.Basic.Port.InterfacePortNumber.On()
                                    self.on.parent = self
                                    self._children_name_map["on"] = "on"

                                    self.weekly = Native.Diagnostic.Schedule.Switch.Test.Basic.Port.InterfacePortNumber.Weekly()
                                    self.weekly.parent = self
                                    self._children_name_map["weekly"] = "weekly"
                                    self._segment_path = lambda: "interface-port-number" + "[number='" + str(self.number) + "']"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Diagnostic.Schedule.Switch.Test.Basic.Port.InterfacePortNumber, ['number'], name, value)


                                class Daily(Entity):
                                    """
                                     Daily Schedule 
                                    
                                    .. attribute:: hh_mm
                                    
                                    	Begin Time hh\:mm
                                    	**type**\: str
                                    
                                    	**pattern:** ([0\-1]?[0\-9]\|2[0\-4])\:([0\-5][0\-9])(\:[0\-5][0\-9])?
                                    
                                    

                                    """

                                    _prefix = 'ios-diag'
                                    _revision = '2017-02-07'

                                    def __init__(self):
                                        super(Native.Diagnostic.Schedule.Switch.Test.Basic.Port.InterfacePortNumber.Daily, self).__init__()

                                        self.yang_name = "daily"
                                        self.yang_parent_name = "interface-port-number"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('hh_mm', (YLeaf(YType.str, 'hh-mm'), ['str'])),
                                        ])
                                        self.hh_mm = None
                                        self._segment_path = lambda: "daily"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Diagnostic.Schedule.Switch.Test.Basic.Port.InterfacePortNumber.Daily, ['hh_mm'], name, value)


                                class On(Entity):
                                    """
                                     Absolute Schedule 
                                    
                                    .. attribute:: month
                                    
                                    	Enter month \-> Jan\|Feb\|Mar\|Apr\|May\|Jun\|Jul\|Aug\|Sep\|Oct\|Nov\|Dec
                                    	**type**\:  :py:class:`MonthType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_types.MonthType>`
                                    
                                    .. attribute:: day_of_month
                                    
                                    	 <1\-31>  Day of month 
                                    	**type**\: int
                                    
                                    	**range:** 1..31
                                    
                                    .. attribute:: year
                                    
                                    	Enter Year <1993\-2035>
                                    	**type**\: int
                                    
                                    	**range:** 1993..2035
                                    
                                    .. attribute:: hh_mm
                                    
                                    	Begin Time hh\:mm
                                    	**type**\: str
                                    
                                    	**pattern:** ([0\-1]?[0\-9]\|2[0\-4])\:([0\-5][0\-9])(\:[0\-5][0\-9])?
                                    
                                    

                                    """

                                    _prefix = 'ios-diag'
                                    _revision = '2017-02-07'

                                    def __init__(self):
                                        super(Native.Diagnostic.Schedule.Switch.Test.Basic.Port.InterfacePortNumber.On, self).__init__()

                                        self.yang_name = "on"
                                        self.yang_parent_name = "interface-port-number"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('month', (YLeaf(YType.enumeration, 'month'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_types', 'MonthType', '')])),
                                            ('day_of_month', (YLeaf(YType.uint16, 'day-of-month'), ['int'])),
                                            ('year', (YLeaf(YType.uint16, 'Year'), ['int'])),
                                            ('hh_mm', (YLeaf(YType.str, 'hh-mm'), ['str'])),
                                        ])
                                        self.month = None
                                        self.day_of_month = None
                                        self.year = None
                                        self.hh_mm = None
                                        self._segment_path = lambda: "on"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Diagnostic.Schedule.Switch.Test.Basic.Port.InterfacePortNumber.On, ['month', 'day_of_month', 'year', 'hh_mm'], name, value)


                                class Weekly(Entity):
                                    """
                                    Weekly schedule
                                    
                                    .. attribute:: day
                                    
                                    	Enter Day of the week   Mon\|Tue\|Wed\|Thu\|Fri\|Sat\|Sun
                                    	**type**\:  :py:class:`WeekdayType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_types.WeekdayType>`
                                    
                                    .. attribute:: hh_mm
                                    
                                    	Begin Time hh\:mm
                                    	**type**\: str
                                    
                                    	**pattern:** ([0\-1]?[0\-9]\|2[0\-4])\:([0\-5][0\-9])(\:[0\-5][0\-9])?
                                    
                                    

                                    """

                                    _prefix = 'ios-diag'
                                    _revision = '2017-02-07'

                                    def __init__(self):
                                        super(Native.Diagnostic.Schedule.Switch.Test.Basic.Port.InterfacePortNumber.Weekly, self).__init__()

                                        self.yang_name = "weekly"
                                        self.yang_parent_name = "interface-port-number"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('day', (YLeaf(YType.enumeration, 'day'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_types', 'WeekdayType', '')])),
                                            ('hh_mm', (YLeaf(YType.str, 'hh-mm'), ['str'])),
                                        ])
                                        self.day = None
                                        self.hh_mm = None
                                        self._segment_path = lambda: "weekly"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Diagnostic.Schedule.Switch.Test.Basic.Port.InterfacePortNumber.Weekly, ['day', 'hh_mm'], name, value)


                            class PortNumberList(Entity):
                                """
                                Port number list (e.g. 2,4\-7)
                                
                                .. attribute:: number_list  (key)
                                
                                	Port number list (e.g. 2,4\-7)
                                	**type**\: str
                                
                                .. attribute:: daily
                                
                                	 Daily Schedule 
                                	**type**\:  :py:class:`Daily <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Diagnostic.Schedule.Switch.Test.Basic.Port.PortNumberList.Daily>`
                                
                                .. attribute:: on
                                
                                	 Absolute Schedule 
                                	**type**\:  :py:class:`On <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Diagnostic.Schedule.Switch.Test.Basic.Port.PortNumberList.On>`
                                
                                .. attribute:: weekly
                                
                                	Weekly schedule
                                	**type**\:  :py:class:`Weekly <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Diagnostic.Schedule.Switch.Test.Basic.Port.PortNumberList.Weekly>`
                                
                                

                                """

                                _prefix = 'ios-diag'
                                _revision = '2017-02-07'

                                def __init__(self):
                                    super(Native.Diagnostic.Schedule.Switch.Test.Basic.Port.PortNumberList, self).__init__()

                                    self.yang_name = "port-number-list"
                                    self.yang_parent_name = "port"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = ['number_list']
                                    self._child_classes = OrderedDict([("daily", ("daily", Native.Diagnostic.Schedule.Switch.Test.Basic.Port.PortNumberList.Daily)), ("on", ("on", Native.Diagnostic.Schedule.Switch.Test.Basic.Port.PortNumberList.On)), ("weekly", ("weekly", Native.Diagnostic.Schedule.Switch.Test.Basic.Port.PortNumberList.Weekly))])
                                    self._leafs = OrderedDict([
                                        ('number_list', (YLeaf(YType.str, 'number-list'), ['str'])),
                                    ])
                                    self.number_list = None

                                    self.daily = Native.Diagnostic.Schedule.Switch.Test.Basic.Port.PortNumberList.Daily()
                                    self.daily.parent = self
                                    self._children_name_map["daily"] = "daily"

                                    self.on = Native.Diagnostic.Schedule.Switch.Test.Basic.Port.PortNumberList.On()
                                    self.on.parent = self
                                    self._children_name_map["on"] = "on"

                                    self.weekly = Native.Diagnostic.Schedule.Switch.Test.Basic.Port.PortNumberList.Weekly()
                                    self.weekly.parent = self
                                    self._children_name_map["weekly"] = "weekly"
                                    self._segment_path = lambda: "port-number-list" + "[number-list='" + str(self.number_list) + "']"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Diagnostic.Schedule.Switch.Test.Basic.Port.PortNumberList, ['number_list'], name, value)


                                class Daily(Entity):
                                    """
                                     Daily Schedule 
                                    
                                    .. attribute:: hh_mm
                                    
                                    	Begin Time hh\:mm
                                    	**type**\: str
                                    
                                    	**pattern:** ([0\-1]?[0\-9]\|2[0\-4])\:([0\-5][0\-9])(\:[0\-5][0\-9])?
                                    
                                    

                                    """

                                    _prefix = 'ios-diag'
                                    _revision = '2017-02-07'

                                    def __init__(self):
                                        super(Native.Diagnostic.Schedule.Switch.Test.Basic.Port.PortNumberList.Daily, self).__init__()

                                        self.yang_name = "daily"
                                        self.yang_parent_name = "port-number-list"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('hh_mm', (YLeaf(YType.str, 'hh-mm'), ['str'])),
                                        ])
                                        self.hh_mm = None
                                        self._segment_path = lambda: "daily"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Diagnostic.Schedule.Switch.Test.Basic.Port.PortNumberList.Daily, ['hh_mm'], name, value)


                                class On(Entity):
                                    """
                                     Absolute Schedule 
                                    
                                    .. attribute:: month
                                    
                                    	Enter month \-> Jan\|Feb\|Mar\|Apr\|May\|Jun\|Jul\|Aug\|Sep\|Oct\|Nov\|Dec
                                    	**type**\:  :py:class:`MonthType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_types.MonthType>`
                                    
                                    .. attribute:: day_of_month
                                    
                                    	 <1\-31>  Day of month 
                                    	**type**\: int
                                    
                                    	**range:** 1..31
                                    
                                    .. attribute:: year
                                    
                                    	Enter Year <1993\-2035>
                                    	**type**\: int
                                    
                                    	**range:** 1993..2035
                                    
                                    .. attribute:: hh_mm
                                    
                                    	Begin Time hh\:mm
                                    	**type**\: str
                                    
                                    	**pattern:** ([0\-1]?[0\-9]\|2[0\-4])\:([0\-5][0\-9])(\:[0\-5][0\-9])?
                                    
                                    

                                    """

                                    _prefix = 'ios-diag'
                                    _revision = '2017-02-07'

                                    def __init__(self):
                                        super(Native.Diagnostic.Schedule.Switch.Test.Basic.Port.PortNumberList.On, self).__init__()

                                        self.yang_name = "on"
                                        self.yang_parent_name = "port-number-list"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('month', (YLeaf(YType.enumeration, 'month'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_types', 'MonthType', '')])),
                                            ('day_of_month', (YLeaf(YType.uint16, 'day-of-month'), ['int'])),
                                            ('year', (YLeaf(YType.uint16, 'Year'), ['int'])),
                                            ('hh_mm', (YLeaf(YType.str, 'hh-mm'), ['str'])),
                                        ])
                                        self.month = None
                                        self.day_of_month = None
                                        self.year = None
                                        self.hh_mm = None
                                        self._segment_path = lambda: "on"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Diagnostic.Schedule.Switch.Test.Basic.Port.PortNumberList.On, ['month', 'day_of_month', 'year', 'hh_mm'], name, value)


                                class Weekly(Entity):
                                    """
                                    Weekly schedule
                                    
                                    .. attribute:: day
                                    
                                    	Enter Day of the week   Mon\|Tue\|Wed\|Thu\|Fri\|Sat\|Sun
                                    	**type**\:  :py:class:`WeekdayType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_types.WeekdayType>`
                                    
                                    .. attribute:: hh_mm
                                    
                                    	Begin Time hh\:mm
                                    	**type**\: str
                                    
                                    	**pattern:** ([0\-1]?[0\-9]\|2[0\-4])\:([0\-5][0\-9])(\:[0\-5][0\-9])?
                                    
                                    

                                    """

                                    _prefix = 'ios-diag'
                                    _revision = '2017-02-07'

                                    def __init__(self):
                                        super(Native.Diagnostic.Schedule.Switch.Test.Basic.Port.PortNumberList.Weekly, self).__init__()

                                        self.yang_name = "weekly"
                                        self.yang_parent_name = "port-number-list"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('day', (YLeaf(YType.enumeration, 'day'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_types', 'WeekdayType', '')])),
                                            ('hh_mm', (YLeaf(YType.str, 'hh-mm'), ['str'])),
                                        ])
                                        self.day = None
                                        self.hh_mm = None
                                        self._segment_path = lambda: "weekly"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Diagnostic.Schedule.Switch.Test.Basic.Port.PortNumberList.Weekly, ['day', 'hh_mm'], name, value)


                            class All(Entity):
                                """
                                Select all ports
                                
                                .. attribute:: daily
                                
                                	 Daily Schedule 
                                	**type**\:  :py:class:`Daily <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Diagnostic.Schedule.Switch.Test.Basic.Port.All.Daily>`
                                
                                .. attribute:: on
                                
                                	 Absolute Schedule 
                                	**type**\:  :py:class:`On <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Diagnostic.Schedule.Switch.Test.Basic.Port.All.On>`
                                
                                .. attribute:: weekly
                                
                                	Weekly schedule
                                	**type**\:  :py:class:`Weekly <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Diagnostic.Schedule.Switch.Test.Basic.Port.All.Weekly>`
                                
                                

                                """

                                _prefix = 'ios-diag'
                                _revision = '2017-02-07'

                                def __init__(self):
                                    super(Native.Diagnostic.Schedule.Switch.Test.Basic.Port.All, self).__init__()

                                    self.yang_name = "all"
                                    self.yang_parent_name = "port"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("daily", ("daily", Native.Diagnostic.Schedule.Switch.Test.Basic.Port.All.Daily)), ("on", ("on", Native.Diagnostic.Schedule.Switch.Test.Basic.Port.All.On)), ("weekly", ("weekly", Native.Diagnostic.Schedule.Switch.Test.Basic.Port.All.Weekly))])
                                    self._leafs = OrderedDict()

                                    self.daily = Native.Diagnostic.Schedule.Switch.Test.Basic.Port.All.Daily()
                                    self.daily.parent = self
                                    self._children_name_map["daily"] = "daily"

                                    self.on = Native.Diagnostic.Schedule.Switch.Test.Basic.Port.All.On()
                                    self.on.parent = self
                                    self._children_name_map["on"] = "on"

                                    self.weekly = Native.Diagnostic.Schedule.Switch.Test.Basic.Port.All.Weekly()
                                    self.weekly.parent = self
                                    self._children_name_map["weekly"] = "weekly"
                                    self._segment_path = lambda: "all"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Diagnostic.Schedule.Switch.Test.Basic.Port.All, [], name, value)


                                class Daily(Entity):
                                    """
                                     Daily Schedule 
                                    
                                    .. attribute:: hh_mm
                                    
                                    	Begin Time hh\:mm
                                    	**type**\: str
                                    
                                    	**pattern:** ([0\-1]?[0\-9]\|2[0\-4])\:([0\-5][0\-9])(\:[0\-5][0\-9])?
                                    
                                    

                                    """

                                    _prefix = 'ios-diag'
                                    _revision = '2017-02-07'

                                    def __init__(self):
                                        super(Native.Diagnostic.Schedule.Switch.Test.Basic.Port.All.Daily, self).__init__()

                                        self.yang_name = "daily"
                                        self.yang_parent_name = "all"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('hh_mm', (YLeaf(YType.str, 'hh-mm'), ['str'])),
                                        ])
                                        self.hh_mm = None
                                        self._segment_path = lambda: "daily"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Diagnostic.Schedule.Switch.Test.Basic.Port.All.Daily, ['hh_mm'], name, value)


                                class On(Entity):
                                    """
                                     Absolute Schedule 
                                    
                                    .. attribute:: month
                                    
                                    	Enter month \-> Jan\|Feb\|Mar\|Apr\|May\|Jun\|Jul\|Aug\|Sep\|Oct\|Nov\|Dec
                                    	**type**\:  :py:class:`MonthType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_types.MonthType>`
                                    
                                    .. attribute:: day_of_month
                                    
                                    	 <1\-31>  Day of month 
                                    	**type**\: int
                                    
                                    	**range:** 1..31
                                    
                                    .. attribute:: year
                                    
                                    	Enter Year <1993\-2035>
                                    	**type**\: int
                                    
                                    	**range:** 1993..2035
                                    
                                    .. attribute:: hh_mm
                                    
                                    	Begin Time hh\:mm
                                    	**type**\: str
                                    
                                    	**pattern:** ([0\-1]?[0\-9]\|2[0\-4])\:([0\-5][0\-9])(\:[0\-5][0\-9])?
                                    
                                    

                                    """

                                    _prefix = 'ios-diag'
                                    _revision = '2017-02-07'

                                    def __init__(self):
                                        super(Native.Diagnostic.Schedule.Switch.Test.Basic.Port.All.On, self).__init__()

                                        self.yang_name = "on"
                                        self.yang_parent_name = "all"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('month', (YLeaf(YType.enumeration, 'month'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_types', 'MonthType', '')])),
                                            ('day_of_month', (YLeaf(YType.uint16, 'day-of-month'), ['int'])),
                                            ('year', (YLeaf(YType.uint16, 'Year'), ['int'])),
                                            ('hh_mm', (YLeaf(YType.str, 'hh-mm'), ['str'])),
                                        ])
                                        self.month = None
                                        self.day_of_month = None
                                        self.year = None
                                        self.hh_mm = None
                                        self._segment_path = lambda: "on"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Diagnostic.Schedule.Switch.Test.Basic.Port.All.On, ['month', 'day_of_month', 'year', 'hh_mm'], name, value)


                                class Weekly(Entity):
                                    """
                                    Weekly schedule
                                    
                                    .. attribute:: day
                                    
                                    	Enter Day of the week   Mon\|Tue\|Wed\|Thu\|Fri\|Sat\|Sun
                                    	**type**\:  :py:class:`WeekdayType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_types.WeekdayType>`
                                    
                                    .. attribute:: hh_mm
                                    
                                    	Begin Time hh\:mm
                                    	**type**\: str
                                    
                                    	**pattern:** ([0\-1]?[0\-9]\|2[0\-4])\:([0\-5][0\-9])(\:[0\-5][0\-9])?
                                    
                                    

                                    """

                                    _prefix = 'ios-diag'
                                    _revision = '2017-02-07'

                                    def __init__(self):
                                        super(Native.Diagnostic.Schedule.Switch.Test.Basic.Port.All.Weekly, self).__init__()

                                        self.yang_name = "weekly"
                                        self.yang_parent_name = "all"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('day', (YLeaf(YType.enumeration, 'day'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_types', 'WeekdayType', '')])),
                                            ('hh_mm', (YLeaf(YType.str, 'hh-mm'), ['str'])),
                                        ])
                                        self.day = None
                                        self.hh_mm = None
                                        self._segment_path = lambda: "weekly"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Diagnostic.Schedule.Switch.Test.Basic.Port.All.Weekly, ['day', 'hh_mm'], name, value)


                    class Complete(Entity):
                        """
                        Select the Complete bootup test suite [Attribute = C]
                        
                        .. attribute:: daily
                        
                        	 Daily Schedule 
                        	**type**\:  :py:class:`Daily <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Diagnostic.Schedule.Switch.Test.Complete.Daily>`
                        
                        .. attribute:: on
                        
                        	 Absolute Schedule 
                        	**type**\:  :py:class:`On <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Diagnostic.Schedule.Switch.Test.Complete.On>`
                        
                        .. attribute:: weekly
                        
                        	Weekly schedule
                        	**type**\:  :py:class:`Weekly <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Diagnostic.Schedule.Switch.Test.Complete.Weekly>`
                        
                        

                        """

                        _prefix = 'ios-diag'
                        _revision = '2017-02-07'

                        def __init__(self):
                            super(Native.Diagnostic.Schedule.Switch.Test.Complete, self).__init__()

                            self.yang_name = "complete"
                            self.yang_parent_name = "test"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("daily", ("daily", Native.Diagnostic.Schedule.Switch.Test.Complete.Daily)), ("on", ("on", Native.Diagnostic.Schedule.Switch.Test.Complete.On)), ("weekly", ("weekly", Native.Diagnostic.Schedule.Switch.Test.Complete.Weekly))])
                            self._leafs = OrderedDict()

                            self.daily = Native.Diagnostic.Schedule.Switch.Test.Complete.Daily()
                            self.daily.parent = self
                            self._children_name_map["daily"] = "daily"

                            self.on = Native.Diagnostic.Schedule.Switch.Test.Complete.On()
                            self.on.parent = self
                            self._children_name_map["on"] = "on"

                            self.weekly = Native.Diagnostic.Schedule.Switch.Test.Complete.Weekly()
                            self.weekly.parent = self
                            self._children_name_map["weekly"] = "weekly"
                            self._segment_path = lambda: "complete"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Diagnostic.Schedule.Switch.Test.Complete, [], name, value)


                        class Daily(Entity):
                            """
                             Daily Schedule 
                            
                            .. attribute:: hh_mm
                            
                            	Begin Time hh\:mm
                            	**type**\: str
                            
                            	**pattern:** ([0\-1]?[0\-9]\|2[0\-4])\:([0\-5][0\-9])(\:[0\-5][0\-9])?
                            
                            

                            """

                            _prefix = 'ios-diag'
                            _revision = '2017-02-07'

                            def __init__(self):
                                super(Native.Diagnostic.Schedule.Switch.Test.Complete.Daily, self).__init__()

                                self.yang_name = "daily"
                                self.yang_parent_name = "complete"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('hh_mm', (YLeaf(YType.str, 'hh-mm'), ['str'])),
                                ])
                                self.hh_mm = None
                                self._segment_path = lambda: "daily"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Diagnostic.Schedule.Switch.Test.Complete.Daily, ['hh_mm'], name, value)


                        class On(Entity):
                            """
                             Absolute Schedule 
                            
                            .. attribute:: month
                            
                            	Enter month \-> Jan\|Feb\|Mar\|Apr\|May\|Jun\|Jul\|Aug\|Sep\|Oct\|Nov\|Dec
                            	**type**\:  :py:class:`MonthType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_types.MonthType>`
                            
                            .. attribute:: day_of_month
                            
                            	 <1\-31>  Day of month 
                            	**type**\: int
                            
                            	**range:** 1..31
                            
                            .. attribute:: year
                            
                            	Enter Year <1993\-2035>
                            	**type**\: int
                            
                            	**range:** 1993..2035
                            
                            .. attribute:: hh_mm
                            
                            	Begin Time hh\:mm
                            	**type**\: str
                            
                            	**pattern:** ([0\-1]?[0\-9]\|2[0\-4])\:([0\-5][0\-9])(\:[0\-5][0\-9])?
                            
                            

                            """

                            _prefix = 'ios-diag'
                            _revision = '2017-02-07'

                            def __init__(self):
                                super(Native.Diagnostic.Schedule.Switch.Test.Complete.On, self).__init__()

                                self.yang_name = "on"
                                self.yang_parent_name = "complete"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('month', (YLeaf(YType.enumeration, 'month'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_types', 'MonthType', '')])),
                                    ('day_of_month', (YLeaf(YType.uint16, 'day-of-month'), ['int'])),
                                    ('year', (YLeaf(YType.uint16, 'Year'), ['int'])),
                                    ('hh_mm', (YLeaf(YType.str, 'hh-mm'), ['str'])),
                                ])
                                self.month = None
                                self.day_of_month = None
                                self.year = None
                                self.hh_mm = None
                                self._segment_path = lambda: "on"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Diagnostic.Schedule.Switch.Test.Complete.On, ['month', 'day_of_month', 'year', 'hh_mm'], name, value)


                        class Weekly(Entity):
                            """
                            Weekly schedule
                            
                            .. attribute:: day
                            
                            	Enter Day of the week   Mon\|Tue\|Wed\|Thu\|Fri\|Sat\|Sun
                            	**type**\:  :py:class:`WeekdayType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_types.WeekdayType>`
                            
                            .. attribute:: hh_mm
                            
                            	Begin Time hh\:mm
                            	**type**\: str
                            
                            	**pattern:** ([0\-1]?[0\-9]\|2[0\-4])\:([0\-5][0\-9])(\:[0\-5][0\-9])?
                            
                            

                            """

                            _prefix = 'ios-diag'
                            _revision = '2017-02-07'

                            def __init__(self):
                                super(Native.Diagnostic.Schedule.Switch.Test.Complete.Weekly, self).__init__()

                                self.yang_name = "weekly"
                                self.yang_parent_name = "complete"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('day', (YLeaf(YType.enumeration, 'day'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_types', 'WeekdayType', '')])),
                                    ('hh_mm', (YLeaf(YType.str, 'hh-mm'), ['str'])),
                                ])
                                self.day = None
                                self.hh_mm = None
                                self._segment_path = lambda: "weekly"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Diagnostic.Schedule.Switch.Test.Complete.Weekly, ['day', 'hh_mm'], name, value)


                    class Minimal(Entity):
                        """
                        Select the Minimal bootup test suite [Attribute = M]
                        
                        .. attribute:: daily
                        
                        	 Daily Schedule 
                        	**type**\:  :py:class:`Daily <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Diagnostic.Schedule.Switch.Test.Minimal.Daily>`
                        
                        .. attribute:: on
                        
                        	 Absolute Schedule 
                        	**type**\:  :py:class:`On <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Diagnostic.Schedule.Switch.Test.Minimal.On>`
                        
                        .. attribute:: weekly
                        
                        	Weekly schedule
                        	**type**\:  :py:class:`Weekly <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Diagnostic.Schedule.Switch.Test.Minimal.Weekly>`
                        
                        

                        """

                        _prefix = 'ios-diag'
                        _revision = '2017-02-07'

                        def __init__(self):
                            super(Native.Diagnostic.Schedule.Switch.Test.Minimal, self).__init__()

                            self.yang_name = "minimal"
                            self.yang_parent_name = "test"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("daily", ("daily", Native.Diagnostic.Schedule.Switch.Test.Minimal.Daily)), ("on", ("on", Native.Diagnostic.Schedule.Switch.Test.Minimal.On)), ("weekly", ("weekly", Native.Diagnostic.Schedule.Switch.Test.Minimal.Weekly))])
                            self._leafs = OrderedDict()

                            self.daily = Native.Diagnostic.Schedule.Switch.Test.Minimal.Daily()
                            self.daily.parent = self
                            self._children_name_map["daily"] = "daily"

                            self.on = Native.Diagnostic.Schedule.Switch.Test.Minimal.On()
                            self.on.parent = self
                            self._children_name_map["on"] = "on"

                            self.weekly = Native.Diagnostic.Schedule.Switch.Test.Minimal.Weekly()
                            self.weekly.parent = self
                            self._children_name_map["weekly"] = "weekly"
                            self._segment_path = lambda: "minimal"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Diagnostic.Schedule.Switch.Test.Minimal, [], name, value)


                        class Daily(Entity):
                            """
                             Daily Schedule 
                            
                            .. attribute:: hh_mm
                            
                            	Begin Time hh\:mm
                            	**type**\: str
                            
                            	**pattern:** ([0\-1]?[0\-9]\|2[0\-4])\:([0\-5][0\-9])(\:[0\-5][0\-9])?
                            
                            

                            """

                            _prefix = 'ios-diag'
                            _revision = '2017-02-07'

                            def __init__(self):
                                super(Native.Diagnostic.Schedule.Switch.Test.Minimal.Daily, self).__init__()

                                self.yang_name = "daily"
                                self.yang_parent_name = "minimal"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('hh_mm', (YLeaf(YType.str, 'hh-mm'), ['str'])),
                                ])
                                self.hh_mm = None
                                self._segment_path = lambda: "daily"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Diagnostic.Schedule.Switch.Test.Minimal.Daily, ['hh_mm'], name, value)


                        class On(Entity):
                            """
                             Absolute Schedule 
                            
                            .. attribute:: month
                            
                            	Enter month \-> Jan\|Feb\|Mar\|Apr\|May\|Jun\|Jul\|Aug\|Sep\|Oct\|Nov\|Dec
                            	**type**\:  :py:class:`MonthType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_types.MonthType>`
                            
                            .. attribute:: day_of_month
                            
                            	 <1\-31>  Day of month 
                            	**type**\: int
                            
                            	**range:** 1..31
                            
                            .. attribute:: year
                            
                            	Enter Year <1993\-2035>
                            	**type**\: int
                            
                            	**range:** 1993..2035
                            
                            .. attribute:: hh_mm
                            
                            	Begin Time hh\:mm
                            	**type**\: str
                            
                            	**pattern:** ([0\-1]?[0\-9]\|2[0\-4])\:([0\-5][0\-9])(\:[0\-5][0\-9])?
                            
                            

                            """

                            _prefix = 'ios-diag'
                            _revision = '2017-02-07'

                            def __init__(self):
                                super(Native.Diagnostic.Schedule.Switch.Test.Minimal.On, self).__init__()

                                self.yang_name = "on"
                                self.yang_parent_name = "minimal"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('month', (YLeaf(YType.enumeration, 'month'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_types', 'MonthType', '')])),
                                    ('day_of_month', (YLeaf(YType.uint16, 'day-of-month'), ['int'])),
                                    ('year', (YLeaf(YType.uint16, 'Year'), ['int'])),
                                    ('hh_mm', (YLeaf(YType.str, 'hh-mm'), ['str'])),
                                ])
                                self.month = None
                                self.day_of_month = None
                                self.year = None
                                self.hh_mm = None
                                self._segment_path = lambda: "on"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Diagnostic.Schedule.Switch.Test.Minimal.On, ['month', 'day_of_month', 'year', 'hh_mm'], name, value)


                        class Weekly(Entity):
                            """
                            Weekly schedule
                            
                            .. attribute:: day
                            
                            	Enter Day of the week   Mon\|Tue\|Wed\|Thu\|Fri\|Sat\|Sun
                            	**type**\:  :py:class:`WeekdayType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_types.WeekdayType>`
                            
                            .. attribute:: hh_mm
                            
                            	Begin Time hh\:mm
                            	**type**\: str
                            
                            	**pattern:** ([0\-1]?[0\-9]\|2[0\-4])\:([0\-5][0\-9])(\:[0\-5][0\-9])?
                            
                            

                            """

                            _prefix = 'ios-diag'
                            _revision = '2017-02-07'

                            def __init__(self):
                                super(Native.Diagnostic.Schedule.Switch.Test.Minimal.Weekly, self).__init__()

                                self.yang_name = "weekly"
                                self.yang_parent_name = "minimal"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('day', (YLeaf(YType.enumeration, 'day'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_types', 'WeekdayType', '')])),
                                    ('hh_mm', (YLeaf(YType.str, 'hh-mm'), ['str'])),
                                ])
                                self.day = None
                                self.hh_mm = None
                                self._segment_path = lambda: "weekly"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Diagnostic.Schedule.Switch.Test.Minimal.Weekly, ['day', 'hh_mm'], name, value)


                    class NonDisruptive(Entity):
                        """
                        Select the Non\-Disruptive test suite [Attribute = N]
                        
                        .. attribute:: daily
                        
                        	 Daily Schedule 
                        	**type**\:  :py:class:`Daily <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Diagnostic.Schedule.Switch.Test.NonDisruptive.Daily>`
                        
                        .. attribute:: on
                        
                        	 Absolute Schedule 
                        	**type**\:  :py:class:`On <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Diagnostic.Schedule.Switch.Test.NonDisruptive.On>`
                        
                        .. attribute:: weekly
                        
                        	Weekly schedule
                        	**type**\:  :py:class:`Weekly <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Diagnostic.Schedule.Switch.Test.NonDisruptive.Weekly>`
                        
                        .. attribute:: port
                        
                        	Interface port selection
                        	**type**\:  :py:class:`Port <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Diagnostic.Schedule.Switch.Test.NonDisruptive.Port>`
                        
                        

                        """

                        _prefix = 'ios-diag'
                        _revision = '2017-02-07'

                        def __init__(self):
                            super(Native.Diagnostic.Schedule.Switch.Test.NonDisruptive, self).__init__()

                            self.yang_name = "non-disruptive"
                            self.yang_parent_name = "test"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("daily", ("daily", Native.Diagnostic.Schedule.Switch.Test.NonDisruptive.Daily)), ("on", ("on", Native.Diagnostic.Schedule.Switch.Test.NonDisruptive.On)), ("weekly", ("weekly", Native.Diagnostic.Schedule.Switch.Test.NonDisruptive.Weekly)), ("port", ("port", Native.Diagnostic.Schedule.Switch.Test.NonDisruptive.Port))])
                            self._leafs = OrderedDict()

                            self.daily = Native.Diagnostic.Schedule.Switch.Test.NonDisruptive.Daily()
                            self.daily.parent = self
                            self._children_name_map["daily"] = "daily"

                            self.on = Native.Diagnostic.Schedule.Switch.Test.NonDisruptive.On()
                            self.on.parent = self
                            self._children_name_map["on"] = "on"

                            self.weekly = Native.Diagnostic.Schedule.Switch.Test.NonDisruptive.Weekly()
                            self.weekly.parent = self
                            self._children_name_map["weekly"] = "weekly"

                            self.port = Native.Diagnostic.Schedule.Switch.Test.NonDisruptive.Port()
                            self.port.parent = self
                            self._children_name_map["port"] = "port"
                            self._segment_path = lambda: "non-disruptive"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Diagnostic.Schedule.Switch.Test.NonDisruptive, [], name, value)


                        class Daily(Entity):
                            """
                             Daily Schedule 
                            
                            .. attribute:: hh_mm
                            
                            	Begin Time hh\:mm
                            	**type**\: str
                            
                            	**pattern:** ([0\-1]?[0\-9]\|2[0\-4])\:([0\-5][0\-9])(\:[0\-5][0\-9])?
                            
                            

                            """

                            _prefix = 'ios-diag'
                            _revision = '2017-02-07'

                            def __init__(self):
                                super(Native.Diagnostic.Schedule.Switch.Test.NonDisruptive.Daily, self).__init__()

                                self.yang_name = "daily"
                                self.yang_parent_name = "non-disruptive"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('hh_mm', (YLeaf(YType.str, 'hh-mm'), ['str'])),
                                ])
                                self.hh_mm = None
                                self._segment_path = lambda: "daily"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Diagnostic.Schedule.Switch.Test.NonDisruptive.Daily, ['hh_mm'], name, value)


                        class On(Entity):
                            """
                             Absolute Schedule 
                            
                            .. attribute:: month
                            
                            	Enter month \-> Jan\|Feb\|Mar\|Apr\|May\|Jun\|Jul\|Aug\|Sep\|Oct\|Nov\|Dec
                            	**type**\:  :py:class:`MonthType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_types.MonthType>`
                            
                            .. attribute:: day_of_month
                            
                            	 <1\-31>  Day of month 
                            	**type**\: int
                            
                            	**range:** 1..31
                            
                            .. attribute:: year
                            
                            	Enter Year <1993\-2035>
                            	**type**\: int
                            
                            	**range:** 1993..2035
                            
                            .. attribute:: hh_mm
                            
                            	Begin Time hh\:mm
                            	**type**\: str
                            
                            	**pattern:** ([0\-1]?[0\-9]\|2[0\-4])\:([0\-5][0\-9])(\:[0\-5][0\-9])?
                            
                            

                            """

                            _prefix = 'ios-diag'
                            _revision = '2017-02-07'

                            def __init__(self):
                                super(Native.Diagnostic.Schedule.Switch.Test.NonDisruptive.On, self).__init__()

                                self.yang_name = "on"
                                self.yang_parent_name = "non-disruptive"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('month', (YLeaf(YType.enumeration, 'month'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_types', 'MonthType', '')])),
                                    ('day_of_month', (YLeaf(YType.uint16, 'day-of-month'), ['int'])),
                                    ('year', (YLeaf(YType.uint16, 'Year'), ['int'])),
                                    ('hh_mm', (YLeaf(YType.str, 'hh-mm'), ['str'])),
                                ])
                                self.month = None
                                self.day_of_month = None
                                self.year = None
                                self.hh_mm = None
                                self._segment_path = lambda: "on"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Diagnostic.Schedule.Switch.Test.NonDisruptive.On, ['month', 'day_of_month', 'year', 'hh_mm'], name, value)


                        class Weekly(Entity):
                            """
                            Weekly schedule
                            
                            .. attribute:: day
                            
                            	Enter Day of the week   Mon\|Tue\|Wed\|Thu\|Fri\|Sat\|Sun
                            	**type**\:  :py:class:`WeekdayType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_types.WeekdayType>`
                            
                            .. attribute:: hh_mm
                            
                            	Begin Time hh\:mm
                            	**type**\: str
                            
                            	**pattern:** ([0\-1]?[0\-9]\|2[0\-4])\:([0\-5][0\-9])(\:[0\-5][0\-9])?
                            
                            

                            """

                            _prefix = 'ios-diag'
                            _revision = '2017-02-07'

                            def __init__(self):
                                super(Native.Diagnostic.Schedule.Switch.Test.NonDisruptive.Weekly, self).__init__()

                                self.yang_name = "weekly"
                                self.yang_parent_name = "non-disruptive"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('day', (YLeaf(YType.enumeration, 'day'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_types', 'WeekdayType', '')])),
                                    ('hh_mm', (YLeaf(YType.str, 'hh-mm'), ['str'])),
                                ])
                                self.day = None
                                self.hh_mm = None
                                self._segment_path = lambda: "weekly"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Diagnostic.Schedule.Switch.Test.NonDisruptive.Weekly, ['day', 'hh_mm'], name, value)


                        class Port(Entity):
                            """
                            Interface port selection
                            
                            .. attribute:: interface_port_number
                            
                            	Interface port number
                            	**type**\: list of  		 :py:class:`InterfacePortNumber <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Diagnostic.Schedule.Switch.Test.NonDisruptive.Port.InterfacePortNumber>`
                            
                            .. attribute:: port_number_list
                            
                            	Port number list (e.g. 2,4\-7)
                            	**type**\: list of  		 :py:class:`PortNumberList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Diagnostic.Schedule.Switch.Test.NonDisruptive.Port.PortNumberList>`
                            
                            .. attribute:: all
                            
                            	Select all ports
                            	**type**\:  :py:class:`All <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Diagnostic.Schedule.Switch.Test.NonDisruptive.Port.All>`
                            
                            

                            """

                            _prefix = 'ios-diag'
                            _revision = '2017-02-07'

                            def __init__(self):
                                super(Native.Diagnostic.Schedule.Switch.Test.NonDisruptive.Port, self).__init__()

                                self.yang_name = "port"
                                self.yang_parent_name = "non-disruptive"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("interface-port-number", ("interface_port_number", Native.Diagnostic.Schedule.Switch.Test.NonDisruptive.Port.InterfacePortNumber)), ("port-number-list", ("port_number_list", Native.Diagnostic.Schedule.Switch.Test.NonDisruptive.Port.PortNumberList)), ("all", ("all", Native.Diagnostic.Schedule.Switch.Test.NonDisruptive.Port.All))])
                                self._leafs = OrderedDict()

                                self.all = Native.Diagnostic.Schedule.Switch.Test.NonDisruptive.Port.All()
                                self.all.parent = self
                                self._children_name_map["all"] = "all"

                                self.interface_port_number = YList(self)
                                self.port_number_list = YList(self)
                                self._segment_path = lambda: "port"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Diagnostic.Schedule.Switch.Test.NonDisruptive.Port, [], name, value)


                            class InterfacePortNumber(Entity):
                                """
                                Interface port number
                                
                                .. attribute:: number  (key)
                                
                                	
                                	**type**\: int
                                
                                	**range:** 1..32
                                
                                .. attribute:: daily
                                
                                	 Daily Schedule 
                                	**type**\:  :py:class:`Daily <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Diagnostic.Schedule.Switch.Test.NonDisruptive.Port.InterfacePortNumber.Daily>`
                                
                                .. attribute:: on
                                
                                	 Absolute Schedule 
                                	**type**\:  :py:class:`On <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Diagnostic.Schedule.Switch.Test.NonDisruptive.Port.InterfacePortNumber.On>`
                                
                                .. attribute:: weekly
                                
                                	Weekly schedule
                                	**type**\:  :py:class:`Weekly <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Diagnostic.Schedule.Switch.Test.NonDisruptive.Port.InterfacePortNumber.Weekly>`
                                
                                

                                """

                                _prefix = 'ios-diag'
                                _revision = '2017-02-07'

                                def __init__(self):
                                    super(Native.Diagnostic.Schedule.Switch.Test.NonDisruptive.Port.InterfacePortNumber, self).__init__()

                                    self.yang_name = "interface-port-number"
                                    self.yang_parent_name = "port"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = ['number']
                                    self._child_classes = OrderedDict([("daily", ("daily", Native.Diagnostic.Schedule.Switch.Test.NonDisruptive.Port.InterfacePortNumber.Daily)), ("on", ("on", Native.Diagnostic.Schedule.Switch.Test.NonDisruptive.Port.InterfacePortNumber.On)), ("weekly", ("weekly", Native.Diagnostic.Schedule.Switch.Test.NonDisruptive.Port.InterfacePortNumber.Weekly))])
                                    self._leafs = OrderedDict([
                                        ('number', (YLeaf(YType.uint8, 'number'), ['int'])),
                                    ])
                                    self.number = None

                                    self.daily = Native.Diagnostic.Schedule.Switch.Test.NonDisruptive.Port.InterfacePortNumber.Daily()
                                    self.daily.parent = self
                                    self._children_name_map["daily"] = "daily"

                                    self.on = Native.Diagnostic.Schedule.Switch.Test.NonDisruptive.Port.InterfacePortNumber.On()
                                    self.on.parent = self
                                    self._children_name_map["on"] = "on"

                                    self.weekly = Native.Diagnostic.Schedule.Switch.Test.NonDisruptive.Port.InterfacePortNumber.Weekly()
                                    self.weekly.parent = self
                                    self._children_name_map["weekly"] = "weekly"
                                    self._segment_path = lambda: "interface-port-number" + "[number='" + str(self.number) + "']"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Diagnostic.Schedule.Switch.Test.NonDisruptive.Port.InterfacePortNumber, ['number'], name, value)


                                class Daily(Entity):
                                    """
                                     Daily Schedule 
                                    
                                    .. attribute:: hh_mm
                                    
                                    	Begin Time hh\:mm
                                    	**type**\: str
                                    
                                    	**pattern:** ([0\-1]?[0\-9]\|2[0\-4])\:([0\-5][0\-9])(\:[0\-5][0\-9])?
                                    
                                    

                                    """

                                    _prefix = 'ios-diag'
                                    _revision = '2017-02-07'

                                    def __init__(self):
                                        super(Native.Diagnostic.Schedule.Switch.Test.NonDisruptive.Port.InterfacePortNumber.Daily, self).__init__()

                                        self.yang_name = "daily"
                                        self.yang_parent_name = "interface-port-number"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('hh_mm', (YLeaf(YType.str, 'hh-mm'), ['str'])),
                                        ])
                                        self.hh_mm = None
                                        self._segment_path = lambda: "daily"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Diagnostic.Schedule.Switch.Test.NonDisruptive.Port.InterfacePortNumber.Daily, ['hh_mm'], name, value)


                                class On(Entity):
                                    """
                                     Absolute Schedule 
                                    
                                    .. attribute:: month
                                    
                                    	Enter month \-> Jan\|Feb\|Mar\|Apr\|May\|Jun\|Jul\|Aug\|Sep\|Oct\|Nov\|Dec
                                    	**type**\:  :py:class:`MonthType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_types.MonthType>`
                                    
                                    .. attribute:: day_of_month
                                    
                                    	 <1\-31>  Day of month 
                                    	**type**\: int
                                    
                                    	**range:** 1..31
                                    
                                    .. attribute:: year
                                    
                                    	Enter Year <1993\-2035>
                                    	**type**\: int
                                    
                                    	**range:** 1993..2035
                                    
                                    .. attribute:: hh_mm
                                    
                                    	Begin Time hh\:mm
                                    	**type**\: str
                                    
                                    	**pattern:** ([0\-1]?[0\-9]\|2[0\-4])\:([0\-5][0\-9])(\:[0\-5][0\-9])?
                                    
                                    

                                    """

                                    _prefix = 'ios-diag'
                                    _revision = '2017-02-07'

                                    def __init__(self):
                                        super(Native.Diagnostic.Schedule.Switch.Test.NonDisruptive.Port.InterfacePortNumber.On, self).__init__()

                                        self.yang_name = "on"
                                        self.yang_parent_name = "interface-port-number"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('month', (YLeaf(YType.enumeration, 'month'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_types', 'MonthType', '')])),
                                            ('day_of_month', (YLeaf(YType.uint16, 'day-of-month'), ['int'])),
                                            ('year', (YLeaf(YType.uint16, 'Year'), ['int'])),
                                            ('hh_mm', (YLeaf(YType.str, 'hh-mm'), ['str'])),
                                        ])
                                        self.month = None
                                        self.day_of_month = None
                                        self.year = None
                                        self.hh_mm = None
                                        self._segment_path = lambda: "on"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Diagnostic.Schedule.Switch.Test.NonDisruptive.Port.InterfacePortNumber.On, ['month', 'day_of_month', 'year', 'hh_mm'], name, value)


                                class Weekly(Entity):
                                    """
                                    Weekly schedule
                                    
                                    .. attribute:: day
                                    
                                    	Enter Day of the week   Mon\|Tue\|Wed\|Thu\|Fri\|Sat\|Sun
                                    	**type**\:  :py:class:`WeekdayType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_types.WeekdayType>`
                                    
                                    .. attribute:: hh_mm
                                    
                                    	Begin Time hh\:mm
                                    	**type**\: str
                                    
                                    	**pattern:** ([0\-1]?[0\-9]\|2[0\-4])\:([0\-5][0\-9])(\:[0\-5][0\-9])?
                                    
                                    

                                    """

                                    _prefix = 'ios-diag'
                                    _revision = '2017-02-07'

                                    def __init__(self):
                                        super(Native.Diagnostic.Schedule.Switch.Test.NonDisruptive.Port.InterfacePortNumber.Weekly, self).__init__()

                                        self.yang_name = "weekly"
                                        self.yang_parent_name = "interface-port-number"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('day', (YLeaf(YType.enumeration, 'day'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_types', 'WeekdayType', '')])),
                                            ('hh_mm', (YLeaf(YType.str, 'hh-mm'), ['str'])),
                                        ])
                                        self.day = None
                                        self.hh_mm = None
                                        self._segment_path = lambda: "weekly"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Diagnostic.Schedule.Switch.Test.NonDisruptive.Port.InterfacePortNumber.Weekly, ['day', 'hh_mm'], name, value)


                            class PortNumberList(Entity):
                                """
                                Port number list (e.g. 2,4\-7)
                                
                                .. attribute:: number_list  (key)
                                
                                	Port number list (e.g. 2,4\-7)
                                	**type**\: str
                                
                                .. attribute:: daily
                                
                                	 Daily Schedule 
                                	**type**\:  :py:class:`Daily <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Diagnostic.Schedule.Switch.Test.NonDisruptive.Port.PortNumberList.Daily>`
                                
                                .. attribute:: on
                                
                                	 Absolute Schedule 
                                	**type**\:  :py:class:`On <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Diagnostic.Schedule.Switch.Test.NonDisruptive.Port.PortNumberList.On>`
                                
                                .. attribute:: weekly
                                
                                	Weekly schedule
                                	**type**\:  :py:class:`Weekly <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Diagnostic.Schedule.Switch.Test.NonDisruptive.Port.PortNumberList.Weekly>`
                                
                                

                                """

                                _prefix = 'ios-diag'
                                _revision = '2017-02-07'

                                def __init__(self):
                                    super(Native.Diagnostic.Schedule.Switch.Test.NonDisruptive.Port.PortNumberList, self).__init__()

                                    self.yang_name = "port-number-list"
                                    self.yang_parent_name = "port"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = ['number_list']
                                    self._child_classes = OrderedDict([("daily", ("daily", Native.Diagnostic.Schedule.Switch.Test.NonDisruptive.Port.PortNumberList.Daily)), ("on", ("on", Native.Diagnostic.Schedule.Switch.Test.NonDisruptive.Port.PortNumberList.On)), ("weekly", ("weekly", Native.Diagnostic.Schedule.Switch.Test.NonDisruptive.Port.PortNumberList.Weekly))])
                                    self._leafs = OrderedDict([
                                        ('number_list', (YLeaf(YType.str, 'number-list'), ['str'])),
                                    ])
                                    self.number_list = None

                                    self.daily = Native.Diagnostic.Schedule.Switch.Test.NonDisruptive.Port.PortNumberList.Daily()
                                    self.daily.parent = self
                                    self._children_name_map["daily"] = "daily"

                                    self.on = Native.Diagnostic.Schedule.Switch.Test.NonDisruptive.Port.PortNumberList.On()
                                    self.on.parent = self
                                    self._children_name_map["on"] = "on"

                                    self.weekly = Native.Diagnostic.Schedule.Switch.Test.NonDisruptive.Port.PortNumberList.Weekly()
                                    self.weekly.parent = self
                                    self._children_name_map["weekly"] = "weekly"
                                    self._segment_path = lambda: "port-number-list" + "[number-list='" + str(self.number_list) + "']"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Diagnostic.Schedule.Switch.Test.NonDisruptive.Port.PortNumberList, ['number_list'], name, value)


                                class Daily(Entity):
                                    """
                                     Daily Schedule 
                                    
                                    .. attribute:: hh_mm
                                    
                                    	Begin Time hh\:mm
                                    	**type**\: str
                                    
                                    	**pattern:** ([0\-1]?[0\-9]\|2[0\-4])\:([0\-5][0\-9])(\:[0\-5][0\-9])?
                                    
                                    

                                    """

                                    _prefix = 'ios-diag'
                                    _revision = '2017-02-07'

                                    def __init__(self):
                                        super(Native.Diagnostic.Schedule.Switch.Test.NonDisruptive.Port.PortNumberList.Daily, self).__init__()

                                        self.yang_name = "daily"
                                        self.yang_parent_name = "port-number-list"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('hh_mm', (YLeaf(YType.str, 'hh-mm'), ['str'])),
                                        ])
                                        self.hh_mm = None
                                        self._segment_path = lambda: "daily"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Diagnostic.Schedule.Switch.Test.NonDisruptive.Port.PortNumberList.Daily, ['hh_mm'], name, value)


                                class On(Entity):
                                    """
                                     Absolute Schedule 
                                    
                                    .. attribute:: month
                                    
                                    	Enter month \-> Jan\|Feb\|Mar\|Apr\|May\|Jun\|Jul\|Aug\|Sep\|Oct\|Nov\|Dec
                                    	**type**\:  :py:class:`MonthType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_types.MonthType>`
                                    
                                    .. attribute:: day_of_month
                                    
                                    	 <1\-31>  Day of month 
                                    	**type**\: int
                                    
                                    	**range:** 1..31
                                    
                                    .. attribute:: year
                                    
                                    	Enter Year <1993\-2035>
                                    	**type**\: int
                                    
                                    	**range:** 1993..2035
                                    
                                    .. attribute:: hh_mm
                                    
                                    	Begin Time hh\:mm
                                    	**type**\: str
                                    
                                    	**pattern:** ([0\-1]?[0\-9]\|2[0\-4])\:([0\-5][0\-9])(\:[0\-5][0\-9])?
                                    
                                    

                                    """

                                    _prefix = 'ios-diag'
                                    _revision = '2017-02-07'

                                    def __init__(self):
                                        super(Native.Diagnostic.Schedule.Switch.Test.NonDisruptive.Port.PortNumberList.On, self).__init__()

                                        self.yang_name = "on"
                                        self.yang_parent_name = "port-number-list"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('month', (YLeaf(YType.enumeration, 'month'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_types', 'MonthType', '')])),
                                            ('day_of_month', (YLeaf(YType.uint16, 'day-of-month'), ['int'])),
                                            ('year', (YLeaf(YType.uint16, 'Year'), ['int'])),
                                            ('hh_mm', (YLeaf(YType.str, 'hh-mm'), ['str'])),
                                        ])
                                        self.month = None
                                        self.day_of_month = None
                                        self.year = None
                                        self.hh_mm = None
                                        self._segment_path = lambda: "on"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Diagnostic.Schedule.Switch.Test.NonDisruptive.Port.PortNumberList.On, ['month', 'day_of_month', 'year', 'hh_mm'], name, value)


                                class Weekly(Entity):
                                    """
                                    Weekly schedule
                                    
                                    .. attribute:: day
                                    
                                    	Enter Day of the week   Mon\|Tue\|Wed\|Thu\|Fri\|Sat\|Sun
                                    	**type**\:  :py:class:`WeekdayType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_types.WeekdayType>`
                                    
                                    .. attribute:: hh_mm
                                    
                                    	Begin Time hh\:mm
                                    	**type**\: str
                                    
                                    	**pattern:** ([0\-1]?[0\-9]\|2[0\-4])\:([0\-5][0\-9])(\:[0\-5][0\-9])?
                                    
                                    

                                    """

                                    _prefix = 'ios-diag'
                                    _revision = '2017-02-07'

                                    def __init__(self):
                                        super(Native.Diagnostic.Schedule.Switch.Test.NonDisruptive.Port.PortNumberList.Weekly, self).__init__()

                                        self.yang_name = "weekly"
                                        self.yang_parent_name = "port-number-list"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('day', (YLeaf(YType.enumeration, 'day'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_types', 'WeekdayType', '')])),
                                            ('hh_mm', (YLeaf(YType.str, 'hh-mm'), ['str'])),
                                        ])
                                        self.day = None
                                        self.hh_mm = None
                                        self._segment_path = lambda: "weekly"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Diagnostic.Schedule.Switch.Test.NonDisruptive.Port.PortNumberList.Weekly, ['day', 'hh_mm'], name, value)


                            class All(Entity):
                                """
                                Select all ports
                                
                                .. attribute:: daily
                                
                                	 Daily Schedule 
                                	**type**\:  :py:class:`Daily <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Diagnostic.Schedule.Switch.Test.NonDisruptive.Port.All.Daily>`
                                
                                .. attribute:: on
                                
                                	 Absolute Schedule 
                                	**type**\:  :py:class:`On <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Diagnostic.Schedule.Switch.Test.NonDisruptive.Port.All.On>`
                                
                                .. attribute:: weekly
                                
                                	Weekly schedule
                                	**type**\:  :py:class:`Weekly <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Diagnostic.Schedule.Switch.Test.NonDisruptive.Port.All.Weekly>`
                                
                                

                                """

                                _prefix = 'ios-diag'
                                _revision = '2017-02-07'

                                def __init__(self):
                                    super(Native.Diagnostic.Schedule.Switch.Test.NonDisruptive.Port.All, self).__init__()

                                    self.yang_name = "all"
                                    self.yang_parent_name = "port"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("daily", ("daily", Native.Diagnostic.Schedule.Switch.Test.NonDisruptive.Port.All.Daily)), ("on", ("on", Native.Diagnostic.Schedule.Switch.Test.NonDisruptive.Port.All.On)), ("weekly", ("weekly", Native.Diagnostic.Schedule.Switch.Test.NonDisruptive.Port.All.Weekly))])
                                    self._leafs = OrderedDict()

                                    self.daily = Native.Diagnostic.Schedule.Switch.Test.NonDisruptive.Port.All.Daily()
                                    self.daily.parent = self
                                    self._children_name_map["daily"] = "daily"

                                    self.on = Native.Diagnostic.Schedule.Switch.Test.NonDisruptive.Port.All.On()
                                    self.on.parent = self
                                    self._children_name_map["on"] = "on"

                                    self.weekly = Native.Diagnostic.Schedule.Switch.Test.NonDisruptive.Port.All.Weekly()
                                    self.weekly.parent = self
                                    self._children_name_map["weekly"] = "weekly"
                                    self._segment_path = lambda: "all"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Diagnostic.Schedule.Switch.Test.NonDisruptive.Port.All, [], name, value)


                                class Daily(Entity):
                                    """
                                     Daily Schedule 
                                    
                                    .. attribute:: hh_mm
                                    
                                    	Begin Time hh\:mm
                                    	**type**\: str
                                    
                                    	**pattern:** ([0\-1]?[0\-9]\|2[0\-4])\:([0\-5][0\-9])(\:[0\-5][0\-9])?
                                    
                                    

                                    """

                                    _prefix = 'ios-diag'
                                    _revision = '2017-02-07'

                                    def __init__(self):
                                        super(Native.Diagnostic.Schedule.Switch.Test.NonDisruptive.Port.All.Daily, self).__init__()

                                        self.yang_name = "daily"
                                        self.yang_parent_name = "all"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('hh_mm', (YLeaf(YType.str, 'hh-mm'), ['str'])),
                                        ])
                                        self.hh_mm = None
                                        self._segment_path = lambda: "daily"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Diagnostic.Schedule.Switch.Test.NonDisruptive.Port.All.Daily, ['hh_mm'], name, value)


                                class On(Entity):
                                    """
                                     Absolute Schedule 
                                    
                                    .. attribute:: month
                                    
                                    	Enter month \-> Jan\|Feb\|Mar\|Apr\|May\|Jun\|Jul\|Aug\|Sep\|Oct\|Nov\|Dec
                                    	**type**\:  :py:class:`MonthType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_types.MonthType>`
                                    
                                    .. attribute:: day_of_month
                                    
                                    	 <1\-31>  Day of month 
                                    	**type**\: int
                                    
                                    	**range:** 1..31
                                    
                                    .. attribute:: year
                                    
                                    	Enter Year <1993\-2035>
                                    	**type**\: int
                                    
                                    	**range:** 1993..2035
                                    
                                    .. attribute:: hh_mm
                                    
                                    	Begin Time hh\:mm
                                    	**type**\: str
                                    
                                    	**pattern:** ([0\-1]?[0\-9]\|2[0\-4])\:([0\-5][0\-9])(\:[0\-5][0\-9])?
                                    
                                    

                                    """

                                    _prefix = 'ios-diag'
                                    _revision = '2017-02-07'

                                    def __init__(self):
                                        super(Native.Diagnostic.Schedule.Switch.Test.NonDisruptive.Port.All.On, self).__init__()

                                        self.yang_name = "on"
                                        self.yang_parent_name = "all"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('month', (YLeaf(YType.enumeration, 'month'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_types', 'MonthType', '')])),
                                            ('day_of_month', (YLeaf(YType.uint16, 'day-of-month'), ['int'])),
                                            ('year', (YLeaf(YType.uint16, 'Year'), ['int'])),
                                            ('hh_mm', (YLeaf(YType.str, 'hh-mm'), ['str'])),
                                        ])
                                        self.month = None
                                        self.day_of_month = None
                                        self.year = None
                                        self.hh_mm = None
                                        self._segment_path = lambda: "on"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Diagnostic.Schedule.Switch.Test.NonDisruptive.Port.All.On, ['month', 'day_of_month', 'year', 'hh_mm'], name, value)


                                class Weekly(Entity):
                                    """
                                    Weekly schedule
                                    
                                    .. attribute:: day
                                    
                                    	Enter Day of the week   Mon\|Tue\|Wed\|Thu\|Fri\|Sat\|Sun
                                    	**type**\:  :py:class:`WeekdayType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_types.WeekdayType>`
                                    
                                    .. attribute:: hh_mm
                                    
                                    	Begin Time hh\:mm
                                    	**type**\: str
                                    
                                    	**pattern:** ([0\-1]?[0\-9]\|2[0\-4])\:([0\-5][0\-9])(\:[0\-5][0\-9])?
                                    
                                    

                                    """

                                    _prefix = 'ios-diag'
                                    _revision = '2017-02-07'

                                    def __init__(self):
                                        super(Native.Diagnostic.Schedule.Switch.Test.NonDisruptive.Port.All.Weekly, self).__init__()

                                        self.yang_name = "weekly"
                                        self.yang_parent_name = "all"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('day', (YLeaf(YType.enumeration, 'day'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_types', 'WeekdayType', '')])),
                                            ('hh_mm', (YLeaf(YType.str, 'hh-mm'), ['str'])),
                                        ])
                                        self.day = None
                                        self.hh_mm = None
                                        self._segment_path = lambda: "weekly"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Diagnostic.Schedule.Switch.Test.NonDisruptive.Port.All.Weekly, ['day', 'hh_mm'], name, value)


                    class PerPort(Entity):
                        """
                        Select the Per\-Port test suite [Attribute = P]
                        
                        .. attribute:: daily
                        
                        	 Daily Schedule 
                        	**type**\:  :py:class:`Daily <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Diagnostic.Schedule.Switch.Test.PerPort.Daily>`
                        
                        .. attribute:: on
                        
                        	 Absolute Schedule 
                        	**type**\:  :py:class:`On <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Diagnostic.Schedule.Switch.Test.PerPort.On>`
                        
                        .. attribute:: weekly
                        
                        	Weekly schedule
                        	**type**\:  :py:class:`Weekly <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Diagnostic.Schedule.Switch.Test.PerPort.Weekly>`
                        
                        .. attribute:: port
                        
                        	Interface port selection
                        	**type**\:  :py:class:`Port <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Diagnostic.Schedule.Switch.Test.PerPort.Port>`
                        
                        

                        """

                        _prefix = 'ios-diag'
                        _revision = '2017-02-07'

                        def __init__(self):
                            super(Native.Diagnostic.Schedule.Switch.Test.PerPort, self).__init__()

                            self.yang_name = "per-port"
                            self.yang_parent_name = "test"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("daily", ("daily", Native.Diagnostic.Schedule.Switch.Test.PerPort.Daily)), ("on", ("on", Native.Diagnostic.Schedule.Switch.Test.PerPort.On)), ("weekly", ("weekly", Native.Diagnostic.Schedule.Switch.Test.PerPort.Weekly)), ("port", ("port", Native.Diagnostic.Schedule.Switch.Test.PerPort.Port))])
                            self._leafs = OrderedDict()

                            self.daily = Native.Diagnostic.Schedule.Switch.Test.PerPort.Daily()
                            self.daily.parent = self
                            self._children_name_map["daily"] = "daily"

                            self.on = Native.Diagnostic.Schedule.Switch.Test.PerPort.On()
                            self.on.parent = self
                            self._children_name_map["on"] = "on"

                            self.weekly = Native.Diagnostic.Schedule.Switch.Test.PerPort.Weekly()
                            self.weekly.parent = self
                            self._children_name_map["weekly"] = "weekly"

                            self.port = Native.Diagnostic.Schedule.Switch.Test.PerPort.Port()
                            self.port.parent = self
                            self._children_name_map["port"] = "port"
                            self._segment_path = lambda: "per-port"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.Diagnostic.Schedule.Switch.Test.PerPort, [], name, value)


                        class Daily(Entity):
                            """
                             Daily Schedule 
                            
                            .. attribute:: hh_mm
                            
                            	Begin Time hh\:mm
                            	**type**\: str
                            
                            	**pattern:** ([0\-1]?[0\-9]\|2[0\-4])\:([0\-5][0\-9])(\:[0\-5][0\-9])?
                            
                            

                            """

                            _prefix = 'ios-diag'
                            _revision = '2017-02-07'

                            def __init__(self):
                                super(Native.Diagnostic.Schedule.Switch.Test.PerPort.Daily, self).__init__()

                                self.yang_name = "daily"
                                self.yang_parent_name = "per-port"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('hh_mm', (YLeaf(YType.str, 'hh-mm'), ['str'])),
                                ])
                                self.hh_mm = None
                                self._segment_path = lambda: "daily"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Diagnostic.Schedule.Switch.Test.PerPort.Daily, ['hh_mm'], name, value)


                        class On(Entity):
                            """
                             Absolute Schedule 
                            
                            .. attribute:: month
                            
                            	Enter month \-> Jan\|Feb\|Mar\|Apr\|May\|Jun\|Jul\|Aug\|Sep\|Oct\|Nov\|Dec
                            	**type**\:  :py:class:`MonthType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_types.MonthType>`
                            
                            .. attribute:: day_of_month
                            
                            	 <1\-31>  Day of month 
                            	**type**\: int
                            
                            	**range:** 1..31
                            
                            .. attribute:: year
                            
                            	Enter Year <1993\-2035>
                            	**type**\: int
                            
                            	**range:** 1993..2035
                            
                            .. attribute:: hh_mm
                            
                            	Begin Time hh\:mm
                            	**type**\: str
                            
                            	**pattern:** ([0\-1]?[0\-9]\|2[0\-4])\:([0\-5][0\-9])(\:[0\-5][0\-9])?
                            
                            

                            """

                            _prefix = 'ios-diag'
                            _revision = '2017-02-07'

                            def __init__(self):
                                super(Native.Diagnostic.Schedule.Switch.Test.PerPort.On, self).__init__()

                                self.yang_name = "on"
                                self.yang_parent_name = "per-port"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('month', (YLeaf(YType.enumeration, 'month'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_types', 'MonthType', '')])),
                                    ('day_of_month', (YLeaf(YType.uint16, 'day-of-month'), ['int'])),
                                    ('year', (YLeaf(YType.uint16, 'Year'), ['int'])),
                                    ('hh_mm', (YLeaf(YType.str, 'hh-mm'), ['str'])),
                                ])
                                self.month = None
                                self.day_of_month = None
                                self.year = None
                                self.hh_mm = None
                                self._segment_path = lambda: "on"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Diagnostic.Schedule.Switch.Test.PerPort.On, ['month', 'day_of_month', 'year', 'hh_mm'], name, value)


                        class Weekly(Entity):
                            """
                            Weekly schedule
                            
                            .. attribute:: day
                            
                            	Enter Day of the week   Mon\|Tue\|Wed\|Thu\|Fri\|Sat\|Sun
                            	**type**\:  :py:class:`WeekdayType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_types.WeekdayType>`
                            
                            .. attribute:: hh_mm
                            
                            	Begin Time hh\:mm
                            	**type**\: str
                            
                            	**pattern:** ([0\-1]?[0\-9]\|2[0\-4])\:([0\-5][0\-9])(\:[0\-5][0\-9])?
                            
                            

                            """

                            _prefix = 'ios-diag'
                            _revision = '2017-02-07'

                            def __init__(self):
                                super(Native.Diagnostic.Schedule.Switch.Test.PerPort.Weekly, self).__init__()

                                self.yang_name = "weekly"
                                self.yang_parent_name = "per-port"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('day', (YLeaf(YType.enumeration, 'day'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_types', 'WeekdayType', '')])),
                                    ('hh_mm', (YLeaf(YType.str, 'hh-mm'), ['str'])),
                                ])
                                self.day = None
                                self.hh_mm = None
                                self._segment_path = lambda: "weekly"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Diagnostic.Schedule.Switch.Test.PerPort.Weekly, ['day', 'hh_mm'], name, value)


                        class Port(Entity):
                            """
                            Interface port selection
                            
                            .. attribute:: interface_port_number
                            
                            	Interface port number
                            	**type**\: list of  		 :py:class:`InterfacePortNumber <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Diagnostic.Schedule.Switch.Test.PerPort.Port.InterfacePortNumber>`
                            
                            .. attribute:: port_number_list
                            
                            	Port number list (e.g. 2,4\-7)
                            	**type**\: list of  		 :py:class:`PortNumberList <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Diagnostic.Schedule.Switch.Test.PerPort.Port.PortNumberList>`
                            
                            .. attribute:: all
                            
                            	Select all ports
                            	**type**\:  :py:class:`All <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Diagnostic.Schedule.Switch.Test.PerPort.Port.All>`
                            
                            

                            """

                            _prefix = 'ios-diag'
                            _revision = '2017-02-07'

                            def __init__(self):
                                super(Native.Diagnostic.Schedule.Switch.Test.PerPort.Port, self).__init__()

                                self.yang_name = "port"
                                self.yang_parent_name = "per-port"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("interface-port-number", ("interface_port_number", Native.Diagnostic.Schedule.Switch.Test.PerPort.Port.InterfacePortNumber)), ("port-number-list", ("port_number_list", Native.Diagnostic.Schedule.Switch.Test.PerPort.Port.PortNumberList)), ("all", ("all", Native.Diagnostic.Schedule.Switch.Test.PerPort.Port.All))])
                                self._leafs = OrderedDict()

                                self.all = Native.Diagnostic.Schedule.Switch.Test.PerPort.Port.All()
                                self.all.parent = self
                                self._children_name_map["all"] = "all"

                                self.interface_port_number = YList(self)
                                self.port_number_list = YList(self)
                                self._segment_path = lambda: "port"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.Diagnostic.Schedule.Switch.Test.PerPort.Port, [], name, value)


                            class InterfacePortNumber(Entity):
                                """
                                Interface port number
                                
                                .. attribute:: number  (key)
                                
                                	
                                	**type**\: int
                                
                                	**range:** 1..32
                                
                                .. attribute:: daily
                                
                                	 Daily Schedule 
                                	**type**\:  :py:class:`Daily <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Diagnostic.Schedule.Switch.Test.PerPort.Port.InterfacePortNumber.Daily>`
                                
                                .. attribute:: on
                                
                                	 Absolute Schedule 
                                	**type**\:  :py:class:`On <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Diagnostic.Schedule.Switch.Test.PerPort.Port.InterfacePortNumber.On>`
                                
                                .. attribute:: weekly
                                
                                	Weekly schedule
                                	**type**\:  :py:class:`Weekly <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Diagnostic.Schedule.Switch.Test.PerPort.Port.InterfacePortNumber.Weekly>`
                                
                                

                                """

                                _prefix = 'ios-diag'
                                _revision = '2017-02-07'

                                def __init__(self):
                                    super(Native.Diagnostic.Schedule.Switch.Test.PerPort.Port.InterfacePortNumber, self).__init__()

                                    self.yang_name = "interface-port-number"
                                    self.yang_parent_name = "port"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = ['number']
                                    self._child_classes = OrderedDict([("daily", ("daily", Native.Diagnostic.Schedule.Switch.Test.PerPort.Port.InterfacePortNumber.Daily)), ("on", ("on", Native.Diagnostic.Schedule.Switch.Test.PerPort.Port.InterfacePortNumber.On)), ("weekly", ("weekly", Native.Diagnostic.Schedule.Switch.Test.PerPort.Port.InterfacePortNumber.Weekly))])
                                    self._leafs = OrderedDict([
                                        ('number', (YLeaf(YType.uint8, 'number'), ['int'])),
                                    ])
                                    self.number = None

                                    self.daily = Native.Diagnostic.Schedule.Switch.Test.PerPort.Port.InterfacePortNumber.Daily()
                                    self.daily.parent = self
                                    self._children_name_map["daily"] = "daily"

                                    self.on = Native.Diagnostic.Schedule.Switch.Test.PerPort.Port.InterfacePortNumber.On()
                                    self.on.parent = self
                                    self._children_name_map["on"] = "on"

                                    self.weekly = Native.Diagnostic.Schedule.Switch.Test.PerPort.Port.InterfacePortNumber.Weekly()
                                    self.weekly.parent = self
                                    self._children_name_map["weekly"] = "weekly"
                                    self._segment_path = lambda: "interface-port-number" + "[number='" + str(self.number) + "']"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Diagnostic.Schedule.Switch.Test.PerPort.Port.InterfacePortNumber, ['number'], name, value)


                                class Daily(Entity):
                                    """
                                     Daily Schedule 
                                    
                                    .. attribute:: hh_mm
                                    
                                    	Begin Time hh\:mm
                                    	**type**\: str
                                    
                                    	**pattern:** ([0\-1]?[0\-9]\|2[0\-4])\:([0\-5][0\-9])(\:[0\-5][0\-9])?
                                    
                                    

                                    """

                                    _prefix = 'ios-diag'
                                    _revision = '2017-02-07'

                                    def __init__(self):
                                        super(Native.Diagnostic.Schedule.Switch.Test.PerPort.Port.InterfacePortNumber.Daily, self).__init__()

                                        self.yang_name = "daily"
                                        self.yang_parent_name = "interface-port-number"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('hh_mm', (YLeaf(YType.str, 'hh-mm'), ['str'])),
                                        ])
                                        self.hh_mm = None
                                        self._segment_path = lambda: "daily"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Diagnostic.Schedule.Switch.Test.PerPort.Port.InterfacePortNumber.Daily, ['hh_mm'], name, value)


                                class On(Entity):
                                    """
                                     Absolute Schedule 
                                    
                                    .. attribute:: month
                                    
                                    	Enter month \-> Jan\|Feb\|Mar\|Apr\|May\|Jun\|Jul\|Aug\|Sep\|Oct\|Nov\|Dec
                                    	**type**\:  :py:class:`MonthType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_types.MonthType>`
                                    
                                    .. attribute:: day_of_month
                                    
                                    	 <1\-31>  Day of month 
                                    	**type**\: int
                                    
                                    	**range:** 1..31
                                    
                                    .. attribute:: year
                                    
                                    	Enter Year <1993\-2035>
                                    	**type**\: int
                                    
                                    	**range:** 1993..2035
                                    
                                    .. attribute:: hh_mm
                                    
                                    	Begin Time hh\:mm
                                    	**type**\: str
                                    
                                    	**pattern:** ([0\-1]?[0\-9]\|2[0\-4])\:([0\-5][0\-9])(\:[0\-5][0\-9])?
                                    
                                    

                                    """

                                    _prefix = 'ios-diag'
                                    _revision = '2017-02-07'

                                    def __init__(self):
                                        super(Native.Diagnostic.Schedule.Switch.Test.PerPort.Port.InterfacePortNumber.On, self).__init__()

                                        self.yang_name = "on"
                                        self.yang_parent_name = "interface-port-number"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('month', (YLeaf(YType.enumeration, 'month'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_types', 'MonthType', '')])),
                                            ('day_of_month', (YLeaf(YType.uint16, 'day-of-month'), ['int'])),
                                            ('year', (YLeaf(YType.uint16, 'Year'), ['int'])),
                                            ('hh_mm', (YLeaf(YType.str, 'hh-mm'), ['str'])),
                                        ])
                                        self.month = None
                                        self.day_of_month = None
                                        self.year = None
                                        self.hh_mm = None
                                        self._segment_path = lambda: "on"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Diagnostic.Schedule.Switch.Test.PerPort.Port.InterfacePortNumber.On, ['month', 'day_of_month', 'year', 'hh_mm'], name, value)


                                class Weekly(Entity):
                                    """
                                    Weekly schedule
                                    
                                    .. attribute:: day
                                    
                                    	Enter Day of the week   Mon\|Tue\|Wed\|Thu\|Fri\|Sat\|Sun
                                    	**type**\:  :py:class:`WeekdayType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_types.WeekdayType>`
                                    
                                    .. attribute:: hh_mm
                                    
                                    	Begin Time hh\:mm
                                    	**type**\: str
                                    
                                    	**pattern:** ([0\-1]?[0\-9]\|2[0\-4])\:([0\-5][0\-9])(\:[0\-5][0\-9])?
                                    
                                    

                                    """

                                    _prefix = 'ios-diag'
                                    _revision = '2017-02-07'

                                    def __init__(self):
                                        super(Native.Diagnostic.Schedule.Switch.Test.PerPort.Port.InterfacePortNumber.Weekly, self).__init__()

                                        self.yang_name = "weekly"
                                        self.yang_parent_name = "interface-port-number"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('day', (YLeaf(YType.enumeration, 'day'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_types', 'WeekdayType', '')])),
                                            ('hh_mm', (YLeaf(YType.str, 'hh-mm'), ['str'])),
                                        ])
                                        self.day = None
                                        self.hh_mm = None
                                        self._segment_path = lambda: "weekly"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Diagnostic.Schedule.Switch.Test.PerPort.Port.InterfacePortNumber.Weekly, ['day', 'hh_mm'], name, value)


                            class PortNumberList(Entity):
                                """
                                Port number list (e.g. 2,4\-7)
                                
                                .. attribute:: number_list  (key)
                                
                                	Port number list (e.g. 2,4\-7)
                                	**type**\: str
                                
                                .. attribute:: daily
                                
                                	 Daily Schedule 
                                	**type**\:  :py:class:`Daily <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Diagnostic.Schedule.Switch.Test.PerPort.Port.PortNumberList.Daily>`
                                
                                .. attribute:: on
                                
                                	 Absolute Schedule 
                                	**type**\:  :py:class:`On <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Diagnostic.Schedule.Switch.Test.PerPort.Port.PortNumberList.On>`
                                
                                .. attribute:: weekly
                                
                                	Weekly schedule
                                	**type**\:  :py:class:`Weekly <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Diagnostic.Schedule.Switch.Test.PerPort.Port.PortNumberList.Weekly>`
                                
                                

                                """

                                _prefix = 'ios-diag'
                                _revision = '2017-02-07'

                                def __init__(self):
                                    super(Native.Diagnostic.Schedule.Switch.Test.PerPort.Port.PortNumberList, self).__init__()

                                    self.yang_name = "port-number-list"
                                    self.yang_parent_name = "port"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = ['number_list']
                                    self._child_classes = OrderedDict([("daily", ("daily", Native.Diagnostic.Schedule.Switch.Test.PerPort.Port.PortNumberList.Daily)), ("on", ("on", Native.Diagnostic.Schedule.Switch.Test.PerPort.Port.PortNumberList.On)), ("weekly", ("weekly", Native.Diagnostic.Schedule.Switch.Test.PerPort.Port.PortNumberList.Weekly))])
                                    self._leafs = OrderedDict([
                                        ('number_list', (YLeaf(YType.str, 'number-list'), ['str'])),
                                    ])
                                    self.number_list = None

                                    self.daily = Native.Diagnostic.Schedule.Switch.Test.PerPort.Port.PortNumberList.Daily()
                                    self.daily.parent = self
                                    self._children_name_map["daily"] = "daily"

                                    self.on = Native.Diagnostic.Schedule.Switch.Test.PerPort.Port.PortNumberList.On()
                                    self.on.parent = self
                                    self._children_name_map["on"] = "on"

                                    self.weekly = Native.Diagnostic.Schedule.Switch.Test.PerPort.Port.PortNumberList.Weekly()
                                    self.weekly.parent = self
                                    self._children_name_map["weekly"] = "weekly"
                                    self._segment_path = lambda: "port-number-list" + "[number-list='" + str(self.number_list) + "']"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Diagnostic.Schedule.Switch.Test.PerPort.Port.PortNumberList, ['number_list'], name, value)


                                class Daily(Entity):
                                    """
                                     Daily Schedule 
                                    
                                    .. attribute:: hh_mm
                                    
                                    	Begin Time hh\:mm
                                    	**type**\: str
                                    
                                    	**pattern:** ([0\-1]?[0\-9]\|2[0\-4])\:([0\-5][0\-9])(\:[0\-5][0\-9])?
                                    
                                    

                                    """

                                    _prefix = 'ios-diag'
                                    _revision = '2017-02-07'

                                    def __init__(self):
                                        super(Native.Diagnostic.Schedule.Switch.Test.PerPort.Port.PortNumberList.Daily, self).__init__()

                                        self.yang_name = "daily"
                                        self.yang_parent_name = "port-number-list"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('hh_mm', (YLeaf(YType.str, 'hh-mm'), ['str'])),
                                        ])
                                        self.hh_mm = None
                                        self._segment_path = lambda: "daily"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Diagnostic.Schedule.Switch.Test.PerPort.Port.PortNumberList.Daily, ['hh_mm'], name, value)


                                class On(Entity):
                                    """
                                     Absolute Schedule 
                                    
                                    .. attribute:: month
                                    
                                    	Enter month \-> Jan\|Feb\|Mar\|Apr\|May\|Jun\|Jul\|Aug\|Sep\|Oct\|Nov\|Dec
                                    	**type**\:  :py:class:`MonthType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_types.MonthType>`
                                    
                                    .. attribute:: day_of_month
                                    
                                    	 <1\-31>  Day of month 
                                    	**type**\: int
                                    
                                    	**range:** 1..31
                                    
                                    .. attribute:: year
                                    
                                    	Enter Year <1993\-2035>
                                    	**type**\: int
                                    
                                    	**range:** 1993..2035
                                    
                                    .. attribute:: hh_mm
                                    
                                    	Begin Time hh\:mm
                                    	**type**\: str
                                    
                                    	**pattern:** ([0\-1]?[0\-9]\|2[0\-4])\:([0\-5][0\-9])(\:[0\-5][0\-9])?
                                    
                                    

                                    """

                                    _prefix = 'ios-diag'
                                    _revision = '2017-02-07'

                                    def __init__(self):
                                        super(Native.Diagnostic.Schedule.Switch.Test.PerPort.Port.PortNumberList.On, self).__init__()

                                        self.yang_name = "on"
                                        self.yang_parent_name = "port-number-list"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('month', (YLeaf(YType.enumeration, 'month'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_types', 'MonthType', '')])),
                                            ('day_of_month', (YLeaf(YType.uint16, 'day-of-month'), ['int'])),
                                            ('year', (YLeaf(YType.uint16, 'Year'), ['int'])),
                                            ('hh_mm', (YLeaf(YType.str, 'hh-mm'), ['str'])),
                                        ])
                                        self.month = None
                                        self.day_of_month = None
                                        self.year = None
                                        self.hh_mm = None
                                        self._segment_path = lambda: "on"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Diagnostic.Schedule.Switch.Test.PerPort.Port.PortNumberList.On, ['month', 'day_of_month', 'year', 'hh_mm'], name, value)


                                class Weekly(Entity):
                                    """
                                    Weekly schedule
                                    
                                    .. attribute:: day
                                    
                                    	Enter Day of the week   Mon\|Tue\|Wed\|Thu\|Fri\|Sat\|Sun
                                    	**type**\:  :py:class:`WeekdayType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_types.WeekdayType>`
                                    
                                    .. attribute:: hh_mm
                                    
                                    	Begin Time hh\:mm
                                    	**type**\: str
                                    
                                    	**pattern:** ([0\-1]?[0\-9]\|2[0\-4])\:([0\-5][0\-9])(\:[0\-5][0\-9])?
                                    
                                    

                                    """

                                    _prefix = 'ios-diag'
                                    _revision = '2017-02-07'

                                    def __init__(self):
                                        super(Native.Diagnostic.Schedule.Switch.Test.PerPort.Port.PortNumberList.Weekly, self).__init__()

                                        self.yang_name = "weekly"
                                        self.yang_parent_name = "port-number-list"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('day', (YLeaf(YType.enumeration, 'day'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_types', 'WeekdayType', '')])),
                                            ('hh_mm', (YLeaf(YType.str, 'hh-mm'), ['str'])),
                                        ])
                                        self.day = None
                                        self.hh_mm = None
                                        self._segment_path = lambda: "weekly"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Diagnostic.Schedule.Switch.Test.PerPort.Port.PortNumberList.Weekly, ['day', 'hh_mm'], name, value)


                            class All(Entity):
                                """
                                Select all ports
                                
                                .. attribute:: daily
                                
                                	 Daily Schedule 
                                	**type**\:  :py:class:`Daily <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Diagnostic.Schedule.Switch.Test.PerPort.Port.All.Daily>`
                                
                                .. attribute:: on
                                
                                	 Absolute Schedule 
                                	**type**\:  :py:class:`On <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Diagnostic.Schedule.Switch.Test.PerPort.Port.All.On>`
                                
                                .. attribute:: weekly
                                
                                	Weekly schedule
                                	**type**\:  :py:class:`Weekly <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Diagnostic.Schedule.Switch.Test.PerPort.Port.All.Weekly>`
                                
                                

                                """

                                _prefix = 'ios-diag'
                                _revision = '2017-02-07'

                                def __init__(self):
                                    super(Native.Diagnostic.Schedule.Switch.Test.PerPort.Port.All, self).__init__()

                                    self.yang_name = "all"
                                    self.yang_parent_name = "port"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("daily", ("daily", Native.Diagnostic.Schedule.Switch.Test.PerPort.Port.All.Daily)), ("on", ("on", Native.Diagnostic.Schedule.Switch.Test.PerPort.Port.All.On)), ("weekly", ("weekly", Native.Diagnostic.Schedule.Switch.Test.PerPort.Port.All.Weekly))])
                                    self._leafs = OrderedDict()

                                    self.daily = Native.Diagnostic.Schedule.Switch.Test.PerPort.Port.All.Daily()
                                    self.daily.parent = self
                                    self._children_name_map["daily"] = "daily"

                                    self.on = Native.Diagnostic.Schedule.Switch.Test.PerPort.Port.All.On()
                                    self.on.parent = self
                                    self._children_name_map["on"] = "on"

                                    self.weekly = Native.Diagnostic.Schedule.Switch.Test.PerPort.Port.All.Weekly()
                                    self.weekly.parent = self
                                    self._children_name_map["weekly"] = "weekly"
                                    self._segment_path = lambda: "all"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.Diagnostic.Schedule.Switch.Test.PerPort.Port.All, [], name, value)


                                class Daily(Entity):
                                    """
                                     Daily Schedule 
                                    
                                    .. attribute:: hh_mm
                                    
                                    	Begin Time hh\:mm
                                    	**type**\: str
                                    
                                    	**pattern:** ([0\-1]?[0\-9]\|2[0\-4])\:([0\-5][0\-9])(\:[0\-5][0\-9])?
                                    
                                    

                                    """

                                    _prefix = 'ios-diag'
                                    _revision = '2017-02-07'

                                    def __init__(self):
                                        super(Native.Diagnostic.Schedule.Switch.Test.PerPort.Port.All.Daily, self).__init__()

                                        self.yang_name = "daily"
                                        self.yang_parent_name = "all"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('hh_mm', (YLeaf(YType.str, 'hh-mm'), ['str'])),
                                        ])
                                        self.hh_mm = None
                                        self._segment_path = lambda: "daily"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Diagnostic.Schedule.Switch.Test.PerPort.Port.All.Daily, ['hh_mm'], name, value)


                                class On(Entity):
                                    """
                                     Absolute Schedule 
                                    
                                    .. attribute:: month
                                    
                                    	Enter month \-> Jan\|Feb\|Mar\|Apr\|May\|Jun\|Jul\|Aug\|Sep\|Oct\|Nov\|Dec
                                    	**type**\:  :py:class:`MonthType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_types.MonthType>`
                                    
                                    .. attribute:: day_of_month
                                    
                                    	 <1\-31>  Day of month 
                                    	**type**\: int
                                    
                                    	**range:** 1..31
                                    
                                    .. attribute:: year
                                    
                                    	Enter Year <1993\-2035>
                                    	**type**\: int
                                    
                                    	**range:** 1993..2035
                                    
                                    .. attribute:: hh_mm
                                    
                                    	Begin Time hh\:mm
                                    	**type**\: str
                                    
                                    	**pattern:** ([0\-1]?[0\-9]\|2[0\-4])\:([0\-5][0\-9])(\:[0\-5][0\-9])?
                                    
                                    

                                    """

                                    _prefix = 'ios-diag'
                                    _revision = '2017-02-07'

                                    def __init__(self):
                                        super(Native.Diagnostic.Schedule.Switch.Test.PerPort.Port.All.On, self).__init__()

                                        self.yang_name = "on"
                                        self.yang_parent_name = "all"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('month', (YLeaf(YType.enumeration, 'month'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_types', 'MonthType', '')])),
                                            ('day_of_month', (YLeaf(YType.uint16, 'day-of-month'), ['int'])),
                                            ('year', (YLeaf(YType.uint16, 'Year'), ['int'])),
                                            ('hh_mm', (YLeaf(YType.str, 'hh-mm'), ['str'])),
                                        ])
                                        self.month = None
                                        self.day_of_month = None
                                        self.year = None
                                        self.hh_mm = None
                                        self._segment_path = lambda: "on"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Diagnostic.Schedule.Switch.Test.PerPort.Port.All.On, ['month', 'day_of_month', 'year', 'hh_mm'], name, value)


                                class Weekly(Entity):
                                    """
                                    Weekly schedule
                                    
                                    .. attribute:: day
                                    
                                    	Enter Day of the week   Mon\|Tue\|Wed\|Thu\|Fri\|Sat\|Sun
                                    	**type**\:  :py:class:`WeekdayType <ydk.models.cisco_ios_xe.Cisco_IOS_XE_types.WeekdayType>`
                                    
                                    .. attribute:: hh_mm
                                    
                                    	Begin Time hh\:mm
                                    	**type**\: str
                                    
                                    	**pattern:** ([0\-1]?[0\-9]\|2[0\-4])\:([0\-5][0\-9])(\:[0\-5][0\-9])?
                                    
                                    

                                    """

                                    _prefix = 'ios-diag'
                                    _revision = '2017-02-07'

                                    def __init__(self):
                                        super(Native.Diagnostic.Schedule.Switch.Test.PerPort.Port.All.Weekly, self).__init__()

                                        self.yang_name = "weekly"
                                        self.yang_parent_name = "all"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('day', (YLeaf(YType.enumeration, 'day'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_types', 'WeekdayType', '')])),
                                            ('hh_mm', (YLeaf(YType.str, 'hh-mm'), ['str'])),
                                        ])
                                        self.day = None
                                        self.hh_mm = None
                                        self._segment_path = lambda: "weekly"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Native.Diagnostic.Schedule.Switch.Test.PerPort.Port.All.Weekly, ['day', 'hh_mm'], name, value)


    class Nat66(Entity):
        """
        NAT66 configuration commands
        
        .. attribute:: prefix
        
        	NAT66 prefix
        	**type**\:  :py:class:`Prefix <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Nat66.Prefix>`
        
        

        """

        _prefix = 'ios-nat'
        _revision = '2018-06-30'

        def __init__(self):
            super(Native.Nat66, self).__init__()

            self.yang_name = "nat66"
            self.yang_parent_name = "native"
            self.is_top_level_class = False
            self.has_list_ancestor = False
            self.ylist_key_names = []
            self._child_classes = OrderedDict([("prefix", ("prefix", Native.Nat66.Prefix))])
            self._leafs = OrderedDict()

            self.prefix = Native.Nat66.Prefix()
            self.prefix.parent = self
            self._children_name_map["prefix"] = "prefix"
            self._segment_path = lambda: "Cisco-IOS-XE-nat:nat66"
            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/%s" % self._segment_path()
            self._is_frozen = True

        def __setattr__(self, name, value):
            self._perform_setattr(Native.Nat66, [], name, value)


        class Prefix(Entity):
            """
            NAT66 prefix
            
            .. attribute:: inside
            
            	inside prefix
            	**type**\: list of  		 :py:class:`Inside <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Nat66.Prefix.Inside>`
            
            

            """

            _prefix = 'ios-nat'
            _revision = '2018-06-30'

            def __init__(self):
                super(Native.Nat66.Prefix, self).__init__()

                self.yang_name = "prefix"
                self.yang_parent_name = "nat66"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = []
                self._child_classes = OrderedDict([("inside", ("inside", Native.Nat66.Prefix.Inside))])
                self._leafs = OrderedDict()

                self.inside = YList(self)
                self._segment_path = lambda: "prefix"
                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/Cisco-IOS-XE-nat:nat66/%s" % self._segment_path()
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(Native.Nat66.Prefix, [], name, value)


            class Inside(Entity):
                """
                inside prefix
                
                .. attribute:: inside_pfx  (key)
                
                	IPv6 prefix
                	**type**\: str
                
                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(/(([0\-9])\|([0\-9]{2})\|(1[0\-1][0\-9])\|(12[0\-8])))
                
                .. attribute:: outside
                
                	outside prefix
                	**type**\: str
                
                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(/(([0\-9])\|([0\-9]{2})\|(1[0\-1][0\-9])\|(12[0\-8])))
                
                

                """

                _prefix = 'ios-nat'
                _revision = '2018-06-30'

                def __init__(self):
                    super(Native.Nat66.Prefix.Inside, self).__init__()

                    self.yang_name = "inside"
                    self.yang_parent_name = "prefix"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = ['inside_pfx']
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('inside_pfx', (YLeaf(YType.str, 'inside-pfx'), ['str'])),
                        ('outside', (YLeaf(YType.str, 'outside'), ['str'])),
                    ])
                    self.inside_pfx = None
                    self.outside = None
                    self._segment_path = lambda: "inside" + "[inside-pfx='" + str(self.inside_pfx) + "']"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/Cisco-IOS-XE-nat:nat66/prefix/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.Nat66.Prefix.Inside, ['inside_pfx', 'outside'], name, value)


    class BbaGroup(Entity):
        """
        Configure BBA Group
        
        .. attribute:: pppoe
        
        	PPPoE type
        	**type**\: list of  		 :py:class:`Pppoe <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.BbaGroup.Pppoe>`
        
        

        """

        _prefix = 'ios-bba'
        _revision = '2017-02-07'

        def __init__(self):
            super(Native.BbaGroup, self).__init__()

            self.yang_name = "bba-group"
            self.yang_parent_name = "native"
            self.is_top_level_class = False
            self.has_list_ancestor = False
            self.ylist_key_names = []
            self._child_classes = OrderedDict([("pppoe", ("pppoe", Native.BbaGroup.Pppoe))])
            self._leafs = OrderedDict()

            self.pppoe = YList(self)
            self._segment_path = lambda: "Cisco-IOS-XE-bba-group:bba-group"
            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/%s" % self._segment_path()
            self._is_frozen = True

        def __setattr__(self, name, value):
            self._perform_setattr(Native.BbaGroup, [], name, value)


        class Pppoe(Entity):
            """
            PPPoE type
            
            .. attribute:: id  (key)
            
            	
            	**type**\: union of the below types:
            
            		**type**\: str
            
            		**type**\:  :py:class:`Id <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.BbaGroup.Pppoe.Id>`
            
            .. attribute:: vendor_tag
            
            	PPPoE Vendor Specific Tag
            	**type**\:  :py:class:`VendorTag <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.BbaGroup.Pppoe.VendorTag>`
            
            .. attribute:: virtual_template
            
            	BBA virtual template command
            	**type**\: int
            
            	**range:** 1..4095
            
            

            """

            _prefix = 'ios-bba'
            _revision = '2017-02-07'

            def __init__(self):
                super(Native.BbaGroup.Pppoe, self).__init__()

                self.yang_name = "pppoe"
                self.yang_parent_name = "bba-group"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = ['id']
                self._child_classes = OrderedDict([("vendor-tag", ("vendor_tag", Native.BbaGroup.Pppoe.VendorTag))])
                self._leafs = OrderedDict([
                    ('id', (YLeaf(YType.str, 'id'), ['str',('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'BbaGroup.Pppoe.Id')])),
                    ('virtual_template', (YLeaf(YType.uint16, 'virtual-template'), ['int'])),
                ])
                self.id = None
                self.virtual_template = None

                self.vendor_tag = Native.BbaGroup.Pppoe.VendorTag()
                self.vendor_tag.parent = self
                self._children_name_map["vendor_tag"] = "vendor-tag"
                self._segment_path = lambda: "pppoe" + "[id='" + str(self.id) + "']"
                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/Cisco-IOS-XE-bba-group:bba-group/%s" % self._segment_path()
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(Native.BbaGroup.Pppoe, ['id', 'virtual_template'], name, value)

            class Id(Enum):
                """
                Id (Enum Class)

                .. data:: global_ = 0

                """

                global_ = Enum.YLeaf(0, "global")



            class VendorTag(Entity):
                """
                PPPoE Vendor Specific Tag
                
                .. attribute:: circuit_id
                
                	Circuit\-Id
                	**type**\:  :py:class:`CircuitId <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.BbaGroup.Pppoe.VendorTag.CircuitId>`
                
                .. attribute:: dsl_sync_rate
                
                	DSL\-Sync\-Rate
                	**type**\:  :py:class:`DslSyncRate <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.BbaGroup.Pppoe.VendorTag.DslSyncRate>`
                
                .. attribute:: remote_id
                
                	Remote\-Id
                	**type**\:  :py:class:`RemoteId <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.BbaGroup.Pppoe.VendorTag.RemoteId>`
                
                .. attribute:: strip
                
                	Strip all vendor tags
                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                
                

                """

                _prefix = 'ios-bba'
                _revision = '2017-02-07'

                def __init__(self):
                    super(Native.BbaGroup.Pppoe.VendorTag, self).__init__()

                    self.yang_name = "vendor-tag"
                    self.yang_parent_name = "pppoe"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("circuit-id", ("circuit_id", Native.BbaGroup.Pppoe.VendorTag.CircuitId)), ("dsl-sync-rate", ("dsl_sync_rate", Native.BbaGroup.Pppoe.VendorTag.DslSyncRate)), ("remote-id", ("remote_id", Native.BbaGroup.Pppoe.VendorTag.RemoteId))])
                    self._leafs = OrderedDict([
                        ('strip', (YLeaf(YType.empty, 'strip'), ['Empty'])),
                    ])
                    self.strip = None

                    self.circuit_id = Native.BbaGroup.Pppoe.VendorTag.CircuitId()
                    self.circuit_id.parent = self
                    self._children_name_map["circuit_id"] = "circuit-id"

                    self.dsl_sync_rate = Native.BbaGroup.Pppoe.VendorTag.DslSyncRate()
                    self.dsl_sync_rate.parent = self
                    self._children_name_map["dsl_sync_rate"] = "dsl-sync-rate"

                    self.remote_id = Native.BbaGroup.Pppoe.VendorTag.RemoteId()
                    self.remote_id.parent = self
                    self._children_name_map["remote_id"] = "remote-id"
                    self._segment_path = lambda: "vendor-tag"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.BbaGroup.Pppoe.VendorTag, ['strip'], name, value)


                class CircuitId(Entity):
                    """
                    Circuit\-Id
                    
                    .. attribute:: service
                    
                    	Enable processing
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios-bba'
                    _revision = '2017-02-07'

                    def __init__(self):
                        super(Native.BbaGroup.Pppoe.VendorTag.CircuitId, self).__init__()

                        self.yang_name = "circuit-id"
                        self.yang_parent_name = "vendor-tag"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('service', (YLeaf(YType.empty, 'service'), ['Empty'])),
                        ])
                        self.service = None
                        self._segment_path = lambda: "circuit-id"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.BbaGroup.Pppoe.VendorTag.CircuitId, ['service'], name, value)


                class DslSyncRate(Entity):
                    """
                    DSL\-Sync\-Rate
                    
                    .. attribute:: service
                    
                    	Enable processing
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios-bba'
                    _revision = '2017-02-07'

                    def __init__(self):
                        super(Native.BbaGroup.Pppoe.VendorTag.DslSyncRate, self).__init__()

                        self.yang_name = "dsl-sync-rate"
                        self.yang_parent_name = "vendor-tag"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('service', (YLeaf(YType.empty, 'service'), ['Empty'])),
                        ])
                        self.service = None
                        self._segment_path = lambda: "dsl-sync-rate"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.BbaGroup.Pppoe.VendorTag.DslSyncRate, ['service'], name, value)


                class RemoteId(Entity):
                    """
                    Remote\-Id
                    
                    .. attribute:: service
                    
                    	Enable processing
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ios-bba'
                    _revision = '2017-02-07'

                    def __init__(self):
                        super(Native.BbaGroup.Pppoe.VendorTag.RemoteId, self).__init__()

                        self.yang_name = "remote-id"
                        self.yang_parent_name = "vendor-tag"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('service', (YLeaf(YType.empty, 'service'), ['Empty'])),
                        ])
                        self.service = None
                        self._segment_path = lambda: "remote-id"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.BbaGroup.Pppoe.VendorTag.RemoteId, ['service'], name, value)


    class Shell(Entity):
        """
        Configure shell command
        
        .. attribute:: trigger
        
        	Set shell trigger configuration
        	**type**\: list of  		 :py:class:`Trigger <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Shell.Trigger>`
        
        

        """

        _prefix = 'ios-plt'
        _revision = '2018-05-17'

        def __init__(self):
            super(Native.Shell, self).__init__()

            self.yang_name = "shell"
            self.yang_parent_name = "native"
            self.is_top_level_class = False
            self.has_list_ancestor = False
            self.ylist_key_names = []
            self._child_classes = OrderedDict([("trigger", ("trigger", Native.Shell.Trigger))])
            self._leafs = OrderedDict()

            self.trigger = YList(self)
            self._segment_path = lambda: "Cisco-IOS-XE-platform:shell"
            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/%s" % self._segment_path()
            self._is_frozen = True

        def __setattr__(self, name, value):
            self._perform_setattr(Native.Shell, [], name, value)


        class Trigger(Entity):
            """
            Set shell trigger configuration
            
            .. attribute:: word  (key)
            
            	
            	**type**\: str
            
            .. attribute:: line
            
            	
            	**type**\: str
            
            

            """

            _prefix = 'ios-plt'
            _revision = '2018-05-17'

            def __init__(self):
                super(Native.Shell.Trigger, self).__init__()

                self.yang_name = "trigger"
                self.yang_parent_name = "shell"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = ['word']
                self._child_classes = OrderedDict([])
                self._leafs = OrderedDict([
                    ('word', (YLeaf(YType.str, 'word'), ['str'])),
                    ('line', (YLeaf(YType.str, 'line'), ['str'])),
                ])
                self.word = None
                self.line = None
                self._segment_path = lambda: "trigger" + "[word='" + str(self.word) + "']"
                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/Cisco-IOS-XE-platform:shell/%s" % self._segment_path()
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(Native.Shell.Trigger, ['word', 'line'], name, value)


    class Vstack(Entity):
        """
        Configure vstack parameters and enable or disable SmartInstall
        
        .. attribute:: director
        
        	Configure director's IP address
        	**type**\: str
        
        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
        
        

        """

        _prefix = 'ios-vstack'
        _revision = '2017-02-07'

        def __init__(self):
            super(Native.Vstack, self).__init__()

            self.yang_name = "vstack"
            self.yang_parent_name = "native"
            self.is_top_level_class = False
            self.has_list_ancestor = False
            self.ylist_key_names = []
            self._child_classes = OrderedDict([])
            self._leafs = OrderedDict([
                ('director', (YLeaf(YType.str, 'director'), ['str'])),
            ])
            self.director = None
            self._segment_path = lambda: "Cisco-IOS-XE-vstack:vstack"
            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/%s" % self._segment_path()
            self._is_frozen = True

        def __setattr__(self, name, value):
            self._perform_setattr(Native.Vstack, ['director'], name, value)


    class PmAgent(Entity):
        """
        pm\-agent Configuration Commands
        
        .. attribute:: config_pm_agent
        
        	
        	**type**\:  :py:class:`ConfigPmAgent <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.PmAgent.ConfigPmAgent>`
        
        

        This class is a :ref:`presence class<presence-class>`

        """

        _prefix = 'ios-pathmgr'
        _revision = '2017-02-07'

        def __init__(self):
            super(Native.PmAgent, self).__init__()

            self.yang_name = "pm-agent"
            self.yang_parent_name = "native"
            self.is_top_level_class = False
            self.has_list_ancestor = False
            self.ylist_key_names = []
            self._child_classes = OrderedDict([("config-pm-agent", ("config_pm_agent", Native.PmAgent.ConfigPmAgent))])
            self.is_presence_container = True
            self._leafs = OrderedDict()

            self.config_pm_agent = Native.PmAgent.ConfigPmAgent()
            self.config_pm_agent.parent = self
            self._children_name_map["config_pm_agent"] = "config-pm-agent"
            self._segment_path = lambda: "Cisco-IOS-XE-pathmgr:pm-agent"
            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/%s" % self._segment_path()
            self._is_frozen = True

        def __setattr__(self, name, value):
            self._perform_setattr(Native.PmAgent, [], name, value)


        class ConfigPmAgent(Entity):
            """
            
            
            .. attribute:: device
            
            	Enter the device ID
            	**type**\:  :py:class:`Device <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.PmAgent.ConfigPmAgent.Device>`
            
            .. attribute:: instance_id
            
            	Enter the instance ID
            	**type**\: list of  		 :py:class:`InstanceId <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.PmAgent.ConfigPmAgent.InstanceId>`
            
            .. attribute:: region
            
            	Enter the region ID
            	**type**\:  :py:class:`Region <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.PmAgent.ConfigPmAgent.Region>`
            
            .. attribute:: shutdown
            
            	shut the device
            	**type**\: :py:class:`Empty<ydk.types.Empty>`
            
            .. attribute:: site
            
            	Enter the site configuration
            	**type**\:  :py:class:`Site <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.PmAgent.ConfigPmAgent.Site>`
            
            .. attribute:: tenant
            
            	enter the tenant configuration
            	**type**\:  :py:class:`Tenant <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.PmAgent.ConfigPmAgent.Tenant>`
            
            .. attribute:: pmcs
            
            	Enter the pmcs configuration
            	**type**\:  :py:class:`Pmcs <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.PmAgent.ConfigPmAgent.Pmcs>`
            
            

            """

            _prefix = 'ios-pathmgr'
            _revision = '2017-02-07'

            def __init__(self):
                super(Native.PmAgent.ConfigPmAgent, self).__init__()

                self.yang_name = "config-pm-agent"
                self.yang_parent_name = "pm-agent"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = []
                self._child_classes = OrderedDict([("device", ("device", Native.PmAgent.ConfigPmAgent.Device)), ("instance-id", ("instance_id", Native.PmAgent.ConfigPmAgent.InstanceId)), ("region", ("region", Native.PmAgent.ConfigPmAgent.Region)), ("site", ("site", Native.PmAgent.ConfigPmAgent.Site)), ("tenant", ("tenant", Native.PmAgent.ConfigPmAgent.Tenant)), ("pmcs", ("pmcs", Native.PmAgent.ConfigPmAgent.Pmcs))])
                self._leafs = OrderedDict([
                    ('shutdown', (YLeaf(YType.empty, 'shutdown'), ['Empty'])),
                ])
                self.shutdown = None

                self.device = Native.PmAgent.ConfigPmAgent.Device()
                self.device.parent = self
                self._children_name_map["device"] = "device"

                self.region = Native.PmAgent.ConfigPmAgent.Region()
                self.region.parent = self
                self._children_name_map["region"] = "region"

                self.site = Native.PmAgent.ConfigPmAgent.Site()
                self.site.parent = self
                self._children_name_map["site"] = "site"

                self.tenant = Native.PmAgent.ConfigPmAgent.Tenant()
                self.tenant.parent = self
                self._children_name_map["tenant"] = "tenant"

                self.pmcs = Native.PmAgent.ConfigPmAgent.Pmcs()
                self.pmcs.parent = self
                self._children_name_map["pmcs"] = "pmcs"

                self.instance_id = YList(self)
                self._segment_path = lambda: "config-pm-agent"
                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/Cisco-IOS-XE-pathmgr:pm-agent/%s" % self._segment_path()
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(Native.PmAgent.ConfigPmAgent, ['shutdown'], name, value)


            class Device(Entity):
                """
                Enter the device ID
                
                .. attribute:: id
                
                	Specify the device ID
                	**type**\:  :py:class:`Id <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.PmAgent.ConfigPmAgent.Device.Id>`
                
                .. attribute:: type
                
                	Enter the device type
                	**type**\:  :py:class:`Type <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.PmAgent.ConfigPmAgent.Device.Type>`
                
                

                """

                _prefix = 'ios-pathmgr'
                _revision = '2017-02-07'

                def __init__(self):
                    super(Native.PmAgent.ConfigPmAgent.Device, self).__init__()

                    self.yang_name = "device"
                    self.yang_parent_name = "config-pm-agent"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("id", ("id", Native.PmAgent.ConfigPmAgent.Device.Id)), ("type", ("type", Native.PmAgent.ConfigPmAgent.Device.Type))])
                    self._leafs = OrderedDict()

                    self.id = Native.PmAgent.ConfigPmAgent.Device.Id()
                    self.id.parent = self
                    self._children_name_map["id"] = "id"

                    self.type = Native.PmAgent.ConfigPmAgent.Device.Type()
                    self.type.parent = self
                    self._children_name_map["type"] = "type"
                    self._segment_path = lambda: "device"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/Cisco-IOS-XE-pathmgr:pm-agent/config-pm-agent/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.PmAgent.ConfigPmAgent.Device, [], name, value)


                class Id(Entity):
                    """
                    Specify the device ID
                    
                    .. attribute:: device_range
                    
                    	
                    	**type**\: list of  		 :py:class:`DeviceRange <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.PmAgent.ConfigPmAgent.Device.Id.DeviceRange>`
                    
                    

                    """

                    _prefix = 'ios-pathmgr'
                    _revision = '2017-02-07'

                    def __init__(self):
                        super(Native.PmAgent.ConfigPmAgent.Device.Id, self).__init__()

                        self.yang_name = "id"
                        self.yang_parent_name = "device"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("device_range", ("device_range", Native.PmAgent.ConfigPmAgent.Device.Id.DeviceRange))])
                        self._leafs = OrderedDict()

                        self.device_range = YList(self)
                        self._segment_path = lambda: "id"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/Cisco-IOS-XE-pathmgr:pm-agent/config-pm-agent/device/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.PmAgent.ConfigPmAgent.Device.Id, [], name, value)


                    class DeviceRange(Entity):
                        """
                        
                        
                        .. attribute:: device_id_range  (key)
                        
                        	Specify the device\-id value
                        	**type**\: int
                        
                        	**range:** 1..65535
                        
                        .. attribute:: name
                        
                        	Specify the device name
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios-pathmgr'
                        _revision = '2017-02-07'

                        def __init__(self):
                            super(Native.PmAgent.ConfigPmAgent.Device.Id.DeviceRange, self).__init__()

                            self.yang_name = "device_range"
                            self.yang_parent_name = "id"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = ['device_id_range']
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('device_id_range', (YLeaf(YType.uint32, 'device_id_range'), ['int'])),
                                ('name', (YLeaf(YType.str, 'name'), ['str'])),
                            ])
                            self.device_id_range = None
                            self.name = None
                            self._segment_path = lambda: "device_range" + "[device_id_range='" + str(self.device_id_range) + "']"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/Cisco-IOS-XE-pathmgr:pm-agent/config-pm-agent/device/id/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.PmAgent.ConfigPmAgent.Device.Id.DeviceRange, ['device_id_range', 'name'], name, value)


                class Type(Entity):
                    """
                    Enter the device type
                    
                    .. attribute:: ntr
                    
                    	ntr device type
                    	**type**\:  :py:class:`Ntr <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.PmAgent.ConfigPmAgent.Device.Type.Ntr>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: pxtr
                    
                    	pxtr device type
                    	**type**\: :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: rtr
                    
                    	rtr device type
                    	**type**\:  :py:class:`Rtr <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.PmAgent.ConfigPmAgent.Device.Type.Rtr>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: xtr
                    
                    	xtr device type
                    	**type**\:  :py:class:`Xtr <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.PmAgent.ConfigPmAgent.Device.Type.Xtr>`
                    
                    	**presence node**\: True
                    
                    

                    """

                    _prefix = 'ios-pathmgr'
                    _revision = '2017-02-07'

                    def __init__(self):
                        super(Native.PmAgent.ConfigPmAgent.Device.Type, self).__init__()

                        self.yang_name = "type"
                        self.yang_parent_name = "device"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("ntr", ("ntr", Native.PmAgent.ConfigPmAgent.Device.Type.Ntr)), ("rtr", ("rtr", Native.PmAgent.ConfigPmAgent.Device.Type.Rtr)), ("xtr", ("xtr", Native.PmAgent.ConfigPmAgent.Device.Type.Xtr))])
                        self._leafs = OrderedDict([
                            ('pxtr', (YLeaf(YType.empty, 'pxtr'), ['Empty'])),
                        ])
                        self.pxtr = None

                        self.ntr = None
                        self._children_name_map["ntr"] = "ntr"

                        self.rtr = None
                        self._children_name_map["rtr"] = "rtr"

                        self.xtr = None
                        self._children_name_map["xtr"] = "xtr"
                        self._segment_path = lambda: "type"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/Cisco-IOS-XE-pathmgr:pm-agent/config-pm-agent/device/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.PmAgent.ConfigPmAgent.Device.Type, ['pxtr'], name, value)


                    class Ntr(Entity):
                        """
                        ntr device type
                        
                        .. attribute:: rtr
                        
                        	rtr device type
                        	**type**\:  :py:class:`Rtr <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.PmAgent.ConfigPmAgent.Device.Type.Ntr.Rtr>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: xtr
                        
                        	xtr device type
                        	**type**\:  :py:class:`Xtr <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.PmAgent.ConfigPmAgent.Device.Type.Ntr.Xtr>`
                        
                        	**presence node**\: True
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-pathmgr'
                        _revision = '2017-02-07'

                        def __init__(self):
                            super(Native.PmAgent.ConfigPmAgent.Device.Type.Ntr, self).__init__()

                            self.yang_name = "ntr"
                            self.yang_parent_name = "type"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("rtr", ("rtr", Native.PmAgent.ConfigPmAgent.Device.Type.Ntr.Rtr)), ("xtr", ("xtr", Native.PmAgent.ConfigPmAgent.Device.Type.Ntr.Xtr))])
                            self.is_presence_container = True
                            self._leafs = OrderedDict()

                            self.rtr = None
                            self._children_name_map["rtr"] = "rtr"

                            self.xtr = None
                            self._children_name_map["xtr"] = "xtr"
                            self._segment_path = lambda: "ntr"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/Cisco-IOS-XE-pathmgr:pm-agent/config-pm-agent/device/type/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.PmAgent.ConfigPmAgent.Device.Type.Ntr, [], name, value)


                        class Rtr(Entity):
                            """
                            rtr device type
                            
                            .. attribute:: xtr
                            
                            	xtr device type
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-pathmgr'
                            _revision = '2017-02-07'

                            def __init__(self):
                                super(Native.PmAgent.ConfigPmAgent.Device.Type.Ntr.Rtr, self).__init__()

                                self.yang_name = "rtr"
                                self.yang_parent_name = "ntr"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('xtr', (YLeaf(YType.empty, 'xtr'), ['Empty'])),
                                ])
                                self.xtr = None
                                self._segment_path = lambda: "rtr"
                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/Cisco-IOS-XE-pathmgr:pm-agent/config-pm-agent/device/type/ntr/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.PmAgent.ConfigPmAgent.Device.Type.Ntr.Rtr, ['xtr'], name, value)


                        class Xtr(Entity):
                            """
                            xtr device type
                            
                            .. attribute:: rtr
                            
                            	rtr device type
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-pathmgr'
                            _revision = '2017-02-07'

                            def __init__(self):
                                super(Native.PmAgent.ConfigPmAgent.Device.Type.Ntr.Xtr, self).__init__()

                                self.yang_name = "xtr"
                                self.yang_parent_name = "ntr"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('rtr', (YLeaf(YType.empty, 'rtr'), ['Empty'])),
                                ])
                                self.rtr = None
                                self._segment_path = lambda: "xtr"
                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/Cisco-IOS-XE-pathmgr:pm-agent/config-pm-agent/device/type/ntr/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.PmAgent.ConfigPmAgent.Device.Type.Ntr.Xtr, ['rtr'], name, value)


                    class Rtr(Entity):
                        """
                        rtr device type
                        
                        .. attribute:: ntr
                        
                        	ntr device type
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: xtr
                        
                        	xtr device type
                        	**type**\:  :py:class:`Xtr <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.PmAgent.ConfigPmAgent.Device.Type.Rtr.Xtr>`
                        
                        	**presence node**\: True
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-pathmgr'
                        _revision = '2017-02-07'

                        def __init__(self):
                            super(Native.PmAgent.ConfigPmAgent.Device.Type.Rtr, self).__init__()

                            self.yang_name = "rtr"
                            self.yang_parent_name = "type"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("xtr", ("xtr", Native.PmAgent.ConfigPmAgent.Device.Type.Rtr.Xtr))])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('ntr', (YLeaf(YType.empty, 'ntr'), ['Empty'])),
                            ])
                            self.ntr = None

                            self.xtr = None
                            self._children_name_map["xtr"] = "xtr"
                            self._segment_path = lambda: "rtr"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/Cisco-IOS-XE-pathmgr:pm-agent/config-pm-agent/device/type/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.PmAgent.ConfigPmAgent.Device.Type.Rtr, ['ntr'], name, value)


                        class Xtr(Entity):
                            """
                            xtr device type
                            
                            .. attribute:: ntr
                            
                            	ntr device type
                            	**type**\: :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ios-pathmgr'
                            _revision = '2017-02-07'

                            def __init__(self):
                                super(Native.PmAgent.ConfigPmAgent.Device.Type.Rtr.Xtr, self).__init__()

                                self.yang_name = "xtr"
                                self.yang_parent_name = "rtr"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self.is_presence_container = True
                                self._leafs = OrderedDict([
                                    ('ntr', (YLeaf(YType.empty, 'ntr'), ['Empty'])),
                                ])
                                self.ntr = None
                                self._segment_path = lambda: "xtr"
                                self._absolute_path = lambda: "Cisco-IOS-XE-native:native/Cisco-IOS-XE-pathmgr:pm-agent/config-pm-agent/device/type/rtr/%s" % self._segment_path()
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.PmAgent.ConfigPmAgent.Device.Type.Rtr.Xtr, ['ntr'], name, value)


                    class Xtr(Entity):
                        """
                        xtr device type
                        
                        .. attribute:: ntr
                        
                        	ntr device type
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: rtr
                        
                        	rtr device type
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ios-pathmgr'
                        _revision = '2017-02-07'

                        def __init__(self):
                            super(Native.PmAgent.ConfigPmAgent.Device.Type.Xtr, self).__init__()

                            self.yang_name = "xtr"
                            self.yang_parent_name = "type"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self.is_presence_container = True
                            self._leafs = OrderedDict([
                                ('ntr', (YLeaf(YType.empty, 'ntr'), ['Empty'])),
                                ('rtr', (YLeaf(YType.empty, 'rtr'), ['Empty'])),
                            ])
                            self.ntr = None
                            self.rtr = None
                            self._segment_path = lambda: "xtr"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/Cisco-IOS-XE-pathmgr:pm-agent/config-pm-agent/device/type/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.PmAgent.ConfigPmAgent.Device.Type.Xtr, ['ntr', 'rtr'], name, value)


            class InstanceId(Entity):
                """
                Enter the instance ID
                
                .. attribute:: instance_id_range  (key)
                
                	Specify the instance\-id value
                	**type**\: int
                
                	**range:** 0..65535
                
                .. attribute:: config_pm_agent_instance
                
                	
                	**type**\:  :py:class:`ConfigPmAgentInstance <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.PmAgent.ConfigPmAgent.InstanceId.ConfigPmAgentInstance>`
                
                

                """

                _prefix = 'ios-pathmgr'
                _revision = '2017-02-07'

                def __init__(self):
                    super(Native.PmAgent.ConfigPmAgent.InstanceId, self).__init__()

                    self.yang_name = "instance-id"
                    self.yang_parent_name = "config-pm-agent"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = ['instance_id_range']
                    self._child_classes = OrderedDict([("config-pm-agent-instance", ("config_pm_agent_instance", Native.PmAgent.ConfigPmAgent.InstanceId.ConfigPmAgentInstance))])
                    self._leafs = OrderedDict([
                        ('instance_id_range', (YLeaf(YType.uint32, 'instance_id_range'), ['int'])),
                    ])
                    self.instance_id_range = None

                    self.config_pm_agent_instance = Native.PmAgent.ConfigPmAgent.InstanceId.ConfigPmAgentInstance()
                    self.config_pm_agent_instance.parent = self
                    self._children_name_map["config_pm_agent_instance"] = "config-pm-agent-instance"
                    self._segment_path = lambda: "instance-id" + "[instance_id_range='" + str(self.instance_id_range) + "']"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/Cisco-IOS-XE-pathmgr:pm-agent/config-pm-agent/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.PmAgent.ConfigPmAgent.InstanceId, ['instance_id_range'], name, value)


                class ConfigPmAgentInstance(Entity):
                    """
                    
                    
                    .. attribute:: enterprise_prefix
                    
                    	Enterprise prefix configuration
                    	**type**\:  :py:class:`EnterprisePrefix <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.PmAgent.ConfigPmAgent.InstanceId.ConfigPmAgentInstance.EnterprisePrefix>`
                    
                    

                    """

                    _prefix = 'ios-pathmgr'
                    _revision = '2017-02-07'

                    def __init__(self):
                        super(Native.PmAgent.ConfigPmAgent.InstanceId.ConfigPmAgentInstance, self).__init__()

                        self.yang_name = "config-pm-agent-instance"
                        self.yang_parent_name = "instance-id"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("enterprise-prefix", ("enterprise_prefix", Native.PmAgent.ConfigPmAgent.InstanceId.ConfigPmAgentInstance.EnterprisePrefix))])
                        self._leafs = OrderedDict()

                        self.enterprise_prefix = Native.PmAgent.ConfigPmAgent.InstanceId.ConfigPmAgentInstance.EnterprisePrefix()
                        self.enterprise_prefix.parent = self
                        self._children_name_map["enterprise_prefix"] = "enterprise-prefix"
                        self._segment_path = lambda: "config-pm-agent-instance"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.PmAgent.ConfigPmAgent.InstanceId.ConfigPmAgentInstance, [], name, value)


                    class EnterprisePrefix(Entity):
                        """
                        Enterprise prefix configuration
                        
                        .. attribute:: ipv4
                        
                        	IPv4 enterprise prefix\-list
                        	**type**\:  :py:class:`Ipv4 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.PmAgent.ConfigPmAgent.InstanceId.ConfigPmAgentInstance.EnterprisePrefix.Ipv4>`
                        
                        .. attribute:: ipv6
                        
                        	IPv6 enterprise prefix\-list
                        	**type**\:  :py:class:`Ipv6 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.PmAgent.ConfigPmAgent.InstanceId.ConfigPmAgentInstance.EnterprisePrefix.Ipv6>`
                        
                        

                        """

                        _prefix = 'ios-pathmgr'
                        _revision = '2017-02-07'

                        def __init__(self):
                            super(Native.PmAgent.ConfigPmAgent.InstanceId.ConfigPmAgentInstance.EnterprisePrefix, self).__init__()

                            self.yang_name = "enterprise-prefix"
                            self.yang_parent_name = "config-pm-agent-instance"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("ipv4", ("ipv4", Native.PmAgent.ConfigPmAgent.InstanceId.ConfigPmAgentInstance.EnterprisePrefix.Ipv4)), ("ipv6", ("ipv6", Native.PmAgent.ConfigPmAgent.InstanceId.ConfigPmAgentInstance.EnterprisePrefix.Ipv6))])
                            self._leafs = OrderedDict()

                            self.ipv4 = Native.PmAgent.ConfigPmAgent.InstanceId.ConfigPmAgentInstance.EnterprisePrefix.Ipv4()
                            self.ipv4.parent = self
                            self._children_name_map["ipv4"] = "ipv4"

                            self.ipv6 = Native.PmAgent.ConfigPmAgent.InstanceId.ConfigPmAgentInstance.EnterprisePrefix.Ipv6()
                            self.ipv6.parent = self
                            self._children_name_map["ipv6"] = "ipv6"
                            self._segment_path = lambda: "enterprise-prefix"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.PmAgent.ConfigPmAgent.InstanceId.ConfigPmAgentInstance.EnterprisePrefix, [], name, value)


                        class Ipv4(Entity):
                            """
                            IPv4 enterprise prefix\-list
                            
                            .. attribute:: prefix_list
                            
                            	Specify prefix\-list with static site targets
                            	**type**\: str
                            
                            

                            """

                            _prefix = 'ios-pathmgr'
                            _revision = '2017-02-07'

                            def __init__(self):
                                super(Native.PmAgent.ConfigPmAgent.InstanceId.ConfigPmAgentInstance.EnterprisePrefix.Ipv4, self).__init__()

                                self.yang_name = "ipv4"
                                self.yang_parent_name = "enterprise-prefix"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('prefix_list', (YLeaf(YType.str, 'prefix-list'), ['str'])),
                                ])
                                self.prefix_list = None
                                self._segment_path = lambda: "ipv4"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.PmAgent.ConfigPmAgent.InstanceId.ConfigPmAgentInstance.EnterprisePrefix.Ipv4, ['prefix_list'], name, value)


                        class Ipv6(Entity):
                            """
                            IPv6 enterprise prefix\-list
                            
                            .. attribute:: prefix_list
                            
                            	Specify prefix\-list with static site targets
                            	**type**\: str
                            
                            

                            """

                            _prefix = 'ios-pathmgr'
                            _revision = '2017-02-07'

                            def __init__(self):
                                super(Native.PmAgent.ConfigPmAgent.InstanceId.ConfigPmAgentInstance.EnterprisePrefix.Ipv6, self).__init__()

                                self.yang_name = "ipv6"
                                self.yang_parent_name = "enterprise-prefix"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('prefix_list', (YLeaf(YType.str, 'prefix-list'), ['str'])),
                                ])
                                self.prefix_list = None
                                self._segment_path = lambda: "ipv6"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.PmAgent.ConfigPmAgent.InstanceId.ConfigPmAgentInstance.EnterprisePrefix.Ipv6, ['prefix_list'], name, value)


            class Region(Entity):
                """
                Enter the region ID
                
                .. attribute:: id
                
                	Specify the region ID
                	**type**\:  :py:class:`Id <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.PmAgent.ConfigPmAgent.Region.Id>`
                
                

                """

                _prefix = 'ios-pathmgr'
                _revision = '2017-02-07'

                def __init__(self):
                    super(Native.PmAgent.ConfigPmAgent.Region, self).__init__()

                    self.yang_name = "region"
                    self.yang_parent_name = "config-pm-agent"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("id", ("id", Native.PmAgent.ConfigPmAgent.Region.Id))])
                    self._leafs = OrderedDict()

                    self.id = Native.PmAgent.ConfigPmAgent.Region.Id()
                    self.id.parent = self
                    self._children_name_map["id"] = "id"
                    self._segment_path = lambda: "region"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/Cisco-IOS-XE-pathmgr:pm-agent/config-pm-agent/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.PmAgent.ConfigPmAgent.Region, [], name, value)


                class Id(Entity):
                    """
                    Specify the region ID
                    
                    .. attribute:: region_id_range
                    
                    	
                    	**type**\: list of  		 :py:class:`RegionIdRange <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.PmAgent.ConfigPmAgent.Region.Id.RegionIdRange>`
                    
                    

                    """

                    _prefix = 'ios-pathmgr'
                    _revision = '2017-02-07'

                    def __init__(self):
                        super(Native.PmAgent.ConfigPmAgent.Region.Id, self).__init__()

                        self.yang_name = "id"
                        self.yang_parent_name = "region"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("region_id_range", ("region_id_range", Native.PmAgent.ConfigPmAgent.Region.Id.RegionIdRange))])
                        self._leafs = OrderedDict()

                        self.region_id_range = YList(self)
                        self._segment_path = lambda: "id"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/Cisco-IOS-XE-pathmgr:pm-agent/config-pm-agent/region/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.PmAgent.ConfigPmAgent.Region.Id, [], name, value)


                    class RegionIdRange(Entity):
                        """
                        
                        
                        .. attribute:: region_id_range  (key)
                        
                        	Specify the region\-id value
                        	**type**\: int
                        
                        	**range:** 1..4294967295
                        
                        .. attribute:: name
                        
                        	Specify the region name
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios-pathmgr'
                        _revision = '2017-02-07'

                        def __init__(self):
                            super(Native.PmAgent.ConfigPmAgent.Region.Id.RegionIdRange, self).__init__()

                            self.yang_name = "region_id_range"
                            self.yang_parent_name = "id"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = ['region_id_range']
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('region_id_range', (YLeaf(YType.uint32, 'region_id_range'), ['int'])),
                                ('name', (YLeaf(YType.str, 'name'), ['str'])),
                            ])
                            self.region_id_range = None
                            self.name = None
                            self._segment_path = lambda: "region_id_range" + "[region_id_range='" + str(self.region_id_range) + "']"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/Cisco-IOS-XE-pathmgr:pm-agent/config-pm-agent/region/id/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.PmAgent.ConfigPmAgent.Region.Id.RegionIdRange, ['region_id_range', 'name'], name, value)


            class Site(Entity):
                """
                Enter the site configuration
                
                .. attribute:: id
                
                	Specify the site ID
                	**type**\:  :py:class:`Id <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.PmAgent.ConfigPmAgent.Site.Id>`
                
                

                """

                _prefix = 'ios-pathmgr'
                _revision = '2017-02-07'

                def __init__(self):
                    super(Native.PmAgent.ConfigPmAgent.Site, self).__init__()

                    self.yang_name = "site"
                    self.yang_parent_name = "config-pm-agent"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("id", ("id", Native.PmAgent.ConfigPmAgent.Site.Id))])
                    self._leafs = OrderedDict()

                    self.id = Native.PmAgent.ConfigPmAgent.Site.Id()
                    self.id.parent = self
                    self._children_name_map["id"] = "id"
                    self._segment_path = lambda: "site"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/Cisco-IOS-XE-pathmgr:pm-agent/config-pm-agent/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.PmAgent.ConfigPmAgent.Site, [], name, value)


                class Id(Entity):
                    """
                    Specify the site ID
                    
                    .. attribute:: site_id_range
                    
                    	
                    	**type**\: list of  		 :py:class:`SiteIdRange <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.PmAgent.ConfigPmAgent.Site.Id.SiteIdRange>`
                    
                    

                    """

                    _prefix = 'ios-pathmgr'
                    _revision = '2017-02-07'

                    def __init__(self):
                        super(Native.PmAgent.ConfigPmAgent.Site.Id, self).__init__()

                        self.yang_name = "id"
                        self.yang_parent_name = "site"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("site_id_range", ("site_id_range", Native.PmAgent.ConfigPmAgent.Site.Id.SiteIdRange))])
                        self._leafs = OrderedDict()

                        self.site_id_range = YList(self)
                        self._segment_path = lambda: "id"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/Cisco-IOS-XE-pathmgr:pm-agent/config-pm-agent/site/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.PmAgent.ConfigPmAgent.Site.Id, [], name, value)


                    class SiteIdRange(Entity):
                        """
                        
                        
                        .. attribute:: site_id_range  (key)
                        
                        	Specify the site\-id value
                        	**type**\: int
                        
                        	**range:** 1..4294967295
                        
                        .. attribute:: name
                        
                        	Specify the site name
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios-pathmgr'
                        _revision = '2017-02-07'

                        def __init__(self):
                            super(Native.PmAgent.ConfigPmAgent.Site.Id.SiteIdRange, self).__init__()

                            self.yang_name = "site_id_range"
                            self.yang_parent_name = "id"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = ['site_id_range']
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('site_id_range', (YLeaf(YType.uint32, 'site_id_range'), ['int'])),
                                ('name', (YLeaf(YType.str, 'name'), ['str'])),
                            ])
                            self.site_id_range = None
                            self.name = None
                            self._segment_path = lambda: "site_id_range" + "[site_id_range='" + str(self.site_id_range) + "']"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/Cisco-IOS-XE-pathmgr:pm-agent/config-pm-agent/site/id/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.PmAgent.ConfigPmAgent.Site.Id.SiteIdRange, ['site_id_range', 'name'], name, value)


            class Tenant(Entity):
                """
                enter the tenant configuration
                
                .. attribute:: id
                
                	specify the tenant id
                	**type**\:  :py:class:`Id <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.PmAgent.ConfigPmAgent.Tenant.Id>`
                
                

                """

                _prefix = 'ios-pathmgr'
                _revision = '2017-02-07'

                def __init__(self):
                    super(Native.PmAgent.ConfigPmAgent.Tenant, self).__init__()

                    self.yang_name = "tenant"
                    self.yang_parent_name = "config-pm-agent"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("id", ("id", Native.PmAgent.ConfigPmAgent.Tenant.Id))])
                    self._leafs = OrderedDict()

                    self.id = Native.PmAgent.ConfigPmAgent.Tenant.Id()
                    self.id.parent = self
                    self._children_name_map["id"] = "id"
                    self._segment_path = lambda: "tenant"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/Cisco-IOS-XE-pathmgr:pm-agent/config-pm-agent/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.PmAgent.ConfigPmAgent.Tenant, [], name, value)


                class Id(Entity):
                    """
                    specify the tenant id
                    
                    .. attribute:: tenant_id_range
                    
                    	
                    	**type**\: list of  		 :py:class:`TenantIdRange <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.PmAgent.ConfigPmAgent.Tenant.Id.TenantIdRange>`
                    
                    

                    """

                    _prefix = 'ios-pathmgr'
                    _revision = '2017-02-07'

                    def __init__(self):
                        super(Native.PmAgent.ConfigPmAgent.Tenant.Id, self).__init__()

                        self.yang_name = "id"
                        self.yang_parent_name = "tenant"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("tenant_id_range", ("tenant_id_range", Native.PmAgent.ConfigPmAgent.Tenant.Id.TenantIdRange))])
                        self._leafs = OrderedDict()

                        self.tenant_id_range = YList(self)
                        self._segment_path = lambda: "id"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/Cisco-IOS-XE-pathmgr:pm-agent/config-pm-agent/tenant/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.PmAgent.ConfigPmAgent.Tenant.Id, [], name, value)


                    class TenantIdRange(Entity):
                        """
                        
                        
                        .. attribute:: tenant_id_range  (key)
                        
                        	specify the tenant\-id value
                        	**type**\: int
                        
                        	**range:** 1..4294967295
                        
                        .. attribute:: name
                        
                        	specify the tenant name
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ios-pathmgr'
                        _revision = '2017-02-07'

                        def __init__(self):
                            super(Native.PmAgent.ConfigPmAgent.Tenant.Id.TenantIdRange, self).__init__()

                            self.yang_name = "tenant_id_range"
                            self.yang_parent_name = "id"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = ['tenant_id_range']
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('tenant_id_range', (YLeaf(YType.uint32, 'tenant_id_range'), ['int'])),
                                ('name', (YLeaf(YType.str, 'name'), ['str'])),
                            ])
                            self.tenant_id_range = None
                            self.name = None
                            self._segment_path = lambda: "tenant_id_range" + "[tenant_id_range='" + str(self.tenant_id_range) + "']"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/Cisco-IOS-XE-pathmgr:pm-agent/config-pm-agent/tenant/id/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.PmAgent.ConfigPmAgent.Tenant.Id.TenantIdRange, ['tenant_id_range', 'name'], name, value)


            class Pmcs(Entity):
                """
                Enter the pmcs configuration
                
                .. attribute:: ipv4
                
                	Enter the IPv4 address
                	**type**\:  :py:class:`Ipv4 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.PmAgent.ConfigPmAgent.Pmcs.Ipv4>`
                
                .. attribute:: ipv6
                
                	Enter the IPv6 address
                	**type**\:  :py:class:`Ipv6 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.PmAgent.ConfigPmAgent.Pmcs.Ipv6>`
                
                

                """

                _prefix = 'ios-pathmgr'
                _revision = '2017-02-07'

                def __init__(self):
                    super(Native.PmAgent.ConfigPmAgent.Pmcs, self).__init__()

                    self.yang_name = "pmcs"
                    self.yang_parent_name = "config-pm-agent"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("ipv4", ("ipv4", Native.PmAgent.ConfigPmAgent.Pmcs.Ipv4)), ("ipv6", ("ipv6", Native.PmAgent.ConfigPmAgent.Pmcs.Ipv6))])
                    self._leafs = OrderedDict()

                    self.ipv4 = Native.PmAgent.ConfigPmAgent.Pmcs.Ipv4()
                    self.ipv4.parent = self
                    self._children_name_map["ipv4"] = "ipv4"

                    self.ipv6 = Native.PmAgent.ConfigPmAgent.Pmcs.Ipv6()
                    self.ipv6.parent = self
                    self._children_name_map["ipv6"] = "ipv6"
                    self._segment_path = lambda: "pmcs"
                    self._absolute_path = lambda: "Cisco-IOS-XE-native:native/Cisco-IOS-XE-pathmgr:pm-agent/config-pm-agent/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Native.PmAgent.ConfigPmAgent.Pmcs, [], name, value)


                class Ipv4(Entity):
                    """
                    Enter the IPv4 address
                    
                    .. attribute:: pmcs_ipv4
                    
                    	
                    	**type**\: list of  		 :py:class:`PmcsIpv4 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.PmAgent.ConfigPmAgent.Pmcs.Ipv4.PmcsIpv4>`
                    
                    

                    """

                    _prefix = 'ios-pathmgr'
                    _revision = '2017-02-07'

                    def __init__(self):
                        super(Native.PmAgent.ConfigPmAgent.Pmcs.Ipv4, self).__init__()

                        self.yang_name = "ipv4"
                        self.yang_parent_name = "pmcs"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("pmcs_ipv4", ("pmcs_ipv4", Native.PmAgent.ConfigPmAgent.Pmcs.Ipv4.PmcsIpv4))])
                        self._leafs = OrderedDict()

                        self.pmcs_ipv4 = YList(self)
                        self._segment_path = lambda: "ipv4"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/Cisco-IOS-XE-pathmgr:pm-agent/config-pm-agent/pmcs/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.PmAgent.ConfigPmAgent.Pmcs.Ipv4, [], name, value)


                    class PmcsIpv4(Entity):
                        """
                        
                        
                        .. attribute:: ipv4  (key)
                        
                        	IPv4 pmcs address e.g 10.10.0.0
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: backup
                        
                        	set ipv4/ipv6 address as backup
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: ipv6
                        
                        	Enter the IPv6 address
                        	**type**\:  :py:class:`Ipv6 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.PmAgent.ConfigPmAgent.Pmcs.Ipv4.PmcsIpv4.Ipv6>`
                        
                        

                        """

                        _prefix = 'ios-pathmgr'
                        _revision = '2017-02-07'

                        def __init__(self):
                            super(Native.PmAgent.ConfigPmAgent.Pmcs.Ipv4.PmcsIpv4, self).__init__()

                            self.yang_name = "pmcs_ipv4"
                            self.yang_parent_name = "ipv4"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = ['ipv4']
                            self._child_classes = OrderedDict([("ipv6", ("ipv6", Native.PmAgent.ConfigPmAgent.Pmcs.Ipv4.PmcsIpv4.Ipv6))])
                            self._leafs = OrderedDict([
                                ('ipv4', (YLeaf(YType.str, 'ipv4'), ['str'])),
                                ('backup', (YLeaf(YType.empty, 'backup'), ['Empty'])),
                            ])
                            self.ipv4 = None
                            self.backup = None

                            self.ipv6 = Native.PmAgent.ConfigPmAgent.Pmcs.Ipv4.PmcsIpv4.Ipv6()
                            self.ipv6.parent = self
                            self._children_name_map["ipv6"] = "ipv6"
                            self._segment_path = lambda: "pmcs_ipv4" + "[ipv4='" + str(self.ipv4) + "']"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/Cisco-IOS-XE-pathmgr:pm-agent/config-pm-agent/pmcs/ipv4/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.PmAgent.ConfigPmAgent.Pmcs.Ipv4.PmcsIpv4, ['ipv4', 'backup'], name, value)


                        class Ipv6(Entity):
                            """
                            Enter the IPv6 address
                            
                            .. attribute:: pmcs_ipv6
                            
                            	
                            	**type**\: list of  		 :py:class:`PmcsIpv6 <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.PmAgent.ConfigPmAgent.Pmcs.Ipv4.PmcsIpv4.Ipv6.PmcsIpv6>`
                            
                            

                            """

                            _prefix = 'ios-pathmgr'
                            _revision = '2017-02-07'

                            def __init__(self):
                                super(Native.PmAgent.ConfigPmAgent.Pmcs.Ipv4.PmcsIpv4.Ipv6, self).__init__()

                                self.yang_name = "ipv6"
                                self.yang_parent_name = "pmcs_ipv4"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("pmcs_ipv6", ("pmcs_ipv6", Native.PmAgent.ConfigPmAgent.Pmcs.Ipv4.PmcsIpv4.Ipv6.PmcsIpv6))])
                                self._leafs = OrderedDict()

                                self.pmcs_ipv6 = YList(self)
                                self._segment_path = lambda: "ipv6"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Native.PmAgent.ConfigPmAgent.Pmcs.Ipv4.PmcsIpv4.Ipv6, [], name, value)


                            class PmcsIpv6(Entity):
                                """
                                
                                
                                .. attribute:: ipv6  (key)
                                
                                	IPv6 pmcs Addr, e.g abcd\:1234
                                	**type**\: str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: backup
                                
                                	set ipv4/ipv6 address as backup
                                	**type**\: :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                """

                                _prefix = 'ios-pathmgr'
                                _revision = '2017-02-07'

                                def __init__(self):
                                    super(Native.PmAgent.ConfigPmAgent.Pmcs.Ipv4.PmcsIpv4.Ipv6.PmcsIpv6, self).__init__()

                                    self.yang_name = "pmcs_ipv6"
                                    self.yang_parent_name = "ipv6"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = ['ipv6']
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('ipv6', (YLeaf(YType.str, 'ipv6'), ['str'])),
                                        ('backup', (YLeaf(YType.empty, 'backup'), ['Empty'])),
                                    ])
                                    self.ipv6 = None
                                    self.backup = None
                                    self._segment_path = lambda: "pmcs_ipv6" + "[ipv6='" + str(self.ipv6) + "']"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Native.PmAgent.ConfigPmAgent.Pmcs.Ipv4.PmcsIpv4.Ipv6.PmcsIpv6, ['ipv6', 'backup'], name, value)


                class Ipv6(Entity):
                    """
                    Enter the IPv6 address
                    
                    .. attribute:: ipv6
                    
                    	
                    	**type**\: list of  		 :py:class:`Ipv6_ <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.PmAgent.ConfigPmAgent.Pmcs.Ipv6.Ipv6_>`
                    
                    

                    """

                    _prefix = 'ios-pathmgr'
                    _revision = '2017-02-07'

                    def __init__(self):
                        super(Native.PmAgent.ConfigPmAgent.Pmcs.Ipv6, self).__init__()

                        self.yang_name = "ipv6"
                        self.yang_parent_name = "pmcs"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("ipv6", ("ipv6", Native.PmAgent.ConfigPmAgent.Pmcs.Ipv6.Ipv6_))])
                        self._leafs = OrderedDict()

                        self.ipv6 = YList(self)
                        self._segment_path = lambda: "ipv6"
                        self._absolute_path = lambda: "Cisco-IOS-XE-native:native/Cisco-IOS-XE-pathmgr:pm-agent/config-pm-agent/pmcs/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Native.PmAgent.ConfigPmAgent.Pmcs.Ipv6, [], name, value)


                    class Ipv6_(Entity):
                        """
                        
                        
                        .. attribute:: ipv6  (key)
                        
                        	IPv6 pmcs Addr, e.g abcd\:1234
                        	**type**\: str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: backup
                        
                        	set ipv4/ipv6 address as backup
                        	**type**\: :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: ipv4
                        
                        	IPv4 pmcs address e.g 10.10.0.0
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ios-pathmgr'
                        _revision = '2017-02-07'

                        def __init__(self):
                            super(Native.PmAgent.ConfigPmAgent.Pmcs.Ipv6.Ipv6_, self).__init__()

                            self.yang_name = "ipv6"
                            self.yang_parent_name = "ipv6"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = ['ipv6']
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('ipv6', (YLeaf(YType.str, 'ipv6'), ['str'])),
                                ('backup', (YLeaf(YType.empty, 'backup'), ['Empty'])),
                                ('ipv4', (YLeaf(YType.str, 'ipv4'), ['str'])),
                            ])
                            self.ipv6 = None
                            self.backup = None
                            self.ipv4 = None
                            self._segment_path = lambda: "ipv6" + "[ipv6='" + str(self.ipv6) + "']"
                            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/Cisco-IOS-XE-pathmgr:pm-agent/config-pm-agent/pmcs/ipv6/%s" % self._segment_path()
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Native.PmAgent.ConfigPmAgent.Pmcs.Ipv6.Ipv6_, ['ipv6', 'backup', 'ipv4'], name, value)


    class Vpdn(Entity):
        """
        Virtual Private Dialup Network
        
        .. attribute:: authen_before_forward
        
        	Authenticate a user locally before tunnelling
        	**type**\: :py:class:`Empty<ydk.types.Empty>`
        
        .. attribute:: enable
        
        	Enable VPDN
        	**type**\: :py:class:`Empty<ydk.types.Empty>`
        
        .. attribute:: search_order
        
        	Configure the order to search different VPDN tunnel types
        	**type**\: list of   :py:class:`SearchOrder <ydk.models.cisco_ios_xe.Cisco_IOS_XE_native.Native.Vpdn.SearchOrder>`
        
        

        """

        _prefix = 'ios-vpdn'
        _revision = '2017-02-07'

        def __init__(self):
            super(Native.Vpdn, self).__init__()

            self.yang_name = "vpdn"
            self.yang_parent_name = "native"
            self.is_top_level_class = False
            self.has_list_ancestor = False
            self.ylist_key_names = []
            self._child_classes = OrderedDict([])
            self._leafs = OrderedDict([
                ('authen_before_forward', (YLeaf(YType.empty, 'authen-before-forward'), ['Empty'])),
                ('enable', (YLeaf(YType.empty, 'enable'), ['Empty'])),
                ('search_order', (YLeafList(YType.enumeration, 'search-order'), [('ydk.models.cisco_ios_xe.Cisco_IOS_XE_native', 'Native', 'Vpdn.SearchOrder')])),
            ])
            self.authen_before_forward = None
            self.enable = None
            self.search_order = []
            self._segment_path = lambda: "Cisco-IOS-XE-vpdn:vpdn"
            self._absolute_path = lambda: "Cisco-IOS-XE-native:native/%s" % self._segment_path()
            self._is_frozen = True

        def __setattr__(self, name, value):
            self._perform_setattr(Native.Vpdn, ['authen_before_forward', 'enable', 'search_order'], name, value)

        class SearchOrder(Enum):
            """
            SearchOrder (Enum Class)

            Configure the order to search different VPDN tunnel types

            .. data:: dnis = 0

            .. data:: domain = 1

            .. data:: multihop_hostname = 2

            """

            dnis = Enum.YLeaf(0, "dnis")

            domain = Enum.YLeaf(1, "domain")

            multihop_hostname = Enum.YLeaf(2, "multihop-hostname")


    def clone_ptr(self):
        self._top_entity = Native()
        return self._top_entity

